AccessConfig class final
An access configuration attached to an instance's network interface. Only one access config per instance is supported.
Constructors
Properties
- externalIpv6 → String?
-
Applies to ipv6AccessConfigs only.
The first IPv6 address of the external IPv6 range associated
with this instance, prefix length is stored inexternalIpv6PrefixLength in ipv6AccessConfig. To
use a static external IP address, it must be unused and in the same region
as the instance's zone. If not specified, Google Cloud will automatically
assign an external IPv6 address from the instance's subnetwork.
final
- externalIpv6PrefixLength → int?
-
Applies to ipv6AccessConfigs only. The prefix length of the
external IPv6 range.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → String?
-
Output only.
Output OnlyType of the resource. Alwayscompute#accessConfig for access configs.final - name → String?
-
The name of this access configuration. In accessConfigs
(IPv4), the default and recommended name is External NAT, but
you can use any arbitrary string, such as My external IP orNetwork Access. In ipv6AccessConfigs, the
recommend name is External IPv6.
final
- natIP → String?
-
Applies to accessConfigs (IPv4) only. Anexternal IP
address associated with this instance. Specify an unused static
external IP address available to the project or leave this field undefined
to use an IP from a shared ephemeral IP address pool. If you specify a
static external IP address, it must live in the same region as the zone of
the instance.
final
- networkTier → String?
-
This signifies the networking tier used for configuring this access
configuration and can only take the following values: PREMIUM,STANDARD.
final
- publicPtrDomainName → String?
-
The DNS domain name for the public PTR record.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- securityPolicy → String?
-
The resource URL for the security policy associated with this access
config.
final
- setPublicPtr → bool?
-
Specifies whether a public DNS 'PTR' record should be created to map the
external IP address of the instance to a DNS domain name.
final
- type → String?
-
The type of configuration. In accessConfigs (IPv4), the
default and only option is ONE_TO_ONE_NAT. Inipv6AccessConfigs, the default and only option isDIRECT_IPV6.
Check the Type enum for the list of possible values.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String