networkTier property
This signifies the networking tier used for configuring this access configuration and can only take the following values: PREMIUM,STANDARD.
If an AccessConfig is specified without a valid external IP address, an ephemeral IP will be created with this networkTier.
If an AccessConfig with a valid external IP address is specified, it must match that of the networkTier associated with the Address resource owning that IP. Check the NetworkTier enum for the list of possible values.
Implementation
final String? networkTier;