securityPolicy property
The resource URL for the security policy associated with this access config.
Implementation
final String? securityPolicy;
The resource URL for the security policy associated with this access config.
final String? securityPolicy;