toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (externalIpv6 != null) 'externalIpv6=$externalIpv6',
    if (externalIpv6PrefixLength != null)
      'externalIpv6PrefixLength=$externalIpv6PrefixLength',
    if (kind != null) 'kind=$kind',
    if (name != null) 'name=$name',
    if (natIP != null) 'natIP=$natIP',
    if (networkTier != null) 'networkTier=$networkTier',
    if (publicPtrDomainName != null)
      'publicPtrDomainName=$publicPtrDomainName',
    if (securityPolicy != null) 'securityPolicy=$securityPolicy',
    if (setPublicPtr != null) 'setPublicPtr=$setPublicPtr',
    if (type != null) 'type=$type',
  ].join(',');
  return 'AccessConfig(${$contents})';
}