AddAccessConfigInstanceRequest class final

A request message for Instances.AddAccessConfig. See the method description for details.

Constructors

AddAccessConfigInstanceRequest({required AccessConfig? accessConfigResource, required String instance, required String networkInterface, required String project, String? requestId, required String zone})
AddAccessConfigInstanceRequest.fromJson(Object? j)
factory

Properties

accessConfigResource AccessConfig?
The body resource for this request
final
hashCode int
The hash code for this object.
no setterinherited
instance String
The instance name for this request.
final
networkInterface String
The name of the network interface to add to this instance.
final
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requestId String?
An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zone String
The name of the zone for this request.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String