replaceExistingAssociation property

bool? replaceExistingAssociation
final

Indicates whether or not to replace it if an association of the attachment already exists. This is false by default, in which case an error will be returned if an association already exists.

Implementation

final bool? replaceExistingAssociation;