AddAssociationOrganizationSecurityPolicyRequest class final

A request message for OrganizationSecurityPolicies.AddAssociation. See the method description for details.

Constructors

AddAssociationOrganizationSecurityPolicyRequest({bool? replaceExistingAssociation, String? requestId, required String securityPolicy, required SecurityPolicyAssociation? securityPolicyAssociationResource})
AddAssociationOrganizationSecurityPolicyRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
replaceExistingAssociation bool?
Indicates whether or not to replace it if an association of the attachment already exists. This is false by default, in which case an error will be returned if an association already exists.
final
requestId String?
An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
securityPolicy String
Name of the security policy to update.
final
securityPolicyAssociationResource SecurityPolicyAssociation?
The body resource for this request
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String