instance property
The instance name for this request stored as resource_id. Name should conform to RFC1035 or be an unsigned long integer.
Implementation
final String instance;
The instance name for this request stored as resource_id. Name should conform to RFC1035 or be an unsigned long integer.
final String instance;