Address class final
Represents an IP Address resource.
Google Compute Engine has two IP Address resources:
For more information, see Reserving a static external IP address.
Constructors
-
Address({String? address, String? addressType, String? creationTimestamp, String? description, BigInt? id, String? ipCollection, String? ipVersion, String? ipv6EndpointType, String? kind, String? labelFingerprint, Map<
String, String> labels = const {}, String? name, String? network, String? networkTier, int? prefixLength, String? purpose, String? region, String? selfLink, String? status, String? subnetwork, List<String> users = const []}) - Address.fromJson(Object? j)
-
factory
Properties
- address → String?
-
The static IP address represented by this resource.
final
- addressType → String?
-
The type of address to reserve, either INTERNAL orEXTERNAL. If unspecified, defaults to EXTERNAL.
Check the AddressType enum for the list of possible values.
final
- creationTimestamp → String?
-
Output only.
Output OnlyCreation timestamp inRFC3339 text format.final - description → String?
-
An optional description of this resource. Provide this field when you
create the resource.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → BigInt?
-
Output only.
Output OnlyThe unique identifier for the resource. This identifier is defined by the server.final - ipCollection → String?
-
Reference to the source of IP addresses.
final
- ipv6EndpointType → String?
-
The endpoint type of this address, which should be VM
or NETLB. This is used for deciding which type of endpoint
this address can be used after the external IPv6 address reservation.
Check the Ipv6EndpointType enum for the list of possible values.
final
- ipVersion → String?
-
The IP version that will be used by this address. Valid options areIPV4 or IPV6.
Check the IpVersion enum for the list of possible values.
final
- kind → String?
-
Output only.
Output OnlyType of the resource. Always compute#address for addresses.final - labelFingerprint → String?
-
A fingerprint for the labels being applied to this Address, which is
essentially a hash of the labels set used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update labels. You must always provide an
up-to-date fingerprint hash in order to update or change labels,
otherwise the request will fail with error412 conditionNotMet.
final
-
labels
→ Map<
String, String> -
Labels for this resource. These can only be added or modified by thesetLabels method. Each label key/value pair must comply withRFC1035.
Label values may be empty.
final
- name → String?
-
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression
[a-z]([-a-z0-9]*[a-z0-9])?. The first character must be a lowercase letter, and all following characters (except for the last character) must be a dash, lowercase letter, or digit. The last character must be a lowercase letter or digit.final - network → String?
-
The URL of the network in which to reserve the address. This field can
only be used with INTERNAL type with theVPC_PEERING purpose.
final
- networkTier → String?
-
This signifies the networking tier used for configuring this address and
can only take the following values: PREMIUM orSTANDARD. Internal IP addresses are always Premium Tier;
global external IP addresses are always Premium Tier; regional external IP
addresses can be either Standard or Premium Tier.
final
- prefixLength → int?
-
The prefix length if the resource represents an IP range.
final
- purpose → String?
-
The purpose of this resource, which can be one of the following values:
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - region → String?
-
Output only.
Output OnlyThe URL of the region where a regional address resides. For regional addresses, you must specify the region as a path parameter in the HTTP request URL. This field is not applicable to global addresses.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfLink → String?
-
Output OnlyServer-defined URL for the resource.final - status → String?
-
Output only.
Output OnlyThe status of the address, which can be one ofRESERVING, RESERVED, or IN_USE. An address that is RESERVING is currently in the process of being reserved. A RESERVED address is currently reserved and available to use. An IN_USE address is currently being used by another resource and is not available. Check the Status enum for the list of possible values.final - subnetwork → String?
-
The URL of the subnetwork in which to reserve the address. If an IP address
is specified, it must be within the subnetwork's IP range. This field can
only be used with INTERNAL type with aGCE_ENDPOINT or DNS_RESOLVER purpose.
final
-
users
→ List<
String> -
Output OnlyThe URLs of the resources that are using this address.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String