ipVersion property
The IP version that will be used by this address. Valid options areIPV4 or IPV6. Check the IpVersion enum for the list of possible values.
Implementation
final String? ipVersion;
The IP version that will be used by this address. Valid options areIPV4 or IPV6. Check the IpVersion enum for the list of possible values.
final String? ipVersion;