network property
The URL of the network in which to reserve the address. This field can only be used with INTERNAL type with theVPC_PEERING purpose.
Implementation
final String? network;
The URL of the network in which to reserve the address. This field can only be used with INTERNAL type with theVPC_PEERING purpose.
final String? network;