networkTier property
This signifies the networking tier used for configuring this address and can only take the following values: PREMIUM orSTANDARD. Internal IP addresses are always Premium Tier; global external IP addresses are always Premium Tier; regional external IP addresses can be either Standard or Premium Tier.
If this field is not specified, it is assumed to be PREMIUM. Check the NetworkTier enum for the list of possible values.
Implementation
final String? networkTier;