toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (address != null) 'address=$address',
    if (addressType != null) 'addressType=$addressType',
    if (creationTimestamp != null) 'creationTimestamp=$creationTimestamp',
    if (description != null) 'description=$description',
    if (id != null) 'id=$id',
    if (ipCollection != null) 'ipCollection=$ipCollection',
    if (ipVersion != null) 'ipVersion=$ipVersion',
    if (ipv6EndpointType != null) 'ipv6EndpointType=$ipv6EndpointType',
    if (kind != null) 'kind=$kind',
    if (labelFingerprint != null) 'labelFingerprint=$labelFingerprint',
    if (name != null) 'name=$name',
    if (network != null) 'network=$network',
    if (networkTier != null) 'networkTier=$networkTier',
    if (prefixLength != null) 'prefixLength=$prefixLength',
    if (purpose != null) 'purpose=$purpose',
    if (region != null) 'region=$region',
    if (selfLink != null) 'selfLink=$selfLink',
    if (status != null) 'status=$status',
    if (subnetwork != null) 'subnetwork=$subnetwork',
  ].join(',');
  return 'Address(${$contents})';
}