Address_IpVersion class final

The IP version that will be used by this address. Valid options areIPV4 or IPV6.

Constructors

Address_IpVersion(String value)
const
Address_IpVersion.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const Address_IpVersion
The default value for Address_IpVersion.
ipv4 → const Address_IpVersion
ipv6 → const Address_IpVersion
undefinedIpVersion → const Address_IpVersion
A value indicating that the enum field is not set.
unspecifiedVersion → const Address_IpVersion