Address_NetworkTier class final
This signifies the networking tier used for configuring this address and can only take the following values: PREMIUM orSTANDARD. Internal IP addresses are always Premium Tier; global external IP addresses are always Premium Tier; regional external IP addresses can be either Standard or Premium Tier.
If this field is not specified, it is assumed to be PREMIUM.
Constructors
- Address_NetworkTier(String value)
-
const
- Address_NetworkTier.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const Address_NetworkTier
- The default value for Address_NetworkTier.
- fixedStandard → const Address_NetworkTier
- Public internet quality with fixed bandwidth.
- High quality, Google-grade network tier, support for all networking products.
- standard → const Address_NetworkTier
- Public internet quality, only limited support for other networking products.
- standardOverridesFixedStandard → const Address_NetworkTier
- (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier is expired or not configured.
- undefinedNetworkTier → const Address_NetworkTier
- A value indicating that the enum field is not set.