Address_Purpose class final

The purpose of this resource, which can be one of the following values:

 - GCE_ENDPOINT for addresses that are used by VM
 instances, alias IP ranges, load balancers, and similar resources.
 - DNS_RESOLVER for a DNS resolver address in a subnetwork
   for a Cloud DNS  inbound
   forwarder IP addresses (regional internal IP address in a subnet of
   a VPC network)
 - VPC_PEERING for global internal IP addresses used for

      private services access allocated ranges.
 - NAT_AUTO for the regional external IP addresses used by
      Cloud NAT when allocating addresses using

      automatic NAT IP address allocation.
 - IPSEC_INTERCONNECT for addresses created from a private
 IP range that are reserved for a VLAN attachment in an
 *HA VPN over Cloud Interconnect* configuration. These addresses
 are regional resources.
 - `SHARED_LOADBALANCER_VIP` for an internal IP address that is assigned
 to multiple internal forwarding rules.
 - `PRIVATE_SERVICE_CONNECT` for a private network address that is
 used to configure Private Service Connect. Only global internal addresses
 can use this purpose.
 - `PASSTHROUGH_LOAD_BALANCER_AVAILABILITY_GROUP0` for addresses
 that can only be assigned to global external Passthrough Network Load
 Balancer forwarding rules, as an Availability Group 0 address.
 - `PASSTHROUGH_LOAD_BALANCER_AVAILABILITY_GROUP1` for addresses that
 can only be assigned to global external Passthrough Network Load Balancer
 forwarding rules, as an Availability Group 1 address.

Constructors

Address_Purpose(String value)
const
Address_Purpose.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const Address_Purpose
The default value for Address_Purpose.
dnsResolver → const Address_Purpose
DNS resolver address in the subnetwork.
gceEndpoint → const Address_Purpose
VM internal/alias IP, Internal LB service IP, etc.
ipsecInterconnect → const Address_Purpose
A regional internal IP address range reserved for the VLAN attachment that is used in HA VPN over Cloud Interconnect. This regional internal IP address range must not overlap with any IP address range of subnet/route in the VPC network and its peering networks. After the VLAN attachment is created with the reserved IP address range, when creating a new VPN gateway, its interface IP address is allocated from the associated VLAN attachment's IP address range.
natAuto → const Address_Purpose
External IP automatically reserved for Cloud NAT.
privateServiceConnect → const Address_Purpose
A private network IP address that can be used to configure Private Service Connect. This purpose can be specified only forGLOBAL addresses of Type INTERNAL
serverless → const Address_Purpose
A regional internal IP address range reserved for Serverless.
sharedLoadbalancerVip → const Address_Purpose
A private network IP address that can be shared by multiple Internal Load Balancer forwarding rules.
undefinedPurpose → const Address_Purpose
A value indicating that the enum field is not set.
vpcPeering → const Address_Purpose
IP range for peer networks.