Address_Status class final

Output only. Output Only The status of the address, which can be one ofRESERVING, RESERVED, or IN_USE. An address that is RESERVING is currently in the process of being reserved. A RESERVED address is currently reserved and available to use. An IN_USE address is currently being used by another resource and is not available.

Constructors

Address_Status(String value)
const
Address_Status.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const Address_Status
The default value for Address_Status.
inUse → const Address_Status
Address is being used by another resource and is not available.
reserved → const Address_Status
Address is reserved and available to use.
reserving → const Address_Status
Address is being reserved.
undefinedStatus → const Address_Status
A value indicating that the enum field is not set.