inUse constant
Address_Status
const inUse
Address is being used by another resource and is not available.
Implementation
static const inUse = Address_Status('IN_USE');
Address is being used by another resource and is not available.
static const inUse = Address_Status('IN_USE');