AdvancedMachineFeatures class final

Specifies options for controlling advanced machine features. Options that would traditionally be configured in a BIOS belong here. Features that require operating system support may have corresponding entries in the GuestOsFeatures of anImage (e.g., whether or not the OS in theImage supports nested virtualization being enabled or disabled).

Constructors

AdvancedMachineFeatures({bool? enableNestedVirtualization, bool? enableUefiNetworking, String? performanceMonitoringUnit, int? threadsPerCore, String? turboMode, int? visibleCoreCount})
AdvancedMachineFeatures.fromJson(Object? j)
factory

Properties

enableNestedVirtualization bool?
Whether to enable nested virtualization or not (default is false).
final
enableUefiNetworking bool?
Whether to enable UEFI networking for instance creation.
final
hashCode int
The hash code for this object.
no setterinherited
performanceMonitoringUnit String?
Type of Performance Monitoring Unit requested on instance. Check the PerformanceMonitoringUnit enum for the list of possible values.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
threadsPerCore int?
The number of threads per physical core. To disable simultaneous multithreading (SMT) set this to 1. If unset, the maximum number of threads supported per core by the underlying processor is assumed.
final
turboMode String?
Turbo frequency mode to use for the instance. Supported modes include:
final
visibleCoreCount int?
The number of physical cores to expose to an instance. Multiply by the number of threads per core to compute the total number of virtual CPUs to expose to the instance. If unset, the number of cores is inferred from the instance's nominal CPU count and the underlying platform's SMT width.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String