capacity method

Advice on making real-time decisions (such as choosing zone or machine types) during deployment to maximize your chances of obtaining capacity.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<CapacityAdviceResponse> capacity(
  CapacityAdviceRpcRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/regions/${request.region}/advice/capacity',
  );
  final response = await _client.post(
    url,
    body: request.capacityAdviceRequestResource,
  );
  return CapacityAdviceResponse.fromJson(response);
}