views property
Defines the extra views returned back in the subnetwork resource. Supported values:
- WITH_UTILIZATION: Utilization data is included in the response. Check the Views enum for the list of possible values.
Implementation
final String? views;