AggregatedListSubnetworksRequest_Views class final
Defines the extra views returned back in the subnetwork resource. Supported values:
- WITH_UTILIZATION: Utilization data is included in the response.
Constructors
- AggregatedListSubnetworksRequest_Views(String value)
-
const
- AggregatedListSubnetworksRequest_Views.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const AggregatedListSubnetworksRequest_Views
- The default value for AggregatedListSubnetworksRequest_Views.
- default$ → const AggregatedListSubnetworksRequest_Views
- undefinedViews → const AggregatedListSubnetworksRequest_Views
- A value indicating that the enum field is not set.
- withUtilization → const AggregatedListSubnetworksRequest_Views
- Utilization data is included in the response.