AggregatedListTargetVpnGatewaysRequest class final

A request message for TargetVpnGateways.AggregatedList. See the method description for details.

Constructors

AggregatedListTargetVpnGatewaysRequest({String? filter, bool? includeAllScopes, int? maxResults, String? orderBy, String? pageToken, required String project, bool? returnPartialSuccess, int? serviceProjectNumber})
AggregatedListTargetVpnGatewaysRequest.fromJson(Object? j)
factory

Properties

filter String?
A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request.
final
hashCode int
The hash code for this object.
no setterinherited
includeAllScopes bool?
Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
final
maxResults int?
The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
final
orderBy String?
Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.
final
pageToken String?
Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
final
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
returnPartialSuccess bool?
Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceProjectNumber int?
The Shared VPC service project id or service project number for which aggregated list request is invoked for subnetworks list-usable api.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String