subnetworkRangeName property
The name of a subnetwork secondary IP range from which to allocate an IP alias range. If not specified, the primary range of the subnetwork is used.
Implementation
final String? subnetworkRangeName;
The name of a subnetwork secondary IP range from which to allocate an IP alias range. If not specified, the primary range of the subnetwork is used.
final String? subnetworkRangeName;