AllocationAggregateReservation class final
This reservation type is specified by total resource amounts (e.g. total count of CPUs) and can account for multiple instance SKUs. In other words, one can create instances of varying shapes against this reservation.
Constructors
-
AllocationAggregateReservation({List<
AllocationAggregateReservationReservedResourceInfo> inUseResources = const [], List<AllocationAggregateReservationReservedResourceInfo> reservedResources = const [], String? vmFamily, String? workloadType}) - AllocationAggregateReservation.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inUseResources
→ List<
AllocationAggregateReservationReservedResourceInfo> -
Output only.
Output onlyList of resources currently in use.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited -
reservedResources
→ List<
AllocationAggregateReservationReservedResourceInfo> -
List of reserved resources (CPUs, memory, accelerators).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- vmFamily → String?
-
The VM family that all instances scheduled against this reservation must
belong to.
Check the VmFamily enum for the list of possible values.
final
- workloadType → String?
-
The workload type of the instances that will target this reservation.
Check the WorkloadType enum for the list of possible values.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String