vmFamily property
The VM family that all instances scheduled against this reservation must belong to. Check the VmFamily enum for the list of possible values.
Implementation
final String? vmFamily;
The VM family that all instances scheduled against this reservation must belong to. Check the VmFamily enum for the list of possible values.
final String? vmFamily;