AllocationAggregateReservation_VmFamily class final
The VM family that all instances scheduled against this reservation must belong to.
Constructors
- AllocationAggregateReservation_VmFamily(String value)
-
const
- AllocationAggregateReservation_VmFamily.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const AllocationAggregateReservation_VmFamily
- The default value for AllocationAggregateReservation_VmFamily.
- undefinedVmFamily → const AllocationAggregateReservation_VmFamily
- A value indicating that the enum field is not set.
- vmFamilyCloudTpuDeviceCt3 → const AllocationAggregateReservation_VmFamily
- vmFamilyCloudTpuLiteDeviceCt5L → const AllocationAggregateReservation_VmFamily
- vmFamilyCloudTpuLitePodSliceCt5Lp → const AllocationAggregateReservation_VmFamily
- vmFamilyCloudTpuLitePodSliceCt6E → const AllocationAggregateReservation_VmFamily
- vmFamilyCloudTpuPodSliceCt3P → const AllocationAggregateReservation_VmFamily
- vmFamilyCloudTpuPodSliceCt4P → const AllocationAggregateReservation_VmFamily
- vmFamilyCloudTpuPodSliceCt5P → const AllocationAggregateReservation_VmFamily
- vmFamilyCloudTpuPodSliceTpu7X → const AllocationAggregateReservation_VmFamily