AllocationResourceStatusHealthInfo class final
Health information for the reservation.
Constructors
- AllocationResourceStatusHealthInfo({int? degradedBlockCount, String? healthStatus, int? healthyBlockCount})
- AllocationResourceStatusHealthInfo.fromJson(Object? j)
-
factory
Properties
- degradedBlockCount → int?
-
The number of reservation blocks that are degraded.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- healthStatus → String?
-
The health status of the reservation.
Check the HealthStatus enum for the list of possible values.
final
- healthyBlockCount → int?
-
The number of reservation blocks that are healthy.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String