interface property

String? interface
final

Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. The default isSCSI. For performance characteristics of SCSI over NVMe, seeLocal SSD performance. Check the Interface enum for the list of possible values.

Implementation

final String? interface;