AllocationSpecificSkuallocationAllocatedInstancePropertiesReservedDisk_Interface class final
Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. The default isSCSI. For performance characteristics of SCSI over NVMe, seeLocal SSD performance.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const AllocationSpecificSkuallocationAllocatedInstancePropertiesReservedDisk_Interface
- The default value for AllocationSpecificSkuallocationAllocatedInstancePropertiesReservedDisk_Interface.
- nvme → const AllocationSpecificSkuallocationAllocatedInstancePropertiesReservedDisk_Interface
- scsi → const AllocationSpecificSkuallocationAllocatedInstancePropertiesReservedDisk_Interface
- undefinedInterface → const AllocationSpecificSkuallocationAllocatedInstancePropertiesReservedDisk_Interface
- A value indicating that the enum field is not set.