AllocationSpecificSkuallocationReservedInstanceProperties class final

Properties of the SKU instances being reserved. Next ID: 10

Properties

guestAccelerators List<AcceleratorConfig>
Specifies accelerator type and count.
final
hashCode int
The hash code for this object.
no setterinherited
localSsds List<AllocationSpecificSkuallocationAllocatedInstancePropertiesReservedDisk>
Specifies amount of local ssd to reserve with each instance. The type of disk is local-ssd.
final
locationHint String?
An opaque location hint used to place the allocation close to other resources. This field is for use by internal tools that use the public API.
final
machineType String?
Specifies type of machine (name only) which has fixed number of vCPUs and fixed amount of memory. This also includes specifying custom machine type following custom-NUMBER_OF_CPUS-AMOUNT_OF_MEMORY pattern.
final
minCpuPlatform String?
Minimum cpu platform the reservation.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String