AllocationSpecificSkureservation class final
This reservation type allows to pre allocate specific instance configuration.
Constructors
- AllocationSpecificSkureservation({int? assuredCount, int? count, int? inUseCount, AllocationSpecificSkuallocationReservedInstanceProperties? instanceProperties, String? sourceInstanceTemplate})
- AllocationSpecificSkureservation.fromJson(Object? j)
-
factory
Properties
- assuredCount → int?
-
Output only.
Output OnlyIndicates how many instances are actually usable currently.final - count → int?
-
Specifies the number of resources that are allocated.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- instanceProperties → AllocationSpecificSkuallocationReservedInstanceProperties?
-
The instance properties for the reservation.
final
- inUseCount → int?
-
Output only.
Output OnlyIndicates how many instances are in use.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceInstanceTemplate → String?
-
Specifies the instance template to create the reservation. If you use
this field, you must exclude the instanceProperties field.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String