assuredCount property
Output only. Output Only Indicates how many instances are actually usable currently.
Implementation
final int? assuredCount;
Output only. Output Only Indicates how many instances are actually usable currently.
final int? assuredCount;