sourceInstanceTemplate property

String? sourceInstanceTemplate
final

Specifies the instance template to create the reservation. If you use this field, you must exclude the instanceProperties field.

This field is optional, and it can be a full or partial URL. For example, the following are all valid URLs to an instance template:

  - https://www.googleapis.com/compute/v1/projects/project/global/instanceTemplates/instanceTemplate
  - projects/project/global/instanceTemplates/instanceTemplate
  - global/instanceTemplates/instanceTemplate

Implementation

final String? sourceInstanceTemplate;