AttachDiskInstanceRequest class final

A request message for Instances.AttachDisk. See the method description for details.

Constructors

AttachDiskInstanceRequest({required AttachedDisk? attachedDiskResource, bool? forceAttach, required String instance, required String project, String? requestId, required String zone})
AttachDiskInstanceRequest.fromJson(Object? j)
factory

Properties

attachedDiskResource AttachedDisk?
The body resource for this request
final
forceAttach bool?
Whether to force attach the regional disk even if it's currently attached to another instance. If you try to force attach a zonal disk to an instance, you will receive an error.
final
hashCode int
The hash code for this object.
no setterinherited
instance String
The instance name for this request.
final
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requestId String?
An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zone String
The name of the zone for this request.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String