AttachedDisk class final

An instance-attached disk resource.

Constructors

AttachedDisk({String? architecture, bool? autoDelete, bool? boot, String? deviceName, CustomerEncryptionKey? diskEncryptionKey, int? diskSizeGb, bool? forceAttach, List<GuestOsFeature> guestOsFeatures = const [], int? index, AttachedDiskInitializeParams? initializeParams, String? interface, String? kind, List<String> licenses = const [], String? mode, String? savedState, InitialStateConfig? shieldedInstanceInitialState, String? source, String? type})
AttachedDisk.fromJson(Object? j)
factory

Properties

architecture String?
Output only. Output Only The architecture of the attached disk. Valid values are ARM64 or X86_64. Check the Architecture enum for the list of possible values.
final
autoDelete bool?
Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance).
final
boot bool?
Indicates that this is a boot disk. The virtual machine will use the first partition of the disk for its root filesystem.
final
deviceName String?
Specifies a unique device name of your choice that is reflected into the/dev/disk/by-id/google-* tree of a Linux operating system running within the instance. This name can be used to reference the device for mounting, resizing, and so on, from within the instance.
final
diskEncryptionKey CustomerEncryptionKey?
Encrypts or decrypts a disk using acustomer-supplied encryption key.
final
diskSizeGb int?
The size of the disk in GB.
final
forceAttach bool?
Input Only Whether to force attach the regional disk even if it's currently attached to another instance. If you try to force attach a zonal disk to an instance, you will receive an error.
final
guestOsFeatures List<GuestOsFeature>
A list of features to enable on the guest operating system. Applicable only for bootable images. Read Enabling guest operating system features to see a list of available options.
final
hashCode int
The hash code for this object.
no setterinherited
index int?
Output only. Output Only A zero-based index to this disk, where 0 is reserved for the boot disk. If you have many disks attached to an instance, each disk would have a unique index number.
final
initializeParams AttachedDiskInitializeParams?
Input Only Specifies the parameters for a new disk that will be created alongside the new instance. Use initialization parameters to create boot disks or local SSDs attached to the new instance.
final
interface String?
Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. For most machine types, the default is SCSI. Local SSDs can use either NVME or SCSI. In certain configurations, persistent disks can use NVMe. For more information, seeAbout persistent disks. Check the Interface enum for the list of possible values.
final
kind String?
Output only. Output Only Type of the resource. Alwayscompute#attachedDisk for attached disks.
final
licenses List<String>
Output only. Output Only Any valid publicly visible licenses.
final
mode String?
The mode in which to attach this disk, either READ_WRITE orREAD_ONLY. If not specified, the default is to attach the disk in READ_WRITE mode. Check the Mode enum for the list of possible values.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
savedState String?
Output only. For LocalSSD disks on VM Instances in STOPPED or SUSPENDED state, this field is set to PRESERVED if the LocalSSD data has been saved to a persistent location by customer request. (see the discard_local_ssd option on Stop/Suspend). Read-only in the api. Check the SavedState enum for the list of possible values.
final
shieldedInstanceInitialState InitialStateConfig?
Output only. Output Only shielded vm initial state stored on disk
final
source String?
Specifies a valid partial or full URL to an existing Persistent Disk resource. When creating a new instance boot disk, one ofinitializeParams.sourceImage orinitializeParams.sourceSnapshot or disks.source is required.
final
type String?
Specifies the type of the disk, either SCRATCH orPERSISTENT. If not specified, the default isPERSISTENT. Check the Type enum for the list of possible values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String