forceAttach property

bool? forceAttach
final

Input Only Whether to force attach the regional disk even if it's currently attached to another instance. If you try to force attach a zonal disk to an instance, you will receive an error.

Implementation

final bool? forceAttach;