initializeParams property
Input Only Specifies the parameters for a new disk that will be created
alongside the new instance. Use initialization parameters to create boot
disks or local SSDs attached to the new instance.
This property is mutually exclusive with the source property; you can only define one or the other, but not both.
Implementation
final AttachedDiskInitializeParams? initializeParams;