AttachedDiskInitializeParams class final

Input Only Specifies the parameters for a new disk that will be created alongside the new instance. Use initialization parameters to create boot disks or local SSDs attached to the new instance.

This field is persisted and returned for instanceTemplate and not returned in the context of instance.

This property is mutually exclusive with the source property; you can only define one or the other, but not both.

Constructors

AttachedDiskInitializeParams({String? architecture, String? description, String? diskName, int? diskSizeGb, String? diskType, bool? enableConfidentialCompute, Map<String, String> labels = const {}, List<String> licenses = const [], String? onUpdateAction, int? provisionedIops, int? provisionedThroughput, List<String> replicaZones = const [], Map<String, String> resourceManagerTags = const {}, List<String> resourcePolicies = const [], String? sourceImage, CustomerEncryptionKey? sourceImageEncryptionKey, String? sourceSnapshot, CustomerEncryptionKey? sourceSnapshotEncryptionKey, String? storagePool})
AttachedDiskInitializeParams.fromJson(Object? j)
factory

Properties

architecture String?
The architecture of the attached disk. Valid values are arm64 or x86_64. Check the Architecture enum for the list of possible values.
final
description String?
An optional description. Provide this property when creating the disk.
final
diskName String?
Specifies the disk name. If not specified, the default is to use the name of the instance. If a disk with the same name already exists in the given region, the existing disk is attached to the new instance and the new disk is not created.
final
diskSizeGb int?
Specifies the size of the disk in base-2 GB. The size must be at least 10 GB. If you specify a sourceImage, which is required for boot disks, the default size is the size of the sourceImage. If you do not specify a sourceImage, the default disk size is 500 GB.
final
diskType String?
Specifies the disk type used for the boot disk or an additional data disk. For valid disk type values, see Supported types for Hyperdisk volumes and Persistent Disk type variables.
final
enableConfidentialCompute bool?
Whether this disk is using confidential compute mode.
final
hashCode int
The hash code for this object.
no setterinherited
labels Map<String, String>
Labels to apply to this disk. These can be later modified by thedisks.setLabels method. This field is only applicable for persistent disks.
final
licenses List<String>
A list of publicly visible licenses. Reserved for Google's use.
final
onUpdateAction String?
Specifies which action to take on instance update with this disk. Default is to use the existing disk. Check the OnUpdateAction enum for the list of possible values.
final
provisionedIops int?
Indicates how many IOPS to provision for the disk. This sets the number of I/O operations per second that the disk can handle. Values must be between 10,000 and 120,000. For more details, see theExtreme persistent disk documentation.
final
provisionedThroughput int?
Indicates how much throughput to provision for the disk. This sets the number of throughput mb per second that the disk can handle. Values must greater than or equal to 1.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
replicaZones List<String>
Required for each regional disk associated with the instance. Specify the URLs of the zones where the disk should be replicated to. You must provide exactly two replica zones, and one zone must be the same as the instance zone.
final
resourceManagerTags Map<String, String>
Input only. Resource manager tags to be bound to the disk. Tag keys and values have the same definition as resource manager tags. Keys and values can be either in numeric format, such as tagKeys/{tag_key_id} and tagValues/{tag_value_id} or in namespaced format such as {org_id|project_id}/{tag_key_short_name} and {tag_value_short_name}. The field is ignored (both PUT & PATCH) when empty.
final
resourcePolicies List<String>
Resource policies applied to this disk for automatic snapshot creations. Specified using the full or partial URL. For instance template, specify only the resource policy name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceImage String?
The source image to create this disk. When creating a new instance boot disk, one of initializeParams.sourceImage orinitializeParams.sourceSnapshot or disks.source is required.
final
sourceImageEncryptionKey CustomerEncryptionKey?
Thecustomer-supplied encryption key of the source image. Required if the source image is protected by a customer-supplied encryption key.
final
sourceSnapshot String?
The source snapshot to create this disk. When creating a new instance boot disk, one of initializeParams.sourceSnapshot orinitializeParams.sourceImage or disks.source is required.
final
sourceSnapshotEncryptionKey CustomerEncryptionKey?
Thecustomer-supplied encryption key of the source snapshot.
final
storagePool String?
The storage pool in which the new disk is created. You can provide this as a partial or full URL to the resource. For example, the following are valid values:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String