architecture property
The architecture of the attached disk. Valid values are arm64 or x86_64. Check the Architecture enum for the list of possible values.
Implementation
final String? architecture;
The architecture of the attached disk. Valid values are arm64 or x86_64. Check the Architecture enum for the list of possible values.
final String? architecture;