resourcePolicies property

List<String> resourcePolicies
final

Resource policies applied to this disk for automatic snapshot creations. Specified using the full or partial URL. For instance template, specify only the resource policy name.

Implementation

final List<String> resourcePolicies;