toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (architecture != null) 'architecture=$architecture',
    if (description != null) 'description=$description',
    if (diskName != null) 'diskName=$diskName',
    if (diskSizeGb != null) 'diskSizeGb=$diskSizeGb',
    if (diskType != null) 'diskType=$diskType',
    if (enableConfidentialCompute != null)
      'enableConfidentialCompute=$enableConfidentialCompute',
    if (onUpdateAction != null) 'onUpdateAction=$onUpdateAction',
    if (provisionedIops != null) 'provisionedIops=$provisionedIops',
    if (provisionedThroughput != null)
      'provisionedThroughput=$provisionedThroughput',
    if (sourceImage != null) 'sourceImage=$sourceImage',
    if (sourceSnapshot != null) 'sourceSnapshot=$sourceSnapshot',
    if (storagePool != null) 'storagePool=$storagePool',
  ].join(',');
  return 'AttachedDiskInitializeParams(${$contents})';
}