AttachedDiskInitializeParams_OnUpdateAction class final

Specifies which action to take on instance update with this disk. Default is to use the existing disk.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const AttachedDiskInitializeParams_OnUpdateAction
The default value for AttachedDiskInitializeParams_OnUpdateAction.
recreateDisk → const AttachedDiskInitializeParams_OnUpdateAction
Always recreate the disk.
recreateDiskIfSourceChanged → const AttachedDiskInitializeParams_OnUpdateAction
Recreate the disk if source (image, snapshot) of this disk is different from source of existing disk.
undefinedOnUpdateAction → const AttachedDiskInitializeParams_OnUpdateAction
A value indicating that the enum field is not set.
useExistingDisk → const AttachedDiskInitializeParams_OnUpdateAction
Use the existing disk, this is the default behaviour.