AttachedDisk_Mode class final
The mode in which to attach this disk, either READ_WRITE orREAD_ONLY. If not specified, the default is to attach the disk in READ_WRITE mode.
Constructors
- AttachedDisk_Mode(String value)
-
const
- AttachedDisk_Mode.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const AttachedDisk_Mode
- The default value for AttachedDisk_Mode.
- readOnly → const AttachedDisk_Mode
- Attaches this disk in read-only mode. Multiple virtual machines can use a disk in read-only mode at a time.
- readWrite → const AttachedDisk_Mode
-
DefaultAttaches this disk in read-write mode. Only one virtual machine at a time can be attached to a disk in read-write mode. - undefinedMode → const AttachedDisk_Mode
- A value indicating that the enum field is not set.