undefinedMode constant
AttachedDisk_Mode
const undefinedMode
A value indicating that the enum field is not set.
Implementation
static const undefinedMode = AttachedDisk_Mode('UNDEFINED_MODE');
A value indicating that the enum field is not set.
static const undefinedMode = AttachedDisk_Mode('UNDEFINED_MODE');