AttachedDisk_SavedState class final

Output only. For LocalSSD disks on VM Instances in STOPPED or SUSPENDED state, this field is set to PRESERVED if the LocalSSD data has been saved to a persistent location by customer request. (see the discard_local_ssd option on Stop/Suspend). Read-only in the api.

Constructors

AttachedDisk_SavedState(String value)
const
AttachedDisk_SavedState.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const AttachedDisk_SavedState
The default value for AttachedDisk_SavedState.
diskSavedStateUnspecified → const AttachedDisk_SavedState
Default Disk state has not been preserved.
preserved → const AttachedDisk_SavedState
Disk state has been preserved.
undefinedSavedState → const AttachedDisk_SavedState
A value indicating that the enum field is not set.