AuditLogConfig class final
Provides the configuration for logging a type of permissions. Example:
{
"audit_log_configs": [
{
"log_type": "DATA_READ",
"exempted_members": [
"user:jose@example.com"
]
},
{
"log_type": "DATA_WRITE"
}
]
}
This enables 'DATA_READ' and 'DATA_WRITE' logging, while exempting jose@example.com from DATA_READ logging.
Constructors
-
AuditLogConfig({List<
String> exemptedMembers = const [], bool? ignoreChildExemptions, String? logType}) - AuditLogConfig.fromJson(Object? j)
-
factory
Properties
-
exemptedMembers
→ List<
String> -
Specifies the identities that do not cause logging for this type of
permission.
Follows the same format of Binding.members.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- ignoreChildExemptions → bool?
-
final
- logType → String?
-
The log type that this config enables.
Check the LogType enum for the list of possible values.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String