Autoscaler class final

Represents an Autoscaler resource.

Google Compute Engine has two Autoscaler resources:

Use autoscalers to automatically add or delete instances from a managed instance group according to your defined autoscaling policy. For more information, read Autoscaling Groups of Instances.

For zonal managed instance groups resource, use the autoscaler resource.

For regional managed instance groups, use theregionAutoscalers resource.

Constructors

Autoscaler({AutoscalingPolicy? autoscalingPolicy, String? creationTimestamp, String? description, BigInt? id, String? kind, String? name, int? recommendedSize, String? region, Map<String, ScalingScheduleStatus> scalingScheduleStatus = const {}, String? selfLink, String? status, List<AutoscalerStatusDetails> statusDetails = const [], String? target, String? zone})
Autoscaler.fromJson(Object? j)
factory

Properties

autoscalingPolicy AutoscalingPolicy?
The configuration parameters for the autoscaling algorithm. You can define one or more signals for an autoscaler: cpuUtilization,customMetricUtilizations, andloadBalancingUtilization.
final
creationTimestamp String?
Output only. Output Only Creation timestamp inRFC3339 text format.
final
description String?
An optional description of this resource. Provide this property when you create the resource.
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output only. Output Only The unique identifier for the resource. This identifier is defined by the server.
final
kind String?
Output only. Output Only Type of the resource. Always compute#autoscaler for autoscalers.
final
name String?
Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
recommendedSize int?
Output only. Output Only Target recommended MIG size (number of instances) computed by autoscaler. Autoscaler calculates the recommended MIG size even when the autoscaling policy mode is different from ON. This field is empty when autoscaler is not connected to an existing managed instance group or autoscaler did not generate its prediction.
final
region String?
Output only. Output Only URL of theregion where the instance group resides (for autoscalers living in regional scope).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scalingScheduleStatus Map<String, ScalingScheduleStatus>
Output only. Output Only Status information of existing scaling schedules.
final
Output Only Server-defined URL for the resource.
final
status String?
Output Only The status of the autoscaler configuration. Current set of possible values:
final
statusDetails List<AutoscalerStatusDetails>
Output Only Human-readable details about the current state of the autoscaler. Read the documentation forCommonly returned status messages for examples of status messages you might encounter.
final
target String?
URL of the managed instance group that this autoscaler will scale. This field is required when creating an autoscaler.
final
zone String?
Output only. Output Only URL of thezone where the instance group resides (for autoscalers living in zonal scope).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String