statusDetails property

List<AutoscalerStatusDetails> statusDetails
final

Output Only Human-readable details about the current state of the autoscaler. Read the documentation forCommonly returned status messages for examples of status messages you might encounter.

Implementation

final List<AutoscalerStatusDetails> statusDetails;