target property
URL of the managed instance group that this autoscaler will scale. This field is required when creating an autoscaler.
Implementation
final String? target;
URL of the managed instance group that this autoscaler will scale. This field is required when creating an autoscaler.
final String? target;