AutoscalerStatusDetails class final

Constructors

AutoscalerStatusDetails({String? message, String? type})
AutoscalerStatusDetails.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
message String?
The status message.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
The type of error, warning, or notice returned. Current set of possible values:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String