update method

Updates an autoscaler in the specified project using the data included in the request.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> update(UpdateAutoscalerRequest request) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/zones/${request.zone}/autoscalers',
    queryParameters: {
      'autoscaler': ?request.autoscaler,
      'requestId': ?request.requestId,
    },
  );
  final response = await _client.put(url, body: request.autoscalerResource);
  return Operation.fromJson(response);
}