maxNumReplicas property

int? maxNumReplicas
final

The maximum number of instances that the autoscaler can scale out to. This is required when creating or updating an autoscaler. The maximum number of replicas must not be lower than minimal number of replicas.

Implementation

final int? maxNumReplicas;