AutoscalingPolicyCpuUtilization_PredictiveMethod class final

Indicates whether predictive autoscaling based on CPU metric is enabled. Valid values are:

  • NONE (default). No predictive method is used. The autoscaler scales the group to meet current demand based on real-time metrics.
  • OPTIMIZE_AVAILABILITY. Predictive autoscaling improves availability by monitoring daily and weekly load patterns and scaling out ahead of anticipated demand.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const AutoscalingPolicyCpuUtilization_PredictiveMethod
The default value for AutoscalingPolicyCpuUtilization_PredictiveMethod.
none → const AutoscalingPolicyCpuUtilization_PredictiveMethod
No predictive method is used. The autoscaler scales the group to meet current demand based on real-time metrics
optimizeAvailability → const AutoscalingPolicyCpuUtilization_PredictiveMethod
Predictive autoscaling improves availability by monitoring daily and weekly load patterns and scaling out ahead of anticipated demand.
undefinedPredictiveMethod → const AutoscalingPolicyCpuUtilization_PredictiveMethod
A value indicating that the enum field is not set.