none constant
No predictive method is used. The autoscaler scales the group to meet current demand based on real-time metrics
Implementation
static const none = AutoscalingPolicyCpuUtilization_PredictiveMethod('NONE');
No predictive method is used. The autoscaler scales the group to meet current demand based on real-time metrics
static const none = AutoscalingPolicyCpuUtilization_PredictiveMethod('NONE');