metric property
The identifier (type) of the Stackdriver Monitoring metric. The metric cannot have negative values.
The metric must have a value type of INT64 orDOUBLE.
Implementation
final String? metric;
The identifier (type) of the Stackdriver Monitoring metric. The metric cannot have negative values.
The metric must have a value type of INT64 orDOUBLE.
final String? metric;