AutoscalingPolicyScaleInControl class final
Configuration that allows for slower scale in so that even if Autoscaler recommends an abrupt scale in of a MIG, it will be throttled as specified by the parameters below.
Constructors
- AutoscalingPolicyScaleInControl({FixedOrPercent? maxScaledInReplicas, int? timeWindowSec})
- AutoscalingPolicyScaleInControl.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxScaledInReplicas → FixedOrPercent?
-
Maximum allowed number (or %) of VMs that can be deducted from the peak
recommendation during the window autoscaler looks at when computing
recommendations. Possibly all these VMs can be deleted at once so user
service needs to be prepared to lose that many VMs in one step.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeWindowSec → int?
-
How far back autoscaling looks when computing recommendations to
include directives regarding slower scale in, as described above.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String