timeWindowSec property

int? timeWindowSec
final

How far back autoscaling looks when computing recommendations to include directives regarding slower scale in, as described above.

Implementation

final int? timeWindowSec;