disabled property

bool? disabled
final

A boolean value that specifies whether a scaling schedule can influence autoscaler recommendations. If set to true, then a scaling schedule has no effect. This field is optional, and its value is false by default.

Implementation

final bool? disabled;