accessKey property

String? accessKey
final

The access key used for s3 bucket authentication. Required for updating or creating a backend that uses AWS v4 signature authentication, but will not be returned as part of the configuration when queried with a REST API GET request.

@InputOnly

Implementation

final String? accessKey;