accessKeyVersion property
The optional version identifier for the access key. You can use this to keep track of different iterations of your access key.
Implementation
final String? accessKeyVersion;
The optional version identifier for the access key. You can use this to keep track of different iterations of your access key.
final String? accessKeyVersion;