Backend class final

Message containing information of one individual backend.

Constructors

Backend({String? balancingMode, double? capacityScaler, List<BackendCustomMetric> customMetrics = const [], String? description, bool? failover, String? group, int? maxConnections, int? maxConnectionsPerEndpoint, int? maxConnectionsPerInstance, int? maxInFlightRequests, int? maxInFlightRequestsPerEndpoint, int? maxInFlightRequestsPerInstance, int? maxRate, double? maxRatePerEndpoint, double? maxRatePerInstance, double? maxUtilization, BackendBackendOrchestrationInfo? orchestrationInfo, String? preference, String? trafficDuration})
Backend.fromJson(Object? j)
factory

Properties

balancingMode String?
Specifies how to determine whether the backend of a load balancer can handle additional traffic or is fully loaded. For usage guidelines, see Connection balancing mode.
final
capacityScaler double?
A multiplier applied to the backend's target capacity of its balancing mode. The default value is 1, which means the group serves up to 100% of its configured capacity (depending onbalancingMode). A setting of 0 means the group is completely drained, offering 0% of its available capacity. The valid ranges are 0.0 and 0.1,1.0. You cannot configure a setting larger than 0 and smaller than0.1. You cannot configure a setting of 0 when there is only one backend attached to the backend service.
final
customMetrics List<BackendCustomMetric>
List of custom metrics that are used for CUSTOM_METRICS BalancingMode.
final
description String?
An optional description of this resource. Provide this property when you create the resource.
final
failover bool?
This field designates whether this is a failover backend. More than one failover backend can be configured for a given BackendService.
final
group String?
The fully-qualified URL of aninstance group or network endpoint group (NEG) resource. To determine what types of backends a load balancer supports, see the Backend services overview.
final
hashCode int
The hash code for this object.
no setterinherited
maxConnections int?
Defines a target maximum number of simultaneous connections. For usage guidelines, seeConnection balancing mode and Utilization balancing mode. Not available if the backend'sbalancingMode is RATE.
final
maxConnectionsPerEndpoint int?
Defines a target maximum number of simultaneous connections. For usage guidelines, seeConnection balancing mode and Utilization balancing mode.
final
maxConnectionsPerInstance int?
Defines a target maximum number of simultaneous connections. For usage guidelines, seeConnection balancing mode and Utilization balancing mode.
final
maxInFlightRequests int?
Defines a maximum number of in-flight requests for the whole NEG or instance group. Not available if backend's balancingMode isRATE or CONNECTION.
final
maxInFlightRequestsPerEndpoint int?
Defines a maximum number of in-flight requests for a single endpoint. Not available if backend's balancingMode is RATE or CONNECTION.
final
maxInFlightRequestsPerInstance int?
Defines a maximum number of in-flight requests for a single VM. Not available if backend's balancingMode is RATE or CONNECTION.
final
maxRate int?
Defines a maximum number of HTTP requests per second (RPS). For usage guidelines, seeRate balancing mode and Utilization balancing mode.
final
maxRatePerEndpoint double?
Defines a maximum target for requests per second (RPS). For usage guidelines, seeRate balancing mode and Utilization balancing mode.
final
maxRatePerInstance double?
Defines a maximum target for requests per second (RPS). For usage guidelines, seeRate balancing mode and Utilization balancing mode.
final
maxUtilization double?
Optional parameter to define a target capacity for theUTILIZATION balancing mode. The valid range is0.0, 1.0.
final
orchestrationInfo BackendBackendOrchestrationInfo?
Information about the resource or system that manages the backend.
final
preference String?
This field indicates whether this backend should be fully utilized before sending traffic to backends with default preference. The possible values are:
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trafficDuration String?
Check the TrafficDuration enum for the list of possible values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String