customMetrics property
List of custom metrics that are used for CUSTOM_METRICS BalancingMode.
Implementation
final List<BackendCustomMetric> customMetrics;
List of custom metrics that are used for CUSTOM_METRICS BalancingMode.
final List<BackendCustomMetric> customMetrics;