group property
The fully-qualified URL of aninstance group or network endpoint group (NEG) resource. To determine what types of backends a load balancer supports, see the Backend services overview.
You must use the fully-qualified URL (starting withhttps://www.googleapis.com/) to specify the instance group or NEG. Partial URLs are not supported.
If haPolicy is specified, backends must refer to NEG resources of type GCE_VM_IP.
Implementation
final String? group;