orchestrationInfo property
Information about the resource or system that manages the backend.
Implementation
final BackendBackendOrchestrationInfo? orchestrationInfo;
Information about the resource or system that manages the backend.
final BackendBackendOrchestrationInfo? orchestrationInfo;