preference property

String? preference
final

This field indicates whether this backend should be fully utilized before sending traffic to backends with default preference. The possible values are:

  • PREFERRED: Backends with this preference level will be filled up to their capacity limits first, based on RTT.
  • DEFAULT: If preferred backends don't have enough capacity, backends in this layer would be used and traffic would be assigned based on the load balancing algorithm you use. This is the default

For global external Passthrough Network Load Balancers, the following restrictions apply:

  • At most one backend can be marked as PREFERRED.
  • PREFERRED and DEFAULT backends cannot reside in the same Cloud region. Check the Preference enum for the list of possible values.

Implementation

final String? preference;