toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (balancingMode != null) 'balancingMode=$balancingMode',
    if (capacityScaler != null) 'capacityScaler=$capacityScaler',
    if (description != null) 'description=$description',
    if (failover != null) 'failover=$failover',
    if (group != null) 'group=$group',
    if (maxConnections != null) 'maxConnections=$maxConnections',
    if (maxConnectionsPerEndpoint != null)
      'maxConnectionsPerEndpoint=$maxConnectionsPerEndpoint',
    if (maxConnectionsPerInstance != null)
      'maxConnectionsPerInstance=$maxConnectionsPerInstance',
    if (maxInFlightRequests != null)
      'maxInFlightRequests=$maxInFlightRequests',
    if (maxInFlightRequestsPerEndpoint != null)
      'maxInFlightRequestsPerEndpoint=$maxInFlightRequestsPerEndpoint',
    if (maxInFlightRequestsPerInstance != null)
      'maxInFlightRequestsPerInstance=$maxInFlightRequestsPerInstance',
    if (maxRate != null) 'maxRate=$maxRate',
    if (maxRatePerEndpoint != null) 'maxRatePerEndpoint=$maxRatePerEndpoint',
    if (maxRatePerInstance != null) 'maxRatePerInstance=$maxRatePerInstance',
    if (maxUtilization != null) 'maxUtilization=$maxUtilization',
    if (preference != null) 'preference=$preference',
    if (trafficDuration != null) 'trafficDuration=$trafficDuration',
  ].join(',');
  return 'Backend(${$contents})';
}