BackendBucket class final

Represents a Cloud Storage Bucket resource.

This Cloud Storage bucket resource is referenced by a URL map of a load balancer. For more information, readBackend Buckets.

Constructors

BackendBucket({String? bucketName, BackendBucketCdnPolicy? cdnPolicy, String? compressionMode, String? creationTimestamp, List<String> customResponseHeaders = const [], String? description, String? edgeSecurityPolicy, bool? enableCdn, BigInt? id, String? kind, String? loadBalancingScheme, String? name, BackendBucketParams? params, String? region, String? selfLink, List<BackendBucketUsedBy> usedBy = const []})
BackendBucket.fromJson(Object? j)
factory

Properties

bucketName String?
Cloud Storage bucket name.
final
cdnPolicy BackendBucketCdnPolicy?
Cloud CDN configuration for this BackendBucket.
final
compressionMode String?
Compress text responses using Brotli or gzip compression, based on the client's Accept-Encoding header. Check the CompressionMode enum for the list of possible values.
final
creationTimestamp String?
Output Only Creation timestamp inRFC3339 text format.
final
customResponseHeaders List<String>
Headers that the Application Load Balancer should add to proxied responses.
final
description String?
An optional textual description of the resource; provided by the client when the resource is created.
final
edgeSecurityPolicy String?
Output Only The resource URL for the edge security policy associated with this backend bucket.
final
enableCdn bool?
If true, enable Cloud CDN for this BackendBucket.
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output Only Unique identifier for the resource; defined by the server.
final
kind String?
Output only. Type of the resource.
final
loadBalancingScheme String?
The value can only be INTERNAL_MANAGED for cross-region internal layer 7 load balancer.
final
name String?
Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
params BackendBucketParams?
Input only. Input Only Additional params passed with the request, but not persisted as part of resource payload.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
region String?
Output only. Output Only URL of the region where the regional backend bucket resides. This field is not applicable to global backend buckets. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output Only Server-defined URL for the resource.
final
usedBy List<BackendBucketUsedBy>
Output only. Output Only List of resources referencing that backend bucket.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String