loadBalancingScheme property

String? loadBalancingScheme
final

The value can only be INTERNAL_MANAGED for cross-region internal layer 7 load balancer.

If loadBalancingScheme is not specified, the backend bucket can be used by classic global external load balancers, or global application external load balancers, or both. Check the LoadBalancingScheme enum for the list of possible values.

Implementation

final String? loadBalancingScheme;