toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (cacheMode != null) 'cacheMode=$cacheMode',
    if (clientTtl != null) 'clientTtl=$clientTtl',
    if (defaultTtl != null) 'defaultTtl=$defaultTtl',
    if (maxTtl != null) 'maxTtl=$maxTtl',
    if (negativeCaching != null) 'negativeCaching=$negativeCaching',
    if (requestCoalescing != null) 'requestCoalescing=$requestCoalescing',
    if (serveWhileStale != null) 'serveWhileStale=$serveWhileStale',
    if (signedUrlCacheMaxAgeSec != null)
      'signedUrlCacheMaxAgeSec=$signedUrlCacheMaxAgeSec',
  ].join(',');
  return 'BackendBucketCdnPolicy(${$contents})';
}