BackendBucketCdnPolicyCacheKeyPolicy class final
Message containing what to include in the cache key for a request for Cloud CDN.
Constructors
-
BackendBucketCdnPolicyCacheKeyPolicy({List<
String> includeHttpHeaders = const [], List<String> queryStringWhitelist = const []}) - BackendBucketCdnPolicyCacheKeyPolicy.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
includeHttpHeaders
→ List<
String> -
Allows HTTP request headers (by name) to be used in the cache key.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited -
queryStringWhitelist
→ List<
String> -
Names of query string parameters to include in cache keys. Default
parameters are always included. '&' and '=' will be percent encoded
and not treated as delimiters.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String