cacheAllStatic constant
BackendBucketCdnPolicy_CacheMode
const cacheAllStatic
Automatically cache static content, including common image formats, media (video and audio), and web assets (JavaScript and CSS). Requests and responses that are marked as uncacheable, as well as dynamic content (including HTML), will not be cached.
Implementation
static const cacheAllStatic = BackendBucketCdnPolicy_CacheMode(
'CACHE_ALL_STATIC',
);