BackendBucket_LoadBalancingScheme class final

The value can only be INTERNAL_MANAGED for cross-region internal layer 7 load balancer.

If loadBalancingScheme is not specified, the backend bucket can be used by classic global external load balancers, or global application external load balancers, or both.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const BackendBucket_LoadBalancingScheme
The default value for BackendBucket_LoadBalancingScheme.
externalManaged → const BackendBucket_LoadBalancingScheme
Signifies that this will be used for regional external Application Load Balancers.
internalManaged → const BackendBucket_LoadBalancingScheme
Signifies that this will be used for internal Application Load Balancers.
undefinedLoadBalancingScheme → const BackendBucket_LoadBalancingScheme
A value indicating that the enum field is not set.