BackendBuckets class final
The BackendBuckets API.
- Implementers
Constructors
- BackendBuckets({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
BackendBucketsusingclientfor transport. - BackendBuckets.fromApiKey([String? apiKey])
-
Creates a
BackendBucketsthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addSignedUrlKey(
AddSignedUrlKeyBackendBucketRequest request) → Future< Operation> - Adds a key for validating requests with signed URLs for this backend bucket.
-
aggregatedList(
AggregatedListBackendBucketsRequest request) → Future< BackendBucketAggregatedList> - Retrieves the list of all BackendBucket resources, regional and global, available to the specified project.
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteBackendBucketRequest request) → Future< Operation> - Deletes the specified BackendBucket resource.
-
deleteSignedUrlKey(
DeleteSignedUrlKeyBackendBucketRequest request) → Future< Operation> - Deletes a key for validating requests with signed URLs for this backend bucket.
-
get(
GetBackendBucketRequest request) → Future< BackendBucket> - Returns the specified BackendBucket resource.
-
getIamPolicy(
GetIamPolicyBackendBucketRequest request) → Future< Policy> - Gets the access control policy for a resource. May be empty if no such policy or resource exists.
-
insert(
InsertBackendBucketRequest request) → Future< Operation> - Creates a BackendBucket resource in the specified project using the data included in the request.
-
list(
ListBackendBucketsRequest request) → Future< BackendBucketList> - Retrieves the list of BackendBucket resources available to the specified project.
-
listUsable(
ListUsableBackendBucketsRequest request) → Future< BackendBucketListUsable> - Retrieves a list of all usable backend buckets in the specified project.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchBackendBucketRequest request) → Future< Operation> - Updates the specified BackendBucket resource with the data included in the request. This method supportsPATCH semantics and uses theJSON merge patch format and processing rules.
-
setEdgeSecurityPolicy(
SetEdgeSecurityPolicyBackendBucketRequest request) → Future< Operation> - Sets the edge security policy for the specified backend bucket.
-
setIamPolicy(
SetIamPolicyBackendBucketRequest request) → Future< Policy> - Sets the access control policy on the specified resource. Replaces any existing policy.
-
testIamPermissions(
TestIamPermissionsBackendBucketRequest request) → Future< TestPermissionsResponse> - Returns permissions that a caller has on the specified resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
UpdateBackendBucketRequest request) → Future< Operation> - Updates the specified BackendBucket resource with the data included in the request.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited