addSignedUrlKey method

Adds a key for validating requests with signed URLs for this backend bucket.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> addSignedUrlKey(
  AddSignedUrlKeyBackendBucketRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/global/backendBuckets/${request.backendBucket}/addSignedUrlKey',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.post(
    url,
    body: request.signedUrlKeyResource,
  );
  return Operation.fromJson(response);
}