dryRun property
If true, the metric data is collected and reported to Cloud Monitoring, but is not used for load balancing.
Implementation
final bool? dryRun;
If true, the metric data is collected and reported to Cloud Monitoring, but is not used for load balancing.
final bool? dryRun;