customMetrics property
List of custom metrics that are used for theWEIGHTED_ROUND_ROBIN locality_lb_policy.
Implementation
final List<BackendServiceCustomMetric> customMetrics;
List of custom metrics that are used for theWEIGHTED_ROUND_ROBIN locality_lb_policy.
final List<BackendServiceCustomMetric> customMetrics;