customResponseHeaders property
Headers that the load balancer adds to proxied responses. See Creating custom headers.
Implementation
final List<String> customResponseHeaders;
Headers that the load balancer adds to proxied responses. See Creating custom headers.
final List<String> customResponseHeaders;