loadBalancingScheme property

String? loadBalancingScheme
final

Specifies the load balancer type. A backend service created for one type of load balancer cannot be used with another. For more information, refer to Backend services product and scheme table. Check the LoadBalancingScheme enum for the list of possible values.

Implementation

final String? loadBalancingScheme;