logConfig property

BackendServiceLogConfig? logConfig
final

This field denotes the logging options for the load balancer traffic served by this backend service. If logging is enabled, logs will be exported to Stackdriver.

Implementation

final BackendServiceLogConfig? logConfig;