metadatas property

Map<String, String> metadatas
final

Deployment metadata associated with the resource to be set by a GKE hub controller and read by the backend RCTH

Implementation

final Map<String, String> metadatas;