orchestrationInfo property
Information about the resource or system that manages the backend service.
Implementation
final BackendServiceOrchestrationInfo? orchestrationInfo;
Information about the resource or system that manages the backend service.
final BackendServiceOrchestrationInfo? orchestrationInfo;