region property

String? region
final

Output only. Output Only URL of the region where the regional backend service resides. This field is not applicable to global backend services. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.

Implementation

final String? region;