securitySettings property
This field specifies the security settings that apply to this backend service. This field is applicable to a global backend service with the load_balancing_scheme set to INTERNAL_SELF_MANAGED.
Implementation
final SecuritySettings? securitySettings;