tlsSettings property
Configuration for Backend Authenticated TLS and mTLS. May only be specified when the backend protocol is SSL, HTTPS or HTTP2.
Implementation
final BackendServiceTlsSettings? tlsSettings;
Configuration for Backend Authenticated TLS and mTLS. May only be specified when the backend protocol is SSL, HTTPS or HTTP2.
final BackendServiceTlsSettings? tlsSettings;