negativeCachingPolicy property

List<BackendServiceCdnPolicyNegativeCachingPolicy> negativeCachingPolicy
final

Sets a cache TTL for the specified HTTP status code. negative_caching must be enabled to configure negative_caching_policy. Omitting the policy and leaving negative_caching enabled will use Cloud CDN's default cache TTLs. Note that when specifying an explicit negative_caching_policy, you should take care to specify a cache TTL for all response codes that you wish to cache. Cloud CDN will not apply any default negative caching when a policy exists.

Implementation

final List<BackendServiceCdnPolicyNegativeCachingPolicy>
negativeCachingPolicy;