requestCoalescing property

bool? requestCoalescing
final

If true then Cloud CDN will combine multiple concurrent cache fill requests into a small number of requests to the origin.

Implementation

final bool? requestCoalescing;