useOriginHeaders constant
BackendServiceCdnPolicy_CacheMode
const useOriginHeaders
Requires the origin to set valid caching headers to cache content. Responses without these headers will not be cached at Google's edge, and will require a full trip to the origin on every request, potentially impacting performance and increasing load on the origin server.
Implementation
static const useOriginHeaders = BackendServiceCdnPolicy_CacheMode(
'USE_ORIGIN_HEADERS',
);