BackendServiceConnectionTrackingPolicy class final

Connection Tracking configuration for this BackendService.

Constructors

BackendServiceConnectionTrackingPolicy({String? connectionPersistenceOnUnhealthyBackends, bool? enableStrongAffinity, int? idleTimeoutSec, String? trackingMode})
BackendServiceConnectionTrackingPolicy.fromJson(Object? j)
factory

Properties

connectionPersistenceOnUnhealthyBackends String?
Specifies connection persistence when backends are unhealthy. The default value is DEFAULT_FOR_PROTOCOL.
final
enableStrongAffinity bool?
Enable Strong Session Affinity for external passthrough Network Load Balancers. This option is not available publicly.
final
hashCode int
The hash code for this object.
no setterinherited
idleTimeoutSec int?
Specifies how long to keep a Connection Tracking entry while there is no matching traffic (in seconds).
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trackingMode String?
Specifies the key used for connection tracking. There are two options:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String