enableStrongAffinity property
Enable Strong Session Affinity for external passthrough Network Load Balancers. This option is not available publicly.
Implementation
final bool? enableStrongAffinity;
Enable Strong Session Affinity for external passthrough Network Load Balancers. This option is not available publicly.
final bool? enableStrongAffinity;