idleTimeoutSec property

int? idleTimeoutSec
final

Specifies how long to keep a Connection Tracking entry while there is no matching traffic (in seconds).

For internal passthrough Network Load Balancers:

  • The minimum (default) is 10 minutes and the maximum is 16 hours.
  • It can be set only if Connection Tracking is less than 5-tuple (i.e. Session Affinity is CLIENT_IP_NO_DESTINATION,CLIENT_IP or CLIENT_IP_PROTO, and Tracking Mode is PER_SESSION).

For external passthrough Network Load Balancers the default is 60 seconds. This option is not available publicly.

Implementation

final int? idleTimeoutSec;