BackendServiceFailoverPolicy class final
For load balancers that have configurable failover: Internal passthrough Network Load Balancers and external passthrough Network Load Balancers. On failover or failback, this field indicates whether connection draining will be honored. Google Cloud has a fixed connection draining timeout of 10 minutes. A setting of true terminates existing TCP connections to the active pool during failover and failback, immediately draining traffic. A setting of false allows existing TCP connections to persist, even on VMs no longer in the active pool, for up to the duration of the connection draining timeout (10 minutes).
Constructors
- BackendServiceFailoverPolicy({bool? disableConnectionDrainOnFailover, bool? dropTrafficIfUnhealthy, double? failoverRatio})
- BackendServiceFailoverPolicy.fromJson(Object? j)
-
factory
Properties
- disableConnectionDrainOnFailover → bool?
-
This can be set to true if the protocol isTCP, UDP, or UNSPECIFIED.
final
- dropTrafficIfUnhealthy → bool?
-
If set to true, connections to the
load balancer are dropped when all primary and all backup backend VMs are
unhealthy.If set to false, connections are distributed
among all primary VMs when all primary and all backup backend VMs are
unhealthy.
For load balancers that have configurable
failover:
Internal passthrough
Network Load
Balancers
and external passthrough
Network Load
Balancers.
The default is false.
final
- failoverRatio → double?
-
The value of the field must be in the range
0, 1. If the value is 0, the load balancer performs a failover when the number of healthy primary VMs equals zero. For all other values, the load balancer performs a failover when the total number of healthy primary VMs is less than this ratio. For load balancers that have configurable failover: Internal TCP/UDP Load Balancing and external TCP/UDP Load Balancing.final - hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String