disableConnectionDrainOnFailover property
This can be set to true if the protocol isTCP, UDP, or UNSPECIFIED.
The default is false.
Implementation
final bool? disableConnectionDrainOnFailover;
This can be set to true if the protocol isTCP, UDP, or UNSPECIFIED.
The default is false.
final bool? disableConnectionDrainOnFailover;