failoverRatio property
The value of the field must be in the range0, 1. If the value is 0, the load balancer performs a
failover when the number of healthy primary VMs equals zero.
For all other values, the load balancer performs a failover when the
total number of healthy primary VMs is less than this ratio.
For load balancers that have configurable
failover:
Internal TCP/UDP Load
Balancing
and external TCP/UDP Load
Balancing.
Implementation
final double? failoverRatio;