BackendServiceGroupHealth class final

Constructors

BackendServiceGroupHealth({Map<String, String> annotations = const {}, List<HealthStatus> healthStatus = const [], String? kind})
BackendServiceGroupHealth.fromJson(Object? j)
factory

Properties

annotations Map<String, String>
Metadata defined as annotations on the network endpoint group.
final
hashCode int
The hash code for this object.
no setterinherited
healthStatus List<HealthStatus>
Health state of the backend instances or endpoints in requested instance or network endpoint group, determined based on configured health checks.
final
kind String?
Output only. Output Only Type of resource. Alwayscompute#backendServiceGroupHealth for the health of backend services.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String