healthStatus property

List<HealthStatus> healthStatus
final

Health state of the backend instances or endpoints in requested instance or network endpoint group, determined based on configured health checks.

Implementation

final List<HealthStatus> healthStatus;