BackendServiceHapolicy class final

Properties

fastIPMove String?
Specifies whether fast IP move is enabled, and if so, the mechanism to achieve it.
final
hashCode int
The hash code for this object.
no setterinherited
leader BackendServiceHapolicyLeader?
Selects one of the network endpoints attached to the backend NEGs of this service as the active endpoint (the leader) that receives all traffic.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String