menu
google_cloud_compute_v1 package
documentation
compute.dart
BackendServiceHapolicyLeaderNetworkEndpoint class
BackendServiceHapolicyLeaderNetworkEndpoint class
dark_mode
light_mode
BackendServiceHapolicyLeaderNetworkEndpoint
class
final
Constructors
BackendServiceHapolicyLeaderNetworkEndpoint
({
String
?
instance
})
BackendServiceHapolicyLeaderNetworkEndpoint.fromJson
(
Object
?
j
)
factory
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
instance
→
String
?
The name of the VM instance of the leader network endpoint. The instance must already be attached to the NEG specified in the haPolicy.leader.backendGroup.
final
qualifiedName
→
String
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or
google.rpc.ErrorInfo
.
final
inherited
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson
(
)
→
Object
toString
(
)
→
String
A string representation of this object.
override
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
Constants
fullyQualifiedName
→ const
String
google_cloud_compute_v1 package
documentation
compute
BackendServiceHapolicyLeaderNetworkEndpoint class
compute library