BackendServiceIap class final
Identity-Aware Proxy
Constructors
- BackendServiceIap({bool? enabled, String? oauth2ClientId, String? oauth2ClientSecret, String? oauth2ClientSecretSha256})
- BackendServiceIap.fromJson(Object? j)
-
factory
Properties
- enabled → bool?
-
Whether the serving infrastructure will authenticate and authorize all
incoming requests.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- oauth2ClientId → String?
-
OAuth2 client ID to use for the authentication flow.
final
- oauth2ClientSecret → String?
-
OAuth2 client secret to use for the authentication flow.
For security reasons, this value cannot be retrieved via the API.
Instead, the SHA-256 hash of the value is returned in the
oauth2ClientSecretSha256 field.
final
- oauth2ClientSecretSha256 → String?
-
Output only.
Output OnlySHA256 hash value for the field oauth2_client_secret above.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String