enabled property
Whether the serving infrastructure will authenticate and authorize all incoming requests.
Implementation
final bool? enabled;
Whether the serving infrastructure will authenticate and authorize all incoming requests.
final bool? enabled;