toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (enabled != null) 'enabled=$enabled',
    if (oauth2ClientId != null) 'oauth2ClientId=$oauth2ClientId',
    if (oauth2ClientSecret != null) 'oauth2ClientSecret=$oauth2ClientSecret',
    if (oauth2ClientSecretSha256 != null)
      'oauth2ClientSecretSha256=$oauth2ClientSecretSha256',
  ].join(',');
  return 'BackendServiceIAP(${$contents})';
}