BackendServiceLocalityLoadBalancingPolicyConfig class final

Container for either a built-in LB policy supported by gRPC or Envoy or a custom one implemented by the end user.

Properties

customPolicy BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy?
final
hashCode int
The hash code for this object.
no setterinherited
policy BackendServiceLocalityLoadBalancingPolicyConfigPolicy?
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String