BackendServiceLocalityLoadBalancingPolicyConfigPolicy_Name class final
The name of a locality load-balancing policy. Valid values include ROUND_ROBIN and, for Java clients, LEAST_REQUEST. For information about these values, see the description of localityLbPolicy.
Do not specify the same policy more than once for a backend. If you do, the configuration is rejected.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const BackendServiceLocalityLoadBalancingPolicyConfigPolicy_Name
- The default value for BackendServiceLocalityLoadBalancingPolicyConfigPolicy_Name.
- invalidLbPolicy → const BackendServiceLocalityLoadBalancingPolicyConfigPolicy_Name
- leastRequest → const BackendServiceLocalityLoadBalancingPolicyConfigPolicy_Name
- An O(1) algorithm which selects two random healthy hosts and picks the host which has fewer active requests.
- maglev → const BackendServiceLocalityLoadBalancingPolicyConfigPolicy_Name
- This algorithm implements consistent hashing to backends. Maglev can be used as a drop in replacement for the ring hash load balancer. Maglev is not as stable as ring hash but has faster table lookup build times and host selection times. For more information about Maglev, seeMaglev: A Fast and Reliable Software Network Load Balancer.
- originalDestination → const BackendServiceLocalityLoadBalancingPolicyConfigPolicy_Name
- Backend host is selected based on the client connection metadata, i.e., connections are opened to the same address as the destination address of the incoming connection before the connection was redirected to the load balancer.
- random → const BackendServiceLocalityLoadBalancingPolicyConfigPolicy_Name
- The load balancer selects a random healthy host.
- ringHash → const BackendServiceLocalityLoadBalancingPolicyConfigPolicy_Name
- The ring/modulo hash load balancer implements consistent hashing to backends. The algorithm has the property that the addition/removal of a host from a set of N hosts only affects 1/N of the requests.
- roundRobin → const BackendServiceLocalityLoadBalancingPolicyConfigPolicy_Name
- This is a simple policy in which each healthy backend is selected in round robin order. This is the default.
- undefinedName → const BackendServiceLocalityLoadBalancingPolicyConfigPolicy_Name
- A value indicating that the enum field is not set.
- weightedGcpRendezvous → const BackendServiceLocalityLoadBalancingPolicyConfigPolicy_Name
- Per-instance weighted Load Balancing via health check reported weights. In internal passthrough network load balancing, it is weighted rendezvous hashing. This option is only supported in internal passthrough network load balancing.
- weightedMaglev → const BackendServiceLocalityLoadBalancingPolicyConfigPolicy_Name
- Per-instance weighted Load Balancing via health check reported weights. If set, the Backend Service must configure a non legacy HTTP-based Health Check, and health check replies are expected to contain non-standard HTTP response header field X-Load-Balancing-Endpoint-Weight to specify the per-instance weights. If set, Load Balancing is weighted based on the per-instance weights reported in the last processed health check replies, as long as every instance either reported a valid weight or had UNAVAILABLE_WEIGHT. Otherwise, Load Balancing remains equal-weight. This option is only supported in Network Load Balancing.
- weightedRoundRobin → const BackendServiceLocalityLoadBalancingPolicyConfigPolicy_Name
- Per-endpoint weighted round-robin Load Balancing using weights computed from Backend reported Custom Metrics. If set, the Backend Service responses are expected to contain non-standard HTTP response header field Endpoint-Load-Metrics. The reported metrics to use for computing the weights are specified via the customMetrics fields.