ringHash constant

The ring/modulo hash load balancer implements consistent hashing to backends. The algorithm has the property that the addition/removal of a host from a set of N hosts only affects 1/N of the requests.

Implementation

static const ringHash =
    BackendServiceLocalityLoadBalancingPolicyConfigPolicy_Name('RING_HASH');