enable property
Denotes whether to enable logging for the load balancer traffic served by this backend service. The default value is false.
Implementation
final bool? enable;
Denotes whether to enable logging for the load balancer traffic served by this backend service. The default value is false.
final bool? enable;