loggingHttpRequestHeaders property
The list of request headers that will be logged to Stackdriver.
Implementation
final List<BackendServiceLogConfigLoggingHttpHeader>
loggingHttpRequestHeaders;
The list of request headers that will be logged to Stackdriver.
final List<BackendServiceLogConfigLoggingHttpHeader>
loggingHttpRequestHeaders;