loggingHttpResponseHeaders property
The list of response headers that will be logged to Stackdriver.
Implementation
final List<BackendServiceLogConfigLoggingHttpHeader>
loggingHttpResponseHeaders;
The list of response headers that will be logged to Stackdriver.
final List<BackendServiceLogConfigLoggingHttpHeader>
loggingHttpResponseHeaders;