BackendServiceTlsSettingsSubjectAltName class final

A Subject Alternative Name that the load balancer matches against the SAN field in the TLS certificate provided by the backend, specified as either a DNS name or a URI, in accordance with RFC 5280 4.2.1.6

Constructors

BackendServiceTlsSettingsSubjectAltName({String? dnsName, String? uniformResourceIdentifier})
BackendServiceTlsSettingsSubjectAltName.fromJson(Object? j)
factory

Properties

dnsName String?
The SAN specified as a DNS Name.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uniformResourceIdentifier String?
The SAN specified as a URI.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String