menu
google_cloud_compute_v1 package
documentation
compute.dart
BackendServiceUsedBy class
BackendServiceUsedBy class
dark_mode
light_mode
BackendServiceUsedBy
class
final
Constructors
BackendServiceUsedBy
({
String
?
reference
})
BackendServiceUsedBy.fromJson
(
Object
?
j
)
factory
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
qualifiedName
→
String
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or
google.rpc.ErrorInfo
.
final
inherited
reference
→
String
?
Output only.
Output Only
Server-defined URL for resources referencing given BackendService like UrlMaps, TargetTcpProxies, TargetSslProxies and ForwardingRule.
final
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson
(
)
→
Object
toString
(
)
→
String
A string representation of this object.
override
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
Constants
fullyQualifiedName
→ const
String
google_cloud_compute_v1 package
documentation
compute
BackendServiceUsedBy class
compute library