BackendService_CompressionMode class final
Compress text responses using Brotli or gzip compression, based on the client's Accept-Encoding header.
Constructors
- BackendService_CompressionMode(String value)
-
const
- BackendService_CompressionMode.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const BackendService_CompressionMode
- The default value for BackendService_CompressionMode.
- automatic → const BackendService_CompressionMode
- Automatically uses the best compression based on the Accept-Encoding header sent by the client.
- disabled → const BackendService_CompressionMode
- Disables compression. Existing compressed responses cached by Cloud CDN will not be served to clients.
- undefinedCompressionMode → const BackendService_CompressionMode
- A value indicating that the enum field is not set.