originalDestination constant
BackendService_LocalityLbPolicy
const originalDestination
Backend host is selected based on the client connection metadata, i.e., connections are opened to the same address as the destination address of the incoming connection before the connection was redirected to the load balancer.
Implementation
static const originalDestination = BackendService_LocalityLbPolicy(
'ORIGINAL_DESTINATION',
);