BackendService_Protocol class final

The protocol this BackendService uses to communicate with backends.

Possible values are HTTP, HTTPS, HTTP2, H2C, TCP, SSL, UDP, GRPC, or UNSPECIFIED, depending on the chosen load balancer or Traffic Director configuration. Refer to Load balancing features for more information.

Must be set to GRPC when the backend service is referenced by a URL map that is bound to target gRPC proxy.

Constructors

BackendService_Protocol(String value)
const
BackendService_Protocol.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const BackendService_Protocol
The default value for BackendService_Protocol.
grpc → const BackendService_Protocol
gRPC (available for Traffic Director).
h2C → const BackendService_Protocol
HTTP2 over cleartext
http → const BackendService_Protocol
http2 → const BackendService_Protocol
HTTP/2 with SSL.
https → const BackendService_Protocol
ssl → const BackendService_Protocol
TCP proxying with SSL.
tcp → const BackendService_Protocol
TCP proxying or TCP pass-through.
udp → const BackendService_Protocol
UDP.
undefinedProtocol → const BackendService_Protocol
A value indicating that the enum field is not set.
unspecified → const BackendService_Protocol
If a Backend Service has UNSPECIFIED as its protocol, it can be used with any L3/L4 Forwarding Rules.