clientIpNoDestination constant

BackendService_SessionAffinity const clientIpNoDestination

1-tuple hash only on packet's source IP address. Connections from the same source IP address will be served by the same backend VM while that VM remains healthy. This option can only be used for Internal TCP/UDP Load Balancing.

Implementation

static const clientIpNoDestination = BackendService_SessionAffinity(
  'CLIENT_IP_NO_DESTINATION',
);