BackendServices class final

The BackendServices API.

Implementers

Constructors

BackendServices({required Client client, Uri? endPoint, String? gcclVersion})
Creates a BackendServices using client for transport.
BackendServices.fromApiKey([String? apiKey])
Creates a BackendServices that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addSignedUrlKey(AddSignedUrlKeyBackendServiceRequest request) Future<Operation>
Adds a key for validating requests with signed URLs for this backend service.
aggregatedList(AggregatedListBackendServicesRequest request) Future<BackendServiceAggregatedList>
Retrieves the list of all BackendService resources, regional and global, available to the specified project.
close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteBackendServiceRequest request) Future<Operation>
Deletes the specified BackendService resource.
deleteSignedUrlKey(DeleteSignedUrlKeyBackendServiceRequest request) Future<Operation>
Deletes a key for validating requests with signed URLs for this backend service.
get(GetBackendServiceRequest request) Future<BackendService>
Returns the specified BackendService resource.
getEffectiveSecurityPolicies(GetEffectiveSecurityPoliciesBackendServiceRequest request) Future<GetEffectiveSecurityPoliciesBackendServiceResponse>
Returns effective security policies applied to this backend service.
getHealth(GetHealthBackendServiceRequest request) Future<BackendServiceGroupHealth>
Gets the most recent health check results for this BackendService.
getIamPolicy(GetIamPolicyBackendServiceRequest request) Future<Policy>
Gets the access control policy for a resource. May be empty if no such policy or resource exists.
insert(InsertBackendServiceRequest request) Future<Operation>
Creates a BackendService resource in the specified project using the data included in the request. For more information, see Backend services overview.
list(ListBackendServicesRequest request) Future<BackendServiceList>
Retrieves the list of BackendService resources available to the specified project.
listUsable(ListUsableBackendServicesRequest request) Future<BackendServiceListUsable>
Retrieves a list of all usable backend services for Application Load Balancers and Proxy Network Load Balancers in the specified project. Backend services for external and internal passthrough Network Load Balancers are not included in the response.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(PatchBackendServiceRequest request) Future<Operation>
Patches the specified BackendService resource with the data included in the request. For more information, see Backend services overview. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.
setEdgeSecurityPolicy(SetEdgeSecurityPolicyBackendServiceRequest request) Future<Operation>
Sets the edge security policy for the specified backend service.
setIamPolicy(SetIamPolicyBackendServiceRequest request) Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy.
setSecurityPolicy(SetSecurityPolicyBackendServiceRequest request) Future<Operation>
Sets the Google Cloud Armor security policy for the specified backend service. For more information, seeGoogle Cloud Armor Overview
testIamPermissions(TestIamPermissionsBackendServiceRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
toString() String
A string representation of this object.
inherited
update(UpdateBackendServiceRequest request) Future<Operation>
Updates the specified BackendService resource with the data included in the request. For more information, seeBackend services overview.

Operators

operator ==(Object other) bool
The equality operator.
inherited