deleteSignedUrlKey method

Deletes a key for validating requests with signed URLs for this backend service.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> deleteSignedUrlKey(
  DeleteSignedUrlKeyBackendServiceRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/global/backendServices/${request.backendService}/deleteSignedUrlKey',
    queryParameters: {
      if (request.keyName case final $1 when $1.isNotDefault) 'keyName': $1,
      'requestId': ?request.requestId,
    },
  );
  final response = await _client.post(url);
  return Operation.fromJson(response);
}