getEffectiveSecurityPolicies method

Returns effective security policies applied to this backend service.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<GetEffectiveSecurityPoliciesBackendServiceResponse>
getEffectiveSecurityPolicies(
  GetEffectiveSecurityPoliciesBackendServiceRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/global/backendServices/${request.backendService}/getEffectiveSecurityPolicies',
  );
  final response = await _client.get(url);
  return GetEffectiveSecurityPoliciesBackendServiceResponse.fromJson(
    response,
  );
}