getHealth method

Gets the most recent health check results for this BackendService.

Example request body:

{ "group": "/zones/us-east1-b/instanceGroups/lb-backend-example" }

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<BackendServiceGroupHealth> getHealth(
  GetHealthBackendServiceRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/global/backendServices/${request.backendService}/getHealth',
  );
  final response = await _client.post(
    url,
    body: request.resourceGroupReferenceResource,
  );
  return BackendServiceGroupHealth.fromJson(response);
}