insert method

Creates a BackendService resource in the specified project using the data included in the request. For more information, see Backend services overview.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> insert(InsertBackendServiceRequest request) async {
  final url = _endPoint.replace(
    path: '/compute/v1/projects/${request.project}/global/backendServices',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.post(
    url,
    body: request.backendServiceResource,
  );
  return Operation.fromJson(response);
}