listUsable method
Retrieves a list of all usable backend services for Application Load Balancers and Proxy Network Load Balancers in the specified project. Backend services for external and internal passthrough Network Load Balancers are not included in the response.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
Future<BackendServiceListUsable> listUsable(
ListUsableBackendServicesRequest request,
) async {
final url = _endPoint.replace(
path:
'/compute/v1/projects/${request.project}/global/backendServices/listUsable',
queryParameters: {
'filter': ?request.filter,
if (request.maxResults case final $1?) 'maxResults': '${$1}',
'orderBy': ?request.orderBy,
'pageToken': ?request.pageToken,
if (request.returnPartialSuccess case final $1?)
'returnPartialSuccess': '${$1}',
},
);
final response = await _client.get(url);
return BackendServiceListUsable.fromJson(response);
}