Backend_BalancingMode class final
Specifies how to determine whether the backend of a load balancer can handle additional traffic or is fully loaded. For usage guidelines, see Connection balancing mode.
Backends must use compatible balancing modes. Backends of a backend service may use different balancing modes. For more information, see Supported balancing modes and target capacity settings and Restrictions and guidance for instance groups.
Note: Currently, if you use the API to configure incompatible balancing modes, the configuration might be accepted even though it has no impact and is ignored. Specifically, Backend.maxUtilization is ignored when Backend.balancingMode is RATE. In the future, this incompatible combination will be rejected.
Constructors
- Backend_BalancingMode(String value)
-
const
- Backend_BalancingMode.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const Backend_BalancingMode
- The default value for Backend_BalancingMode.
- connection → const Backend_BalancingMode
- Balance based on the number of simultaneous connections.
- customMetrics → const Backend_BalancingMode
- Based on custom defined and reported metrics.
- inFlight → const Backend_BalancingMode
- Balance based on the number of in-flight requests.
- rate → const Backend_BalancingMode
- Balance based on requests per second (RPS).
- undefinedBalancingMode → const Backend_BalancingMode
- A value indicating that the enum field is not set.
- utilization → const Backend_BalancingMode
- Balance based on the backend utilization.