short constant
Backend_TrafficDuration
const short
Most requests are expected to finish with a sub-second latency.
Implementation
static const short = Backend_TrafficDuration('SHORT');
Most requests are expected to finish with a sub-second latency.
static const short = Backend_TrafficDuration('SHORT');