BfdPacket class final

Constructors

BfdPacket({bool? authenticationPresent, bool? controlPlaneIndependent, bool? demand, String? diagnostic, bool? final$, int? length, int? minEchoRxIntervalMs, int? minRxIntervalMs, int? minTxIntervalMs, int? multiplier, bool? multipoint, int? myDiscriminator, bool? poll, String? state, int? version, int? yourDiscriminator})
BfdPacket.fromJson(Object? j)
factory

Properties

authenticationPresent bool?
The Authentication Present bit of the BFD packet. This is specified in section 4.1 ofRFC5880
final
controlPlaneIndependent bool?
The Control Plane Independent bit of the BFD packet. This is specified in section 4.1 ofRFC5880
final
demand bool?
The demand bit of the BFD packet. This is specified in section 4.1 ofRFC5880
final
diagnostic String?
The diagnostic code specifies the local system's reason for the last change in session state. This allows remote systems to determine the reason that the previous session failed, for example. These diagnostic codes are specified in section 4.1 ofRFC5880 Check the Diagnostic enum for the list of possible values.
final
final$ bool?
The Final bit of the BFD packet. This is specified in section 4.1 ofRFC5880
final
hashCode int
The hash code for this object.
no setterinherited
length int?
The length of the BFD Control packet in bytes. This is specified in section 4.1 ofRFC5880
final
minEchoRxIntervalMs int?
The Required Min Echo RX Interval value in the BFD packet. This is specified in section 4.1 ofRFC5880
final
minRxIntervalMs int?
The Required Min RX Interval value in the BFD packet. This is specified in section 4.1 ofRFC5880
final
minTxIntervalMs int?
The Desired Min TX Interval value in the BFD packet. This is specified in section 4.1 ofRFC5880
final
multiplier int?
The detection time multiplier of the BFD packet. This is specified in section 4.1 ofRFC5880
final
multipoint bool?
The multipoint bit of the BFD packet. This is specified in section 4.1 ofRFC5880
final
myDiscriminator int?
The My Discriminator value in the BFD packet. This is specified in section 4.1 ofRFC5880
final
poll bool?
The Poll bit of the BFD packet. This is specified in section 4.1 ofRFC5880
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
The current BFD session state as seen by the transmitting system. These states are specified in section 4.1 ofRFC5880 Check the State enum for the list of possible values.
final
version int?
The version number of the BFD protocol, as specified in section 4.1 ofRFC5880.
final
yourDiscriminator int?
The Your Discriminator value in the BFD packet. This is specified in section 4.1 ofRFC5880
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String