toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (authenticationPresent != null)
      'authenticationPresent=$authenticationPresent',
    if (controlPlaneIndependent != null)
      'controlPlaneIndependent=$controlPlaneIndependent',
    if (demand != null) 'demand=$demand',
    if (diagnostic != null) 'diagnostic=$diagnostic',
    if (final$ != null) 'final=${final$}',
    if (length != null) 'length=$length',
    if (minEchoRxIntervalMs != null)
      'minEchoRxIntervalMs=$minEchoRxIntervalMs',
    if (minRxIntervalMs != null) 'minRxIntervalMs=$minRxIntervalMs',
    if (minTxIntervalMs != null) 'minTxIntervalMs=$minTxIntervalMs',
    if (multiplier != null) 'multiplier=$multiplier',
    if (multipoint != null) 'multipoint=$multipoint',
    if (myDiscriminator != null) 'myDiscriminator=$myDiscriminator',
    if (poll != null) 'poll=$poll',
    if (state != null) 'state=$state',
    if (version != null) 'version=$version',
    if (yourDiscriminator != null) 'yourDiscriminator=$yourDiscriminator',
  ].join(',');
  return 'BfdPacket(${$contents})';
}