BfdPacket_State class final

The current BFD session state as seen by the transmitting system. These states are specified in section 4.1 ofRFC5880

Constructors

BfdPacket_State(String value)
const
BfdPacket_State.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const BfdPacket_State
The default value for BfdPacket_State.
adminDown → const BfdPacket_State
down → const BfdPacket_State
init → const BfdPacket_State
stateUnspecified → const BfdPacket_State
undefinedState → const BfdPacket_State
A value indicating that the enum field is not set.
up → const BfdPacket_State