undefinedState constant
BfdPacket_State
const undefinedState
A value indicating that the enum field is not set.
Implementation
static const undefinedState = BfdPacket_State('UNDEFINED_STATE');
A value indicating that the enum field is not set.
static const undefinedState = BfdPacket_State('UNDEFINED_STATE');