localState property
The current BFD session state as seen by the transmitting system. These states are specified in section 4.1 ofRFC5880 Check the LocalState enum for the list of possible values.
Implementation
final String? localState;
The current BFD session state as seen by the transmitting system. These states are specified in section 4.1 ofRFC5880 Check the LocalState enum for the list of possible values.
final String? localState;