BfdStatusPacketCounts class final

Constructors

BfdStatusPacketCounts({int? numRx, int? numRxRejected, int? numRxSuccessful, int? numTx})
BfdStatusPacketCounts.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
numRx int?
Number of packets received since the beginning of the current BFD session.
final
numRxRejected int?
Number of packets received that were rejected because of errors since the beginning of the current BFD session.
final
numRxSuccessful int?
Number of packets received that were successfully processed since the beginning of the current BFD session.
final
numTx int?
Number of packets transmitted since the beginning of the current BFD session.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String