BfdStatus_BfdSessionInitializationMode class final
The BFD session initialization mode for this BGP peer. If set to ACTIVE, the Cloud Router will initiate the BFD session for this BGP peer. If set to PASSIVE, the Cloud Router will wait for the peer router to initiate the BFD session for this BGP peer. If set to DISABLED, BFD is disabled for this BGP peer.
Constructors
- BfdStatus_BfdSessionInitializationMode(String value)
-
const
- BfdStatus_BfdSessionInitializationMode.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const BfdStatus_BfdSessionInitializationMode
- The default value for BfdStatus_BfdSessionInitializationMode.
- active → const BfdStatus_BfdSessionInitializationMode
- disabled → const BfdStatus_BfdSessionInitializationMode
- passive → const BfdStatus_BfdSessionInitializationMode
- undefinedBfdSessionInitializationMode → const BfdStatus_BfdSessionInitializationMode
- A value indicating that the enum field is not set.