BfdStatus_LocalDiagnostic class final
The diagnostic code specifies the local system's reason for the last change in session state. This allows remote systems to determine the reason that the previous session failed, for example. These diagnostic codes are specified in section 4.1 ofRFC5880
Constructors
- BfdStatus_LocalDiagnostic(String value)
-
const
- BfdStatus_LocalDiagnostic.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const BfdStatus_LocalDiagnostic
- The default value for BfdStatus_LocalDiagnostic.
- administrativelyDown → const BfdStatus_LocalDiagnostic
- concatenatedPathDown → const BfdStatus_LocalDiagnostic
- controlDetectionTimeExpired → const BfdStatus_LocalDiagnostic
- diagnosticUnspecified → const BfdStatus_LocalDiagnostic
- echoFunctionFailed → const BfdStatus_LocalDiagnostic
- forwardingPlaneReset → const BfdStatus_LocalDiagnostic
- neighborSignaledSessionDown → const BfdStatus_LocalDiagnostic
- noDiagnostic → const BfdStatus_LocalDiagnostic
- pathDown → const BfdStatus_LocalDiagnostic
- reverseConcatenatedPathDown → const BfdStatus_LocalDiagnostic
- undefinedLocalDiagnostic → const BfdStatus_LocalDiagnostic
- A value indicating that the enum field is not set.