BfdStatus_LocalState class final

The current BFD session state as seen by the transmitting system. These states are specified in section 4.1 ofRFC5880

Constructors

BfdStatus_LocalState(String value)
const
BfdStatus_LocalState.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const BfdStatus_LocalState
The default value for BfdStatus_LocalState.
adminDown → const BfdStatus_LocalState
down → const BfdStatus_LocalState
init → const BfdStatus_LocalState
stateUnspecified → const BfdStatus_LocalState
undefinedLocalState → const BfdStatus_LocalState
A value indicating that the enum field is not set.
up → const BfdStatus_LocalState