origin property
Output only. Output only BGP origin (EGP, IGP or INCOMPLETE)
Check the Origin enum for the list of possible values.
Implementation
final String? origin;
Output only. Output only BGP origin (EGP, IGP or INCOMPLETE)
Check the Origin enum for the list of possible values.
final String? origin;