BgpRouteAsPath class
final
Properties
asns
→ List <int >
Output only. Output only ASNs in the path segment. When type is SEQUENCE, these are
ordered.
final
asns32
→ List <int >
Output only. Output only ASNs in the path segment. This field is for better
support of 32 bit ASNs as the other asns field suffers from overflow when
the ASN is larger. When type is SEQUENCE, these are ordered.
final
hashCode
→ int
The hash code for this object.
no setter inherited
qualifiedName
→ String
The fully qualified name of this message, i.e., google.protobuf.Duration
or google.rpc.ErrorInfo.
final inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
type
→ String ?
Output only. Output only Type of AS-PATH segment (SEQUENCE or SET)
Check the Type enum for the list of possible values.
final
google_cloud_compute_v1 0.1.1