BgpRoute_Origin class final

Output only. Output only BGP origin (EGP, IGP or INCOMPLETE)

Constructors

BgpRoute_Origin(String value)
const
BgpRoute_Origin.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const BgpRoute_Origin
The default value for BgpRoute_Origin.
bgpOriginEgp → const BgpRoute_Origin
bgpOriginIgp → const BgpRoute_Origin
bgpOriginIncomplete → const BgpRoute_Origin
undefinedOrigin → const BgpRoute_Origin
A value indicating that the enum field is not set.