minCount property

int? minCount
final

The minimum number of instances to create. If no min_count is specified then count is used as the default value. Ifmin_count instances cannot be created, then no instances will be created and instances already created will be deleted.

Implementation

final int? minCount;