BulkInsertOperationStatus class final

Constructors

BulkInsertOperationStatus({int? createdVmCount, int? deletedVmCount, int? failedToCreateVmCount, String? status, int? targetVmCount})
BulkInsertOperationStatus.fromJson(Object? j)
factory

Properties

createdVmCount int?
Output Only Count of VMs successfully created so far.
final
deletedVmCount int?
Output Only Count of VMs that got deleted during rollback.
final
failedToCreateVmCount int?
Output Only Count of VMs that started creating but encountered an error.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
Output Only Creation status of BulkInsert operation - information if the flow is rolling forward or rolling back. Check the Status enum for the list of possible values.
final
targetVmCount int?
Output Only Count of VMs originally planned to be created.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String