BundledLocalSsds class final

Constructors

BundledLocalSsds({String? defaultInterface, int? partitionCount})
BundledLocalSsds.fromJson(Object? j)
factory

Properties

defaultInterface String?
The default disk interface if the interface is not specified.
final
hashCode int
The hash code for this object.
no setterinherited
partitionCount int?
The number of partitions.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String