CacheInvalidationRule class
final
Properties
-
cacheTags
→ List<String>
-
A list of cache tags used to identify cached objects.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
host
→ String?
-
If set, this invalidation rule will only apply to requests with a Host
header matching host.
final
-
path
→ String?
-
final
-
qualifiedName
→ String
-
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or google.rpc.ErrorInfo.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited