host property
If set, this invalidation rule will only apply to requests with a Host header matching host.
Implementation
final String? host;
If set, this invalidation rule will only apply to requests with a Host header matching host.
final String? host;