includeQueryString property

bool? includeQueryString
final

If true, include query string parameters in the cache key according to query_string_whitelist and query_string_blacklist. If neither is set, the entire query string will be included. If false, the query string will be excluded from the cache key entirely.

Implementation

final bool? includeQueryString;