queryStringBlacklist property

List<String> queryStringBlacklist
final

Names of query string parameters to exclude in cache keys. All other parameters will be included. Either specify query_string_whitelist or query_string_blacklist, not both. '&' and '=' will be percent encoded and not treated as delimiters.

Implementation

final List<String> queryStringBlacklist;