queryStringWhitelist property

List<String> queryStringWhitelist
final

Names of query string parameters to include in cache keys. All other parameters will be excluded. Either specify query_string_whitelist or query_string_blacklist, not both. '&' and '=' will be percent encoded and not treated as delimiters.

Implementation

final List<String> queryStringWhitelist;