cacheMode property
Specifies the cache setting for all responses from this route. If not
specified, Cloud CDN uses CACHE_ALL_STATIC mode.
Check the CacheMode enum for the list of possible values.
Implementation
final String? cacheMode;
Specifies the cache setting for all responses from this route. If not
specified, Cloud CDN uses CACHE_ALL_STATIC mode.
Check the CacheMode enum for the list of possible values.
final String? cacheMode;