CachePolicyCacheKeyPolicy class final
Message containing what to include in the cache key for a request for Cache Policy defined on Route Action.
Constructors
-
CachePolicyCacheKeyPolicy({List<
String> excludedQueryParameters = const [], bool? includeHost, bool? includeProtocol, bool? includeQueryString, List<String> includedCookieNames = const [], List<String> includedHeaderNames = const [], List<String> includedQueryParameters = const []}) - CachePolicyCacheKeyPolicy.fromJson(Object? j)
-
factory
Properties
-
excludedQueryParameters
→ List<
String> -
Names of query string parameters to exclude in cache keys. All other
parameters will be included. Either specify
excludedQueryParametersorincludedQueryParameters, not both. '&' and '=' will be percent encoded and not treated as delimiters.final - hashCode → int
-
The hash code for this object.
no setterinherited
-
includedCookieNames
→ List<
String> -
Allows HTTP cookies (by name) to be used in the cache key.
The name=value pair will be used in the cache key Cloud CDN generates.
final
-
includedHeaderNames
→ List<
String> -
Allows HTTP request headers (by name) to be used in the cache key.
final
-
includedQueryParameters
→ List<
String> -
Names of query string parameters to include in cache keys. All other
parameters will be excluded. Either specify
includedQueryParametersorexcludedQueryParameters, not both. '&' and '=' will be percent encoded and not treated as delimiters.final - includeHost → bool?
-
If true, requests to different hosts will be cached separately.
final
- includeProtocol → bool?
-
If true, http and https requests will be cached separately.
final
- includeQueryString → bool?
-
If true, include query string parameters in the cache key according to
includedQueryParametersandexcludedQueryParameters. If neither is set, the entire query string will be included. If false, the query string will be excluded from the cache key entirely.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String