includedQueryParameters property

List<String> includedQueryParameters
final

Names of query string parameters to include in cache keys. All other parameters will be excluded. Either specify includedQueryParameters or excludedQueryParameters, not both. '&' and '=' will be percent encoded and not treated as delimiters.

Implementation

final List<String> includedQueryParameters;