CalendarModeAdviceRequest class final

A request to recommend the best way to consume the specified resources in the future.

Constructors

CalendarModeAdviceRequest({Map<String, FutureResourcesSpec> futureResourcesSpecs = const {}})
CalendarModeAdviceRequest.fromJson(Object? j)
factory

Properties

futureResourcesSpecs Map<String, FutureResourcesSpec>
Specification of resources to create in the future. The key of the map is an arbitrary string specified by the caller. Value of the map is a specification of required resources and their constraints. Currently only one value is allowed in this map.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String