recommendations property

List<CalendarModeRecommendation> recommendations
final

Recommendations where, how and when to create the requested resources in order to maximize their obtainability and minimize cost.

Implementation

final List<CalendarModeRecommendation> recommendations;