recommendationsPerSpec property

Map<String, FutureResourcesRecommendation> recommendationsPerSpec
final

Recommendations for every future resource specification passed in CalendarModeAdviceRequest. Keys of the map correspond to keys specified in the request.

Implementation

final Map<String, FutureResourcesRecommendation> recommendationsPerSpec;