CapacityAdviceRequest class final

A request to provide Assistant Scores. These scores determine VM obtainability and preemption likelihood.

Properties

distributionPolicy CapacityAdviceRequestDistributionPolicy?
Policy specifying the distribution of instances across zones within the requested region.
final
hashCode int
The hash code for this object.
no setterinherited
instanceFlexibilityPolicy CapacityAdviceRequestInstanceFlexibilityPolicy?
Policy for instance selectors.
final
instanceProperties CapacityAdviceRequestInstanceProperties?
Instance properties for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int?
The number of VM instances to request.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String