CapacityAdviceRequestDistributionPolicy class final
Distribution policy.
Constructors
-
CapacityAdviceRequestDistributionPolicy({String? targetShape, List<
CapacityAdviceRequestDistributionPolicyZoneConfiguration> zones = const []}) - CapacityAdviceRequestDistributionPolicy.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetShape → String?
-
Target distribution shape. You can specify the following values:ANY, ANY_SINGLE_ZONE, or BALANCED.
Check the TargetShape enum for the list of possible values.
final
-
zones
→ List<
CapacityAdviceRequestDistributionPolicyZoneConfiguration> -
Zones where Capacity Advisor looks for capacity.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String