CapacityAdviceRequestInstanceFlexibilityPolicy class final
Specification of alternative, flexible instance configurations.
Constructors
-
CapacityAdviceRequestInstanceFlexibilityPolicy({Map<
String, CapacityAdviceRequestInstanceFlexibilityPolicyInstanceSelection> instanceSelections = const {}}) - CapacityAdviceRequestInstanceFlexibilityPolicy.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
instanceSelections
→ Map<
String, CapacityAdviceRequestInstanceFlexibilityPolicyInstanceSelection> -
Named instance selections to configure properties.
The key is an arbitrary, unique RFC1035 string that identifies the
instance selection.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String