CapacityAdviceRequestInstanceFlexibilityPolicyInstanceSelection class final

Machine specification.

Properties

disks List<CapacityAdviceRequestInstanceFlexibilityPolicyInstanceSelectionAttachedDisk>
Local SSDs.
final
guestAccelerators List<AcceleratorConfig>
Accelerators configuration.
final
hashCode int
The hash code for this object.
no setterinherited
machineTypes List<String>
Full machine-type names, e.g. "n1-standard-16".
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String