CapacityAdviceRequestInstancePropertiesScheduling_ProvisioningModel class final

Specifies the provisioning model.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const CapacityAdviceRequestInstancePropertiesScheduling_ProvisioningModel
The default value for CapacityAdviceRequestInstancePropertiesScheduling_ProvisioningModel.
flexStart → const CapacityAdviceRequestInstancePropertiesScheduling_ProvisioningModel
Instance is provisioned using the Flex Start provisioning model and has a limited runtime.
reservationBound → const CapacityAdviceRequestInstancePropertiesScheduling_ProvisioningModel
Bound to the lifecycle of the reservation in which it is provisioned.
spot → const CapacityAdviceRequestInstancePropertiesScheduling_ProvisioningModel
Heavily discounted, no guaranteed runtime.
standard → const CapacityAdviceRequestInstancePropertiesScheduling_ProvisioningModel
Standard provisioning with user controlled runtime, no discounts.
undefinedProvisioningModel → const CapacityAdviceRequestInstancePropertiesScheduling_ProvisioningModel
A value indicating that the enum field is not set.