recommendations property
Initially the API will provide one recommendation which balances the individual scores according to the service provider's preference.
Implementation
final List<CapacityAdviceResponseRecommendation> recommendations;
Initially the API will provide one recommendation which balances the individual scores according to the service provider's preference.
final List<CapacityAdviceResponseRecommendation> recommendations;