provisioningModel property
The provisioning model that you want to view recommendations for. Check the ProvisioningModel enum for the list of possible values.
Implementation
final String? provisioningModel;
The provisioning model that you want to view recommendations for. Check the ProvisioningModel enum for the list of possible values.
final String? provisioningModel;