CapacityHistoryRequest class final

A request to get the capacity history.

Properties

hashCode int
The hash code for this object.
no setterinherited
instanceProperties CapacityHistoryRequestInstanceProperties?
Instance properties for this request.
final
locationPolicy CapacityHistoryRequestLocationPolicy?
Location policy for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
types List<String>
List of history types to get capacity history for. Check the Types enum for the list of possible values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String