CapacityHistoryResponse class final
Contains the capacity history.
Constructors
-
CapacityHistoryResponse({String? location, String? machineType, List<
CapacityHistoryResponsePreemptionRecord> preemptionHistory = const [], List<CapacityHistoryResponsePriceRecord> priceHistory = const []}) - CapacityHistoryResponse.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- location → String?
-
Output only. The location (region or zone) for which the capacity history is returned.
It is returned as a URL - For example,https://www.googleapis.com/compute/v1/projects/project/zones/zone.
final
- machineType → String?
-
The machine type for which the capacity history is returned.
final
-
preemptionHistory
→ List<
CapacityHistoryResponsePreemptionRecord> -
The preemption history for the requested machine type and location.
final
-
priceHistory
→ List<
CapacityHistoryResponsePriceRecord> -
The price history for the requested machine type and location.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String