preemptionHistory property
The preemption history for the requested machine type and location.
Implementation
final List<CapacityHistoryResponsePreemptionRecord> preemptionHistory;
The preemption history for the requested machine type and location.
final List<CapacityHistoryResponsePreemptionRecord> preemptionHistory;