priceHistory property
The price history for the requested machine type and location.
Implementation
final List<CapacityHistoryResponsePriceRecord> priceHistory;
The price history for the requested machine type and location.
final List<CapacityHistoryResponsePriceRecord> priceHistory;