maxPendingRequests property

int? maxPendingRequests
final

The maximum number of pending requests allowed to the backend service. If not specified, there is no limit.

Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true.

Implementation

final int? maxPendingRequests;