maxRequests property
The maximum number of parallel requests that allowed to the backend service. If not specified, there is no limit.
Implementation
final int? maxRequests;
The maximum number of parallel requests that allowed to the backend service. If not specified, there is no limit.
final int? maxRequests;