maxRetries property
The maximum number of parallel retries allowed to the backend cluster. If not specified, the default is 1.
Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true.
Implementation
final int? maxRetries;