customEndTimestamp property

String? customEndTimestamp
final

Input Only Optional, specifies the requested commitment end time inRFC3339 text format. Use this option when the desired commitment's end date is later than the start date + term duration.

Implementation

final String? customEndTimestamp;