description property
An optional description of the commitment. You can provide this property when you create the resource.
Implementation
final String? description;
An optional description of the commitment. You can provide this property when you create the resource.
final String? description;