params property
Input only. Additional params passed with the request, but not persisted as part of resource payload.
Implementation
final CommitmentParams? params;
Input only. Additional params passed with the request, but not persisted as part of resource payload.
final CommitmentParams? params;