region property
Output only. Output Only URL of the region where the commitment and committed
resources are located.
Implementation
final String? region;
Output only. Output Only URL of the region where the commitment and committed
resources are located.
final String? region;