resources property

List<ResourceCommitment> resources
final

The list of all the hardware resources, with their types and amounts, that you want to commit to. Specify as a separate entry in the list for each individual resource type.

Implementation

final List<ResourceCommitment> resources;