toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (autoRenew != null) 'autoRenew=$autoRenew',
    if (category != null) 'category=$category',
    if (creationTimestamp != null) 'creationTimestamp=$creationTimestamp',
    if (customEndTimestamp != null) 'customEndTimestamp=$customEndTimestamp',
    if (description != null) 'description=$description',
    if (endTimestamp != null) 'endTimestamp=$endTimestamp',
    if (id != null) 'id=$id',
    if (kind != null) 'kind=$kind',
    if (name != null) 'name=$name',
    if (plan != null) 'plan=$plan',
    if (region != null) 'region=$region',
    if (selfLink != null) 'selfLink=$selfLink',
    if (splitSourceCommitment != null)
      'splitSourceCommitment=$splitSourceCommitment',
    if (startTimestamp != null) 'startTimestamp=$startTimestamp',
    if (status != null) 'status=$status',
    if (statusMessage != null) 'statusMessage=$statusMessage',
    if (type != null) 'type=$type',
  ].join(',');
  return 'Commitment(${$contents})';
}