undefinedPlan constant
Commitment_Plan
const undefinedPlan
A value indicating that the enum field is not set.
Implementation
static const undefinedPlan = Commitment_Plan('UNDEFINED_PLAN');
A value indicating that the enum field is not set.
static const undefinedPlan = Commitment_Plan('UNDEFINED_PLAN');