Commitment_Status class final

Output only. Output Only Status of the commitment with regards to eventual expiration (each commitment has an end date defined). Status can be one of the following values: NOT_YET_ACTIVE, ACTIVE, orEXPIRED.

Constructors

Commitment_Status(String value)
const
Commitment_Status.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const Commitment_Status
The default value for Commitment_Status.
active → const Commitment_Status
cancelled → const Commitment_Status
Deprecate CANCELED status. Will use separate status to differentiate cancel by mergeCud or manual cancellation.
creating → const Commitment_Status
expired → const Commitment_Status
notYetActive → const Commitment_Status
undefinedStatus → const Commitment_Status
A value indicating that the enum field is not set.