CompositeHealthCheck class final
Represents a composite health check.
A composite health check resource specifies the health source resources and the health destination resource to which the aggregated health result from the health source resources is delivered.
Constructors
-
CompositeHealthCheck({String? creationTimestamp, String? description, String? fingerprint, String? healthDestination, List<
String> healthSources = const [], BigInt? id, String? kind, String? name, String? region, String? selfLink, String? selfLinkWithId}) - CompositeHealthCheck.fromJson(Object? j)
-
factory
Properties
- creationTimestamp → String?
-
Output only.
Output OnlyCreation timestamp inRFC3339 text format.final - description → String?
-
An optional description of this resource. Provide this property when you
create the resource.
final
- fingerprint → String?
-
Fingerprint of this resource. A hash of the contents stored in this object.
This field is used in optimistic locking. This field will be ignored when
inserting a CompositeHealthCheck. An up-to-date fingerprint
must be provided in order to patch the CompositeHealthCheck; Otherwise,
the request will fail with error 412 conditionNotMet. To see
the latest fingerprint, make a get() request to retrieve the
CompositeHealthCheck.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- healthDestination → String?
-
URL to the destination resource. Must be set. Must be aForwardingRule. The ForwardingRule must have
load balancing scheme INTERNAL orINTERNAL_MANAGED and must be regional and in the same region
as the CompositeHealthCheck (cross-region deployment forINTERNAL_MANAGED is not supported). Can be mutated.
final
-
healthSources
→ List<
String> -
URLs to the HealthSource resources whose results are AND'ed.
I.e. he aggregated result is is HEALTHY only if all sources
are HEALTHY. Must have at least 1. Must not have more than 10.
Must be regional and in the same region as theCompositeHealthCheck. Can be mutated.
final
- id → BigInt?
-
Output only.
Output OnlyA unique identifier for this resource type. The server generates this identifier.final - kind → String?
-
Output only.
Output OnlyType of the resource. Alwayscompute#compositeHealthCheck for composite health checks.final - name → String?
-
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression
[a-z]([-a-z0-9]*[a-z0-9])?which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - region → String?
-
Output only.
Output OnlyURL of the region where the composite health check resides. This field applies only to the regional resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfLink → String?
-
Output only.
Output OnlyServer-defined URL for the resource.final - selfLinkWithId → String?
-
Output only.
Output OnlyServer-defined URL with id for the resource.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String