id property
Output only. Output Only A unique identifier for this resource type. The server
generates this identifier.
Implementation
final BigInt? id;
Output only. Output Only A unique identifier for this resource type. The server
generates this identifier.
final BigInt? id;