CompositeHealthCheckHealth class final

Response message for RegionCompositeHealthChecks.GetHealth

Properties

hashCode int
The hash code for this object.
no setterinherited
healthSources List<CompositeHealthChecksGetHealthResponseHealthSourceHealth>
Health sources and their corresponding health states.
final
healthState String?
Health state of the CompositeHealthCheck. Check the HealthState enum for the list of possible values.
final
kind String?
Output only. Output Only Type of resource. Alwayscompute#compositeHealthCheckHealth for the health of composite health checks.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String