CompositeHealthChecksGetHealthResponseHealthSourceHealth class final

Properties

hashCode int
The hash code for this object.
no setterinherited
healthState String?
Health state of the associated HealthSource resource. Check the HealthState enum for the list of possible values.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String?
Fully qualified URL of the associated HealthSource resource.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String