ConfidentialInstanceConfig class final

A set of Confidential Instance options.

Constructors

ConfidentialInstanceConfig({String? confidentialInstanceType, bool? enableConfidentialCompute})
ConfidentialInstanceConfig.fromJson(Object? j)
factory

Properties

confidentialInstanceType String?
Defines the type of technology used by the confidential instance. Check the ConfidentialInstanceType enum for the list of possible values.
final
enableConfidentialCompute bool?
Defines whether the instance should have confidential compute enabled.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String