enableConfidentialCompute property
Defines whether the instance should have confidential compute enabled.
Implementation
final bool? enableConfidentialCompute;
Defines whether the instance should have confidential compute enabled.
final bool? enableConfidentialCompute;