httpHeaderName property
The hash based on the value of the specified header field. This field is applicable if the sessionAffinity is set toHEADER_FIELD.
Implementation
final String? httpHeaderName;
The hash based on the value of the specified header field. This field is applicable if the sessionAffinity is set toHEADER_FIELD.
final String? httpHeaderName;