disabled property
If true, disables the CORS policy. The default value is false, which indicates that the CORS policy is in effect.
Implementation
final bool? disabled;
If true, disables the CORS policy. The default value is false, which indicates that the CORS policy is in effect.
final bool? disabled;