maxAge property
Specifies how long results of a preflight request can be cached in seconds. This field translates to the Access-Control-Max-Age header.
Implementation
final int? maxAge;
Specifies how long results of a preflight request can be cached in seconds. This field translates to the Access-Control-Max-Age header.
final int? maxAge;