region property
The name of theregion where the managed instance group is located. It should conform to RFC1035.
Implementation
final String region;
The name of theregion where the managed instance group is located. It should conform to RFC1035.
final String region;