CreateSnapshotDiskRequest class final

A request message for Disks.CreateSnapshot. See the method description for details.

Constructors

CreateSnapshotDiskRequest({required String disk, bool? guestFlush, required String project, String? requestId, required Snapshot? snapshotResource, required String zone})
CreateSnapshotDiskRequest.fromJson(Object? j)
factory

Properties

disk String
Name of the persistent disk to snapshot.
final
guestFlush bool?
Input Only Whether to attempt an application consistent snapshot by informing the OS to prepare for the snapshot process.
final
hashCode int
The hash code for this object.
no setterinherited
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requestId String?
An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snapshotResource Snapshot?
The body resource for this request
final
zone String
The name of the zone for this request.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String