list method

Lists the cross-site networks for a project in the given scope.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<CrossSiteNetworkList> list(
  ListCrossSiteNetworksRequest request,
) async {
  final url = _endPoint.replace(
    path: '/compute/v1/projects/${request.project}/global/crossSiteNetworks',
    queryParameters: {
      'filter': ?request.filter,
      if (request.maxResults case final $1?) 'maxResults': '${$1}',
      'orderBy': ?request.orderBy,
      'pageToken': ?request.pageToken,
      if (request.returnPartialSuccess case final $1?)
        'returnPartialSuccess': '${$1}',
    },
  );
  final response = await _client.get(url);
  return CrossSiteNetworkList.fromJson(response);
}