CustomErrorResponsePolicy class final

Specifies the custom error response policy that must be applied when the backend service or backend bucket responds with an error.

Properties

errorResponseRules List<CustomErrorResponsePolicyCustomErrorResponseRule>
Specifies rules for returning error responses.
final
errorService String?
The full or partial URL to the BackendBucket resource that contains the custom error content. Examples are:
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String