errorResponseRules property

Specifies rules for returning error responses.

In a given policy, if you specify rules for both a range of error codes as well as rules for specific error codes then rules with specific error codes have a higher priority. For example, assume that you configure a rule for 401 (Un-authorized) code, and another for all 4 series error codes (4XX). If the backend service returns a401, then the rule for 401 will be applied. However if the backend service returns a 403, the rule for4xx takes effect.

Implementation

final List<CustomErrorResponsePolicyCustomErrorResponseRule>
errorResponseRules;