CustomerEncryptionKey class final

Constructors

CustomerEncryptionKey({String? kmsKeyName, String? kmsKeyServiceAccount, String? rawKey, String? rsaEncryptedKey, String? sha256})
CustomerEncryptionKey.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
kmsKeyName String?
The name of the encryption key that is stored in Google Cloud KMS. For example:
final
kmsKeyServiceAccount String?
The service account being used for the encryption request for the given KMS key. If absent, the Compute Engine default service account is used. For example:
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
rawKey String?
DEPRECATED CSEK is no longer supported. Use CMEK instead. Specifies a 256-bit customer-supplied encryption key, encoded in RFC 4648 base64 to either encrypt or decrypt this resource. You can provide either the rawKey or thersaEncryptedKey. For example:
final
rsaEncryptedKey String?
DEPRECATED CSEK is no longer supported. Use CMEK instead. Specifies an RFC 4648 base64 encoded, RSA-wrapped 2048-bit customer-supplied encryption key to either encrypt or decrypt this resource. You can provide either the rawKey or thersaEncryptedKey. For example:
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sha256 String?
DEPRECATED CSEK is no longer supported. Use CMEK instead. Output only TheRFC 4648 base64 encoded SHA-256 hash of the customer-supplied encryption key that protects this resource.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String