kmsKeyServiceAccount property

String? kmsKeyServiceAccount
final

The service account being used for the encryption request for the given KMS key. If absent, the Compute Engine default service account is used. For example:

"kmsKeyServiceAccount": "name@project_id.iam.gserviceaccount.com/

Implementation

final String? kmsKeyServiceAccount;