CustomerEncryptionKeyProtectedDisk class final

Properties

diskEncryptionKey CustomerEncryptionKey?
Decrypts data associated with the disk with acustomer-supplied encryption key.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String?
Specifies a valid partial or full URL to an existing Persistent Disk resource. This field is only applicable for persistent disks. For example:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String