networkInterfaceName property
The name of the dynamic network interface to be deleted from the instance.
Implementation
final String networkInterfaceName;
The name of the dynamic network interface to be deleted from the instance.
final String networkInterfaceName;