DeleteNodesNodeGroupRequest class final
A request message for NodeGroups.DeleteNodes. See the method description for details.
Constructors
- DeleteNodesNodeGroupRequest({required String nodeGroup, required NodeGroupsDeleteNodesRequest? nodeGroupsDeleteNodesRequestResource, required String project, String? requestId, required String zone})
- DeleteNodesNodeGroupRequest.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- nodeGroup → String
-
Name of the NodeGroup resource whose nodes will be deleted.
final
- nodeGroupsDeleteNodesRequestResource → NodeGroupsDeleteNodesRequest?
-
The body resource for this request
final
- project → String
-
Project ID for this request.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - requestId → String?
-
An optional request ID to identify requests. Specify a unique request ID so
that if you must retry your request, the server will know to ignore the
request if it has already been completed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- zone → String
-
The name of the zone for this request.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String