DeletePerInstanceConfigsRegionInstanceGroupManagerRequest class final

A request message for RegionInstanceGroupManagers.DeletePerInstanceConfigs. See the method description for details.

Constructors

DeletePerInstanceConfigsRegionInstanceGroupManagerRequest({required String instanceGroupManager, required String project, required String region, required RegionInstanceGroupManagerDeleteInstanceConfigReq? regionInstanceGroupManagerDeleteInstanceConfigReqResource})
DeletePerInstanceConfigsRegionInstanceGroupManagerRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
instanceGroupManager String
The name of the managed instance group. It should conform to RFC1035.
final
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
region String
Name of the region scoping this request, should conform to RFC1035.
final
regionInstanceGroupManagerDeleteInstanceConfigReqResource RegionInstanceGroupManagerDeleteInstanceConfigReq?
The body resource for this request
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String