region property
The name of the region where the network endpoint group is located. It should comply with RFC1035.
Implementation
final String region;
The name of the region where the network endpoint group is located. It should comply with RFC1035.
final String region;