DeleteSignedUrlKeyBackendBucketRequest class final

A request message for BackendBuckets.DeleteSignedUrlKey. See the method description for details.

Constructors

DeleteSignedUrlKeyBackendBucketRequest({required String backendBucket, required String keyName, required String project, String? requestId})
DeleteSignedUrlKeyBackendBucketRequest.fromJson(Object? j)
factory

Properties

backendBucket String
Name of the BackendBucket resource to which the Signed URL Key should be added. The name should conform to RFC1035.
final
hashCode int
The hash code for this object.
no setterinherited
keyName String
The name of the Signed URL Key to delete.
final
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requestId String?
An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String