DeleteZoneOperationRequest class final

A request message for ZoneOperations.Delete. See the method description for details.

Constructors

DeleteZoneOperationRequest({required String operation, required String project, required String zone})
DeleteZoneOperationRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
operation String
Name of the Operations resource to delete, or its unique numeric identifier.
final
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zone String
Name of the zone for this request.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String