deviceName property
The device name of the disk to detach. Make a get() request on the instance to view currently attached disks and device names.
Implementation
final String deviceName;
The device name of the disk to detach. Make a get() request on the instance to view currently attached disks and device names.
final String deviceName;