networkEndpointGroup property
The name of the network endpoint group where you are removing network endpoints. It should comply with RFC1035.
Implementation
final String networkEndpointGroup;
The name of the network endpoint group where you are removing network endpoints. It should comply with RFC1035.
final String networkEndpointGroup;