networkEndpointGroup property
The name of the network endpoint group you are detaching network endpoints from. It should comply with RFC1035.
Implementation
final String networkEndpointGroup;
The name of the network endpoint group you are detaching network endpoints from. It should comply with RFC1035.
final String networkEndpointGroup;