asyncSecondaryDisks property
Output only. Output Only A list of disks this disk is asynchronously replicated to.
Implementation
final Map<String, DiskAsyncReplicationList> asyncSecondaryDisks;
Output only. Output Only A list of disks this disk is asynchronously replicated to.
final Map<String, DiskAsyncReplicationList> asyncSecondaryDisks;