locationHint property

String? locationHint
final

An opaque location hint used to place the disk close to other resources. This field is for use by internal tools that use the public API.

Implementation

final String? locationHint;