sizeGb property

int? sizeGb
final

Size, in GB, of the persistent disk. You can specify this field when creating a persistent disk using thesourceImage, sourceSnapshot, orsourceDisk parameter, or specify it alone to create an empty persistent disk.

If you specify this field along with a source, the value ofsizeGb must not be less than the size of the source. Acceptable values are greater than 0.

Implementation

final int? sizeGb;