sourceDiskId property
Output only. Output Only The unique ID of the disk used to create this disk. This
value identifies the exact disk that was used to create this persistent
disk. For example, if you created the persistent disk from a disk that
was later deleted and recreated under the same name, the source disk ID
would identify the exact version of the disk that was used.
Implementation
final String? sourceDiskId;