sourceImageId property
Output only. Output Only The ID value of the image used to create this disk. This
value identifies the exact image that was used to create this persistent
disk. For example, if you created the persistent disk from an image that
was later deleted and recreated under the same name, the source image ID
would identify the exact version of the image that was used.
Implementation
final String? sourceImageId;