sourceInstantSnapshotId property
Output only. Output Only The unique ID of the instant snapshot used to create this
disk. This value identifies the exact instant snapshot that was used to
create this persistent disk. For example, if you created the persistent
disk from an instant snapshot that was later deleted and recreated under
the same name, the source instant snapshot ID would identify the exact
version of the instant snapshot that was used.
Implementation
final String? sourceInstantSnapshotId;