sourceSnapshotId property
Output only. Output Only The unique ID of the snapshot used to create this disk. This
value identifies the exact snapshot that was used to create this persistent
disk. For example, if you created the persistent disk from a snapshot that
was later deleted and recreated under the same name, the source snapshot ID
would identify the exact version of the snapshot that was used.
Implementation
final String? sourceSnapshotId;