toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (accessMode != null) 'accessMode=$accessMode',
    if (architecture != null) 'architecture=$architecture',
    if (creationTimestamp != null) 'creationTimestamp=$creationTimestamp',
    if (description != null) 'description=$description',
    if (enableConfidentialCompute != null)
      'enableConfidentialCompute=$enableConfidentialCompute',
    if (id != null) 'id=$id',
    if (kind != null) 'kind=$kind',
    if (labelFingerprint != null) 'labelFingerprint=$labelFingerprint',
    if (lastAttachTimestamp != null)
      'lastAttachTimestamp=$lastAttachTimestamp',
    if (lastDetachTimestamp != null)
      'lastDetachTimestamp=$lastDetachTimestamp',
    if (locationHint != null) 'locationHint=$locationHint',
    if (name != null) 'name=$name',
    if (options != null) 'options=$options',
    if (physicalBlockSizeBytes != null)
      'physicalBlockSizeBytes=$physicalBlockSizeBytes',
    if (provisionedIops != null) 'provisionedIops=$provisionedIops',
    if (provisionedThroughput != null)
      'provisionedThroughput=$provisionedThroughput',
    if (region != null) 'region=$region',
    if (satisfiesPzi != null) 'satisfiesPzi=$satisfiesPzi',
    if (satisfiesPzs != null) 'satisfiesPzs=$satisfiesPzs',
    if (selfLink != null) 'selfLink=$selfLink',
    if (sizeGb != null) 'sizeGb=$sizeGb',
    if (sourceConsistencyGroupPolicy != null)
      'sourceConsistencyGroupPolicy=$sourceConsistencyGroupPolicy',
    if (sourceConsistencyGroupPolicyId != null)
      'sourceConsistencyGroupPolicyId=$sourceConsistencyGroupPolicyId',
    if (sourceDisk != null) 'sourceDisk=$sourceDisk',
    if (sourceDiskId != null) 'sourceDiskId=$sourceDiskId',
    if (sourceImage != null) 'sourceImage=$sourceImage',
    if (sourceImageId != null) 'sourceImageId=$sourceImageId',
    if (sourceInstantSnapshot != null)
      'sourceInstantSnapshot=$sourceInstantSnapshot',
    if (sourceInstantSnapshotId != null)
      'sourceInstantSnapshotId=$sourceInstantSnapshotId',
    if (sourceSnapshot != null) 'sourceSnapshot=$sourceSnapshot',
    if (sourceSnapshotId != null) 'sourceSnapshotId=$sourceSnapshotId',
    if (sourceStorageObject != null)
      'sourceStorageObject=$sourceStorageObject',
    if (status != null) 'status=$status',
    if (storagePool != null) 'storagePool=$storagePool',
    if (type != null) 'type=$type',
    if (zone != null) 'zone=$zone',
  ].join(',');
  return 'Disk(${$contents})';
}