DiskAsyncReplication class final

Constructors

DiskAsyncReplication({String? consistencyGroupPolicy, String? consistencyGroupPolicyId, String? disk, String? diskId})
DiskAsyncReplication.fromJson(Object? j)
factory

Properties

consistencyGroupPolicy String?
Output only. Output Only URL of the DiskConsistencyGroupPolicy if replication was started on the disk as a member of a group.
final
consistencyGroupPolicyId String?
Output only. Output Only ID of the DiskConsistencyGroupPolicy if replication was started on the disk as a member of a group.
final
disk String?
The other disk asynchronously replicated to or from the current disk. You can provide this as a partial or full URL to the resource. For example, the following are valid values:
final
diskId String?
Output only. Output Only The unique ID of the other disk asynchronously replicated to or from the current disk. This value identifies the exact disk that was used to create this replication. For example, if you started replicating the persistent disk from a disk that was later deleted and recreated under the same name, the disk ID would identify the exact version of the disk that was used.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String