consistencyGroupPolicy property
Output only. Output Only URL of the DiskConsistencyGroupPolicy if replication was
started on the disk as a member of a group.
Implementation
final String? consistencyGroupPolicy;
Output only. Output Only URL of the DiskConsistencyGroupPolicy if replication was
started on the disk as a member of a group.
final String? consistencyGroupPolicy;