consistencyGroupPolicyId property
Output only. Output Only ID of the DiskConsistencyGroupPolicy if replication was
started on the disk as a member of a group.
Implementation
final String? consistencyGroupPolicyId;
Output only. Output Only ID of the DiskConsistencyGroupPolicy if replication was
started on the disk as a member of a group.
final String? consistencyGroupPolicyId;