disk property

String? disk
final

The other disk asynchronously replicated to or from the current disk. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

 - https://www.googleapis.com/compute/v1/projects/project/zones/zone/disks/disk
  • projects/project/zones/zone/disks/disk
  • zones/zone/disks/disk

Implementation

final String? disk;