DiskInstantiationConfig class final

A specification of the desired way to instantiate a disk in the instance template when its created from a source instance.

Constructors

DiskInstantiationConfig({bool? autoDelete, String? customImage, String? deviceName, String? instantiateFrom})
DiskInstantiationConfig.fromJson(Object? j)
factory

Properties

autoDelete bool?
Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance).
final
customImage String?
The custom source image to be used to restore this disk when instantiating this instance template.
final
deviceName String?
Specifies the device name of the disk to which the configurations apply to.
final
hashCode int
The hash code for this object.
no setterinherited
instantiateFrom String?
Specifies whether to include the disk and what image to use. Possible values are:
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String