customImage property
The custom source image to be used to restore this disk when instantiating this instance template.
Implementation
final String? customImage;
The custom source image to be used to restore this disk when instantiating this instance template.
final String? customImage;