Disk_AccessMode class final

The access mode of the disk.

 - READ_WRITE_SINGLE: The default AccessMode, means the
 disk can be attached to single instance in RW mode.
 - READ_WRITE_MANY: The AccessMode means the disk can be
 attached to multiple instances in RW mode.
 - READ_ONLY_MANY: The AccessMode means the disk can be
 attached to multiple instances in RO mode.

The AccessMode is only valid for Hyperdisk disk types.

Constructors

Disk_AccessMode(String value)
const
Disk_AccessMode.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const Disk_AccessMode
The default value for Disk_AccessMode.
readOnlyMany → const Disk_AccessMode
The AccessMode means the disk can be attached to multiple instances in RO mode.
readWriteMany → const Disk_AccessMode
The AccessMode means the disk can be attached to multiple instances in RW mode.
readWriteSingle → const Disk_AccessMode
The default AccessMode, means the disk can be attached to single instance in RW mode.
undefinedAccessMode → const Disk_AccessMode
A value indicating that the enum field is not set.