Disk_Status class final

Output only. Output Only The status of disk creation.

 - CREATING: Disk is provisioning.
 - RESTORING: Source data is being copied into the
 disk.
 - FAILED: Disk creation failed.
 - READY: Disk is ready for use.
 - DELETING: Disk is deleting.

Constructors

Disk_Status(String value)
const
Disk_Status.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const Disk_Status
The default value for Disk_Status.
creating → const Disk_Status
Disk is provisioning
deleting → const Disk_Status
Disk is deleting.
failed → const Disk_Status
Disk creation failed.
ready → const Disk_Status
Disk is ready for use.
restoring → const Disk_Status
Source data is being copied into the disk.
unavailable → const Disk_Status
Disk is currently unavailable and cannot be accessed, attached or detached.
undefinedStatus → const Disk_Status
A value indicating that the enum field is not set.