delete method

Future<Operation> delete(
  1. DeleteDiskRequest request
)

Deletes the specified persistent disk. Deleting a disk removes its data permanently and is irreversible. However, deleting a disk does not delete any snapshots previously made from the disk. You must separatelydelete snapshots.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> delete(DeleteDiskRequest request) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/zones/${request.zone}/disks/${request.disk}',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.delete(url);
  return Operation.fromJson(response);
}