resize method

Future<Operation> resize(
  1. ResizeDiskRequest request
)

Resizes the specified persistent disk. You can only increase the size of the disk.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> resize(ResizeDiskRequest request) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/zones/${request.zone}/disks/${request.disk}/resize',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.post(
    url,
    body: request.disksResizeRequestResource,
  );
  return Operation.fromJson(response);
}