stopAsyncReplication method

Future<Operation> stopAsyncReplication(
  1. StopAsyncReplicationDiskRequest request
)

Stops asynchronous replication. Can be invoked either on the primary or on the secondary disk.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> stopAsyncReplication(
  StopAsyncReplicationDiskRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/zones/${request.zone}/disks/${request.disk}/stopAsyncReplication',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.post(url);
  return Operation.fromJson(response);
}