update method

Future<Operation> update(
  1. UpdateDiskRequest request
)

Updates the specified disk with the data included in the request. The update is performed only on selected fields included as part of update-mask.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> update(UpdateDiskRequest request) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/zones/${request.zone}/disks/${request.disk}',
    queryParameters: {
      'paths': ?request.paths,
      'requestId': ?request.requestId,
      'updateMask': ?request.updateMask,
    },
  );
  final response = await _client.patch(url, body: request.diskResource);
  return Operation.fromJson(response);
}