updateKmsKey method

Future<Operation> updateKmsKey(
  1. UpdateKmsKeyDiskRequest request
)

Rotates the customer-managed encryption key to the latest version for the specified persistent disk.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> updateKmsKey(UpdateKmsKeyDiskRequest request) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/zones/${request.zone}/disks/${request.disk}/updateKmsKey',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.post(
    url,
    body: request.diskUpdateKmsKeyRequestResource,
  );
  return Operation.fromJson(response);
}