DisksAddResourcePoliciesRequest class final

Constructors

DisksAddResourcePoliciesRequest({List<String> resourcePolicies = const []})
DisksAddResourcePoliciesRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
resourcePolicies List<String>
Full or relative path to the resource policy to be added to this disk. You can only specify one resource policy.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String