anySingleZone constant

DistributionPolicy_TargetShape const anySingleZone

The group creates all VM instances within a single zone. The zone is selected based on the present resource constraints and to maximize utilization of unused zonal reservations. Recommended for batch workloads with heavy interprocess communication.

Implementation

static const anySingleZone = DistributionPolicy_TargetShape(
  'ANY_SINGLE_ZONE',
);