ErrorDetails class final
Container for structured error details providing additional context specific to the encountered error code.
Constructors
- ErrorDetails({ErrorInfo? errorInfo, Help? help, LocalizedMessage? localizedMessage, QuotaExceededInfo? quotaInfo})
- ErrorDetails.fromJson(Object? j)
-
factory
Properties
- errorInfo → ErrorInfo?
-
Error information containing structured domain, reason, and metadata.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- help → Help?
-
Links and information to help the user resolve the error.
final
- localizedMessage → LocalizedMessage?
-
A localized human-readable error message intended for end users.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - quotaInfo → QuotaExceededInfo?
-
Details about quota limits and metrics when a quota is exceeded.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String