True if the peering route has been imported from a peer. The actual import
happens if the field networkPeering.importCustomRoutes is true
for this network, and networkPeering.exportCustomRoutes is
true for the peer network, and the import does not result in a route
conflict.