location property

String? location
final

Optional. String indicating the location of the expression for error reporting, e.g. a file name and a position in the file.

Implementation

final String? location;