ExternalVpnGateway class final

Represents an external VPN gateway.

External VPN gateway is the on-premises VPN gateway(s) or another cloud provider's VPN gateway that connects to your Google Cloud VPN gateway.

To create a highly available VPN from Google Cloud Platform to your VPN gateway or another cloud provider's VPN gateway, you must create a external VPN gateway resource with information about the other gateway.

For more information about using external VPN gateways, see Creating an HA VPN gateway and tunnel pair to a peer VPN.

Constructors

ExternalVpnGateway({String? creationTimestamp, String? description, BigInt? id, List<ExternalVpnGatewayInterface> interfaces = const [], String? kind, String? labelFingerprint, Map<String, String> labels = const {}, String? name, ExternalVpnGatewayParams? params, String? redundancyType, String? selfLink})
ExternalVpnGateway.fromJson(Object? j)
factory

Properties

creationTimestamp String?
Output only. Output Only Creation timestamp inRFC3339 text format.
final
description String?
An optional description of this resource. Provide this property when you create the resource.
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output only. Output Only The unique identifier for the resource. This identifier is defined by the server.
final
interfaces List<ExternalVpnGatewayInterface>
A list of interfaces for this external VPN gateway.
final
kind String?
Output only. Output Only Type of the resource. Alwayscompute#externalVpnGateway for externalVpnGateways.
final
labelFingerprint String?
A fingerprint for the labels being applied to this ExternalVpnGateway, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet.
final
labels Map<String, String>
Labels for this resource. These can only be added or modified by thesetLabels method. Each label key/value pair must comply withRFC1035. Label values may be empty.
final
name String?
Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
params ExternalVpnGatewayParams?
Input only. Input Only Additional params passed with the request, but not persisted as part of resource payload.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
redundancyType String?
Indicates the user-supplied redundancy type of this external VPN gateway. Check the RedundancyType enum for the list of possible values.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output only. Output Only Server-defined URL for the resource.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String