FirewallLogConfig class final
The available logging options for a firewall rule.
Constructors
- FirewallLogConfig({bool? enable, String? metadata})
- FirewallLogConfig.fromJson(Object? j)
-
factory
Properties
- enable → bool?
-
This field denotes whether to enable logging for a particular firewall
rule.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- metadata → String?
-
This field can only be specified for a particular firewall rule if
logging is enabled for that rule. This field denotes whether to include
or exclude metadata for firewall logs.
Check the Metadata enum for the list of possible values.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String