metadata property

String? metadata
final

This field can only be specified for a particular firewall rule if logging is enabled for that rule. This field denotes whether to include or exclude metadata for firewall logs. Check the Metadata enum for the list of possible values.

Implementation

final String? metadata;