FirewallPolicies class final

The FirewallPolicies API.

Implementers

Constructors

FirewallPolicies({required Client client, Uri? endPoint, String? gcclVersion})
Creates a FirewallPolicies using client for transport.
FirewallPolicies.fromApiKey([String? apiKey])
Creates a FirewallPolicies that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addAssociation(AddAssociationFirewallPolicyRequest request) Future<Operation>
Inserts an association for the specified firewall policy.
addRule(AddRuleFirewallPolicyRequest request) Future<Operation>
Inserts a rule into a firewall policy.
cloneRules(CloneRulesFirewallPolicyRequest request) Future<Operation>
Copies rules to the specified firewall policy.
close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteFirewallPolicyRequest request) Future<Operation>
Deletes the specified policy.
get(GetFirewallPolicyRequest request) Future<FirewallPolicy>
Returns the specified firewall policy.
getAssociation(GetAssociationFirewallPolicyRequest request) Future<FirewallPolicyAssociation>
Gets an association with the specified name.
getIamPolicy(GetIamPolicyFirewallPolicyRequest request) Future<Policy>
Gets the access control policy for a resource. May be empty if no such policy or resource exists.
getRule(GetRuleFirewallPolicyRequest request) Future<FirewallPolicyRule>
Gets a rule of the specified priority.
insert(InsertFirewallPolicyRequest request) Future<Operation>
Creates a new policy in the specified project using the data included in the request.
list(ListFirewallPoliciesRequest request) Future<FirewallPolicyList>
Lists all the policies that have been configured for the specified folder or organization.
listAssociations(ListAssociationsFirewallPolicyRequest request) Future<FirewallPoliciesListAssociationsResponse>
Lists associations of a specified target, i.e., organization or folder.
move(MoveFirewallPolicyRequest request) Future<Operation>
Moves the specified firewall policy.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(PatchFirewallPolicyRequest request) Future<Operation>
Patches the specified policy with the data included in the request.
patchRule(PatchRuleFirewallPolicyRequest request) Future<Operation>
Patches a rule of the specified priority.
removeAssociation(RemoveAssociationFirewallPolicyRequest request) Future<Operation>
Removes an association for the specified firewall policy.
removeRule(RemoveRuleFirewallPolicyRequest request) Future<Operation>
Deletes a rule of the specified priority.
setIamPolicy(SetIamPolicyFirewallPolicyRequest request) Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy.
testIamPermissions(TestIamPermissionsFirewallPolicyRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited