insert method

Creates a new policy in the specified project using the data included in the request.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> insert(InsertFirewallPolicyRequest request) async {
  final url = _endPoint.replace(
    path: '/compute/v1/locations/global/firewallPolicies',
    queryParameters: {
      if (request.parentId case final $1 when $1.isNotDefault) 'parentId': $1,
      'requestId': ?request.requestId,
    },
  );
  final response = await _client.post(
    url,
    body: request.firewallPolicyResource,
  );
  return Operation.fromJson(response);
}