FirewallPolicy class final

Represents a Firewall Policy resource.

Constructors

FirewallPolicy({List<FirewallPolicyAssociation> associations = const [], String? creationTimestamp, String? description, String? displayName, String? fingerprint, BigInt? id, String? kind, String? name, List<FirewallPolicyRule> packetMirroringRules = const [], String? parent, String? policyType, String? region, int? ruleTupleCount, List<FirewallPolicyRule> rules = const [], String? selfLink, String? selfLinkWithId, String? shortName})
FirewallPolicy.fromJson(Object? j)
factory

Properties

associations List<FirewallPolicyAssociation>
A list of associations that belong to this firewall policy.
final
creationTimestamp String?
Output only. Output Only Creation timestamp inRFC3339 text format.
final
description String?
An optional description of this resource. Provide this property when you create the resource.
final
displayName String?
Deprecated, please use short name instead. User-provided name of the Organization firewall policy. The name should be unique in the organization in which the firewall policy is created. This field is not applicable to network firewall policies. This name must be set on creation and cannot be changed. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
fingerprint String?
Specifies a fingerprint for this resource, which is essentially a hash of the metadata's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update metadata. You must always provide an up-to-date fingerprint hash in order to update or change metadata, otherwise the request will fail with error412 conditionNotMet.
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output Only The unique identifier for the resource. This identifier is defined by the server.
final
kind String?
Output only. Output only Type of the resource. Alwayscompute#firewallPolicyfor firewall policies
final
name String?
Name of the resource. For Organization Firewall Policies it's a Output Only numeric ID allocated by Google Cloud which uniquely identifies the Organization Firewall Policy.
final
packetMirroringRules List<FirewallPolicyRule>
A list of packet mirroring rules that belong to this policy.
final
parent String?
Output only. Output Only The parent of the firewall policy. This field is not applicable to network firewall policies.
final
policyType String?
The type of the firewall policy. This field can be one of VPC_POLICY, RDMA_ROCE_POLICY or ULL_POLICY.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
region String?
Output only. Output Only URL of the region where the regional firewall policy resides. This field is not applicable to global firewall policies. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
final
rules List<FirewallPolicyRule>
A list of rules that belong to this policy. There must always be a default rule (rule with priority 2147483647 and match "*"). If no rules are provided when creating a firewall policy, a default rule with action "allow" will be added.
final
ruleTupleCount int?
Output only. Output Only Total count of all firewall policy rule tuples. A firewall policy can not exceed a set number of tuples.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output Only Server-defined URL for the resource.
final
selfLinkWithId String?
Output only. Output Only Server-defined URL for this resource with the resource id.
final
shortName String?
User-provided name of the Organization firewall policy. The name should be unique in the organization in which the firewall policy is created. This field is not applicable to network firewall policies. This name must be set on creation and cannot be changed. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String