associations property
A list of associations that belong to this firewall policy.
Implementation
final List<FirewallPolicyAssociation> associations;
A list of associations that belong to this firewall policy.
final List<FirewallPolicyAssociation> associations;