packetMirroringRules property
A list of packet mirroring rules that belong to this policy.
Implementation
final List<FirewallPolicyRule> packetMirroringRules;
A list of packet mirroring rules that belong to this policy.
final List<FirewallPolicyRule> packetMirroringRules;