parent property
Output only. Output Only The parent of the firewall policy.
This field is not applicable to network firewall policies.
Implementation
final String? parent;
Output only. Output Only The parent of the firewall policy.
This field is not applicable to network firewall policies.
final String? parent;