region property
Output only. Output Only URL of the region where the regional firewall policy resides.
This field is not applicable to global firewall policies.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Implementation
final String? region;