ruleTupleCount property
Output only. Output Only Total count of all firewall policy rule tuples. A firewall
policy can not exceed a set number of tuples.
Implementation
final int? ruleTupleCount;
Output only. Output Only Total count of all firewall policy rule tuples. A firewall
policy can not exceed a set number of tuples.
final int? ruleTupleCount;