FirewallPolicyAssociation class
final
Properties
-
attachmentTarget
→ String?
-
The target that the firewall policy is attached to.
final
-
displayName
→ String?
-
Output Only Deprecated, please use short name instead. The display name
of the firewall policy of the association.
final
-
firewallPolicyId
→ String?
-
Output only.
Output Only The firewall policy ID of the association.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
name
→ String?
-
The name for an association.
final
-
qualifiedName
→ String
-
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or google.rpc.ErrorInfo.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
shortName
→ String?
-
Output only.
Output Only The short name of the firewall policy of the association.
final