FirewallPolicyRule class final

Represents a rule that describes one or more match conditions along with the action to be taken when traffic matches this condition (allow or deny).

Constructors

FirewallPolicyRule({String? action, String? description, String? direction, bool? disabled, bool? enableLogging, String? kind, FirewallPolicyRuleMatcher? match, int? priority, String? ruleName, int? ruleTupleCount, String? securityProfileGroup, List<String> targetForwardingRules = const [], List<String> targetResources = const [], List<FirewallPolicyRuleSecureTag> targetSecureTags = const [], List<String> targetServiceAccounts = const [], String? targetType, bool? tlsInspect})
FirewallPolicyRule.fromJson(Object? j)
factory

Properties

action String?
The Action to perform when the client connection triggers the rule. Valid actions for firewall rules are: "allow", "deny", "apply_security_profile_group" and "goto_next" ( "apply_security_profile_group" can be specified only for global network firewall policies or hierarchical firewall policies). Valid actions for packet mirroring rules are: "mirror", "do_not_mirror" and "goto_next".
final
description String?
An optional description for this resource.
final
direction String?
The direction in which this rule applies. Check the Direction enum for the list of possible values.
final
disabled bool?
Denotes whether the firewall policy rule is disabled. When set to true, the firewall policy rule is not enforced and traffic behaves as if it did not exist. If this is unspecified, the firewall policy rule will be enabled.
final
enableLogging bool?
Denotes whether to enable logging for a particular rule. If logging is enabled, logs will be exported to the configured export destination in Stackdriver. Logs may be exported to BigQuery or Pub/Sub. Note: you cannot enable logging on "goto_next" rules.
final
hashCode int
The hash code for this object.
no setterinherited
kind String?
Output only. Output only Type of the resource. Returnscompute#firewallPolicyRule for firewall rules andcompute#packetMirroringRule for packet mirroring rules.
final
match FirewallPolicyRuleMatcher?
A match condition that incoming traffic is evaluated against. If it evaluates to true, the corresponding 'action' is enforced.
final
priority int?
An integer indicating the priority of a rule in the list. The priority must be a positive value between 0 and 2147483647. Rules are evaluated from highest to lowest priority where 0 is the highest priority and 2147483647 is the lowest priority.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
ruleName String?
An optional name for the rule. This field is not a unique identifier and can be updated.
final
ruleTupleCount int?
Output only. Output Only Calculation of the complexity of a single firewall policy rule.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
securityProfileGroup String?
A fully-qualified URL of a SecurityProfileGroup resource instance. Example: https://networksecurity.googleapis.com/v1/projects/{project}/locations/{location}/securityProfileGroups/my-security-profile-group Must be specified if action is one of 'apply_security_profile_group' or 'mirror'. Cannot be specified for other actions. Can be specified only for global network firewall policies or hierarchical firewall policies.
final
targetForwardingRules List<String>
A list of forwarding rules to which this rule applies. This field allows you to control which load balancers get this rule. For example, the following are valid values:
final
targetResources List<String>
A list of network resource URLs to which this rule applies. This field allows you to control which network's VMs get this rule. If this field is left blank, all VMs within the organization will receive the rule.
final
targetSecureTags List<FirewallPolicyRuleSecureTag>
A list of secure tags that controls which instances the firewall rule applies to. If targetSecureTag are specified, then the firewall rule applies only to instances in the VPC network that have one of those EFFECTIVE secure tags, if all the target_secure_tag are in INEFFECTIVE state, then this rule will be ignored.targetSecureTag may not be set at the same time astargetServiceAccounts. If neither targetServiceAccounts nortargetSecureTag are specified, the firewall rule applies to all instances on the specified network. Maximum number of target label tags allowed is 256.
final
targetServiceAccounts List<String>
A list of service accounts indicating the sets of instances that are applied with this rule.
final
targetType String?
Target types of the firewall policy rule. Default value is INSTANCES. Check the TargetType enum for the list of possible values.
final
tlsInspect bool?
Boolean flag indicating if the traffic should be TLS decrypted. Can be set only if action = 'apply_security_profile_group' and cannot be set for other actions.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String