direction property
The direction in which this rule applies. Check the Direction enum for the list of possible values.
Implementation
final String? direction;
The direction in which this rule applies. Check the Direction enum for the list of possible values.
final String? direction;