match property
A match condition that incoming traffic is evaluated against. If it evaluates to true, the corresponding 'action' is enforced.
Implementation
final FirewallPolicyRuleMatcher? match;
A match condition that incoming traffic is evaluated against. If it evaluates to true, the corresponding 'action' is enforced.
final FirewallPolicyRuleMatcher? match;