ruleName property
An optional name for the rule. This field is not a unique identifier and can be updated.
Implementation
final String? ruleName;
An optional name for the rule. This field is not a unique identifier and can be updated.
final String? ruleName;