ruleTupleCount property
Output only. Output Only Calculation of the complexity of a single firewall policy
rule.
Implementation
final int? ruleTupleCount;
Output only. Output Only Calculation of the complexity of a single firewall policy
rule.
final int? ruleTupleCount;