targetForwardingRules property

List<String> targetForwardingRules
final

A list of forwarding rules to which this rule applies. This field allows you to control which load balancers get this rule. For example, the following are valid values:

 - https://www.googleapis.com/compute/v1/projects/project/global/forwardingRules/forwardingRule
 - https://www.googleapis.com/compute/v1/projects/project/regions/region/forwardingRules/forwardingRule
 - projects/project/global/
 forwardingRules/forwardingRule
 - projects/project/regions/region/forwardingRules/
 forwardingRule

Implementation

final List<String> targetForwardingRules;