toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (action != null) 'action=$action',
    if (description != null) 'description=$description',
    if (direction != null) 'direction=$direction',
    if (disabled != null) 'disabled=$disabled',
    if (enableLogging != null) 'enableLogging=$enableLogging',
    if (kind != null) 'kind=$kind',
    if (priority != null) 'priority=$priority',
    if (ruleName != null) 'ruleName=$ruleName',
    if (ruleTupleCount != null) 'ruleTupleCount=$ruleTupleCount',
    if (securityProfileGroup != null)
      'securityProfileGroup=$securityProfileGroup',
    if (targetType != null) 'targetType=$targetType',
    if (tlsInspect != null) 'tlsInspect=$tlsInspect',
  ].join(',');
  return 'FirewallPolicyRule(${$contents})';
}