FirewallPolicyRuleMatcher class final

Represents a match condition that incoming traffic is evaluated against. Exactly one field must be specified.

Constructors

FirewallPolicyRuleMatcher({List<String> destAddressGroups = const [], List<String> destFqdns = const [], List<String> destIpRanges = const [], String? destNetworkContext, String? destNetworkType, List<String> destRegionCodes = const [], List<String> destThreatIntelligences = const [], List<FirewallPolicyRuleMatcherLayer4Config> layer4Configs = const [], List<String> srcAddressGroups = const [], List<String> srcFqdns = const [], List<String> srcIpRanges = const [], String? srcNetworkContext, String? srcNetworkType, List<String> srcNetworks = const [], List<String> srcRegionCodes = const [], List<FirewallPolicyRuleSecureTag> srcSecureTags = const [], List<String> srcThreatIntelligences = const []})
FirewallPolicyRuleMatcher.fromJson(Object? j)
factory

Properties

destAddressGroups List<String>
Address groups which should be matched against the traffic destination. Maximum number of destination address groups is 10.
final
destFqdns List<String>
Fully Qualified Domain Name (FQDN) which should be matched against traffic destination. Maximum number of destination fqdn allowed is 100.
final
destIpRanges List<String>
CIDR IP address range. Maximum number of destination CIDR IP ranges allowed is 5000.
final
destNetworkContext String?
Network context of the traffic destination. Allowed values are:
final
destNetworkType String?
Network type of the traffic destination. Allowed values are:
final
destRegionCodes List<String>
Region codes whose IP addresses will be used to match for destination of traffic. Should be specified as 2 letter country code defined as per ISO 3166 alpha-2 country codes. ex."US" Maximum number of dest region codes allowed is 5000.
final
destThreatIntelligences List<String>
Names of Network Threat Intelligence lists. The IPs in these lists will be matched against traffic destination.
final
hashCode int
The hash code for this object.
no setterinherited
layer4Configs List<FirewallPolicyRuleMatcherLayer4Config>
Pairs of IP protocols and ports that the rule should match.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
srcAddressGroups List<String>
Address groups which should be matched against the traffic source. Maximum number of source address groups is 10.
final
srcFqdns List<String>
Fully Qualified Domain Name (FQDN) which should be matched against traffic source. Maximum number of source fqdn allowed is 100.
final
srcIpRanges List<String>
CIDR IP address range. Maximum number of source CIDR IP ranges allowed is 5000.
final
srcNetworkContext String?
Network context of the traffic source. Allowed values are:
final
srcNetworks List<String>
Networks of the traffic source. It can be either a full or partial url.
final
srcNetworkType String?
Network type of the traffic source. Allowed values are:
final
srcRegionCodes List<String>
Region codes whose IP addresses will be used to match for source of traffic. Should be specified as 2 letter country code defined as per ISO 3166 alpha-2 country codes. ex."US" Maximum number of source region codes allowed is 5000.
final
srcSecureTags List<FirewallPolicyRuleSecureTag>
List of secure tag values, which should be matched at the source of the traffic. For INGRESS rule, if all the srcSecureTag are INEFFECTIVE, and there is no srcIpRange, this rule will be ignored. Maximum number of source tag values allowed is 256.
final
srcThreatIntelligences List<String>
Names of Network Threat Intelligence lists. The IPs in these lists will be matched against traffic source.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String