ports property

List<String> ports
final

An optional list of ports to which this rule applies. This field is only applicable for UDP or TCP protocol. Each entry must be either an integer or a range. If not specified, this rule applies to connections through any port.

Example inputs include: "22","80","443", and "12345-12349".

Implementation

final List<String> ports;