FirewallPolicyRuleMatcher_DestNetworkContext class final
Network context of the traffic destination. Allowed values are:
- UNSPECIFIED
- INTERNET
- NON_INTERNET
Additional supported values which may be not listed in the enum directly due to technical reasons: INTERNET INTRA_VPC NON_INTERNET UNSPECIFIED VPC_NETWORKS
Constructors
- FirewallPolicyRuleMatcher_DestNetworkContext(String value)
-
const
- FirewallPolicyRuleMatcher_DestNetworkContext.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const FirewallPolicyRuleMatcher_DestNetworkContext
- The default value for FirewallPolicyRuleMatcher_DestNetworkContext.
- undefinedDestNetworkContext → const FirewallPolicyRuleMatcher_DestNetworkContext
- A value indicating that the enum field is not set.