FirewallPolicyRule_Direction class final

The direction in which this rule applies.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const FirewallPolicyRule_Direction
The default value for FirewallPolicyRule_Direction.
egress → const FirewallPolicyRule_Direction
ingress → const FirewallPolicyRule_Direction
undefinedDirection → const FirewallPolicyRule_Direction
A value indicating that the enum field is not set.