Firewalls class final

The Firewalls API.

Implementers

Constructors

Firewalls({required Client client, Uri? endPoint, String? gcclVersion})
Creates a Firewalls using client for transport.
Firewalls.fromApiKey([String? apiKey])
Creates a Firewalls that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteFirewallRequest request) Future<Operation>
Deletes the specified firewall.
get(GetFirewallRequest request) Future<Firewall>
Returns the specified firewall.
insert(InsertFirewallRequest request) Future<Operation>
Creates a firewall rule in the specified project using the data included in the request.
list(ListFirewallsRequest request) Future<FirewallList>
Retrieves the list of firewall rules available to the specified project.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(PatchFirewallRequest request) Future<Operation>
Updates the specified firewall rule with the data included in the request. This method supportsPATCH semantics and uses theJSON merge patch format and processing rules.
testIamPermissions(TestIamPermissionsFirewallRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
toString() String
A string representation of this object.
inherited
update(UpdateFirewallRequest request) Future<Operation>
Updates the specified firewall rule with the data included in the request. Note that all fields will be updated if using PUT, even fields that are not specified. To update individual fields, please use PATCH instead.

Operators

operator ==(Object other) bool
The equality operator.
inherited