insert method

Creates a firewall rule in the specified project using the data included in the request.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> insert(InsertFirewallRequest request) async {
  final url = _endPoint.replace(
    path: '/compute/v1/projects/${request.project}/global/firewalls',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.post(url, body: request.firewallResource);
  return Operation.fromJson(response);
}