patch method

Updates the specified firewall rule with the data included in the request. This method supportsPATCH semantics and uses theJSON merge patch format and processing rules.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> patch(PatchFirewallRequest request) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/global/firewalls/${request.firewall}',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.patch(url, body: request.firewallResource);
  return Operation.fromJson(response);
}