FixedOrPercent class final
Encapsulates numeric value that can be either absolute or relative.
Constructors
- FixedOrPercent({int? calculated, int? fixed, int? percent})
- FixedOrPercent.fromJson(Object? j)
-
factory
Properties
- calculated → int?
-
Output only. Absolute value of VM instances calculated based on the specific mode.
final
- fixed → int?
-
Specifies a fixed number of VM instances. This must be a positive integer.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- percent → int?
-
Specifies a percentage of instances between 0 to 100%, inclusive. For
example, specify 80 for 80%.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String