FlexibleTimeRange class final

Specifies a flexible time range with flexible start time and duration.

It is possible to specify a contradictory time range that cannot be matched by any Interval. This causes a validation error.

Constructors

FlexibleTimeRange({String? maxDuration, String? minDuration, String? startTimeNotEarlierThan, String? startTimeNotLaterThan})
FlexibleTimeRange.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
maxDuration String?
final
minDuration String?
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTimeNotEarlierThan String?
final
startTimeNotLaterThan String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String