backendService property

String? backendService
final

Identifies the backend service to which the forwarding rule sends traffic. Required for internal and external passthrough Network Load Balancers; must be omitted for all other load balancer types.

Implementation

final String? backendService;