baseForwardingRule property
Output only. Output Only The URL for the corresponding base forwarding rule. By base
forwarding rule, we mean the forwarding rule that has the same IP address,
protocol, and port settings with the current forwarding rule, but without
sourceIPRanges specified.
Always empty if the current forwarding rule does not have sourceIPRanges
specified.
Implementation
final String? baseForwardingRule;