ipVersion property
The IP Version that will be used by this forwarding rule. Valid options are IPV4 or IPV6. Check the IpVersion enum for the list of possible values.
Implementation
final String? ipVersion;
The IP Version that will be used by this forwarding rule. Valid options are IPV4 or IPV6. Check the IpVersion enum for the list of possible values.
final String? ipVersion;