networkTier property
This signifies the networking tier used for configuring this load balancer and can only take the following values:PREMIUM, STANDARD.
For regional ForwardingRule, the valid values are PREMIUM andSTANDARD. For GlobalForwardingRule, the valid value isPREMIUM.
If this field is not specified, it is assumed to be PREMIUM. If IPAddress is specified, this value must be equal to the networkTier of the Address. Check the NetworkTier enum for the list of possible values.
Implementation
final String? networkTier;