serviceName property

String? serviceName
final

Output Only The internal fully qualified service name for this forwarding rule.

This field is only used for internal load balancing.

Implementation

final String? serviceName;