toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (iPAddress != null) 'IPAddress=$iPAddress',
    if (iPProtocol != null) 'IPProtocol=$iPProtocol',
    if (allPorts != null) 'allPorts=$allPorts',
    if (allowGlobalAccess != null) 'allowGlobalAccess=$allowGlobalAccess',
    if (allowPscGlobalAccess != null)
      'allowPscGlobalAccess=$allowPscGlobalAccess',
    if (backendService != null) 'backendService=$backendService',
    if (baseForwardingRule != null) 'baseForwardingRule=$baseForwardingRule',
    if (creationTimestamp != null) 'creationTimestamp=$creationTimestamp',
    if (description != null) 'description=$description',
    if (externalManagedBackendBucketMigrationState != null)
      'externalManagedBackendBucketMigrationState=$externalManagedBackendBucketMigrationState',
    if (externalManagedBackendBucketMigrationTestingPercentage != null)
      'externalManagedBackendBucketMigrationTestingPercentage=$externalManagedBackendBucketMigrationTestingPercentage',
    if (fingerprint != null) 'fingerprint=$fingerprint',
    if (id != null) 'id=$id',
    if (ipCollection != null) 'ipCollection=$ipCollection',
    if (ipVersion != null) 'ipVersion=$ipVersion',
    if (isMirroringCollector != null)
      'isMirroringCollector=$isMirroringCollector',
    if (kind != null) 'kind=$kind',
    if (labelFingerprint != null) 'labelFingerprint=$labelFingerprint',
    if (loadBalancingScheme != null)
      'loadBalancingScheme=$loadBalancingScheme',
    if (name != null) 'name=$name',
    if (network != null) 'network=$network',
    if (networkTier != null) 'networkTier=$networkTier',
    if (noAutomateDnsZone != null) 'noAutomateDnsZone=$noAutomateDnsZone',
    if (portRange != null) 'portRange=$portRange',
    if (pscConnectionId != null) 'pscConnectionId=$pscConnectionId',
    if (pscConnectionStatus != null)
      'pscConnectionStatus=$pscConnectionStatus',
    if (region != null) 'region=$region',
    if (selfLink != null) 'selfLink=$selfLink',
    if (selfLinkWithId != null) 'selfLinkWithId=$selfLinkWithId',
    if (serviceLabel != null) 'serviceLabel=$serviceLabel',
    if (serviceName != null) 'serviceName=$serviceName',
    if (subnetwork != null) 'subnetwork=$subnetwork',
    if (target != null) 'target=$target',
  ].join(',');
  return 'ForwardingRule(${$contents})';
}