ForwardingRule_IpprotocolEnum class final
The IP protocol to which this rule applies.
For protocol forwarding, valid options are TCP, UDP, ESP,AH, SCTP, ICMP andL3_DEFAULT.
The valid IP protocols are different for different load balancing products as described in Load balancing features.
Constructors
- ForwardingRule_IpprotocolEnum(String value)
-
const
- ForwardingRule_IpprotocolEnum.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const ForwardingRule_IpprotocolEnum
- The default value for ForwardingRule_IpprotocolEnum.
- ah → const ForwardingRule_IpprotocolEnum
- esp → const ForwardingRule_IpprotocolEnum
- icmp → const ForwardingRule_IpprotocolEnum
- l3Default → const ForwardingRule_IpprotocolEnum
- sctp → const ForwardingRule_IpprotocolEnum
- tcp → const ForwardingRule_IpprotocolEnum
- udp → const ForwardingRule_IpprotocolEnum
- undefinedIPProtocolEnum → const ForwardingRule_IpprotocolEnum
- A value indicating that the enum field is not set.