ForwardingRule_LoadBalancingScheme class final
Specifies the forwarding rule type.
For more information about forwarding rules, refer to Forwarding rule concepts.
Constructors
- ForwardingRule_LoadBalancingScheme(String value)
-
const
- ForwardingRule_LoadBalancingScheme.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const ForwardingRule_LoadBalancingScheme
- The default value for ForwardingRule_LoadBalancingScheme.
- external → const ForwardingRule_LoadBalancingScheme
- externalManaged → const ForwardingRule_LoadBalancingScheme
- internal → const ForwardingRule_LoadBalancingScheme
- internalManaged → const ForwardingRule_LoadBalancingScheme
- internalSelfManaged → const ForwardingRule_LoadBalancingScheme
- invalid → const ForwardingRule_LoadBalancingScheme
- undefinedLoadBalancingScheme → const ForwardingRule_LoadBalancingScheme
- A value indicating that the enum field is not set.