ForwardingRule_NetworkTier class final

This signifies the networking tier used for configuring this load balancer and can only take the following values:PREMIUM, STANDARD.

For regional ForwardingRule, the valid values are PREMIUM andSTANDARD. For GlobalForwardingRule, the valid value isPREMIUM.

If this field is not specified, it is assumed to be PREMIUM. If IPAddress is specified, this value must be equal to the networkTier of the Address.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const ForwardingRule_NetworkTier
The default value for ForwardingRule_NetworkTier.
fixedStandard → const ForwardingRule_NetworkTier
Public internet quality with fixed bandwidth.
premium → const ForwardingRule_NetworkTier
High quality, Google-grade network tier, support for all networking products.
standard → const ForwardingRule_NetworkTier
Public internet quality, only limited support for other networking products.
standardOverridesFixedStandard → const ForwardingRule_NetworkTier
(Output only) Temporary tier for FIXED_STANDARD when fixed standard tier is expired or not configured.
undefinedNetworkTier → const ForwardingRule_NetworkTier
A value indicating that the enum field is not set.