ForwardingRule_PscConnectionStatus class final

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const ForwardingRule_PscConnectionStatus
The default value for ForwardingRule_PscConnectionStatus.
accepted → const ForwardingRule_PscConnectionStatus
The connection has been accepted by the producer.
closed → const ForwardingRule_PscConnectionStatus
The connection has been closed by the producer and will not serve traffic going forward.
needsAttention → const ForwardingRule_PscConnectionStatus
The connection has been accepted by the producer, but the producer needs to take further action before the forwarding rule can serve traffic.
pending → const ForwardingRule_PscConnectionStatus
The connection is pending acceptance by the producer.
rejected → const ForwardingRule_PscConnectionStatus
The connection has been rejected by the producer.
statusUnspecified → const ForwardingRule_PscConnectionStatus
undefinedPscConnectionStatus → const ForwardingRule_PscConnectionStatus
A value indicating that the enum field is not set.