ForwardingRulesScopedList class final

Constructors

ForwardingRulesScopedList({List<ForwardingRule> forwardingRules = const [], Warning? warning})
ForwardingRulesScopedList.fromJson(Object? j)
factory

Properties

forwardingRules List<ForwardingRule>
A list of forwarding rules contained in this scope.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warning Warning?
Informational warning which replaces the list of forwarding rules when the list is empty.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String