FutureReservation class final

Constructors

FutureReservation({AllocationAggregateReservation? aggregateReservation, String? autoCreatedReservationsDeleteTime, Duration? autoCreatedReservationsDuration, bool? autoDeleteAutoCreatedReservations, FutureReservationCommitmentInfo? commitmentInfo, String? confidentialComputeType, String? creationTimestamp, String? deploymentType, String? description, bool? enableEmergentMaintenance, BigInt? id, String? kind, String? name, String? namePrefix, FutureReservationParams? params, String? planningStatus, String? reservationMode, String? reservationName, ResourceMetadata? resourceMetadata, String? resourceName, String? schedulingType, String? selfLink, String? selfLinkWithId, ShareSettings? shareSettings, bool? specificReservationRequired, FutureReservationSpecificSkuproperties? specificSkuProperties, FutureReservationStatus? status, FutureReservationStoragePoolProperties? storagePoolProperties, FutureReservationTimeWindow? timeWindow, String? zone})
FutureReservation.fromJson(Object? j)
factory

Properties

aggregateReservation AllocationAggregateReservation?
Aggregate reservation details for the future reservation.
final
autoCreatedReservationsDeleteTime String?
Future timestamp when the FR auto-created reservations will be deleted by Compute Engine. Format of this field must be a valid href="https://www.ietf.org/rfc/rfc3339.txt">RFC3339 value.
final
autoCreatedReservationsDuration Duration?
Specifies the duration of auto-created reservations. It represents relative time to future reservation start_time when auto-created reservations will be automatically deleted by Compute Engine. Duration time unit is represented as a count of seconds and fractions of seconds at nanosecond resolution.
final
autoDeleteAutoCreatedReservations bool?
Setting for enabling or disabling automatic deletion for auto-created reservation. If set to true, auto-created reservations will be deleted at Future Reservation's end time (default) or at user's defined timestamp if any of the auto_created_reservations_delete_time, auto_created_reservations_duration values is specified. For keeping auto-created reservation indefinitely, this value should be set to false.
final
commitmentInfo FutureReservationCommitmentInfo?
If not present, then FR will not deliver a new commitment or update an existing commitment.
final
confidentialComputeType String?
Check the ConfidentialComputeType enum for the list of possible values.
final
creationTimestamp String?
Output only. Output Only The creation timestamp for this future reservation inRFC3339 text format.
final
deploymentType String?
Type of the deployment requested as part of future reservation. Check the DeploymentType enum for the list of possible values.
final
description String?
An optional description of this resource. Provide this property when you create the future reservation.
final
enableEmergentMaintenance bool?
Indicates if this group of VMs have emergent maintenance enabled.
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output only. Output Only A unique identifier for this future reservation. The server defines this identifier.
final
kind String?
Output only. Output Only Type of the resource. Alwayscompute#futureReservation for future reservations.
final
name String?
The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
namePrefix String?
Name prefix for the reservations to be created at the time of delivery. The name prefix must comply with RFC1035. Maximum allowed length for name prefix is 20. Automatically created reservations name format will be -date-####.
final
params FutureReservationParams?
Input only. Additional params passed with the request, but not persisted as part of resource payload.
final
planningStatus String?
Planning state before being submitted for evaluation Check the PlanningStatus enum for the list of possible values.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
reservationMode String?
The reservation mode which determines reservation-termination behavior and expected pricing. Check the ReservationMode enum for the list of possible values.
final
reservationName String?
Name of reservations where the capacity is provisioned at the time of delivery of future reservations. If the reservation with the given name does not exist already, it is created automatically at the time of Approval with INACTIVE state till specified start-time. Either provide the reservation_name or a name_prefix.
final
resourceMetadata ResourceMetadata?
Output only. Contains standard resource metadata for an FutureReservation resource. It is populated for each instance of the FutureReservation resource, and includes the api_version the instance was retrieved through, and its canonical resource_type name.
final
resourceName String?
Name of the resource intended to be delivered. Name should conform to RFC1035. This will be the name of storage pool or Exapool for persistent disk FRs.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schedulingType String?
Maintenance information for this reservation Check the SchedulingType enum for the list of possible values.
final
Output only. Output Only Server-defined fully-qualified URL for this resource.
final
selfLinkWithId String?
Output only. Output Only Server-defined URL for this resource with the resource id.
final
shareSettings ShareSettings?
List of Projects/Folders to share with.
final
specificReservationRequired bool?
Indicates whether the auto-created reservation can be consumed by VMs with affinity for "any" reservation. If the field is set, then only VMs that target the reservation by name can consume from the delivered reservation.
final
specificSkuProperties FutureReservationSpecificSkuproperties?
Future Reservation configuration to indicate instance properties and total count.
final
status FutureReservationStatus?
Output only. Output only Status of the Future Reservation
final
storagePoolProperties FutureReservationStoragePoolProperties?
Storage pool details for the future reservation.
final
timeWindow FutureReservationTimeWindow?
Time window for this Future Reservation.
final
zone String?
Output only. Output Only URL of the Zone where this future reservation resides.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String