autoCreatedReservationsDuration property

Duration? autoCreatedReservationsDuration
final

Specifies the duration of auto-created reservations. It represents relative time to future reservation start_time when auto-created reservations will be automatically deleted by Compute Engine. Duration time unit is represented as a count of seconds and fractions of seconds at nanosecond resolution.

Implementation

final Duration? autoCreatedReservationsDuration;