autoDeleteAutoCreatedReservations property

bool? autoDeleteAutoCreatedReservations
final

Setting for enabling or disabling automatic deletion for auto-created reservation. If set to true, auto-created reservations will be deleted at Future Reservation's end time (default) or at user's defined timestamp if any of the auto_created_reservations_delete_time, auto_created_reservations_duration values is specified. For keeping auto-created reservation indefinitely, this value should be set to false.

Implementation

final bool? autoDeleteAutoCreatedReservations;