commitmentInfo property
If not present, then FR will not deliver a new commitment or update an existing commitment.
Implementation
final FutureReservationCommitmentInfo? commitmentInfo;
If not present, then FR will not deliver a new commitment or update an existing commitment.
final FutureReservationCommitmentInfo? commitmentInfo;