description property
An optional description of this resource. Provide this property when you create the future reservation.
Implementation
final String? description;
An optional description of this resource. Provide this property when you create the future reservation.
final String? description;