params property
Input only. Additional params passed with the request, but not persisted as part of resource payload.
Implementation
final FutureReservationParams? params;
Input only. Additional params passed with the request, but not persisted as part of resource payload.
final FutureReservationParams? params;