planningStatus property
Planning state before being submitted for evaluation Check the PlanningStatus enum for the list of possible values.
Implementation
final String? planningStatus;
Planning state before being submitted for evaluation Check the PlanningStatus enum for the list of possible values.
final String? planningStatus;