toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (autoCreatedReservationsDeleteTime != null)
      'autoCreatedReservationsDeleteTime=$autoCreatedReservationsDeleteTime',
    if (autoDeleteAutoCreatedReservations != null)
      'autoDeleteAutoCreatedReservations=$autoDeleteAutoCreatedReservations',
    if (confidentialComputeType != null)
      'confidentialComputeType=$confidentialComputeType',
    if (creationTimestamp != null) 'creationTimestamp=$creationTimestamp',
    if (deploymentType != null) 'deploymentType=$deploymentType',
    if (description != null) 'description=$description',
    if (enableEmergentMaintenance != null)
      'enableEmergentMaintenance=$enableEmergentMaintenance',
    if (id != null) 'id=$id',
    if (kind != null) 'kind=$kind',
    if (name != null) 'name=$name',
    if (namePrefix != null) 'namePrefix=$namePrefix',
    if (planningStatus != null) 'planningStatus=$planningStatus',
    if (reservationMode != null) 'reservationMode=$reservationMode',
    if (reservationName != null) 'reservationName=$reservationName',
    if (resourceName != null) 'resourceName=$resourceName',
    if (schedulingType != null) 'schedulingType=$schedulingType',
    if (selfLink != null) 'selfLink=$selfLink',
    if (selfLinkWithId != null) 'selfLinkWithId=$selfLinkWithId',
    if (specificReservationRequired != null)
      'specificReservationRequired=$specificReservationRequired',
    if (zone != null) 'zone=$zone',
  ].join(',');
  return 'FutureReservation(${$contents})';
}