FutureReservationCommitmentInfo class final

Constructors

FutureReservationCommitmentInfo({String? commitmentName, String? commitmentPlan, String? previousCommitmentTerms})
FutureReservationCommitmentInfo.fromJson(Object? j)
factory

Properties

commitmentName String?
name of the commitment where capacity is being delivered to.
final
commitmentPlan String?
Indicates if a Commitment needs to be created as part of FR delivery. If this field is not present, then no commitment needs to be created. Check the CommitmentPlan enum for the list of possible values.
final
hashCode int
The hash code for this object.
no setterinherited
previousCommitmentTerms String?
Only applicable if FR is delivering to the same reservation. If set, all parent commitments will be extended to match the end date of the plan for this commitment. Check the PreviousCommitmentTerms enum for the list of possible values.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String