commitmentPlan property

String? commitmentPlan
final

Indicates if a Commitment needs to be created as part of FR delivery. If this field is not present, then no commitment needs to be created. Check the CommitmentPlan enum for the list of possible values.

Implementation

final String? commitmentPlan;