previousCommitmentTerms property

String? previousCommitmentTerms
final

Only applicable if FR is delivering to the same reservation. If set, all parent commitments will be extended to match the end date of the plan for this commitment. Check the PreviousCommitmentTerms enum for the list of possible values.

Implementation

final String? previousCommitmentTerms;