FutureReservationCommitmentInfo_PreviousCommitmentTerms class final

Only applicable if FR is delivering to the same reservation. If set, all parent commitments will be extended to match the end date of the plan for this commitment.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const FutureReservationCommitmentInfo_PreviousCommitmentTerms
The default value for FutureReservationCommitmentInfo_PreviousCommitmentTerms.
extend → const FutureReservationCommitmentInfo_PreviousCommitmentTerms
All associated parent Committed Used Discount(s) end-date/term will be extended to the end-time of this future reservation. Default is to extend previous commitment(s) time to the end_time of the reservation.
previouscommitmenttermUnspecified → const FutureReservationCommitmentInfo_PreviousCommitmentTerms
No changes to associated parents Committed Used Discount(s) terms.
undefinedPreviousCommitmentTerms → const FutureReservationCommitmentInfo_PreviousCommitmentTerms
A value indicating that the enum field is not set.