FutureReservationSpecificSkuproperties class final

Properties

hashCode int
The hash code for this object.
no setterinherited
instanceProperties AllocationSpecificSkuallocationReservedInstanceProperties?
Properties of the SKU instances being reserved.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceInstanceTemplate String?
The instance template that will be used to populate the ReservedInstanceProperties of the future reservation
final
totalCount int?
Total number of instances for which capacity assurance is requested at a future time period.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String