sourceInstanceTemplate property
The instance template that will be used to populate the ReservedInstanceProperties of the future reservation
Implementation
final String? sourceInstanceTemplate;
The instance template that will be used to populate the ReservedInstanceProperties of the future reservation
final String? sourceInstanceTemplate;