totalCount property
Total number of instances for which capacity assurance is requested at a future time period.
Implementation
final int? totalCount;
Total number of instances for which capacity assurance is requested at a future time period.
final int? totalCount;