amendmentStatus property
Output only. Output Only The current status of the requested amendment.
Check the AmendmentStatus enum for the list of possible values.
Implementation
final String? amendmentStatus;
Output only. Output Only The current status of the requested amendment.
Check the AmendmentStatus enum for the list of possible values.
final String? amendmentStatus;