existingMatchingUsageInfo property
Output only. Output Only Represents the existing matching usage for the future
reservation.
Implementation
final FutureReservationStatusExistingMatchingUsageInfo?
existingMatchingUsageInfo;
Output only. Output Only Represents the existing matching usage for the future
reservation.
final FutureReservationStatusExistingMatchingUsageInfo?
existingMatchingUsageInfo;