procurementStatus property
Output only. Current state of this Future Reservation Check the ProcurementStatus enum for the list of possible values.
Implementation
final String? procurementStatus;
Output only. Current state of this Future Reservation Check the ProcurementStatus enum for the list of possible values.
final String? procurementStatus;