FutureReservationStatusExistingMatchingUsageInfo class final
Output Only Represents the existing matching usage for the future
reservation.
Constructors
- FutureReservationStatusExistingMatchingUsageInfo({int? count, String? timestamp})
- FutureReservationStatusExistingMatchingUsageInfo.fromJson(Object? j)
-
factory
Properties
- count → int?
-
Output only. Count to represent min(FR total_count,
matching_reserved_capacity+matching_unreserved_instances)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → String?
-
Output only. Timestamp when the matching usage was calculated
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String