FutureReservationStatusLastKnownGoodState class final

The state that the future reservation will be reverted to should the amendment be declined.

Properties

description String?
Output only. Output Only The description of the FutureReservation before an amendment was requested.
final
existingMatchingUsageInfo FutureReservationStatusExistingMatchingUsageInfo?
Output only. Output Only Represents the matching usage for the future reservation before an amendment was requested.
final
futureReservationSpecs FutureReservationStatusLastKnownGoodStateFutureReservationSpecs?
final
hashCode int
The hash code for this object.
no setterinherited
lockTime String?
Output only. Output Only The lock time of the FutureReservation before an amendment was requested.
final
namePrefix String?
Output only. Output Only The name prefix of the Future Reservation before an amendment was requested.
final
procurementStatus String?
Output only. Output Only The status of the last known good state for the Future Reservation. Check the ProcurementStatus enum for the list of possible values.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String