procurementStatus property
Output only. Output Only The status of the last known good state for the Future
Reservation.
Check the ProcurementStatus enum for the list of possible values.
Implementation
final String? procurementStatus;
Output only. Output Only The status of the last known good state for the Future
Reservation.
Check the ProcurementStatus enum for the list of possible values.
final String? procurementStatus;