FutureReservationStatusLastKnownGoodStateFutureReservationSpecs class final
The properties of the last known good state for the Future Reservation.
Constructors
- FutureReservationStatusLastKnownGoodStateFutureReservationSpecs({FutureReservationSpecificSkuproperties? specificSkuProperties, FutureReservationTimeWindow? timeWindow})
- FutureReservationStatusLastKnownGoodStateFutureReservationSpecs.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
Output only.
Output OnlyThe previous share settings of the Future Reservation.final - specificSkuProperties → FutureReservationSpecificSkuproperties?
-
Output only.
Output OnlyThe previous instance related properties of the Future Reservation.final - timeWindow → FutureReservationTimeWindow?
-
Output only.
Output OnlyThe previous time window of the Future Reservation.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String