FutureReservationStatusLastKnownGoodState_ProcurementStatus class final

Output only. Output Only The status of the last known good state for the Future Reservation.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const FutureReservationStatusLastKnownGoodState_ProcurementStatus
The default value for FutureReservationStatusLastKnownGoodState_ProcurementStatus.
approved → const FutureReservationStatusLastKnownGoodState_ProcurementStatus
Future reservation is approved by GCP.
cancelled → const FutureReservationStatusLastKnownGoodState_ProcurementStatus
Future reservation is cancelled by the customer.
committed → const FutureReservationStatusLastKnownGoodState_ProcurementStatus
Future reservation is committed by the customer.
declined → const FutureReservationStatusLastKnownGoodState_ProcurementStatus
Future reservation is rejected by GCP.
drafting → const FutureReservationStatusLastKnownGoodState_ProcurementStatus
Related status for PlanningStatus.Draft. Transitions to PENDING_APPROVAL upon user submitting FR.
failed → const FutureReservationStatusLastKnownGoodState_ProcurementStatus
Future reservation failed. No additional reservations were provided.
failedPartiallyFulfilled → const FutureReservationStatusLastKnownGoodState_ProcurementStatus
Future reservation is partially fulfilled. Additional reservations were provided but did not reach total_count reserved instance slots.
fulfilled → const FutureReservationStatusLastKnownGoodState_ProcurementStatus
Future reservation is fulfilled completely.
pendingAmendmentApproval → const FutureReservationStatusLastKnownGoodState_ProcurementStatus
An Amendment to the Future Reservation has been requested. If the Amendment is declined, the Future Reservation will be restored to the last known good state.
pendingApproval → const FutureReservationStatusLastKnownGoodState_ProcurementStatus
Future reservation is pending approval by GCP.
procurementStatusUnspecified → const FutureReservationStatusLastKnownGoodState_ProcurementStatus
procuring → const FutureReservationStatusLastKnownGoodState_ProcurementStatus
Future reservation is being procured by GCP. Beyond this point, Future reservation is locked and no further modifications are allowed.
provisioning → const FutureReservationStatusLastKnownGoodState_ProcurementStatus
Future reservation capacity is being provisioned. This state will be entered after start_time, while reservations are being created to provide total_count reserved instance slots. This state will not persist past start_time + 24h.
undefinedProcurementStatus → const FutureReservationStatusLastKnownGoodState_ProcurementStatus
A value indicating that the enum field is not set.