pendingAmendmentApproval constant

An Amendment to the Future Reservation has been requested. If the Amendment is declined, the Future Reservation will be restored to the last known good state.

Implementation

static const pendingAmendmentApproval =
    FutureReservationStatusLastKnownGoodState_ProcurementStatus(
      'PENDING_AMENDMENT_APPROVAL',
    );