sourceInstanceTemplateId property
ID of the instance template used to populate the Future Reservation properties.
Implementation
final String? sourceInstanceTemplateId;
ID of the instance template used to populate the Future Reservation properties.
final String? sourceInstanceTemplateId;