FutureReservationStatus_AmendmentStatus class final

Output only. Output Only The current status of the requested amendment.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const FutureReservationStatus_AmendmentStatus
The default value for FutureReservationStatus_AmendmentStatus.
amendmentApproved → const FutureReservationStatus_AmendmentStatus
The requested amendment to the Future Resevation has been approved and applied by GCP.
amendmentDeclined → const FutureReservationStatus_AmendmentStatus
The requested amendment to the Future Reservation has been declined by GCP and the original state was restored.
amendmentInReview → const FutureReservationStatus_AmendmentStatus
The requested amendment to the Future Reservation is currently being reviewd by GCP.
amendmentStatusUnspecified → const FutureReservationStatus_AmendmentStatus
undefinedAmendmentStatus → const FutureReservationStatus_AmendmentStatus
A value indicating that the enum field is not set.