FutureReservationStoragePoolProperties class final

Storage pool properties for the future reservation.

Constructors

FutureReservationStoragePoolProperties({StoragePoolExapoolProvisionedCapacityGb? requestedExapoolProvisionedCapacityGb, FutureReservationStoragePoolProvisionedCapacity? requestedStoragePoolProvisionedCapacity, String? storagePoolType})
FutureReservationStoragePoolProperties.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requestedExapoolProvisionedCapacityGb StoragePoolExapoolProvisionedCapacityGb?
Requested exapool provisioned capacity in GiB.
final
requestedStoragePoolProvisionedCapacity FutureReservationStoragePoolProvisionedCapacity?
Requested storage pool provisioned capacity.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storagePoolType String?
Type of the storage pool.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String