FutureReservationStoragePoolProvisionedCapacity class final
Storage pool provisioned capacities for each SKU type.
Constructors
- FutureReservationStoragePoolProvisionedCapacity({int? poolProvisionedCapacityGb, int? poolProvisionedIops, int? poolProvisionedThroughput})
- FutureReservationStoragePoolProvisionedCapacity.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- poolProvisionedCapacityGb → int?
-
Size of the storage pool in GiB.
final
- poolProvisionedIops → int?
-
Provisioned IOPS of the storage pool. Only relevant if the storage pool
type is hyperdisk-balanced.
final
- poolProvisionedThroughput → int?
-
Provisioned throughput of the storage pool in MiB/s. Only relevant if
the storage pool type is hyperdisk-balanced or hyperdisk-throughput.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String