FutureReservationTimeWindow class final

Constructors

FutureReservationTimeWindow({Duration? duration, String? endTime, String? startTime})
FutureReservationTimeWindow.fromJson(Object? j)
factory

Properties

duration Duration?
final
endTime String?
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime String?
Start time of the Future Reservation. The start_time is an RFC3339 string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String