FutureReservation_PlanningStatus class final

Planning state before being submitted for evaluation

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const FutureReservation_PlanningStatus
The default value for FutureReservation_PlanningStatus.
draft → const FutureReservation_PlanningStatus
Future Reservation is being drafted.
planningStatusUnspecified → const FutureReservation_PlanningStatus
submitted → const FutureReservation_PlanningStatus
Future Reservation has been submitted for evaluation by GCP.
undefinedPlanningStatus → const FutureReservation_PlanningStatus
A value indicating that the enum field is not set.