FutureReservationsListResponse class
final
Properties
etag
→ String ?
final
hashCode
→ int
The hash code for this object.
no setter inherited
id
→ String ?
Output Only The unique identifier for the resource. This identifier is
defined by the server.
final
items
→ List <FutureReservation >
Output Only A list of future reservation resources.
final
kind
→ String ?
Output only. Output Only Type of resource.Alwayscompute#FutureReservationsListResponse for lists of
reservations
final
nextPageToken
→ String ?
Output Only This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
final
qualifiedName
→ String
The fully qualified name of this message, i.e., google.protobuf.Duration
or google.rpc.ErrorInfo.
final inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
selfLink
→ String ?
Output only. Output Only Server-defined URL for this resource.
final
unreachables
→ List <String >
Output only. Output Only Unreachable resources.
final
warning
→ Warning ?
Output Only Informational warning message.
final
google_cloud_compute_v1 0.1.1