FutureResourcesSpec class final

Specification of resources to be created at some time in the future within an optionally specified set of locations, and within the specified time range.

Constructors

FutureResourcesSpec({String? deploymentType, FutureResourcesSpecLocationPolicy? locationPolicy, FutureResourcesSpecTargetResources? targetResources, FlexibleTimeRange? timeRangeSpec})
FutureResourcesSpec.fromJson(Object? j)
factory

Properties

deploymentType String?
Indicates if the reservation allocation strategy is static (DENSE) or dynamic (STANDARD). Defaults to DENSE. Check the DeploymentType enum for the list of possible values.
final
hashCode int
The hash code for this object.
no setterinherited
locationPolicy FutureResourcesSpecLocationPolicy?
Optional location policy allowing to exclude some zone(s) in which the resources must not be created.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetResources FutureResourcesSpecTargetResources?
Specification of the reserved resources.
final
timeRangeSpec FlexibleTimeRange?
Specification of a time range in which the resources may be created. The time range specifies start of resource use and planned end of resource use.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String