FutureResourcesSpecAggregateResources class final

Constructors

FutureResourcesSpecAggregateResources({int? acceleratorCount, String? vmFamily, String? workloadType})
FutureResourcesSpecAggregateResources.fromJson(Object? j)
factory

Properties

acceleratorCount int?
Size of the request, in accelerator (chip) count.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vmFamily String?
The VM family that all instances scheduled against this reservation must belong to. Use for TPU reservations. Check the VmFamily enum for the list of possible values.
final
workloadType String?
Workload type. Use for TPU reservations. Check the WorkloadType enum for the list of possible values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String