preference property
Preference for this location. Check the Preference enum for the list of possible values.
Implementation
final String? preference;
Preference for this location. Check the Preference enum for the list of possible values.
final String? preference;