FutureResourcesSpecSpecificSkuresources class final

Constructors

FutureResourcesSpecSpecificSkuresources({int? instanceCount, List<FutureResourcesSpecLocalSsdPartition> localSsdPartitions = const [], String? machineType})
FutureResourcesSpecSpecificSkuresources.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
instanceCount int?
Size of the request, in instance count.
final
localSsdPartitions List<FutureResourcesSpecLocalSsdPartition>
Local SSD partitions. You do not have to include SSD partitions that are built in the machine type.
final
machineType String?
The machine type to use for instances that will use the reservation. This field only accepts machine type names. e.g. n2-standard-4 and does not accept machine type full or partial url. e.g. projects/my-l7ilb-project/zones/us-central1-a/machineTypes/n2-standard-4. Use for GPU reservations.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String