localSsdPartitions property
Local SSD partitions. You do not have to include SSD partitions that are built in the machine type.
Implementation
final List<FutureResourcesSpecLocalSsdPartition> localSsdPartitions;
Local SSD partitions. You do not have to include SSD partitions that are built in the machine type.
final List<FutureResourcesSpecLocalSsdPartition> localSsdPartitions;