GetEffectiveFirewallsInstanceRequest class final

A request message for Instances.GetEffectiveFirewalls. See the method description for details.

Constructors

GetEffectiveFirewallsInstanceRequest({required String instance, required String networkInterface, required String project, required String zone})
GetEffectiveFirewallsInstanceRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
instance String
Name of the instance scoping this request.
final
networkInterface String
The name of the network interface to get the effective firewalls.
final
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zone String
The name of the zone for this request.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String