GetFromFamilyImageRequest class final

A request message for Images.GetFromFamily. See the method description for details.

Constructors

GetFromFamilyImageRequest({required String family, required String project})
GetFromFamilyImageRequest.fromJson(Object? j)
factory

Properties

family String
Name of the image family to search for.
final
hashCode int
The hash code for this object.
no setterinherited
project String
The image project that the image belongs to. For example, to get a CentOS image, specify centos-cloud as the image project.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String