GetGlobalForwardingRuleRequest class final

A request message for GlobalForwardingRules.Get. See the method description for details.

Constructors

GetGlobalForwardingRuleRequest({required String forwardingRule, required String project, String? view})
GetGlobalForwardingRuleRequest.fromJson(Object? j)
factory

Properties

forwardingRule String
Name of the ForwardingRule resource to return.
final
hashCode int
The hash code for this object.
no setterinherited
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
view String?
Check the View enum for the list of possible values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String