GetGlobalForwardingRuleRequest_View class final

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const GetGlobalForwardingRuleRequest_View
The default value for GetGlobalForwardingRuleRequest_View.
basic → const GetGlobalForwardingRuleRequest_View
The default view of a ForwardingRule, which includes the basic fields.
full → const GetGlobalForwardingRuleRequest_View
The full view, including the ForwardingRule.attached_extensions field.
undefinedView → const GetGlobalForwardingRuleRequest_View
A value indicating that the enum field is not set.