GetHealthBackendServiceRequest class final

A request message for BackendServices.GetHealth. See the method description for details.

Constructors

GetHealthBackendServiceRequest({required String backendService, required String project, required ResourceGroupReference? resourceGroupReferenceResource})
GetHealthBackendServiceRequest.fromJson(Object? j)
factory

Properties

backendService String
Name of the BackendService resource to which the queried instance belongs.
final
hashCode int
The hash code for this object.
no setterinherited
project String
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
resourceGroupReferenceResource ResourceGroupReference?
The body resource for this request
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String