GetHealthOperationMetadataHealthInfo class final

Health information.

Constructors

GetHealthOperationMetadataHealthInfo({String? availabilitySloStatus, String? healthStatus, String? repairCategory, String? unhealthyReason, String? updateTime})
GetHealthOperationMetadataHealthInfo.fromJson(Object? j)
factory

Properties

availabilitySloStatus String?
Output only. The availability SLO status. Check the AvailabilitySloStatus enum for the list of possible values.
final
hashCode int
The hash code for this object.
no setterinherited
healthStatus String?
Output only. The health status. Check the HealthStatus enum for the list of possible values.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
repairCategory String?
Output only. The repair category. Check the RepairCategory enum for the list of possible values.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unhealthyReason String?
Output only. The reason for unhealthy status. Check the UnhealthyReason enum for the list of possible values.
final
updateTime String?
Output only. The time when health info was updated.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String