GetHealthReservationSlotRequest class final

A request message for ReservationSlots.GetHealth. See the method description for details.

Constructors

GetHealthReservationSlotRequest({required String parentName, required String project, String? requestId, required String reservationSlot, required String zone})
GetHealthReservationSlotRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
parentName String
The name of the parent reservation, parent block and parent sub-block. In the format of reservations/{reservation_name}/reservationBlocks/{reservation_block_name}/reservationSubBlocks/{reservation_sub_block_name}
final
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requestId String?
An optional request ID to identify requests.
final
reservationSlot String
The name of the reservation slot. Name should conform to RFC1035 or be a resource ID.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zone String
Name of the zone for this request. Zone name should conform to RFC1035.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String