GetHostRequest class final

A request message for Hosts.Get. See the method description for details.

Constructors

GetHostRequest({required String association, required String host, required String project, required String zone})
GetHostRequest.fromJson(Object? j)
factory

Properties

association String
The parent resource association for the Host. This field specifies the hierarchical context (e.g., reservation, block, sub-block) when accessing the host. For example, reservations/reservation_name, reservations/reservation_name/reservationBlocks/reservation_block_name or reservations/reservation_name/reservationBlocks/reservation_block_name/reservationSubBlocks/reservation_sub_block_name.
final
hashCode int
The hash code for this object.
no setterinherited
host String
The name of the host, formatted as RFC1035 or a resource ID number.
final
project String
The project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zone String
The name of the zone for this request, formatted as RFC1035.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String