GetIamPolicyBackendServiceRequest class final

A request message for BackendServices.GetIamPolicy. See the method description for details.

Constructors

GetIamPolicyBackendServiceRequest({int? optionsRequestedPolicyVersion, required String project, required String resource})
GetIamPolicyBackendServiceRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
optionsRequestedPolicyVersion int?
Requested IAM Policy version.
final
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
resource String
Name or id of the resource for this request.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String