GetInstanceGroupManagerRequest class final

A request message for InstanceGroupManagers.Get. See the method description for details.

Constructors

GetInstanceGroupManagerRequest({required String instanceGroupManager, required String project, required String zone})
GetInstanceGroupManagerRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
instanceGroupManager String
The name of the managed instance group.
final
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zone String
The name of thezone where the managed instance group is located.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String