GetInstanceGroupManagerResizeRequestRequest class final

A request message for InstanceGroupManagerResizeRequests.Get. See the method description for details.

Constructors

GetInstanceGroupManagerResizeRequestRequest({required String instanceGroupManager, required String project, required String resizeRequest, required String zone})
GetInstanceGroupManagerResizeRequestRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
instanceGroupManager String
The name of the managed instance group. Name should conform to RFC1035 or be a resource ID.
final
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
resizeRequest String
The name of the resize request. Name should conform to RFC1035 or be a resource ID.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zone String
Name of the href="/compute/docs/regions-zones/#available">zone scoping this request. Name should conform to RFC1035.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String