GetMacsecConfigInterconnectRequest class final

A request message for Interconnects.GetMacsecConfig. See the method description for details.

Constructors

GetMacsecConfigInterconnectRequest({required String interconnect, required String project})
GetMacsecConfigInterconnectRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
interconnect String
Name of the interconnect resource to query.
final
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String