GetNamedSetRouterRequest class final

A request message for Routers.GetNamedSet. See the method description for details.

Constructors

GetNamedSetRouterRequest({String? namedSet, required String project, required String region, required String router})
GetNamedSetRouterRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
namedSet String?
The Named Set name for this request. Name must conform to RFC1035
final
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
region String
Name of the region for this request.
final
router String
Name of the Router resource to query for the named set. The name should conform to RFC1035.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String