zone property
The name of the zone where the network endpoint group is located. It should comply with RFC1035.
Implementation
final String zone;
The name of the zone where the network endpoint group is located. It should comply with RFC1035.
final String zone;