GetPreviewFeatureRequest class final

A request message for PreviewFeatures.Get. See the method description for details.

Constructors

GetPreviewFeatureRequest({required String previewFeature, required String project})
GetPreviewFeatureRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
previewFeature String
Name of the PreviewFeature for this request.
final
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String