GetRegionBackendBucketRequest class final

A request message for RegionBackendBuckets.Get. See the method description for details.

Constructors

GetRegionBackendBucketRequest({required String backendBucket, required String project, required String region})
GetRegionBackendBucketRequest.fromJson(Object? j)
factory

Properties

backendBucket String
Name of the BackendBucket resource to return.
final
hashCode int
The hash code for this object.
no setterinherited
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
region String
Name of the region scoping this request.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String