GetRegionNetworkEndpointGroupRequest class final
A request message for RegionNetworkEndpointGroups.Get. See the method description for details.
Constructors
- GetRegionNetworkEndpointGroupRequest({required String networkEndpointGroup, required String project, required String region})
- GetRegionNetworkEndpointGroupRequest.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- networkEndpointGroup → String
-
The name of the network endpoint group. It should comply with RFC1035.
final
- project → String
-
Project ID for this request.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - region → String
-
The name of the region where
the network endpoint group is located. It should comply with RFC1035.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String