GetRegionSslPolicyRequest class final

A request message for RegionSslPolicies.Get. See the method description for details.

Constructors

GetRegionSslPolicyRequest({required String project, required String region, required String sslPolicy})
GetRegionSslPolicyRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
region String
Name of the region scoping this request.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sslPolicy String
Name of the SSL policy to update. The name must be 1-63 characters long, and comply with RFC1035.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String