GetRegionTargetHttpsProxyRequest class final

A request message for RegionTargetHttpsProxies.Get. See the method description for details.

Constructors

GetRegionTargetHttpsProxyRequest({required String project, required String region, required String targetHttpsProxy})
GetRegionTargetHttpsProxyRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
region String
Name of the region scoping this request.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetHttpsProxy String
Name of the TargetHttpsProxy resource to return.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String