GetReservationBlockRequest_View class final

View of the Block.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const GetReservationBlockRequest_View
The default value for GetReservationBlockRequest_View.
basic → const GetReservationBlockRequest_View
This view includes basic information about the reservation block
blockViewUnspecified → const GetReservationBlockRequest_View
The default / unset value. The API will default to the BASIC view.
full → const GetReservationBlockRequest_View
Includes detailed topology view.
undefinedView → const GetReservationBlockRequest_View
A value indicating that the enum field is not set.