GetReservationSlotRequest class final

A request message for ReservationSlots.Get. See the method description for details.

Constructors

GetReservationSlotRequest({required String parentName, required String project, required String reservationSlot, required String zone})
GetReservationSlotRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
parentName String
The name of the parent reservation and parent block, formatted as reservations/{reservation_name}/reservationBlocks/{reservation_block_name}/reservationSubBlocks/{reservation_sub_block_name}
final
project String
The project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
reservationSlot String
The name of the reservation slot, formatted as RFC1035 or a resource ID number.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zone String
The name of the zone for this request, formatted as RFC1035.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String