reservationSlot property
The name of the reservation slot, formatted as RFC1035 or a resource ID number.
Implementation
final String reservationSlot;
The name of the reservation slot, formatted as RFC1035 or a resource ID number.
final String reservationSlot;