GetReservationSubBlockRequest_View class final
View of the subBlock.
Constructors
- GetReservationSubBlockRequest_View(String value)
-
const
- GetReservationSubBlockRequest_View.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const GetReservationSubBlockRequest_View
- The default value for GetReservationSubBlockRequest_View.
- subBlockViewBasic → const GetReservationSubBlockRequest_View
- This view includes basic information about the reservation sub block
- subBlockViewFull → const GetReservationSubBlockRequest_View
- Includes detailed topology view.
- subBlockViewUnspecified → const GetReservationSubBlockRequest_View
- The default / unset value. The API will default to the BASIC view.
- undefinedView → const GetReservationSubBlockRequest_View
- A value indicating that the enum field is not set.