GetRoutePolicyRouterRequest class final
A request message for Routers.GetRoutePolicy. See the method description for details.
Constructors
- GetRoutePolicyRouterRequest({String? policy, required String project, required String region, required String router})
- GetRoutePolicyRouterRequest.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- policy → String?
-
The Policy name for this request. Name must conform to RFC1035
final
- project → String
-
Project ID for this request.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - region → String
-
Name of the region for this request.
final
- router → String
-
Name of the Router resource to query for the route policy. The name should
conform to RFC1035.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String