router property
Name of the Router resource to query for the route policy. The name should conform to RFC1035.
Implementation
final String router;
Name of the Router resource to query for the route policy. The name should conform to RFC1035.
final String router;