GetRuleFirewallPolicyRequest class final

A request message for FirewallPolicies.GetRule. See the method description for details.

Constructors

GetRuleFirewallPolicyRequest({required String firewallPolicy, int? priority})
GetRuleFirewallPolicyRequest.fromJson(Object? j)
factory

Properties

firewallPolicy String
Name of the firewall policy to which the queried rule belongs.
final
hashCode int
The hash code for this object.
no setterinherited
priority int?
The priority of the rule to get from the firewall policy.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String