GetSerialPortOutputInstanceRequest class final

A request message for Instances.GetSerialPortOutput. See the method description for details.

Constructors

GetSerialPortOutputInstanceRequest({required String instance, int? port, required String project, int? start, required String zone})
GetSerialPortOutputInstanceRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
instance String
Name of the instance for this request.
final
port int?
Specifies which COM or serial port to retrieve data from.
final
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start int?
Specifies the starting byte position of the output to return. To start with the first byte of output to the specified port, omit this field or set it to 0.
final
zone String
The name of the zone for this request.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String