GetServiceAttachmentRequest class final
A request message for ServiceAttachments.Get. See the method description for details.
Constructors
- GetServiceAttachmentRequest({required String project, required String region, required String serviceAttachment, bool? showNatIps})
- GetServiceAttachmentRequest.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- project → String
-
Project ID for this request.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - region → String
-
Name of the region of this request.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceAttachment → String
-
Name of the ServiceAttachment resource to return.
final
- showNatIps → bool?
-
Indicates whether NAT IPs should be included in the response.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String