GetSubnetworkRequest class final

A request message for Subnetworks.Get. See the method description for details.

Constructors

GetSubnetworkRequest({required String project, required String region, required String subnetwork, String? views})
GetSubnetworkRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
region String
Name of the region scoping this request.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subnetwork String
Name of the Subnetwork resource to return.
final
views String?
Defines the extra views returned back in the subnetwork resource. Supported values:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String