GetTargetGrpcProxyRequest class final

A request message for TargetGrpcProxies.Get. See the method description for details.

Constructors

GetTargetGrpcProxyRequest({required String project, required String targetGrpcProxy})
GetTargetGrpcProxyRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetGrpcProxy String
Name of the TargetGrpcProxy resource to return.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String