GetVersionHostRequest class final

A request message for Hosts.GetVersion. See the method description for details.

Constructors

GetVersionHostRequest({required String association, required String host, required HostsGetVersionRequest? hostsGetVersionRequestResource, required String project, String? requestId, required String zone})
GetVersionHostRequest.fromJson(Object? j)
factory

Properties

association String
The parent resource association for the Host. This field specifies the hierarchical context (e.g., reservation, block, sub-block) when accessing the host.
final
hashCode int
The hash code for this object.
no setterinherited
host String
The name of the host, formatted as RFC1035 or a resource ID number.
final
hostsGetVersionRequestResource HostsGetVersionRequest?
The body resource for this request
final
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requestId String?
An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zone String
Name of the zone for this request. Zone name should conform to RFC1035.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String