returnPartialSuccess property

bool? returnPartialSuccess
final

Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.

For example, when partial success behavior is enabled, aggregatedList for a single zone scope either returns all resources in the zone or no resources, with an error code.

Implementation

final bool? returnPartialSuccess;