insert method

Creates an address resource in the specified project by using the data included in the request.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> insert(InsertGlobalAddressRequest request) async {
  final url = _endPoint.replace(
    path: '/compute/v1/projects/${request.project}/global/addresses',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.post(url, body: request.addressResource);
  return Operation.fromJson(response);
}