GlobalAddressesMoveRequest class final

Constructors

GlobalAddressesMoveRequest({String? description, String? destinationAddress})
GlobalAddressesMoveRequest.fromJson(Object? j)
factory

Properties

description String?
An optional destination address description if intended to be different from the source.
final
destinationAddress String?
The URL of the destination address to move to. This can be a full or partial URL. For example, the following are all valid URLs to a address:
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String