GlobalForwardingRules class final

The GlobalForwardingRules API.

Implementers

Constructors

GlobalForwardingRules({required Client client, Uri? endPoint, String? gcclVersion})
Creates a GlobalForwardingRules using client for transport.
GlobalForwardingRules.fromApiKey([String? apiKey])
Creates a GlobalForwardingRules that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteGlobalForwardingRuleRequest request) Future<Operation>
Deletes the specified GlobalForwardingRule resource.
get(GetGlobalForwardingRuleRequest request) Future<ForwardingRule>
Returns the specified GlobalForwardingRule resource. Gets a list of available forwarding rules by making a list() request.
insert(InsertGlobalForwardingRuleRequest request) Future<Operation>
Creates a GlobalForwardingRule resource in the specified project using the data included in the request.
list(ListGlobalForwardingRulesRequest request) Future<ForwardingRuleList>
Retrieves a list of GlobalForwardingRule resources available to the specified project.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(PatchGlobalForwardingRuleRequest request) Future<Operation>
Updates the specified forwarding rule with the data included in the request. This method supportsPATCH semantics and uses theJSON merge patch format and processing rules. Currently, you can only patch the network_tier field.
setLabels(SetLabelsGlobalForwardingRuleRequest request) Future<Operation>
Sets the labels on the specified resource. To learn more about labels, read the Labeling resources documentation.
setTarget(SetTargetGlobalForwardingRuleRequest request) Future<Operation>
Changes target URL for the GlobalForwardingRule resource. The new target should be of the same type as the old target.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited