get method

Returns the specified GlobalForwardingRule resource. Gets a list of available forwarding rules by making a list() request.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<ForwardingRule> get(GetGlobalForwardingRuleRequest request) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/global/forwardingRules/${request.forwardingRule}',
    queryParameters: {'view': ?request.view},
  );
  final response = await _client.get(url);
  return ForwardingRule.fromJson(response);
}