setLabels method

Sets the labels on the specified resource. To learn more about labels, read the Labeling resources documentation.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> setLabels(
  SetLabelsGlobalForwardingRuleRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/global/forwardingRules/${request.resource}/setLabels',
  );
  final response = await _client.post(
    url,
    body: request.globalSetLabelsRequestResource,
  );
  return Operation.fromJson(response);
}