setTarget method

Changes target URL for the GlobalForwardingRule resource. The new target should be of the same type as the old target.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> setTarget(
  SetTargetGlobalForwardingRuleRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/global/forwardingRules/${request.forwardingRule}/setTarget',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.post(
    url,
    body: request.targetReferenceResource,
  );
  return Operation.fromJson(response);
}