delete method

Deletes the specified network endpoint group.Note that the NEG cannot be deleted if there are backend services referencing it.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> delete(
  DeleteGlobalNetworkEndpointGroupRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/global/networkEndpointGroups/${request.networkEndpointGroup}',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.delete(url);
  return Operation.fromJson(response);
}