detachNetworkEndpoints method

Detach the network endpoint from the specified network endpoint group.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> detachNetworkEndpoints(
  DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/global/networkEndpointGroups/${request.networkEndpointGroup}/detachNetworkEndpoints',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.post(
    url,
    body: request.globalNetworkEndpointGroupsDetachEndpointsRequestResource,
  );
  return Operation.fromJson(response);
}