GlobalOperations class final

The GlobalOperations API.

Implementers

Constructors

GlobalOperations({required Client client, Uri? endPoint, String? gcclVersion})
Creates a GlobalOperations using client for transport.
GlobalOperations.fromApiKey([String? apiKey])
Creates a GlobalOperations that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(AggregatedListGlobalOperationsRequest request) Future<OperationAggregatedList>
Retrieves an aggregated list of all operations.
close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteGlobalOperationRequest request) Future<DeleteGlobalOperationResponse>
Deletes the specified Operations resource.
get(GetGlobalOperationRequest request) Future<Operation>
Retrieves the specified Operations resource.
list(ListGlobalOperationsRequest request) Future<OperationList>
Retrieves a list of Operation resources contained within the specified project.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
wait(WaitGlobalOperationRequest request) Future<Operation>
Waits for the specified Operation resource to return as DONE or for the request to approach the 2 minute deadline, and retrieves the specified Operation resource. This method differs from the GET method in that it waits for no more than the default deadline (2 minutes) and then returns the current state of the operation, which might be DONE or still in progress.

Operators

operator ==(Object other) bool
The equality operator.
inherited