get method

Retrieves the specified Operations resource. Gets a list of operations by making a list() request.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> get(GetGlobalOrganizationOperationRequest request) async {
  final url = _endPoint.replace(
    path: '/compute/v1/locations/global/operations/${request.operation}',
    queryParameters: {'parentId': ?request.parentId},
  );
  final response = await _client.get(url);
  return Operation.fromJson(response);
}