GlobalOrganizationSetPolicyRequest class final

Constructors

GlobalOrganizationSetPolicyRequest({List<Binding> bindings = const [], String? etag, Policy? policy})
GlobalOrganizationSetPolicyRequest.fromJson(Object? j)
factory

Properties

bindings List<Binding>
Flatten Policy to create a backward compatible wire-format. Deprecated. Use 'policy' to specify bindings.
final
etag String?
Flatten Policy to create a backward compatible wire-format. Deprecated. Use 'policy' to specify the etag.
final
hashCode int
The hash code for this object.
no setterinherited
policy Policy?
REQUIRED: The complete policy to be applied to the 'resource'. The size of the policy is limited to a few 10s of KB. An empty policy is in general a valid policy but certain services (like Projects) might reject them.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String