labels property

Map<String, String> labels
final

A list of labels to apply for this resource. Each label must comply with the requirements for labels. For example,"webserver-frontend": "images". A label value can also be empty (e.g. "my-label": "").

Implementation

final Map<String, String> labels;