GlobalSetPolicyRequest class
final
Properties
bindings
→ List <Binding >
Flatten Policy to create a backward compatible wire-format.
Deprecated. Use 'policy' to specify bindings.
final
etag
→ String ?
Flatten Policy to create a backward compatible wire-format.
Deprecated. Use 'policy' to specify the etag.
final
hashCode
→ int
The hash code for this object.
no setter inherited
policy
→ Policy ?
REQUIRED: The complete policy to be applied to the 'resource'. The size of
the policy is limited to a few 10s of KB. An empty policy is in general a
valid policy but certain services (like Projects) might reject them.
final
qualifiedName
→ String
The fully qualified name of this message, i.e., google.protobuf.Duration
or google.rpc.ErrorInfo.
final inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
google_cloud_compute_v1 0.1.0