GlobalVmExtensionPolicies class final

The GlobalVmExtensionPolicies API.

Implementers

Constructors

GlobalVmExtensionPolicies({required Client client, Uri? endPoint, String? gcclVersion})
Creates a GlobalVmExtensionPolicies using client for transport.
GlobalVmExtensionPolicies.fromApiKey([String? apiKey])
Creates a GlobalVmExtensionPolicies that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(AggregatedListGlobalVmExtensionPoliciesRequest request) Future<VmExtensionPolicyAggregatedListResponse>
Retrieves the list of all VM Extension Policy resources available to the specified project.
close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteGlobalVmExtensionPolicyRequest request) Future<Operation>
Purge scoped resources (zonal policies) from a global VM extension policy, and then delete the global VM extension policy. Purge of the scoped resources is a pre-condition of the global VM extension policy deletion. The deletion of the global VM extension policy happens after the purge rollout is done, so it's not a part of the LRO. It's an automatic process that triggers in the backend.
get(GetGlobalVmExtensionPolicyRequest request) Future<GlobalVmExtensionPolicy>
Gets details of a global VM extension policy.
insert(InsertGlobalVmExtensionPolicyRequest request) Future<Operation>
Creates a new project level GlobalVmExtensionPolicy.
list(ListGlobalVmExtensionPoliciesRequest request) Future<GlobalVmExtensionPolicyList>
Lists global VM extension policies.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(UpdateGlobalVmExtensionPolicyRequest request) Future<Operation>
Updates a global VM extension policy.

Operators

operator ==(Object other) bool
The equality operator.
inherited