pinnedVersion property
Optional. The version pinning for the extension. If empty, the extension will be installed with the latest version released by the extension producer.
Implementation
final String? pinnedVersion;
Optional. The version pinning for the extension. If empty, the extension will be installed with the latest version released by the extension producer.
final String? pinnedVersion;