GlobalVmExtensionPolicyRolloutOperationRolloutInput class final

Constructors

GlobalVmExtensionPolicyRolloutOperationRolloutInput({String? conflictBehavior, String? name, String? predefinedRolloutPlan, String? retryUuid})
GlobalVmExtensionPolicyRolloutOperationRolloutInput.fromJson(Object? j)
factory

Properties

conflictBehavior String?
Optional. Specifies the behavior of the rollout if a conflict is detected in a project during a rollout. This only applies to insert and update methods.
final
hashCode int
The hash code for this object.
no setterinherited
name String?
Optional. The name of the rollout plan. Ex. projects//locations/global/rolloutPlans/.
final
predefinedRolloutPlan String?
Optional. Specifies the predefined rollout plan for the policy. Valid values are SLOW_ROLLOUT and FAST_ROLLOUT. The recommended value is SLOW_ROLLOUT for progressive rollout. For more information, see Rollout plans for global policies. Check the PredefinedRolloutPlan enum for the list of possible values.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
retryUuid String?
Optional. The UUID that identifies a policy rollout retry attempt for update and delete operations. Set this field only when retrying a rollout for an existing extension policy.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String