GlobalVmExtensionPolicyRolloutOperationRolloutInput_PredefinedRolloutPlan class final
Optional. Specifies the predefined rollout plan for the policy. Valid values
are SLOW_ROLLOUT and FAST_ROLLOUT. The recommended value is
SLOW_ROLLOUT for progressive rollout. For more information, see Rollout
plans for global policies.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const GlobalVmExtensionPolicyRolloutOperationRolloutInput_PredefinedRolloutPlan
- The default value for GlobalVmExtensionPolicyRolloutOperationRolloutInput_PredefinedRolloutPlan.
- fastRollout → const GlobalVmExtensionPolicyRolloutOperationRolloutInput_PredefinedRolloutPlan
- rolloutPlanUnspecified → const GlobalVmExtensionPolicyRolloutOperationRolloutInput_PredefinedRolloutPlan
- slowRollout → const GlobalVmExtensionPolicyRolloutOperationRolloutInput_PredefinedRolloutPlan
- undefinedPredefinedRolloutPlan → const GlobalVmExtensionPolicyRolloutOperationRolloutInput_PredefinedRolloutPlan
- A value indicating that the enum field is not set.