GlobalVmExtensionPolicy_ScopedResourceStatus class final
Output only. Output Only The scoped resource status. It's only for tracking the
purging status of the policy.
Constructors
- GlobalVmExtensionPolicy_ScopedResourceStatus(String value)
-
const
- GlobalVmExtensionPolicy_ScopedResourceStatus.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const GlobalVmExtensionPolicy_ScopedResourceStatus
- The default value for GlobalVmExtensionPolicy_ScopedResourceStatus.
- scopedResourceStatusDeleting → const GlobalVmExtensionPolicy_ScopedResourceStatus
- The zonal policies are being deleted.
- scopedResourceStatusUnspecified → const GlobalVmExtensionPolicy_ScopedResourceStatus
- Default value. This value is unused.
- undefinedScopedResourceStatus → const GlobalVmExtensionPolicy_ScopedResourceStatus
- A value indicating that the enum field is not set.