GroupMaintenanceInfo class final
Maintenance Info for ReservationBlocks.
Constructors
- GroupMaintenanceInfo({int? instanceMaintenanceOngoingCount, int? instanceMaintenancePendingCount, int? maintenanceOngoingCount, int? maintenancePendingCount, String? schedulingType, int? subblockInfraMaintenanceOngoingCount, int? subblockInfraMaintenancePendingCount, UpcomingMaintenance? upcomingGroupMaintenance})
- GroupMaintenanceInfo.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- instanceMaintenanceOngoingCount → int?
-
Describes number of instances that have ongoing maintenance.
final
- instanceMaintenancePendingCount → int?
-
Describes number of instances that have pending maintenance.
final
- maintenanceOngoingCount → int?
-
Progress for ongoing maintenance for this group of VMs/hosts.
Describes number of hosts in the block that have ongoing maintenance.
final
- maintenancePendingCount → int?
-
Progress for ongoing maintenance for this group of VMs/hosts.
Describes number of hosts in the block that have pending maintenance.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schedulingType → String?
-
The type of maintenance for the reservation.
Check the SchedulingType enum for the list of possible values.
final
- subblockInfraMaintenanceOngoingCount → int?
-
Describes number of subblock Infrastructure that has ongoing maintenance.
Here, Subblock Infrastructure Maintenance pertains to upstream hardware
contained in the Subblock that is necessary for a VM Family(e.g. NVLink
Domains). Not all VM Families will support this field.
final
- subblockInfraMaintenancePendingCount → int?
-
Describes number of subblock Infrastructure that has pending maintenance.
Here, Subblock Infrastructure Maintenance pertains to upstream hardware
contained in the Subblock that is necessary for a VM Family (e.g. NVLink
Domains). Not all VM Families will support this field.
final
- upcomingGroupMaintenance → UpcomingMaintenance?
-
Maintenance information on this group of VMs.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String