maintenanceOngoingCount property
Progress for ongoing maintenance for this group of VMs/hosts. Describes number of hosts in the block that have ongoing maintenance.
Implementation
final int? maintenanceOngoingCount;
Progress for ongoing maintenance for this group of VMs/hosts. Describes number of hosts in the block that have ongoing maintenance.
final int? maintenanceOngoingCount;