subblockInfraMaintenanceOngoingCount property

int? subblockInfraMaintenanceOngoingCount
final

Describes number of subblock Infrastructure that has ongoing maintenance. Here, Subblock Infrastructure Maintenance pertains to upstream hardware contained in the Subblock that is necessary for a VM Family(e.g. NVLink Domains). Not all VM Families will support this field.

Implementation

final int? subblockInfraMaintenanceOngoingCount;