toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (instanceMaintenanceOngoingCount != null)
      'instanceMaintenanceOngoingCount=$instanceMaintenanceOngoingCount',
    if (instanceMaintenancePendingCount != null)
      'instanceMaintenancePendingCount=$instanceMaintenancePendingCount',
    if (maintenanceOngoingCount != null)
      'maintenanceOngoingCount=$maintenanceOngoingCount',
    if (maintenancePendingCount != null)
      'maintenancePendingCount=$maintenancePendingCount',
    if (schedulingType != null) 'schedulingType=$schedulingType',
    if (subblockInfraMaintenanceOngoingCount != null)
      'subblockInfraMaintenanceOngoingCount=$subblockInfraMaintenanceOngoingCount',
    if (subblockInfraMaintenancePendingCount != null)
      'subblockInfraMaintenancePendingCount=$subblockInfraMaintenancePendingCount',
  ].join(',');
  return 'GroupMaintenanceInfo(${$contents})';
}