port property
The TCP port number to which the health check prober sends packets. Valid values are 1 through 65535.
Implementation
final int? port;
The TCP port number to which the health check prober sends packets. Valid values are 1 through 65535.
final int? port;