GuestAttributesEntry class final

A guest attributes namespace/key/value entry.

Constructors

GuestAttributesEntry({String? key, String? namespace, String? value})
GuestAttributesEntry.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
key String?
Key for the guest attribute entry.
final
namespace String?
Namespace for the guest attribute entry.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String?
Value for the guest attribute entry.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String