HealthAggregationPolicy class final
Represents a health aggregation policy.
A health aggregation policy resource defines a policy to aggregate health.
For more information, see Health checks overview.
Constructors
- HealthAggregationPolicy({String? creationTimestamp, String? description, String? fingerprint, int? healthyPercentThreshold, BigInt? id, String? kind, int? minHealthyThreshold, String? name, String? policyType, String? region, String? selfLink, String? selfLinkWithId})
- HealthAggregationPolicy.fromJson(Object? j)
-
factory
Properties
- creationTimestamp → String?
-
Output only.
Output OnlyCreation timestamp inRFC3339 text format.final - description → String?
-
An optional description of this resource. Provide this property when you
create the resource.
final
- fingerprint → String?
-
Fingerprint of this resource. A hash of the contents stored in this object.
This field is used in optimistic locking. This field will be ignored when
inserting a HealthAggregationPolicy. An up-to-date fingerprint
must be provided in order to patch the HealthAggregationPolicy; Otherwise,
the request will fail with error 412 conditionNotMet. To see
the latest fingerprint, make a get() request to retrieve the
HealthAggregationPolicy.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- healthyPercentThreshold → int?
-
Can only be set if the policyType field isBACKEND_SERVICE_POLICY. Specifies the threshold (as a
percentage) of healthy endpoints required in order to consider the
aggregated health result HEALTHY. Defaults to 60. Must be in
range
0, 100. Not applicable if the policyType field isDNB_PUBLIC_IP_POLICY. Can be mutated. This field is optional, and will be set to the default if unspecified. Note that both this threshold and minHealthyThreshold must be satisfied in order for HEALTHY to be the aggregated result. "Endpoints" refers to network endpoints within a Network Endpoint Group or instances within an Instance Group.final - id → BigInt?
-
Output only.
Output OnlyThe unique identifier for the resource. This identifier is defined by the server.final - kind → String?
-
Output only.
Output OnlyType of the resource. Alwayscompute#healthAggregationPolicy for health aggregation policies.final - minHealthyThreshold → int?
-
Can only be set if the policyType field isBACKEND_SERVICE_POLICY. Specifies the minimum number of
healthy endpoints required in order to consider the aggregated health
result HEALTHY. Defaults to 1. Must be positive. Not
applicable if the policyType field isDNB_PUBLIC_IP_POLICY. Can be mutated. This field is optional,
and will be set to the default if unspecified. Note that both this
threshold and healthyPercentThreshold must be satisfied in
order for HEALTHY to be the aggregated result. "Endpoints" refers to
network endpoints within a Network Endpoint Group or instances within an
Instance Group.
final
- name → String?
-
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression
[a-z]([-a-z0-9]*[a-z0-9])?which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.final - policyType → String?
-
Specifies the type of the healthAggregationPolicy. The only allowed value
for global resources is DNS_PUBLIC_IP_POLICY. The only allowed
value for regional resources is BACKEND_SERVICE_POLICY. Must
be specified when the healthAggregationPolicy is created, and cannot be
mutated.
Check the PolicyType enum for the list of possible values.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - region → String?
-
Output only.
Output OnlyURL of the region where the health aggregation policy resides. This field applies only to the regional resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfLink → String?
-
Output only.
Output OnlyServer-defined URL for the resource.final - selfLinkWithId → String?
-
Output only.
Output OnlyServer-defined URL with id for the resource.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String