toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (creationTimestamp != null) 'creationTimestamp=$creationTimestamp',
    if (description != null) 'description=$description',
    if (fingerprint != null) 'fingerprint=$fingerprint',
    if (healthyPercentThreshold != null)
      'healthyPercentThreshold=$healthyPercentThreshold',
    if (id != null) 'id=$id',
    if (kind != null) 'kind=$kind',
    if (minHealthyThreshold != null)
      'minHealthyThreshold=$minHealthyThreshold',
    if (name != null) 'name=$name',
    if (policyType != null) 'policyType=$policyType',
    if (region != null) 'region=$region',
    if (selfLink != null) 'selfLink=$selfLink',
    if (selfLinkWithId != null) 'selfLinkWithId=$selfLinkWithId',
  ].join(',');
  return 'HealthAggregationPolicy(${$contents})';
}