healthyThreshold property
A so-far unhealthy instance will be marked healthy after this many consecutive successes. The default value is 2.
Implementation
final int? healthyThreshold;
A so-far unhealthy instance will be marked healthy after this many consecutive successes. The default value is 2.
final int? healthyThreshold;