toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (checkIntervalSec != null) 'checkIntervalSec=$checkIntervalSec',
    if (creationTimestamp != null) 'creationTimestamp=$creationTimestamp',
    if (description != null) 'description=$description',
    if (healthyThreshold != null) 'healthyThreshold=$healthyThreshold',
    if (id != null) 'id=$id',
    if (kind != null) 'kind=$kind',
    if (name != null) 'name=$name',
    if (region != null) 'region=$region',
    if (selfLink != null) 'selfLink=$selfLink',
    if (timeoutSec != null) 'timeoutSec=$timeoutSec',
    if (type != null) 'type=$type',
    if (unhealthyThreshold != null) 'unhealthyThreshold=$unhealthyThreshold',
  ].join(',');
  return 'HealthCheck(${$contents})';
}