unhealthyThreshold property
A so-far healthy instance will be marked unhealthy after this many consecutive failures. The default value is 2.
Implementation
final int? unhealthyThreshold;
A so-far healthy instance will be marked unhealthy after this many consecutive failures. The default value is 2.
final int? unhealthyThreshold;