enable property
Indicates whether or not to export logs. This is false by default, which means no health check logging will be done.
Implementation
final bool? enable;
Indicates whether or not to export logs. This is false by default, which means no health check logging will be done.
final bool? enable;