notificationEndpoints property

List<String> notificationEndpoints
final

A list of URLs to the NotificationEndpoint resources. Must not have more than 10. A list of endpoints for receiving notifications of change in health status. For regionalHealthCheckService,NotificationEndpoint must be regional and in the same region. For global HealthCheckService,NotificationEndpoint must be global.

Implementation

final List<String> notificationEndpoints;