HealthCheckServiceAggregatedList class final
Contains a list of HealthCheckServicesScopedList.
Constructors
-
HealthCheckServiceAggregatedList({String? id, Map<
String, HealthCheckServicesScopedList> items = const {}, String? kind, String? nextPageToken, String? selfLink, List<String> unreachables = const [], Warning? warning}) - HealthCheckServiceAggregatedList.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
Output OnlyUnique identifier for the resource; defined by the server.final -
items
→ Map<
String, HealthCheckServicesScopedList> -
A list of HealthCheckServicesScopedList resources.
final
- kind → String?
-
Output only. Type of resource.
final
- nextPageToken → String?
-
Output OnlyThis token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfLink → String?
-
Output only.
Output OnlyServer-defined URL for this resource.final -
unreachables
→ List<
String> -
Output only.
Output OnlyUnreachable resources.final - warning → Warning?
-
Output OnlyInformational warning message.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String