HealthChecks class final

The HealthChecks API.

Implementers

Constructors

HealthChecks({required Client client, Uri? endPoint, String? gcclVersion})
Creates a HealthChecks using client for transport.
HealthChecks.fromApiKey([String? apiKey])
Creates a HealthChecks that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(AggregatedListHealthChecksRequest request) Future<HealthChecksAggregatedList>
Retrieves the list of all HealthCheck resources, regional and global, available to the specified project.
close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteHealthCheckRequest request) Future<Operation>
Deletes the specified HealthCheck resource.
get(GetHealthCheckRequest request) Future<HealthCheck>
Returns the specified HealthCheck resource.
insert(InsertHealthCheckRequest request) Future<Operation>
Creates a HealthCheck resource in the specified project using the data included in the request.
list(ListHealthChecksRequest request) Future<HealthCheckList>
Retrieves the list of HealthCheck resources available to the specified project.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(PatchHealthCheckRequest request) Future<Operation>
Updates a HealthCheck resource in the specified project using the data included in the request. This method supportsPATCH semantics and uses theJSON merge patch format and processing rules.
testIamPermissions(TestIamPermissionsHealthCheckRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
toString() String
A string representation of this object.
inherited
update(UpdateHealthCheckRequest request) Future<Operation>
Updates a HealthCheck resource in the specified project using the data included in the request.

Operators

operator ==(Object other) bool
The equality operator.
inherited