healthAggregationPolicy property
URL to the HealthAggregationPolicy resource. Must be set. Must be regional and in the same region as the HealthSource. Can be mutated.
Implementation
final String? healthAggregationPolicy;
URL to the HealthAggregationPolicy resource. Must be set. Must be regional and in the same region as the HealthSource. Can be mutated.
final String? healthAggregationPolicy;