HealthSourceHealth class final

Response message for RegionHealthSources.GetHealth

Constructors

HealthSourceHealth({String? healthState, String? kind, List<HealthSourcesGetHealthResponseSourceInfo> sources = const []})
HealthSourceHealth.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
healthState String?
Health state of the HealthSource. Check the HealthState enum for the list of possible values.
final
kind String?
Output only. Output Only Type of resource. Alwayscompute#healthSourceHealth for the health of health sources.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sources List<HealthSourcesGetHealthResponseSourceInfo>
Health state details of the sources.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String