HealthSourceHealth_HealthState class final
Health state of the HealthSource.
Constructors
- HealthSourceHealth_HealthState(String value)
-
const
- HealthSourceHealth_HealthState.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const HealthSourceHealth_HealthState
- The default value for HealthSourceHealth_HealthState.
- healthy → const HealthSourceHealth_HealthState
- undefinedHealthState → const HealthSourceHealth_HealthState
- A value indicating that the enum field is not set.
- unhealthy → const HealthSourceHealth_HealthState
- unknown → const HealthSourceHealth_HealthState