HealthSourcesGetHealthResponseSourceInfo class
final
Properties
backends
→ List <HealthSourcesGetHealthResponseSourceInfoBackendInfo >
Represents an instance group or network endpoint group behind the source
backend service. Only used if the sourceType of the regionHealthSource
is BACKEND_SERVICE.
final
forwardingRule
→ String ?
Fully qualified URL of the forwarding rule associated with the source
resource if it is a L4ILB backend service.
final
hashCode
→ int
The hash code for this object.
no setter inherited
qualifiedName
→ String
The fully qualified name of this message, i.e., google.protobuf.Duration
or google.rpc.ErrorInfo.
final inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
source
→ String ?
Fully qualified URL of the associated source resource. This is always a
backend service URL.
final
google_cloud_compute_v1 0.1.0