forwardingRule property
Fully qualified URL of the forwarding rule associated with the source resource if it is a L4ILB backend service.
Implementation
final String? forwardingRule;
Fully qualified URL of the forwarding rule associated with the source resource if it is a L4ILB backend service.
final String? forwardingRule;