endpointCount property
Total number of endpoints when determining the health of the regionHealthSource.
Implementation
final int? endpointCount;
Total number of endpoints when determining the health of the regionHealthSource.
final int? endpointCount;