group property
Fully qualified URL of an instance group or network endpoint group behind the source backend service.
Implementation
final String? group;
Fully qualified URL of an instance group or network endpoint group behind the source backend service.
final String? group;