forwardingRule property
URL of the forwarding rule associated with the health status of the instance.
Implementation
final String? forwardingRule;
URL of the forwarding rule associated with the health status of the instance.
final String? forwardingRule;