ipAddress property

String? ipAddress
final

For target pool based Network Load Balancing, it indicates the forwarding rule's IP address assigned to this instance. For other types of load balancing, the field indicates VM internal ip.

Implementation

final String? ipAddress;