HealthStatusForNetworkEndpoint class final

Constructors

HealthStatusForNetworkEndpoint({BackendServiceReference? backendService, ForwardingRuleReference? forwardingRule, HealthCheckReference? healthCheck, HealthCheckServiceReference? healthCheckService, String? healthState, String? ipv6HealthState})
HealthStatusForNetworkEndpoint.fromJson(Object? j)
factory

Properties

backendService BackendServiceReference?
URL of the backend service associated with the health state of the network endpoint.
final
forwardingRule ForwardingRuleReference?
URL of the forwarding rule associated with the health state of the network endpoint.
final
hashCode int
The hash code for this object.
no setterinherited
healthCheck HealthCheckReference?
URL of the health check associated with the health state of the network endpoint.
final
healthCheckService HealthCheckServiceReference?
URL of the health check service associated with the health state of the network endpoint.
final
healthState String?
Health state of the network endpoint determined based on the health checks configured. Check the HealthState enum for the list of possible values.
final
ipv6HealthState String?
Health state of the ipv6 network endpoint determined based on the health checks configured. Check the Ipv6HealthState enum for the list of possible values.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String