backendService property
URL of the backend service associated with the health state of the network endpoint.
Implementation
final BackendServiceReference? backendService;
URL of the backend service associated with the health state of the network endpoint.
final BackendServiceReference? backendService;