forwardingRule property
URL of the forwarding rule associated with the health state of the network endpoint.
Implementation
final ForwardingRuleReference? forwardingRule;
URL of the forwarding rule associated with the health state of the network endpoint.
final ForwardingRuleReference? forwardingRule;