healthCheck property
URL of the health check associated with the health state of the network endpoint.
Implementation
final HealthCheckReference? healthCheck;
URL of the health check associated with the health state of the network endpoint.
final HealthCheckReference? healthCheck;