healthCheckService property
URL of the health check service associated with the health state of the network endpoint.
Implementation
final HealthCheckServiceReference? healthCheckService;
URL of the health check service associated with the health state of the network endpoint.
final HealthCheckServiceReference? healthCheckService;