healthState property
Health state of the network endpoint determined based on the health checks configured. Check the HealthState enum for the list of possible values.
Implementation
final String? healthState;
Health state of the network endpoint determined based on the health checks configured. Check the HealthState enum for the list of possible values.
final String? healthState;