ipv6HealthState property
Health state of the ipv6 network endpoint determined based on the health checks configured. Check the Ipv6HealthState enum for the list of possible values.
Implementation
final String? ipv6HealthState;
Health state of the ipv6 network endpoint determined based on the health checks configured. Check the Ipv6HealthState enum for the list of possible values.
final String? ipv6HealthState;