HealthStatusForNetworkEndpoint_Ipv6HealthState class final
Health state of the ipv6 network endpoint determined based on the health checks configured. Additional supported values which may be not listed in the enum directly due to technical reasons: DRAINING HEALTHY UNHEALTHY UNKNOWN
Constructors
- HealthStatusForNetworkEndpoint_Ipv6HealthState(String value)
-
const
- HealthStatusForNetworkEndpoint_Ipv6HealthState.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const HealthStatusForNetworkEndpoint_Ipv6HealthState
- The default value for HealthStatusForNetworkEndpoint_Ipv6HealthState.
- undefinedIpv6HealthState → const HealthStatusForNetworkEndpoint_Ipv6HealthState
- A value indicating that the enum field is not set.