HealthStatus_HealthState class final

Health state of the IPv4 address of the instance.

Constructors

HealthStatus_HealthState(String value)
const
HealthStatus_HealthState.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const HealthStatus_HealthState
The default value for HealthStatus_HealthState.
healthy → const HealthStatus_HealthState
undefinedHealthState → const HealthStatus_HealthState
A value indicating that the enum field is not set.
unhealthy → const HealthStatus_HealthState