HealthStatus_WeightError class final

Constructors

HealthStatus_WeightError(String value)
const
HealthStatus_WeightError.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const HealthStatus_WeightError
The default value for HealthStatus_WeightError.
invalidWeight → const HealthStatus_WeightError
The response to a Health Check probe had the HTTP response header field X-Load-Balancing-Endpoint-Weight, but its content was invalid (i.e., not a non-negative single-precision floating-point number in decimal string representation).
missingWeight → const HealthStatus_WeightError
The response to a Health Check probe did not have the HTTP response header field X-Load-Balancing-Endpoint-Weight.
unavailableWeight → const HealthStatus_WeightError
This is the value when the accompanied health status is either TIMEOUT (i.e.,the Health Check probe was not able to get a response in time) or UNKNOWN. For the latter, it should be typically because there has not been sufficient time to parse and report the weight for a new backend (which is with 0.0.0.0 ip address). However, it can be also due to an outage case for which the health status is explicitly reset to UNKNOWN.
undefinedWeightError → const HealthStatus_WeightError
A value indicating that the enum field is not set.
weightNone → const HealthStatus_WeightError
This is the default value when WeightReportMode is DISABLE, and is also the initial value when WeightReportMode has just updated to ENABLE or DRY_RUN and there has not been sufficient time to parse and report the backend weight.