unavailableWeight constant

HealthStatus_WeightError const unavailableWeight

This is the value when the accompanied health status is either TIMEOUT (i.e.,the Health Check probe was not able to get a response in time) or UNKNOWN. For the latter, it should be typically because there has not been sufficient time to parse and report the weight for a new backend (which is with 0.0.0.0 ip address). However, it can be also due to an outage case for which the health status is explicitly reset to UNKNOWN.

Implementation

static const unavailableWeight = HealthStatus_WeightError(
  'UNAVAILABLE_WEIGHT',
);