weightNone constant

HealthStatus_WeightError const weightNone

This is the default value when WeightReportMode is DISABLE, and is also the initial value when WeightReportMode has just updated to ENABLE or DRY_RUN and there has not been sufficient time to parse and report the backend weight.

Implementation

static const weightNone = HealthStatus_WeightError('WEIGHT_NONE');