Host class final

Represents a host resource.

Constructors

Host({List<String> aliasLinks = const [], String? creationTimestamp, String? description, BigInt? id, String? kind, String? name, String? selfLink, String? selfLinkWithId, String? state, HostStatus? status, String? zone})
Host.fromJson(Object? j)
factory

Properties

Output only. All aliases for this resource. e.g. projects/123/zones/us-centra1-a/reservation/r1/reservationBlock/b1/hosts/h1
final
creationTimestamp String?
Output only. The creation timestamp, formatted asRFC3339 text.
final
description String?
An optional description of this resource.
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output only. The unique identifier for this resource. This identifier is defined by the server.
final
kind String?
Output only. The type of resource. Alwayscompute#host for hosts.
final
name String?
Output only. The name of the host.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output only. The self link of the host.
final
selfLinkWithId String?
Output only. The self link with id of the host.
final
state String?
Output only. The state of the host. Check the State enum for the list of possible values.
final
status HostStatus?
Output only. The status of the host
final
zone String?
Output only. The zone in which the host resides.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String