pathMatcher property
The name of the PathMatcher to use to match the path portion of the URL if the hostRule matches the URL's host portion.
Implementation
final String? pathMatcher;
The name of the PathMatcher to use to match the path portion of the URL if the hostRule matches the URL's host portion.
final String? pathMatcher;