Host_State class final

Output only. The state of the host.

Constructors

Host_State(String value)
const
Host_State.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const Host_State
The default value for Host_State.
active → const Host_State
The host has allocated all its resources.
creating → const Host_State
The resources are being allocated for the host.
deleting → const Host_State
The host is currently being deleted.
stateUnspecified → const Host_State
unavailable → const Host_State
The host is currently unavailable.
undefinedState → const Host_State
A value indicating that the enum field is not set.