Hosts class final
The Hosts API.
- Implementers
Constructors
- Hosts({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
Hostsusingclientfor transport. - Hosts.fromApiKey([String? apiKey])
-
Creates a
Hoststhat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
get(
GetHostRequest request) → Future< Host> - Retrieves information about the specified host.
-
getVersion(
GetVersionHostRequest request) → Future< Operation> - Allows customers to get SBOM versions of a host.
-
list(
ListHostsRequest request) → Future< HostsListResponse> - Retrieves a list of hosts.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited