port property
The TCP port number to which the health check prober sends packets. The default value is 443. Valid values are 1 through65535.
Implementation
final int? port;
The TCP port number to which the health check prober sends packets. The default value is 443. Valid values are 1 through65535.
final int? port;