HttpFaultAbort class final

Specification for how requests are aborted as part of fault injection.

Constructors

HttpFaultAbort({int? httpStatus, double? percentage})
HttpFaultAbort.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
httpStatus int?
The HTTP status code used to abort the request.
final
percentage double?
The percentage of traffic for connections, operations, or requests that is aborted as part of fault injection.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String