delay property
The specification for how client requests are delayed as part of fault injection, before being sent to a backend service.
Implementation
final HttpFaultDelay? delay;
The specification for how client requests are delayed as part of fault injection, before being sent to a backend service.
final HttpFaultDelay? delay;