HttpHeaderAction class final

The request and response header transformations that take effect before the request is passed along to the selected backendService.

Constructors

HttpHeaderAction({List<HttpHeaderOption> requestHeadersToAdd = const [], List<String> requestHeadersToRemove = const [], List<HttpHeaderOption> responseHeadersToAdd = const [], List<String> responseHeadersToRemove = const []})
HttpHeaderAction.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requestHeadersToAdd List<HttpHeaderOption>
Headers to add to a matching request before forwarding the request to thebackendService.
final
requestHeadersToRemove List<String>
A list of header names for headers that need to be removed from the request before forwarding the request to the backendService.
final
responseHeadersToAdd List<HttpHeaderOption>
Headers to add the response before sending the response back to the client.
final
responseHeadersToRemove List<String>
A list of header names for headers that need to be removed from the response before sending the response back to the client.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String