requestHeadersToAdd property
Headers to add to a matching request before forwarding the request to thebackendService.
Implementation
final List<HttpHeaderOption> requestHeadersToAdd;
Headers to add to a matching request before forwarding the request to thebackendService.
final List<HttpHeaderOption> requestHeadersToAdd;