requestHeadersToRemove property

List<String> requestHeadersToRemove
final

A list of header names for headers that need to be removed from the request before forwarding the request to the backendService.

Implementation

final List<String> requestHeadersToRemove;