responseHeadersToAdd property
Headers to add the response before sending the response back to the client.
Implementation
final List<HttpHeaderOption> responseHeadersToAdd;
Headers to add the response before sending the response back to the client.
final List<HttpHeaderOption> responseHeadersToAdd;