responseHeadersToRemove property

List<String> responseHeadersToRemove
final

A list of header names for headers that need to be removed from the response before sending the response back to the client.

Implementation

final List<String> responseHeadersToRemove;