invertMatch property

bool? invertMatch
final

If set to false, the headerMatch is considered a match if the preceding match criteria are met. If set to true, the headerMatch is considered a match if the preceding match criteria are NOT met.

The default setting is false.

Implementation

final bool? invertMatch;