HttpHeaderOption class final

Specification determining how headers are added to requests or responses.

Constructors

HttpHeaderOption({String? headerName, String? headerValue, bool? replace})
HttpHeaderOption.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
headerName String?
The name of the header.
final
headerValue String?
The value of the header to add.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
replace bool?
If false, headerValue is appended to any values that already exist for the header. If true, headerValue is set for the header, discarding any values that were set for that header.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String