exactMatch property
The queryParameterMatch matches if the value of the parameter exactly matches the contents of exactMatch.
Only one of presentMatch, exactMatch, orregexMatch must be set.
Implementation
final String? exactMatch;
The queryParameterMatch matches if the value of the parameter exactly matches the contents of exactMatch.
Only one of presentMatch, exactMatch, orregexMatch must be set.
final String? exactMatch;