presentMatch property

bool? presentMatch
final

Specifies that the queryParameterMatch matches if the request contains the query parameter, irrespective of whether the parameter has a value or not.

Only one of presentMatch, exactMatch, orregexMatch must be set.

Implementation

final bool? presentMatch;