HttpRedirectAction class final

Specifies settings for an HTTP redirect.

Constructors

HttpRedirectAction({String? hostRedirect, bool? httpsRedirect, String? pathRedirect, String? prefixRedirect, String? redirectResponseCode, bool? stripQuery})
HttpRedirectAction.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
hostRedirect String?
The host that is used in the redirect response instead of the one that was supplied in the request.
final
httpsRedirect bool?
If set to true, the URL scheme in the redirected request is set to HTTPS. If set to false, the URL scheme of the redirected request remains the same as that of the request.
final
pathRedirect String?
The path that is used in the redirect response instead of the one that was supplied in the request.
final
prefixRedirect String?
The prefix that replaces the prefixMatch specified in the HttpRouteRuleMatch, retaining the remaining portion of the URL before redirecting the request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
redirectResponseCode String?
The HTTP Status code to use for this RedirectAction.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stripQuery bool?
If set to true, any accompanying query portion of the original URL is removed before redirecting the request. If set to false, the query portion of the original URL is retained.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String