hostRedirect property
The host that is used in the redirect response instead of the one that was supplied in the request.
The value must be from 1 to 255 characters.
Implementation
final String? hostRedirect;
The host that is used in the redirect response instead of the one that was supplied in the request.
The value must be from 1 to 255 characters.
final String? hostRedirect;