stripQuery property

bool? stripQuery
final

If set to true, any accompanying query portion of the original URL is removed before redirecting the request. If set to false, the query portion of the original URL is retained.

The default is set to false.

Implementation

final bool? stripQuery;