HttpRedirectAction_RedirectResponseCode class final

The HTTP Status code to use for this RedirectAction.

Supported values are:

  • MOVED_PERMANENTLY_DEFAULT, which is the default value and corresponds to 301.
  • FOUND, which corresponds to 302.
  • SEE_OTHER which corresponds to 303.
  • TEMPORARY_REDIRECT, which corresponds to 307. In this case, the request method is retained.
  • PERMANENT_REDIRECT, which corresponds to 308. In this case, the request method is retained.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const HttpRedirectAction_RedirectResponseCode
The default value for HttpRedirectAction_RedirectResponseCode.
found → const HttpRedirectAction_RedirectResponseCode
Http Status Code 302 - Found.
movedPermanentlyDefault → const HttpRedirectAction_RedirectResponseCode
Http Status Code 301 - Moved Permanently.
permanentRedirect → const HttpRedirectAction_RedirectResponseCode
Http Status Code 308 - Permanent Redirect maintaining HTTP method.
seeOther → const HttpRedirectAction_RedirectResponseCode
Http Status Code 303 - See Other.
temporaryRedirect → const HttpRedirectAction_RedirectResponseCode
Http Status Code 307 - Temporary Redirect maintaining HTTP method.
undefinedRedirectResponseCode → const HttpRedirectAction_RedirectResponseCode
A value indicating that the enum field is not set.