HttpRetryPolicy class final
The retry policy associates with HttpRouteRule
Constructors
-
HttpRetryPolicy({int? numRetries, Duration? perTryTimeout, List<
String> retryConditions = const []}) - HttpRetryPolicy.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- numRetries → int?
-
Specifies the allowed number retries. This number must be > 0.
If not specified, defaults to 1.
final
- perTryTimeout → Duration?
-
Specifies a non-zero timeout per retry attempt.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited -
retryConditions
→ List<
String> -
Specifies one or more conditions when this retry policy applies. Valid
values are:
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String