HttpRouteAction class final

Constructors

HttpRouteAction({CachePolicy? cachePolicy, CorsPolicy? corsPolicy, HttpFaultInjection? faultInjectionPolicy, Duration? maxStreamDuration, RequestMirrorPolicy? requestMirrorPolicy, HttpRetryPolicy? retryPolicy, Duration? timeout, UrlRewrite? urlRewrite, List<WeightedBackendService> weightedBackendServices = const []})
HttpRouteAction.fromJson(Object? j)
factory

Properties

cachePolicy CachePolicy?
Specifies the cache policy configuration for matched traffic. Available only for Global EXTERNAL_MANAGED load balancer schemes. At least one property must be specified. This policy cannot be specified if any target backend has Identity-Aware Proxy enabled.
final
corsPolicy CorsPolicy?
The specification for allowing client-side cross-origin requests. For more information about the W3C recommendation for cross-origin resource sharing (CORS), see Fetch API Living Standard.
final
faultInjectionPolicy HttpFaultInjection?
The specification for fault injection introduced into traffic to test the resiliency of clients to backend service failure. As part of fault injection, when clients send requests to a backend service, delays can be introduced by a load balancer on a percentage of requests before sending those requests to the backend service. Similarly requests from clients can be aborted by the load balancer for a percentage of requests.timeout and retry_policy is ignored by clients that are configured with a fault_injection_policy if:
final
hashCode int
The hash code for this object.
no setterinherited
maxStreamDuration Duration?
Specifies the maximum duration (timeout) for streams on the selected route. Unlike the timeout field where the timeout duration starts from the time the request has been fully processed (known asend-of-stream), the duration in this field is computed from the beginning of the stream until the response has been processed, including all retries. A stream that does not complete in this duration is closed.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requestMirrorPolicy RequestMirrorPolicy?
Specifies the policy on how requests intended for the route's backends are shadowed to a separate mirrored backend service. The load balancer does not wait for responses from the shadow service. Before sending traffic to the shadow service, the host / authority header is suffixed with-shadow.
final
retryPolicy HttpRetryPolicy?
Specifies the retry policy associated with this route.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration?
Specifies the timeout for the selected route. Timeout is computed from the time the request has been fully processed (known as end-of-stream) up until the response has been processed. Timeout includes all retries.
final
urlRewrite UrlRewrite?
The spec to modify the URL of the request, before forwarding the request to the matched service.
final
weightedBackendServices List<WeightedBackendService>
A list of weighted backend services to send traffic to when a route match occurs. The weights determine the fraction of traffic that flows to their corresponding backend service. If all traffic needs to go to a single backend service, there must be oneweightedBackendService with weight set to a non-zero number.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String