requestMirrorPolicy property

RequestMirrorPolicy? requestMirrorPolicy
final

Specifies the policy on how requests intended for the route's backends are shadowed to a separate mirrored backend service. The load balancer does not wait for responses from the shadow service. Before sending traffic to the shadow service, the host / authority header is suffixed with-shadow.

Not supported when the URL map is bound to a target gRPC proxy that has the validateForProxyless field set to true.

Implementation

final RequestMirrorPolicy? requestMirrorPolicy;