description property

String? description
final

The short description conveying the intent of this routeRule.

The description can have a maximum length of 1024 characters.

Implementation

final String? description;