matchRules property

List<HttpRouteRuleMatch> matchRules
final

The list of criteria for matching attributes of a request to thisrouteRule. This list has OR semantics: the request matches this routeRule when any of thematchRules are satisfied. However predicates within a given matchRule have AND semantics. All predicates within a matchRule must match for the request to match the rule.

Implementation

final List<HttpRouteRuleMatch> matchRules;