pathTemplateMatch property

String? pathTemplateMatch
final

If specified, this field defines a path template pattern that must match the :path header after the query string is removed.

A path template pattern can include variables and wildcards. Variables are enclosed in curly braces, for example{variable_name}. Wildcards include * that matches a single path segment, and ** that matches zero or more path segments. The pattern must follow these rules:

  - The value must be between 1 and 1024 characters.
  - The pattern must start with a leading slash ("/").
  - No more than 5 operators (variables or wildcards) may appear in
  the pattern.

Precisely one ofprefixMatch, fullPathMatch,regexMatch, or pathTemplateMatch must be set.

Implementation

final String? pathTemplateMatch;