queryParameterMatches property

List<HttpQueryParameterMatch> queryParameterMatches
final

Specifies a list of query parameter match criteria, all of which must match corresponding query parameters in the request.

Not supported when the URL map is bound to a target gRPC proxy.

Implementation

final List<HttpQueryParameterMatch> queryParameterMatches;