HttpshealthCheck_ProxyHeader class final
Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE.
Constructors
- HttpshealthCheck_ProxyHeader(String value)
-
const
- HttpshealthCheck_ProxyHeader.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const HttpshealthCheck_ProxyHeader
- The default value for HttpshealthCheck_ProxyHeader.
- none → const HttpshealthCheck_ProxyHeader
- proxyV1 → const HttpshealthCheck_ProxyHeader
- undefinedProxyHeader → const HttpshealthCheck_ProxyHeader
- A value indicating that the enum field is not set.