architecture property
The architecture of the image. Valid values are ARM64 or X86_64. Check the Architecture enum for the list of possible values.
Implementation
final String? architecture;
The architecture of the image. Valid values are ARM64 or X86_64. Check the Architecture enum for the list of possible values.
final String? architecture;