enableConfidentialCompute property
Output only. Whether this image is created from a confidential compute mode disk.
Output Only: This field is not set by user, but from source disk.
Implementation
final bool? enableConfidentialCompute;
Output only. Whether this image is created from a confidential compute mode disk.
Output Only: This field is not set by user, but from source disk.
final bool? enableConfidentialCompute;