guestOsFeatures property

List<GuestOsFeature> guestOsFeatures
final

A list of features to enable on the guest operating system. Applicable only for bootable images. To see a list of available options, see theguestOSfeatures[].type parameter.

Implementation

final List<GuestOsFeature> guestOsFeatures;