sourceDisk property

String? sourceDisk
final

URL of the source disk used to create this image. For example, the following are valid values:

In order to create an image, you must provide the full or partial URL of one of the following:

  • The rawDisk.source URL
  • The sourceDisk URL
  • The sourceImage URL
  • The sourceSnapshot URL

Implementation

final String? sourceDisk;