sourceDiskEncryptionKey property
Thecustomer-supplied encryption key of the source disk. Required if the source disk is protected by a customer-supplied encryption key.
Implementation
final CustomerEncryptionKey? sourceDiskEncryptionKey;
Thecustomer-supplied encryption key of the source disk. Required if the source disk is protected by a customer-supplied encryption key.
final CustomerEncryptionKey? sourceDiskEncryptionKey;