sourceDiskId property
Output only. Output Only
The ID value of the disk used to create this image. This value may be used
to determine whether the image was taken from the current or a previous
instance of a given disk name.
Implementation
final String? sourceDiskId;