toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (architecture != null) 'architecture=$architecture',
    if (archiveSizeBytes != null) 'archiveSizeBytes=$archiveSizeBytes',
    if (creationTimestamp != null) 'creationTimestamp=$creationTimestamp',
    if (description != null) 'description=$description',
    if (diskSizeGb != null) 'diskSizeGb=$diskSizeGb',
    if (enableConfidentialCompute != null)
      'enableConfidentialCompute=$enableConfidentialCompute',
    if (family != null) 'family=$family',
    if (id != null) 'id=$id',
    if (kind != null) 'kind=$kind',
    if (labelFingerprint != null) 'labelFingerprint=$labelFingerprint',
    if (name != null) 'name=$name',
    if (satisfiesPzi != null) 'satisfiesPzi=$satisfiesPzi',
    if (satisfiesPzs != null) 'satisfiesPzs=$satisfiesPzs',
    if (selfLink != null) 'selfLink=$selfLink',
    if (sourceDisk != null) 'sourceDisk=$sourceDisk',
    if (sourceDiskId != null) 'sourceDiskId=$sourceDiskId',
    if (sourceImage != null) 'sourceImage=$sourceImage',
    if (sourceImageId != null) 'sourceImageId=$sourceImageId',
    if (sourceSnapshot != null) 'sourceSnapshot=$sourceSnapshot',
    if (sourceSnapshotId != null) 'sourceSnapshotId=$sourceSnapshotId',
    if (sourceType != null) 'sourceType=$sourceType',
    if (status != null) 'status=$status',
  ].join(',');
  return 'Image(${$contents})';
}