ImageFamilyView class final

Constructors

ImageFamilyView({Image? image})
ImageFamilyView.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
image Image?
The latest image that is part of the specified image family in the requested location, and that is not deprecated.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String