image property
The latest image that is part of the specified image family in the requested location, and that is not deprecated.
Implementation
final Image? image;
The latest image that is part of the specified image family in the requested location, and that is not deprecated.
final Image? image;