ImageFamilyViews class final

The ImageFamilyViews API.

Implementers

Constructors

ImageFamilyViews({required Client client, Uri? endPoint, String? gcclVersion})
Creates a ImageFamilyViews using client for transport.
ImageFamilyViews.fromApiKey([String? apiKey])
Creates a ImageFamilyViews that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
get(GetImageFamilyViewRequest request) Future<ImageFamilyView>
Returns the latest image that is part of an image family, is not deprecated and is rolled out in the specified zone.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited