get method
Returns the latest image that is part of an image family, is not deprecated and is rolled out in the specified zone.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
Future<ImageFamilyView> get(GetImageFamilyViewRequest request) async {
final url = _endPoint.replace(
path:
'/compute/v1/projects/${request.project}/zones/${request.zone}/imageFamilyViews/${request.family}',
);
final response = await _client.get(url);
return ImageFamilyView.fromJson(response);
}