Image_Architecture class final
The architecture of the image. Valid values are ARM64 or X86_64.
Constructors
- Image_Architecture(String value)
-
const
- Image_Architecture.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const Image_Architecture
- The default value for Image_Architecture.
- architectureUnspecified → const Image_Architecture
- Default value indicating Architecture is not set.
- arm64 → const Image_Architecture
- Machines with architecture ARM64
- undefinedArchitecture → const Image_Architecture
- A value indicating that the enum field is not set.
- x8664 → const Image_Architecture
- Machines with architecture X86_64