Image_Status class final

Output only. Output Only The status of the image. An image can be used to create other resources, such as instances, only after the image has been successfully created and the status is set to READY. Possible values are FAILED, PENDING, orREADY.

Constructors

Image_Status(String value)
const
Image_Status.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const Image_Status
The default value for Image_Status.
deleting → const Image_Status
Image is deleting.
failed → const Image_Status
Image creation failed due to an error.
pending → const Image_Status
Image hasn't been created as yet.
ready → const Image_Status
Image has been successfully created.
undefinedStatus → const Image_Status
A value indicating that the enum field is not set.