getFromFamily method

Future<Image> getFromFamily(
  1. GetFromFamilyImageRequest request
)

Returns the latest image that is part of an image family and is not deprecated. For more information on image families, seePublic image families documentation.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Image> getFromFamily(GetFromFamilyImageRequest request) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/global/images/family/${request.family}',
  );
  final response = await _client.get(url);
  return Image.fromJson(response);
}