insert method

Future<Operation> insert(
  1. InsertImageRequest request
)

Creates an image in the specified project using the data included in the request.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> insert(InsertImageRequest request) async {
  final url = _endPoint.replace(
    path: '/compute/v1/projects/${request.project}/global/images',
    queryParameters: {
      if (request.forceCreate case final $1?) 'forceCreate': '${$1}',
      'requestId': ?request.requestId,
    },
  );
  final response = await _client.post(url, body: request.imageResource);
  return Operation.fromJson(response);
}