patch method

Future<Operation> patch(
  1. PatchImageRequest request
)

Patches the specified image with the data included in the request. Only the following fields can be modified: family, description, deprecation status.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> patch(PatchImageRequest request) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/global/images/${request.image}',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.patch(url, body: request.imageResource);
  return Operation.fromJson(response);
}