InitialStateConfig class final
Initial State for shielded instance, these are public keys which are safe to store in public
Constructors
-
InitialStateConfig({List<
FileContentBuffer> dbs = const [], List<FileContentBuffer> dbxs = const [], List<FileContentBuffer> keks = const [], FileContentBuffer? pk}) - InitialStateConfig.fromJson(Object? j)
-
factory
Properties
-
dbs
→ List<
FileContentBuffer> -
The Key Database (db).
final
-
dbxs
→ List<
FileContentBuffer> -
The forbidden key database (dbx).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
keks
→ List<
FileContentBuffer> -
The Key Exchange Key (KEK).
final
- pk → FileContentBuffer?
-
The Platform Key (PK).
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String