instanceGroupManager property
The name of the managed instance group to which the resize request will be added. Name should conform to RFC1035 or be a resource ID.
Implementation
final String instanceGroupManager;
The name of the managed instance group to which the resize request will be added. Name should conform to RFC1035 or be a resource ID.
final String instanceGroupManager;