zone property
The name of the zone where you want to create the network endpoint group. It should comply with RFC1035.
Implementation
final String zone;
The name of the zone where you want to create the network endpoint group. It should comply with RFC1035.
final String zone;