InsertOrganizationSecurityPolicyRequest class final

A request message for OrganizationSecurityPolicies.Insert. See the method description for details.

Constructors

InsertOrganizationSecurityPolicyRequest({String? parentId, String? requestId, required SecurityPolicy? securityPolicyResource})
InsertOrganizationSecurityPolicyRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
parentId String?
Parent ID for this request. The ID can be either be "folders/FOLDER_ID" if the parent is a folder or "organizations/ORGANIZATION_ID" if the parent is an organization.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requestId String?
An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
securityPolicyResource SecurityPolicy?
The body resource for this request
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String