InsertRegionBackendServiceRequest class final
A request message for RegionBackendServices.Insert. See the method description for details.
Constructors
- InsertRegionBackendServiceRequest({required BackendService? backendServiceResource, required String project, required String region, String? requestId})
- InsertRegionBackendServiceRequest.fromJson(Object? j)
-
factory
Properties
- backendServiceResource → BackendService?
-
The body resource for this request
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- project → String
-
Project ID for this request.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - region → String
-
Name of the region scoping this request.
final
- requestId → String?
-
An optional request ID to identify requests. Specify a unique request ID so
that if you must retry your request, the server will know to ignore the
request if it has already been completed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String