instanceGroupManager property
Name of the managed instance group to which the resize request is scoped. Name should conform to RFC1035 or be a resource ID.
Implementation
final String instanceGroupManager;
Name of the managed instance group to which the resize request is scoped. Name should conform to RFC1035 or be a resource ID.
final String instanceGroupManager;