InsertRegionNetworkEndpointGroupRequest class final

A request message for RegionNetworkEndpointGroups.Insert. See the method description for details.

Constructors

InsertRegionNetworkEndpointGroupRequest({required NetworkEndpointGroup? networkEndpointGroupResource, required String project, required String region, String? requestId})
InsertRegionNetworkEndpointGroupRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
networkEndpointGroupResource NetworkEndpointGroup?
The body resource for this request
final
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
region String
The name of the region where you want to create the network endpoint group. It should comply with RFC1035.
final
requestId String?
An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String