region property
The name of the region where you want to create the network endpoint group. It should comply with RFC1035.
Implementation
final String region;
The name of the region where you want to create the network endpoint group. It should comply with RFC1035.
final String region;