localSsdEncryptionMode property
Specifies which method should be used for encrypting the Local SSDs attached to the VM. Check the LocalSsdEncryptionMode enum for the list of possible values.
Implementation
final String? localSsdEncryptionMode;
Specifies which method should be used for encrypting the Local SSDs attached to the VM. Check the LocalSsdEncryptionMode enum for the list of possible values.
final String? localSsdEncryptionMode;