metadata property
The metadata key/value pairs assigned to this instance. This includes metadata keys that were explicitly defined for the instance.
Implementation
final Metadata? metadata;
The metadata key/value pairs assigned to this instance. This includes metadata keys that were explicitly defined for the instance.
final Metadata? metadata;