resourceStatus property
Output only. Output Only Specifies values set for instance attributes as
compared to the values requested by user in the corresponding input only
field.
Implementation
final ResourceStatus? resourceStatus;
Output only. Output Only Specifies values set for instance attributes as
compared to the values requested by user in the corresponding input only
field.
final ResourceStatus? resourceStatus;