sourceMachineImageEncryptionKey property
Source machine image encryption key when creating an instance from a machine image.
Implementation
final CustomerEncryptionKey? sourceMachineImageEncryptionKey;
Source machine image encryption key when creating an instance from a machine image.
final CustomerEncryptionKey? sourceMachineImageEncryptionKey;