toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (canIpForward != null) 'canIpForward=$canIpForward',
    if (cpuPlatform != null) 'cpuPlatform=$cpuPlatform',
    if (creationTimestamp != null) 'creationTimestamp=$creationTimestamp',
    if (deletionProtection != null) 'deletionProtection=$deletionProtection',
    if (description != null) 'description=$description',
    if (fingerprint != null) 'fingerprint=$fingerprint',
    if (hostname != null) 'hostname=$hostname',
    if (id != null) 'id=$id',
    if (keyRevocationActionType != null)
      'keyRevocationActionType=$keyRevocationActionType',
    if (kind != null) 'kind=$kind',
    if (labelFingerprint != null) 'labelFingerprint=$labelFingerprint',
    if (lastStartTimestamp != null) 'lastStartTimestamp=$lastStartTimestamp',
    if (lastStopTimestamp != null) 'lastStopTimestamp=$lastStopTimestamp',
    if (lastSuspendedTimestamp != null)
      'lastSuspendedTimestamp=$lastSuspendedTimestamp',
    if (localSsdEncryptionMode != null)
      'localSsdEncryptionMode=$localSsdEncryptionMode',
    if (machineType != null) 'machineType=$machineType',
    if (minCpuPlatform != null) 'minCpuPlatform=$minCpuPlatform',
    if (name != null) 'name=$name',
    if (privateIpv6GoogleAccess != null)
      'privateIpv6GoogleAccess=$privateIpv6GoogleAccess',
    if (satisfiesPzi != null) 'satisfiesPzi=$satisfiesPzi',
    if (satisfiesPzs != null) 'satisfiesPzs=$satisfiesPzs',
    if (selfLink != null) 'selfLink=$selfLink',
    if (sourceMachineImage != null) 'sourceMachineImage=$sourceMachineImage',
    if (startRestricted != null) 'startRestricted=$startRestricted',
    if (status != null) 'status=$status',
    if (statusMessage != null) 'statusMessage=$statusMessage',
    if (zone != null) 'zone=$zone',
  ].join(',');
  return 'Instance(${$contents})';
}