InstanceConsumptionData class final

Constructors

InstanceConsumptionData({InstanceConsumptionInfo? consumptionInfo, String? instance})
InstanceConsumptionData.fromJson(Object? j)
factory

Properties

consumptionInfo InstanceConsumptionInfo?
Output only. Resources consumed by the instance.
final
hashCode int
The hash code for this object.
no setterinherited
instance String?
Output only. Server-defined URL for the instance.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String