InstanceConsumptionInfo class
final
Properties
-
guestCpus
→ int?
-
Output only. The number of virtual CPUs that are available to the instance.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
localSsdGb
→ int?
-
Output only. The amount of local SSD storage available to the instance,
defined in GiB.
final
-
memoryMb
→ int?
-
Output only. The amount of physical memory available to the instance,
defined in MiB.
final
-
minNodeCpus
→ int?
-
Output only. The minimal guaranteed number of virtual CPUs that are reserved.
final
-
qualifiedName
→ String
-
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or google.rpc.ErrorInfo.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited