InstanceFlexibilityPolicy class final
A flexible specification of machine types for instances to create.
Constructors
-
InstanceFlexibilityPolicy({Map<
String, InstanceFlexibilityPolicyInstanceSelection> instanceSelections = const {}}) - InstanceFlexibilityPolicy.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
instanceSelections
→ Map<
String, InstanceFlexibilityPolicyInstanceSelection> -
Specification of alternative, flexible instance subsets.
One of them will be selected to create the instances
based on various criteria, like:
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String