InstanceFlexibilityPolicyInstanceSelection class final

Specification of machine type to use. Every position inside this message is an alternative. The count specified in the shape flexibility must not exceed the number of entries in per_instance_properties or the capacity of the name_pattern, if used.

Constructors

InstanceFlexibilityPolicyInstanceSelection({List<AttachedDisk> disks = const [], List<String> machineTypes = const [], String? minCpuPlatform, int? rank})
InstanceFlexibilityPolicyInstanceSelection.fromJson(Object? j)
factory

Properties

disks List<AttachedDisk>
Disks to be attached to the instances created from in this selection. They override the disks specified in the instance properties.
final
hashCode int
The hash code for this object.
no setterinherited
machineTypes List<String>
Alternative machine types to use for instances that are created from these properties. This field only accepts a machine type names, for example n2-standard-4 and not URLs or partial URLs.
final
minCpuPlatform String?
Name of the minimum CPU platform to be used by this instance selection. e.g. 'Intel Ice Lake'.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
rank int?
Rank when prioritizing the shape flexibilities. The instance selections with rank are considered first, in the ascending order of the rank. If not set, defaults to 0.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String