fingerprint property
Output only. Output Only The fingerprint of the named ports. The system
uses this fingerprint to detect conflicts when multiple users change the
named ports concurrently.
Implementation
final String? fingerprint;
Output only. Output Only The fingerprint of the named ports. The system
uses this fingerprint to detect conflicts when multiple users change the
named ports concurrently.
final String? fingerprint;