id property
Output only. Output Only A unique identifier for this instance group, generated
by the server.
Implementation
final BigInt? id;
Output only. Output Only A unique identifier for this instance group, generated
by the server.
final BigInt? id;