namedPorts property
Optional. Assigns a name to a port number. For example:{name: "http", port: 80}
This
allows the system to reference ports by the assigned name instead of a
port number. Named ports can also contain multiple ports. For example:{name: "app1", port: 8080}, {name:
"app1", port: 8081}, {name: "app2", port:
8082}
Named ports apply to all instances in this instance group.
Implementation
final List<NamedPort> namedPorts;