subnetwork property
Output only. Output Only The URL of the subnetwork to which all instances in the
instance group belong. If your instance has multiple network interfaces,
then the network and subnetwork fields only refer to the
network and subnet used by your primary interface (nic0).
Implementation
final String? subnetwork;