creationTimestamp property
Output only. The creation timestamp for this managed instance group inRFC3339 text format.
Implementation
final String? creationTimestamp;
Output only. The creation timestamp for this managed instance group inRFC3339 text format.
final String? creationTimestamp;