currentActions property
Output only. The list of instance actions and the number of instances in this managed instance group that are scheduled for each of those actions.
Implementation
final InstanceGroupManagerActionsSummary? currentActions;
Output only. The list of instance actions and the number of instances in this managed instance group that are scheduled for each of those actions.
final InstanceGroupManagerActionsSummary? currentActions;