zone property
Output only. The URL of azone where the managed instance group is located (for zonal resources).
Implementation
final String? zone;
Output only. The URL of azone where the managed instance group is located (for zonal resources).
final String? zone;