InstanceGroupManagerActionsSummary class final

Constructors

InstanceGroupManagerActionsSummary({int? abandoning, int? creating, int? creatingWithoutRetries, int? deleting, int? none, int? recreating, int? refreshing, int? restarting, int? resuming, int? starting, int? stopping, int? suspending, int? verifying})
InstanceGroupManagerActionsSummary.fromJson(Object? j)
factory

Properties

abandoning int?
Output only. The total number of instances in the managed instance group that are scheduled to be abandoned. Abandoning an instance removes it from the managed instance group without deleting it.
final
creating int?
Output only. The number of instances in the managed instance group that are scheduled to be created or are currently being created. If the group fails to create any of these instances, it tries again until it creates the instance successfully.
final
creatingWithoutRetries int?
Output only. The number of instances that the managed instance group will attempt to create. The group attempts to create each instance only once. If the group fails to create any of these instances, it decreases the group's targetSize value accordingly.
final
deleting int?
Output only. The number of instances in the managed instance group that are scheduled to be deleted or are currently being deleted.
final
hashCode int
The hash code for this object.
no setterinherited
none int?
Output only. The number of instances in the managed instance group that are running and have no scheduled actions.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
recreating int?
Output only. The number of instances in the managed instance group that are scheduled to be recreated or are currently being being recreated. Recreating an instance deletes the existing root persistent disk and creates a new disk from the image that is defined in the instance template.
final
refreshing int?
Output only. The number of instances in the managed instance group that are being reconfigured with properties that do not require a restart or a recreate action. For example, setting or removing target pools for the instance.
final
restarting int?
Output only. The number of instances in the managed instance group that are scheduled to be restarted or are currently being restarted.
final
resuming int?
Output only. The number of instances in the managed instance group that are scheduled to be resumed or are currently being resumed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
starting int?
Output only. The number of instances in the managed instance group that are scheduled to be started or are currently being started.
final
stopping int?
Output only. The number of instances in the managed instance group that are scheduled to be stopped or are currently being stopped.
final
suspending int?
Output only. The number of instances in the managed instance group that are scheduled to be suspended or are currently being suspended.
final
verifying int?
Output only. The number of instances in the managed instance group that are being verified. See the managedInstances[].currentAction property in the listManagedInstances method documentation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String