deleting property
Output only. The number of instances in the managed instance group that are scheduled to be deleted or are currently being deleted.
Implementation
final int? deleting;
Output only. The number of instances in the managed instance group that are scheduled to be deleted or are currently being deleted.
final int? deleting;