none property
Output only. The number of instances in the managed instance group that are running and have no scheduled actions.
Implementation
final int? none;
Output only. The number of instances in the managed instance group that are running and have no scheduled actions.
final int? none;