refreshing property

int? refreshing
final

Output only. The number of instances in the managed instance group that are being reconfigured with properties that do not require a restart or a recreate action. For example, setting or removing target pools for the instance.

Implementation

final int? refreshing;