restarting property
Output only. The number of instances in the managed instance group that are scheduled to be restarted or are currently being restarted.
Implementation
final int? restarting;
Output only. The number of instances in the managed instance group that are scheduled to be restarted or are currently being restarted.
final int? restarting;