resuming property

int? resuming
final

Output only. The number of instances in the managed instance group that are scheduled to be resumed or are currently being resumed.

Implementation

final int? resuming;