stopping property

int? stopping
final

Output only. The number of instances in the managed instance group that are scheduled to be stopped or are currently being stopped.

Implementation

final int? stopping;