suspending property

int? suspending
final

Output only. The number of instances in the managed instance group that are scheduled to be suspended or are currently being suspended.

Implementation

final int? suspending;