toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (abandoning != null) 'abandoning=$abandoning',
    if (creating != null) 'creating=$creating',
    if (creatingWithoutRetries != null)
      'creatingWithoutRetries=$creatingWithoutRetries',
    if (deleting != null) 'deleting=$deleting',
    if (none != null) 'none=$none',
    if (recreating != null) 'recreating=$recreating',
    if (refreshing != null) 'refreshing=$refreshing',
    if (restarting != null) 'restarting=$restarting',
    if (resuming != null) 'resuming=$resuming',
    if (starting != null) 'starting=$starting',
    if (stopping != null) 'stopping=$stopping',
    if (suspending != null) 'suspending=$suspending',
    if (verifying != null) 'verifying=$verifying',
  ].join(',');
  return 'InstanceGroupManagerActionsSummary(${$contents})';
}