kind property
Output only. The resource type, which is alwayscompute#instanceGroupManagerAggregatedList for an aggregated list of managed instance groups.
Implementation
final String? kind;
Output only. The resource type, which is alwayscompute#instanceGroupManagerAggregatedList for an aggregated list of managed instance groups.
final String? kind;