InstanceGroupManagerInstanceLifecyclePolicy class final

Constructors

InstanceGroupManagerInstanceLifecyclePolicy({String? defaultActionOnFailure, String? forceUpdateOnRepair, String? onFailedHealthCheck, InstanceGroupManagerInstanceLifecyclePolicyOnRepair? onRepair})
InstanceGroupManagerInstanceLifecyclePolicy.fromJson(Object? j)
factory

Properties

defaultActionOnFailure String?
The action that a MIG performs on a failed VM. If the value of the onFailedHealthCheck field is DEFAULT_ACTION, then the same action also applies to the VMs on which your application fails a health check. Valid values are
final
forceUpdateOnRepair String?
A bit indicating whether to forcefully apply the group's latest configuration when repairing a VM. Valid options are:
final
hashCode int
The hash code for this object.
no setterinherited
onFailedHealthCheck String?
The action that a MIG performs on an unhealthy VM. A VM is marked as unhealthy when the application running on that VM fails a health check. Valid values are:
final
onRepair InstanceGroupManagerInstanceLifecyclePolicyOnRepair?
Configuration for VM repairs in the MIG.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String