InstanceGroupManagerInstanceLifecyclePolicyOnRepair class final
Configuration for VM repairs in the MIG.
Constructors
- InstanceGroupManagerInstanceLifecyclePolicyOnRepair({String? allowChangingZone})
- InstanceGroupManagerInstanceLifecyclePolicyOnRepair.fromJson(Object? j)
-
factory
Properties
- allowChangingZone → String?
-
Specifies whether the MIG can change a VM's zone during a repair.
Valid values are:
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String