InstanceGroupManagerInstanceLifecyclePolicyOnRepair_AllowChangingZone class final
Specifies whether the MIG can change a VM's zone during a repair. Valid values are:
- NO (default): MIG cannot change a VM's zone during a repair.
- YES: MIG can select a different zone for the VM during a repair.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const InstanceGroupManagerInstanceLifecyclePolicyOnRepair_AllowChangingZone
- The default value for InstanceGroupManagerInstanceLifecyclePolicyOnRepair_AllowChangingZone.
- no → const InstanceGroupManagerInstanceLifecyclePolicyOnRepair_AllowChangingZone
-
DefaultMIG cannot change a VM's zone during a repair. - undefinedAllowChangingZone → const InstanceGroupManagerInstanceLifecyclePolicyOnRepair_AllowChangingZone
- A value indicating that the enum field is not set.
- yes → const InstanceGroupManagerInstanceLifecyclePolicyOnRepair_AllowChangingZone
- MIG can select a different zone for the VM during a repair.