yes constant
MIG can select a different zone for the VM during a repair.
Implementation
static const yes =
InstanceGroupManagerInstanceLifecyclePolicyOnRepair_AllowChangingZone(
'YES',
);
MIG can select a different zone for the VM during a repair.
static const yes =
InstanceGroupManagerInstanceLifecyclePolicyOnRepair_AllowChangingZone(
'YES',
);