InstanceGroupManagerInstanceLifecyclePolicy_DefaultActionOnFailure class final

The action that a MIG performs on a failed VM. If the value of the onFailedHealthCheck field is DEFAULT_ACTION, then the same action also applies to the VMs on which your application fails a health check. Valid values are

  • REPAIR (default): MIG automatically repairs a failed VM by recreating it. For more information, see About repairing VMs in a MIG.
  • DO_NOTHING: MIG does not repair a failed VM.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const InstanceGroupManagerInstanceLifecyclePolicy_DefaultActionOnFailure
The default value for InstanceGroupManagerInstanceLifecyclePolicy_DefaultActionOnFailure.
doNothing → const InstanceGroupManagerInstanceLifecyclePolicy_DefaultActionOnFailure
MIG does not repair a failed VM.
repair → const InstanceGroupManagerInstanceLifecyclePolicy_DefaultActionOnFailure
(default): MIG automatically repairs a failed VM by recreating it. For more information, see About repairing VMs in a MIG.
undefinedDefaultActionOnFailure → const InstanceGroupManagerInstanceLifecyclePolicy_DefaultActionOnFailure
A value indicating that the enum field is not set.