InstanceGroupManagerInstanceLifecyclePolicy_OnFailedHealthCheck class final
The action that a MIG performs on an unhealthy VM. A VM is marked as unhealthy when the application running on that VM fails a health check. Valid values are:
- DEFAULT_ACTION (default): MIG uses the same action configured for instanceLifecyclePolicy.defaultActionOnFailure field.
- REPAIR: MIG automatically repairs an unhealthy VM by recreating it.
- DO_NOTHING: MIG doesn't repair an unhealthy VM. For more information, see About repairing VMs in a MIG. Additional supported values which may be not listed in the enum directly due to technical reasons: DO_NOTHING REPAIR
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const InstanceGroupManagerInstanceLifecyclePolicy_OnFailedHealthCheck
- The default value for InstanceGroupManagerInstanceLifecyclePolicy_OnFailedHealthCheck.
- defaultAction → const InstanceGroupManagerInstanceLifecyclePolicy_OnFailedHealthCheck
- (Default) MIG uses the same action configured for instanceLifecyclePolicy.defaultActionOnFailure field.
- undefinedOnFailedHealthCheck → const InstanceGroupManagerInstanceLifecyclePolicy_OnFailedHealthCheck
- A value indicating that the enum field is not set.