InstanceGroupManagerResizeRequest class final
InstanceGroupManagerResizeRequest represents a request to create a number of VMs: either immediately or by queuing the request for the specified time. This resize request is nested under InstanceGroupManager and the VMs created by this request are added to the owning InstanceGroupManager.
Constructors
-
InstanceGroupManagerResizeRequest({String? creationTimestamp, String? description, BigInt? id, List<
PerInstanceConfig> instances = const [], String? kind, String? name, String? region, Duration? requestedRunDuration, int? resizeBy, String? selfLink, String? selfLinkWithId, String? state, InstanceGroupManagerResizeRequestStatus? status, String? zone}) - InstanceGroupManagerResizeRequest.fromJson(Object? j)
-
factory
Properties
- creationTimestamp → String?
-
Output only. The creation timestamp for this resize request inRFC3339
text format.
final
- description → String?
-
An optional description of this resource.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → BigInt?
-
Output only. A unique identifier for this resource type. The server generates this
identifier.
final
-
instances
→ List<
PerInstanceConfig> -
The names of instances to be created by this resize request. The number of
names specified determines the number of instances to create. The group's
target size will be increased by this number. This field cannot be used
together with 'resize_by'.
final
- kind → String?
-
Output only. The resource type, which is alwayscompute#instanceGroupManagerResizeRequest for resize requests.
final
- name → String?
-
The name of this resize request. The name must be 1-63 characters
long, and comply withRFC1035.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - region → String?
-
Output only. The URL of a region
where the resize request is located. Populated only for regional resize
requests.
final
- requestedRunDuration → Duration?
-
Requested run duration for instances that will be created by this request.
At the end of the run duration instance will be deleted.
final
- resizeBy → int?
-
The number of instances to be created by this resize request. The group's
target size will be increased by this number. This field cannot be used
together with 'instances'.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfLink → String?
-
Output only. The URL for this resize request. The server defines this URL.
final
- selfLinkWithId → String?
-
Output only. Server-defined URL for this resource with the resource id.
final
- state → String?
-
Output only. Current state of the request.
Check the State enum for the list of possible values.
final
- status → InstanceGroupManagerResizeRequestStatus?
-
Output only. Status of the request.
final
- zone → String?
-
Output only. The URL of a zone
where the resize request is located. Populated only for zonal resize
requests.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String