region property
Output only. The URL of a region where the resize request is located. Populated only for regional resize requests.
Implementation
final String? region;
Output only. The URL of a region where the resize request is located. Populated only for regional resize requests.
final String? region;