requestedRunDuration property
Requested run duration for instances that will be created by this request. At the end of the run duration instance will be deleted.
Implementation
final Duration? requestedRunDuration;
Requested run duration for instances that will be created by this request. At the end of the run duration instance will be deleted.
final Duration? requestedRunDuration;