state property
Output only. Current state of the request. Check the State enum for the list of possible values.
Implementation
final String? state;
Output only. Current state of the request. Check the State enum for the list of possible values.
final String? state;