zone property
Output only. The URL of a zone where the resize request is located. Populated only for zonal resize requests.
Implementation
final String? zone;
Output only. The URL of a zone where the resize request is located. Populated only for zonal resize requests.
final String? zone;