InstanceGroupManagerResizeRequest_State class final

Output only. Current state of the request.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const InstanceGroupManagerResizeRequest_State
The default value for InstanceGroupManagerResizeRequest_State.
accepted → const InstanceGroupManagerResizeRequest_State
The request was created successfully and was accepted for provisioning when the capacity becomes available.
cancelled → const InstanceGroupManagerResizeRequest_State
The request is cancelled.
creating → const InstanceGroupManagerResizeRequest_State
Resize request is being created and may still fail creation.
failed → const InstanceGroupManagerResizeRequest_State
The request failed before or during provisioning. If the request fails during provisioning, any VMs that were created during provisioning are rolled back and removed from the MIG.
stateUnspecified → const InstanceGroupManagerResizeRequest_State
Default value. This value should never be returned.
succeeded → const InstanceGroupManagerResizeRequest_State
The request succeeded.
undefinedState → const InstanceGroupManagerResizeRequest_State
A value indicating that the enum field is not set.