delete method

Deletes the specified, inactive resize request. Requests that are still active cannot be deleted. Deleting request does not delete instances that were provisioned previously.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> delete(
  DeleteInstanceGroupManagerResizeRequestRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/zones/${request.zone}/instanceGroupManagers/${request.instanceGroupManager}/resizeRequests/${request.resizeRequest}',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.delete(url);
  return Operation.fromJson(response);
}