InstanceGroupManagerStandbyPolicy_Mode class final

Defines how a MIG resumes or starts VMs from a standby pool when the group scales out. The default mode is MANUAL.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const InstanceGroupManagerStandbyPolicy_Mode
The default value for InstanceGroupManagerStandbyPolicy_Mode.
manual → const InstanceGroupManagerStandbyPolicy_Mode
MIG does not automatically resume or start VMs in the standby pool when the group scales out.
scaleOutPool → const InstanceGroupManagerStandbyPolicy_Mode
MIG automatically resumes or starts VMs in the standby pool when the group scales out, and replenishes the standby pool afterwards.
undefinedMode → const InstanceGroupManagerStandbyPolicy_Mode
A value indicating that the enum field is not set.