currentInstanceStatuses property

InstanceGroupManagerStatusInstanceStatusSummary? currentInstanceStatuses
final

Output only. The list of instance statuses and the number of instances in this managed instance group that have the status. Currently only shown for TPU MIGs

Implementation

final InstanceGroupManagerStatusInstanceStatusSummary?
currentInstanceStatuses;