InstanceGroupManagerStatusAcceleratorTopology class final

Properties

acceleratorTopology String?
Output only. Topology in the format of: "16x16", "4x4x4", etc. The value is the same as configured in the WorkloadPolicy.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
Output only. The state of the accelerator topology. Check the State enum for the list of possible values.
final
stateDetails InstanceGroupManagerStatusAcceleratorTopologyAcceleratorTopologyStateDetails?
Output only. The result of the latest accelerator topology state check.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String