acceleratorTopology property
Output only. Topology in the format of: "16x16", "4x4x4", etc. The value is the same as configured in the WorkloadPolicy.
Implementation
final String? acceleratorTopology;
Output only. Topology in the format of: "16x16", "4x4x4", etc. The value is the same as configured in the WorkloadPolicy.
final String? acceleratorTopology;