state property
Output only. The state of the accelerator topology. Check the State enum for the list of possible values.
Implementation
final String? state;
Output only. The state of the accelerator topology. Check the State enum for the list of possible values.
final String? state;