InstanceGroupManagerStatusAcceleratorTopologyAcceleratorTopologyStateDetails class
final
Properties
-
error
→ Error?
-
Output only. Encountered errors.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
qualifiedName
→ String
-
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or google.rpc.ErrorInfo.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
timestamp
→ String?
-
Output only. Timestamp is shown only if there is an error. The field
has // RFC3339 //
text format.
final