timestamp property
Output only. Timestamp is shown only if there is an error. The field has // RFC3339 // text format.
Implementation
final String? timestamp;
Output only. Timestamp is shown only if there is an error. The field has // RFC3339 // text format.
final String? timestamp;