incomplete constant

The configuration is incomplete and the accelerator topology cannot be activated due to insufficient number of running VMs.

Implementation

static const incomplete = InstanceGroupManagerStatusAcceleratorTopology_State(
  'INCOMPLETE',
);