InstanceGroupManagerStatusAllInstancesConfig class final

Properties

currentRevision String?
Output only. Current all-instances configuration revision. This value is in RFC3339 text format.
final
effective bool?
Output only. A bit indicating whether this configuration has been applied to all managed instances in the group.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String