effective property
Output only. A bit indicating whether this configuration has been applied to all managed instances in the group.
Implementation
final bool? effective;
Output only. A bit indicating whether this configuration has been applied to all managed instances in the group.
final bool? effective;