InstanceGroupManagerStatusBulkInstanceOperationLastProgressCheck class
final
Properties
-
error
→ Error?
-
Output only. Errors encountered during bulk instance operation.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
qualifiedName
→ String
-
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or google.rpc.ErrorInfo.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
timestamp
→ String?
-
Output only. Timestamp of the last progress check of bulk instance
operation. Timestamp is in RFC3339 text format.
final