deprovisioning property
Output only. The number of instances in the managed instance group that have DEPROVISIONING status.
Implementation
final int? deprovisioning;
Output only. The number of instances in the managed instance group that have DEPROVISIONING status.
final int? deprovisioning;