pendingStop property
Output only. The number of instances in the managed instance group that have PENDING_STOP status.
Implementation
final int? pendingStop;
Output only. The number of instances in the managed instance group that have PENDING_STOP status.
final int? pendingStop;