provisioning property
Output only. The number of instances in the managed instance group that have PROVISIONING status.
Implementation
final int? provisioning;
Output only. The number of instances in the managed instance group that have PROVISIONING status.
final int? provisioning;