repairing property
Output only. The number of instances in the managed instance group that have REPAIRING status.
Implementation
final int? repairing;
Output only. The number of instances in the managed instance group that have REPAIRING status.
final int? repairing;