running property
Output only. The number of instances in the managed instance group that have RUNNING status.
Implementation
final int? running;
Output only. The number of instances in the managed instance group that have RUNNING status.
final int? running;