stopped property
Output only. The number of instances in the managed instance group that have STOPPED status.
Implementation
final int? stopped;
Output only. The number of instances in the managed instance group that have STOPPED status.
final int? stopped;