stopping property
Output only. The number of instances in the managed instance group that have STOPPING status.
Implementation
final int? stopping;
Output only. The number of instances in the managed instance group that have STOPPING status.
final int? stopping;