suspended property
Output only. The number of instances in the managed instance group that have SUSPENDED status.
Implementation
final int? suspended;
Output only. The number of instances in the managed instance group that have SUSPENDED status.
final int? suspended;