suspending property
Output only. The number of instances in the managed instance group that have SUSPENDING status.
Implementation
final int? suspending;
Output only. The number of instances in the managed instance group that have SUSPENDING status.
final int? suspending;