terminated property
Output only. The number of instances in the managed instance group that have TERMINATED status.
Implementation
final int? terminated;
Output only. The number of instances in the managed instance group that have TERMINATED status.
final int? terminated;