toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (deprovisioning != null) 'deprovisioning=$deprovisioning',
    if (nonExistent != null) 'nonExistent=$nonExistent',
    if (pending != null) 'pending=$pending',
    if (pendingStop != null) 'pendingStop=$pendingStop',
    if (provisioning != null) 'provisioning=$provisioning',
    if (repairing != null) 'repairing=$repairing',
    if (running != null) 'running=$running',
    if (staging != null) 'staging=$staging',
    if (stopped != null) 'stopped=$stopped',
    if (stopping != null) 'stopping=$stopping',
    if (suspended != null) 'suspended=$suspended',
    if (suspending != null) 'suspending=$suspending',
    if (terminated != null) 'terminated=$terminated',
  ].join(',');
  return 'InstanceGroupManagerStatusInstanceStatusSummary(${$contents})';
}