menu
google_cloud_compute_v1 package
documentation
compute.dart
InstanceGroupManagerTargetSizePolicy class
InstanceGroupManagerTargetSizePolicy class
dark_mode
light_mode
InstanceGroupManagerTargetSizePolicy
class
final
Constructors
InstanceGroupManagerTargetSizePolicy
({
String
?
mode
})
InstanceGroupManagerTargetSizePolicy.fromJson
(
Object
?
j
)
factory
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
mode
→
String
?
The mode of target size policy based on which the MIG creates its VMs individually or all at once. Check the Mode enum for the list of possible values.
final
qualifiedName
→
String
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or
google.rpc.ErrorInfo
.
final
inherited
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson
(
)
→
Object
toString
(
)
→
String
A string representation of this object.
override
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
Constants
fullyQualifiedName
→ const
String
google_cloud_compute_v1 package
documentation
compute
InstanceGroupManagerTargetSizePolicy class
compute library