InstanceGroupManagerTargetSizePolicy_Mode class final

The mode of target size policy based on which the MIG creates its VMs individually or all at once.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const InstanceGroupManagerTargetSizePolicy_Mode
The default value for InstanceGroupManagerTargetSizePolicy_Mode.
bulk → const InstanceGroupManagerTargetSizePolicy_Mode
The mode in which the MIG creates VMs all at once. In this mode, if the MIG is unable to create even one VM, the MIG waits until all VMs can be created at the same time.
individual → const InstanceGroupManagerTargetSizePolicy_Mode
The mode in which the MIG creates VMs individually. In this mode, if the MIG is unable to create a VM, the MIG will continue to create the other VMs in the group. This is the default mode.
undefinedMode → const InstanceGroupManagerTargetSizePolicy_Mode
A value indicating that the enum field is not set.
unspecifiedMode → const InstanceGroupManagerTargetSizePolicy_Mode
If mode is unspecified, MIG will behave as in the default INDIVIDUAL mode.