The maximum number of instances that can be created above the specifiedtargetSize during the update process. This value can be
either a fixed number or, if the group has 10 or more instances, a
percentage. If you set a percentage, the number of instances is rounded
if necessary. The default value for maxSurge is a fixed
value equal to the number of zones in which the managed instance group
operates.
The maximum number of instances that can be unavailable during the update
process. An instance is considered available if all of the following
conditions are satisfied:
Minimal action to be taken on an instance. Use this option to minimize
disruption as much as possible or to apply a more disruptive action than
is necessary.
Most disruptive action that is allowed to be taken on an instance.
You can specify either NONE to forbid any actions,REFRESH to avoid restarting the VM and to limit disruption
as much as possible. RESTART to allow actions that can be
applied without instance replacing or REPLACE to allow all
possible actions. If the Updater determines that the minimal update
action needed is more disruptive than most disruptive allowed action you
specify it will not perform the update at all.
Check the MostDisruptiveAllowedAction enum for the list of possible values.
The type
of update process. You can specify either PROACTIVE so
that the MIG automatically updates VMs to the latest configurations orOPPORTUNISTIC so that you can select the VMs that you want
to update.
Check the Type enum for the list of possible values.