InstanceGroupManagerUpdatePolicy_MinimalAction class final
Minimal action to be taken on an instance. Use this option to minimize disruption as much as possible or to apply a more disruptive action than is necessary.
- To limit disruption as much as possible, set the minimal action toREFRESH. If your update requires a more disruptive action, Compute Engine performs the necessary action to execute the update.
- To apply a more disruptive action than is strictly necessary, set the minimal action to RESTART or REPLACE. For example, Compute Engine does not need to restart a VM to change its metadata. But if your application reads instance metadata only when a VM is restarted, you can set the minimal action to RESTART in order to pick up metadata changes. Additional supported values which may be not listed in the enum directly due to technical reasons: NONE REFRESH REPLACE RESTART
Constructors
- InstanceGroupManagerUpdatePolicy_MinimalAction(String value)
-
const
- InstanceGroupManagerUpdatePolicy_MinimalAction.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const InstanceGroupManagerUpdatePolicy_MinimalAction
- The default value for InstanceGroupManagerUpdatePolicy_MinimalAction.
- undefinedMinimalAction → const InstanceGroupManagerUpdatePolicy_MinimalAction
- A value indicating that the enum field is not set.