InstanceGroupManager_ListManagedInstancesResults class final

Pagination behavior of the listManagedInstances API method for this managed instance group.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const InstanceGroupManager_ListManagedInstancesResults
The default value for InstanceGroupManager_ListManagedInstancesResults.
pageless → const InstanceGroupManager_ListManagedInstancesResults
(Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.
paginated → const InstanceGroupManager_ListManagedInstancesResults
Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.
undefinedListManagedInstancesResults → const InstanceGroupManager_ListManagedInstancesResults
A value indicating that the enum field is not set.