applyUpdatesToInstances method

Applies changes to selected instances on the managed instance group. This method can be used to apply new overrides and/or new versions.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> applyUpdatesToInstances(
  ApplyUpdatesToInstancesInstanceGroupManagerRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/zones/${request.zone}/instanceGroupManagers/${request.instanceGroupManager}/applyUpdatesToInstances',
  );
  final response = await _client.post(
    url,
    body: request.instanceGroupManagersApplyUpdatesRequestResource,
  );
  return Operation.fromJson(response);
}