get method

Returns all of the details about the specified managed instance group.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<InstanceGroupManager> get(
  GetInstanceGroupManagerRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/zones/${request.zone}/instanceGroupManagers/${request.instanceGroupManager}',
  );
  final response = await _client.get(url);
  return InstanceGroupManager.fromJson(response);
}