minimalAction property
The minimal action that you want to perform on each instance during the update:
- REPLACE: At minimum, delete the instance and create it
again.
- RESTART: Stop the instance and start it again.
- REFRESH: Do not stop the instance and limit disruption as much as possible.
- NONE: Do not disrupt the instance at all.
By default, the minimum action is NONE. If your update requires a more disruptive action than you set with this flag, the necessary action is performed to execute the update. Check the MinimalAction enum for the list of possible values.
Implementation
final String? minimalAction;