InstanceGroupManagersDeleteInstancesRequest class final

Constructors

InstanceGroupManagersDeleteInstancesRequest({List<String> instances = const [], bool? skipInstancesOnValidationError})
InstanceGroupManagersDeleteInstancesRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
instances List<String>
The URLs of one or more instances to delete. This can be a full URL or a partial URL, such as zones/ZONE/instances/INSTANCE_NAME. Queued instances do not have URL and can be deleted only by name. One cannot specify both URLs and names in a single request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skipInstancesOnValidationError bool?
Specifies whether the request should proceed despite the inclusion of instances that are not members of the group or that are already in the process of being deleted or abandoned. If this field is set to false and such an instance is specified in the request, the operation fails. The operation always fails if the request contains a malformed instance URL or a reference to an instance that exists in a zone or region other than the group's zone or region.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String