managedInstances property
Output only. Output Only The list of instances in the managed instance group.
Implementation
final List<ManagedInstance> managedInstances;
Output only. Output Only The list of instances in the managed instance group.
final List<ManagedInstance> managedInstances;