InstanceGroupManagersScopedList class final

Constructors

InstanceGroupManagersScopedList({List<InstanceGroupManager> instanceGroupManagers = const [], Warning? warning})
InstanceGroupManagersScopedList.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
instanceGroupManagers List<InstanceGroupManager>
Output only. The list of managed instance groups that are contained in the specified project and zone.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warning Warning?
Output only. The warning that replaces the list of managed instance groups when the list is empty.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String