instanceGroupManagers property
Output only. The list of managed instance groups that are contained in the specified project and zone.
Implementation
final List<InstanceGroupManager> instanceGroupManagers;
Output only. The list of managed instance groups that are contained in the specified project and zone.
final List<InstanceGroupManager> instanceGroupManagers;