targetPools property

List<String> targetPools
final

The list of target pool URLs that instances in this managed instance group belong to. The managed instance group applies these target pools to all of the instances in the group. Existing instances and new instances in the group all receive these target pool settings.

Implementation

final List<String> targetPools;