forceStop property
If this flag is set to true, the Instance Group Manager will proceed to stop the instances, skipping initialization on them.
Implementation
final bool? forceStop;
If this flag is set to true, the Instance Group Manager will proceed to stop the instances, skipping initialization on them.
final bool? forceStop;