delete method

Deletes the specified instance group. The instances in the group are not deleted. Note that instance group must not belong to a backend service. Read Deleting an instance group for more information.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> delete(DeleteInstanceGroupRequest request) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/zones/${request.zone}/instanceGroups/${request.instanceGroup}',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.delete(url);
  return Operation.fromJson(response);
}