InstanceGroupsScopedList class final

Constructors

InstanceGroupsScopedList({List<InstanceGroup> instanceGroups = const [], Warning? warning})
InstanceGroupsScopedList.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
instanceGroups List<InstanceGroup>
Output only. Output Only The list ofinstance groups that are contained in this scope.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warning Warning?
Output only. Output Only An informational warning that replaces the list of instance groups when the list is empty.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String