InstanceGroupsSetNamedPortsRequest class final

Constructors

InstanceGroupsSetNamedPortsRequest({String? fingerprint, List<NamedPort> namedPorts = const []})
InstanceGroupsSetNamedPortsRequest.fromJson(Object? j)
factory

Properties

fingerprint String?
The fingerprint of the named ports information for this instance group. Use this optional property to prevent conflicts when multiple users change the named ports settings concurrently. Obtain the fingerprint with theinstanceGroups.get method. Then, include the fingerprint in your request to ensure that you do not overwrite changes that were applied from another concurrent request. A request with an incorrect fingerprint will fail with error412 conditionNotMet.
final
hashCode int
The hash code for this object.
no setterinherited
namedPorts List<NamedPort>
The list of named ports to set for this instance group.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String