InstanceList class final

Contains a list of instances.

Constructors

InstanceList({String? id, List<Instance> items = const [], String? kind, String? nextPageToken, String? selfLink, Warning? warning})
InstanceList.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String?
Output Only Unique identifier for the resource; defined by the server.
final
items List<Instance>
A list of Instance resources.
final
kind String?
Output only. Output Only Type of resource. Always compute#instanceList for lists of Instance resources.
final
nextPageToken String?
Output Only This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output only. Output Only Server-defined URL for this resource.
final
warning Warning?
Output Only Informational warning message.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String