InstanceManagedByIgmError class final

Properties

error InstanceManagedByIgmErrorManagedInstanceError?
Output only. Contents of the error.
final
hashCode int
The hash code for this object.
no setterinherited
instanceActionDetails InstanceManagedByIgmErrorInstanceActionDetails?
Output only. Details of the instance action that triggered this error. May be null, if the error was not caused by an action on an instance. This field is optional.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp String?
Output only. The time that this error occurred. This value is in RFC3339 text format.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String