InstanceManagedByIgmErrorInstanceActionDetails class final

Properties

action String?
Output only. Action that managed instance group was executing on the instance when the error occurred. Possible values: Check the Action enum for the list of possible values.
final
hashCode int
The hash code for this object.
no setterinherited
instance String?
Output only. The URL of the instance. The URL can be set even if the instance has not yet been created.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version ManagedInstanceVersion?
Output only. Version this instance was created from, or was being created from, but the creation failed. Corresponds to one of the versions that were set on the Instance Group Manager resource at the time this instance was being created.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String