action property

String? action
final

Output only. Action that managed instance group was executing on the instance when the error occurred. Possible values: Check the Action enum for the list of possible values.

Implementation

final String? action;