instance property
Output only. The URL of the instance. The URL can be set even if the instance has not yet been created.
Implementation
final String? instance;
Output only. The URL of the instance. The URL can be set even if the instance has not yet been created.
final String? instance;