InstanceManagedByIgmErrorInstanceActionDetails_Action class final

Output only. Action that managed instance group was executing on the instance when the error occurred. Possible values:

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const InstanceManagedByIgmErrorInstanceActionDetails_Action
The default value for InstanceManagedByIgmErrorInstanceActionDetails_Action.
abandoning → const InstanceManagedByIgmErrorInstanceActionDetails_Action
The managed instance group is abandoning this instance. The instance will be removed from the instance group and from any target pools that are associated with this group.
creating → const InstanceManagedByIgmErrorInstanceActionDetails_Action
The managed instance group is creating this instance. If the group fails to create this instance, it will try again until it is successful.
creatingWithoutRetries → const InstanceManagedByIgmErrorInstanceActionDetails_Action
The managed instance group is attempting to create this instance only once. If the group fails to create this instance, it does not try again and the group's targetSize value is decreased.
deleting → const InstanceManagedByIgmErrorInstanceActionDetails_Action
The managed instance group is permanently deleting this instance.
none → const InstanceManagedByIgmErrorInstanceActionDetails_Action
The managed instance group has not scheduled any actions for this instance.
recreating → const InstanceManagedByIgmErrorInstanceActionDetails_Action
The managed instance group is recreating this instance.
refreshing → const InstanceManagedByIgmErrorInstanceActionDetails_Action
The managed instance group is applying configuration changes to the instance without stopping it. For example, the group can update the target pool list for an instance without stopping that instance.
restarting → const InstanceManagedByIgmErrorInstanceActionDetails_Action
The managed instance group is restarting this instance.
resuming → const InstanceManagedByIgmErrorInstanceActionDetails_Action
The managed instance group is resuming this instance.
starting → const InstanceManagedByIgmErrorInstanceActionDetails_Action
The managed instance group is starting this instance.
stopping → const InstanceManagedByIgmErrorInstanceActionDetails_Action
The managed instance group is stopping this instance.
suspending → const InstanceManagedByIgmErrorInstanceActionDetails_Action
The managed instance group is suspending this instance.
undefinedAction → const InstanceManagedByIgmErrorInstanceActionDetails_Action
A value indicating that the enum field is not set.
verifying → const InstanceManagedByIgmErrorInstanceActionDetails_Action
The managed instance group is verifying this already created instance. Verification happens every time the instance is (re)created or restarted and consists of: