none constant
The managed instance group has not scheduled any actions for this instance.
Implementation
static const none = InstanceManagedByIgmErrorInstanceActionDetails_Action(
'NONE',
);
The managed instance group has not scheduled any actions for this instance.
static const none = InstanceManagedByIgmErrorInstanceActionDetails_Action(
'NONE',
);