InstanceProperties class final

Constructors

InstanceProperties({AdvancedMachineFeatures? advancedMachineFeatures, bool? canIpForward, ConfidentialInstanceConfig? confidentialInstanceConfig, String? description, List<AttachedDisk> disks = const [], List<AcceleratorConfig> guestAccelerators = const [], String? keyRevocationActionType, Map<String, String> labels = const {}, String? localSsdEncryptionMode, String? machineType, Metadata? metadata, String? minCpuPlatform, List<NetworkInterface> networkInterfaces = const [], NetworkPerformanceConfig? networkPerformanceConfig, String? privateIpv6GoogleAccess, ReservationAffinity? reservationAffinity, Map<String, String> resourceManagerTags = const {}, List<String> resourcePolicies = const [], Scheduling? scheduling, List<ServiceAccount> serviceAccounts = const [], ShieldedInstanceConfig? shieldedInstanceConfig, Tags? tags, WorkloadIdentityConfig? workloadIdentityConfig})
InstanceProperties.fromJson(Object? j)
factory

Properties

advancedMachineFeatures AdvancedMachineFeatures?
Controls for advanced machine-related behavior features. Note that for MachineImage, this is not supported yet.
final
canIpForward bool?
Enables instances created based on these properties to send packets with source IP addresses other than their own and receive packets with destination IP addresses other than their own. If these instances will be used as an IP gateway or it will be set as the next-hop in a Route resource, specify true. If unsure, leave this set tofalse. See theEnable IP forwarding documentation for more information.
final
confidentialInstanceConfig ConfidentialInstanceConfig?
Specifies the Confidential Instance options. Note that for MachineImage, this is not supported yet.
final
description String?
An optional text description for the instances that are created from these properties.
final
disks List<AttachedDisk>
An array of disks that are associated with the instances that are created from these properties.
final
guestAccelerators List<AcceleratorConfig>
A list of guest accelerator cards' type and count to use for instances created from these properties.
final
hashCode int
The hash code for this object.
no setterinherited
keyRevocationActionType String?
KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified. Check the KeyRevocationActionType enum for the list of possible values.
final
labels Map<String, String>
Labels to apply to instances that are created from these properties.
final
localSsdEncryptionMode String?
Specifies which method should be used for encrypting the Local SSDs attached to the VM. Check the LocalSsdEncryptionMode enum for the list of possible values.
final
machineType String?
The machine type to use for instances that are created from these properties. This field only accepts a machine type name, for example n2-standard-4. If you use the machine type full or partial URL, for example projects/my-l7ilb-project/zones/us-central1-a/machineTypes/n2-standard-4, the request will result in an INTERNAL_ERROR.
final
metadata Metadata?
The metadata key/value pairs to assign to instances that are created from these properties. These pairs can consist of custom metadata or predefined keys. SeeProject and instance metadata for more information.
final
minCpuPlatform String?
Minimum cpu/platform to be used by instances. The instance may be scheduled on the specified or newer cpu/platform. Applicable values are the friendly names of CPU platforms, such asminCpuPlatform: "Intel Haswell" orminCpuPlatform: "Intel Sandy Bridge". For more information, read Specifying a Minimum CPU Platform.
final
networkInterfaces List<NetworkInterface>
An array of network access configurations for this interface.
final
networkPerformanceConfig NetworkPerformanceConfig?
Note that for MachineImage, this is not supported yet.
final
privateIpv6GoogleAccess String?
The private IPv6 google access type for VMs. If not specified, use INHERIT_FROM_SUBNETWORK as default. Note that for MachineImage, this is not supported yet. Check the PrivateIpv6GoogleAccess enum for the list of possible values.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
reservationAffinity ReservationAffinity?
Specifies the reservations that instances can consume from. Note that for MachineImage, this is not supported yet.
final
resourceManagerTags Map<String, String>
Input only. Resource manager tags to be bound to the instance. Tag keys and values have the same definition as resource manager tags. Keys and values can be either in numeric format, such as tagKeys/{tag_key_id} and tagValues/{tag_value_id} or in namespaced format such as {org_id|project_id}/{tag_key_short_name} and {tag_value_short_name}. The field is ignored (both PUT & PATCH) when empty.
final
resourcePolicies List<String>
Resource policies (names, not URLs) applied to instances created from these properties. Note that for MachineImage, this is not supported yet.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheduling Scheduling?
Specifies the scheduling options for the instances that are created from these properties.
final
serviceAccounts List<ServiceAccount>
A list of service accounts with specified scopes. Access tokens for these service accounts are available to the instances that are created from these properties. Use metadata queries to obtain the access tokens for these instances.
final
shieldedInstanceConfig ShieldedInstanceConfig?
Note that for MachineImage, this is not supported yet.
final
tags Tags?
A list of tags to apply to the instances that are created from these properties. The tags identify valid sources or targets for network firewalls. The setTags method can modify this list of tags. Each tag within the list must comply with RFC1035.
final
workloadIdentityConfig WorkloadIdentityConfig?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String