description property
An optional text description for the instances that are created from these properties.
Implementation
final String? description;
An optional text description for the instances that are created from these properties.
final String? description;