disks property
An array of disks that are associated with the instances that are created from these properties.
Implementation
final List<AttachedDisk> disks;
An array of disks that are associated with the instances that are created from these properties.
final List<AttachedDisk> disks;