metadata property

Metadata? metadata
final

The metadata key/value pairs to assign to instances that are created from these properties. These pairs can consist of custom metadata or predefined keys. SeeProject and instance metadata for more information.

Implementation

final Metadata? metadata;