scheduling property
Specifies the scheduling options for the instances that are created from these properties.
Implementation
final Scheduling? scheduling;
Specifies the scheduling options for the instances that are created from these properties.
final Scheduling? scheduling;