InstanceProperties_LocalSsdEncryptionMode class final

Specifies which method should be used for encrypting the Local SSDs attached to the VM.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const InstanceProperties_LocalSsdEncryptionMode
The default value for InstanceProperties_LocalSsdEncryptionMode.
ephemeralKeyEncryption → const InstanceProperties_LocalSsdEncryptionMode
The given VM will opt-in for using ephemeral key for encryption of Local SSDs. The Local SSDs will not be able to recover data in case of VM crash.
localSsdEncryptionModeUnspecified → const InstanceProperties_LocalSsdEncryptionMode
The given VM will be encrypted using keys managed by the cloud infrastructure and the keys will be deleted when the VM is deleted.
standardEncryption → const InstanceProperties_LocalSsdEncryptionMode
The given VM will be encrypted using keys managed by the cloud infrastructure and the keys will be deleted when the VM is deleted.
undefinedLocalSsdEncryptionMode → const InstanceProperties_LocalSsdEncryptionMode
A value indicating that the enum field is not set.