InstanceProperties_PrivateIpv6GoogleAccess class final

The private IPv6 google access type for VMs. If not specified, use INHERIT_FROM_SUBNETWORK as default. Note that for MachineImage, this is not supported yet.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const InstanceProperties_PrivateIpv6GoogleAccess
The default value for InstanceProperties_PrivateIpv6GoogleAccess.
enableBidirectionalAccessToGoogle → const InstanceProperties_PrivateIpv6GoogleAccess
Bidirectional private IPv6 access to/from Google services. If specified, the subnetwork who is attached to the instance's default network interface will be assigned an internal IPv6 prefix if it doesn't have before.
enableOutboundVmAccessToGoogle → const InstanceProperties_PrivateIpv6GoogleAccess
Outbound private IPv6 access from VMs in this subnet to Google services. If specified, the subnetwork who is attached to the instance's default network interface will be assigned an internal IPv6 prefix if it doesn't have before.
inheritFromSubnetwork → const InstanceProperties_PrivateIpv6GoogleAccess
Each network interface inherits PrivateIpv6GoogleAccess from its subnetwork.
undefinedPrivateIpv6GoogleAccess → const InstanceProperties_PrivateIpv6GoogleAccess
A value indicating that the enum field is not set.