metadata property
The metadata key/value pairs assigned to all the instances in the corresponding scope.
Implementation
final InstanceSettingsMetadata? metadata;
The metadata key/value pairs assigned to all the instances in the corresponding scope.
final InstanceSettingsMetadata? metadata;