InstanceTemplate class final

Represents an Instance Template resource.

Google Compute Engine has two Instance Template resources:

You can reuse a global instance template in different regions whereas you can use a regional instance template in a specified region only. If you want to reduce cross-region dependency or achieve data residency, use a regional instance template.

To create VMs, managed instance groups, and reservations, you can use either global or regional instance templates.

For more information, readInstance Templates.

Constructors

InstanceTemplate({String? creationTimestamp, String? description, BigInt? id, String? kind, String? name, InstanceProperties? properties, String? region, String? selfLink, String? sourceInstance, SourceInstanceParams? sourceInstanceParams})
InstanceTemplate.fromJson(Object? j)
factory

Properties

creationTimestamp String?
Output only. Output Only The creation timestamp for this instance template inRFC3339 text format.
final
description String?
An optional description of this resource. Provide this property when you create the resource.
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output only. Output Only A unique identifier for this instance template. The server defines this identifier.
final
kind String?
Output only. Output Only The resource type, which is alwayscompute#instanceTemplate for instance templates.
final
name String?
Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
properties InstanceProperties?
The instance properties for this instance template.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
region String?
Output only. Output Only URL of the region where the instance template resides. Only applicable for regional resources.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output only. Output Only The URL for this instance template. The server defines this URL.
final
sourceInstance String?
The source instance used to create the template. You can provide this as a partial or full URL to the resource. For example, the following are valid values:
final
sourceInstanceParams SourceInstanceParams?
The source instance params to use to create this instance template.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String