region property
Output only. Output Only URL of the region where the instance template resides. Only
applicable for regional resources.
Implementation
final String? region;
Output only. Output Only URL of the region where the instance template resides. Only
applicable for regional resources.
final String? region;