InstanceTemplates class final

The InstanceTemplates API.

Implementers

Constructors

InstanceTemplates({required Client client, Uri? endPoint, String? gcclVersion})
Creates a InstanceTemplates using client for transport.
InstanceTemplates.fromApiKey([String? apiKey])
Creates a InstanceTemplates that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(AggregatedListInstanceTemplatesRequest request) Future<InstanceTemplateAggregatedList>
Retrieves the list of all InstanceTemplates resources, regional and global, available to the specified project.
close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteInstanceTemplateRequest request) Future<Operation>
Deletes the specified instance template. Deleting an instance template is permanent and cannot be undone. It is not possible to delete templates that are already in use by a managed instance group.
get(GetInstanceTemplateRequest request) Future<InstanceTemplate>
Returns the specified instance template.
getIamPolicy(GetIamPolicyInstanceTemplateRequest request) Future<Policy>
Gets the access control policy for a resource. May be empty if no such policy or resource exists.
insert(InsertInstanceTemplateRequest request) Future<Operation>
Creates an instance template in the specified project using the data that is included in the request. If you are creating a new template to update an existing instance group, your new instance template must use the same network or, if applicable, the same subnetwork as the original template.
list(ListInstanceTemplatesRequest request) Future<InstanceTemplateList>
Retrieves a list of instance templates that are contained within the specified project.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setIamPolicy(SetIamPolicyInstanceTemplateRequest request) Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy.
testIamPermissions(TestIamPermissionsInstanceTemplateRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited