InstanceTemplatesScopedList class final

Constructors

InstanceTemplatesScopedList({List<InstanceTemplate> instanceTemplates = const [], Warning? warning})
InstanceTemplatesScopedList.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
instanceTemplates List<InstanceTemplate>
Output Only A list of instance templates that are contained within the specified project and zone.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warning Warning?
Output Only An informational warning that replaces the list of instance templates when the list is empty.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String