instanceTemplates property
Output Only A list of instance templates that are contained within
the specified project and zone.
Implementation
final List<InstanceTemplate> instanceTemplates;
Output Only A list of instance templates that are contained within
the specified project and zone.
final List<InstanceTemplate> instanceTemplates;