InstanceWithNamedPorts class final

Constructors

InstanceWithNamedPorts({String? instance, List<NamedPort> namedPorts = const [], String? status})
InstanceWithNamedPorts.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
instance String?
Output only. Output Only The URL of the instance.
final
namedPorts List<NamedPort>
Output only. Output Only The named ports that belong to this instance group.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
Output only. Output Only The status of the instance. Check the Status enum for the list of possible values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String