ephemeralKeyEncryption constant

Instance_LocalSsdEncryptionMode const ephemeralKeyEncryption

The given VM will opt-in for using ephemeral key for encryption of Local SSDs. The Local SSDs will not be able to recover data in case of VM crash.

Implementation

static const ephemeralKeyEncryption = Instance_LocalSsdEncryptionMode(
  'EPHEMERAL_KEY_ENCRYPTION',
);