localSsdEncryptionModeUnspecified constant
Instance_LocalSsdEncryptionMode
const localSsdEncryptionModeUnspecified
The given VM will be encrypted using keys managed by the cloud infrastructure and the keys will be deleted when the VM is deleted.
Implementation
static const localSsdEncryptionModeUnspecified =
Instance_LocalSsdEncryptionMode('LOCAL_SSD_ENCRYPTION_MODE_UNSPECIFIED');