standardEncryption constant

Instance_LocalSsdEncryptionMode const standardEncryption

The given VM will be encrypted using keys managed by the cloud infrastructure and the keys will be deleted when the VM is deleted.

Implementation

static const standardEncryption = Instance_LocalSsdEncryptionMode(
  'STANDARD_ENCRYPTION',
);