aggregatedList method
Retrieves an aggregated list of all of the instances in your project across all regions and zones.
The performance of this method degrades when a filter is specified on a project that has a very large number of instances.
To prevent failure, Google recommends that you set the
returnPartialSuccess parameter to true.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
Future<InstanceAggregatedList> aggregatedList(
AggregatedListInstancesRequest request,
) async {
final url = _endPoint.replace(
path: '/compute/v1/projects/${request.project}/aggregated/instances',
queryParameters: {
'filter': ?request.filter,
if (request.includeAllScopes case final $1?)
'includeAllScopes': '${$1}',
if (request.maxResults case final $1?) 'maxResults': '${$1}',
'orderBy': ?request.orderBy,
'pageToken': ?request.pageToken,
if (request.returnPartialSuccess case final $1?)
'returnPartialSuccess': '${$1}',
if (request.serviceProjectNumber case final $1?)
'serviceProjectNumber': '${$1}',
},
);
final response = await _client.get(url);
return InstanceAggregatedList.fromJson(response);
}