getEffectiveFirewalls method

Returns effective firewalls applied to an interface of the instance.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<InstancesGetEffectiveFirewallsResponse> getEffectiveFirewalls(
  GetEffectiveFirewallsInstanceRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/zones/${request.zone}/instances/${request.instance}/getEffectiveFirewalls',
    queryParameters: {
      if (request.networkInterface case final $1 when $1.isNotDefault)
        'networkInterface': $1,
    },
  );
  final response = await _client.get(url);
  return InstancesGetEffectiveFirewallsResponse.fromJson(response);
}