insert method

Creates an instance resource in the specified project using the data included in the request.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> insert(InsertInstanceRequest request) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/zones/${request.zone}/instances',
    queryParameters: {
      'requestId': ?request.requestId,
      'sourceInstanceTemplate': ?request.sourceInstanceTemplate,
      'sourceMachineImage': ?request.sourceMachineImage,
    },
  );
  final response = await _client.post(url, body: request.instanceResource);
  return Operation.fromJson(response);
}