listReferrers method
Retrieves a list of resources that refer to the VM instance specified in the request. For example, if the VM instance is part of a managed or unmanaged instance group, the referrers list includes the instance group. For more information, readViewing referrers to VM instances.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
Future<InstanceListReferrers> listReferrers(
ListReferrersInstancesRequest request,
) async {
final url = _endPoint.replace(
path:
'/compute/v1/projects/${request.project}/zones/${request.zone}/instances/${request.instance}/referrers',
queryParameters: {
'filter': ?request.filter,
if (request.maxResults case final $1?) 'maxResults': '${$1}',
'orderBy': ?request.orderBy,
'pageToken': ?request.pageToken,
if (request.returnPartialSuccess case final $1?)
'returnPartialSuccess': '${$1}',
},
);
final response = await _client.get(url);
return InstanceListReferrers.fromJson(response);
}