updateAccessConfig method

Future<Operation> updateAccessConfig(
  1. UpdateAccessConfigInstanceRequest request
)

Updates the specified access config from an instance's network interface with the data included in the request. This method supportsPATCH semantics and uses theJSON merge patch format and processing rules.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> updateAccessConfig(
  UpdateAccessConfigInstanceRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/zones/${request.zone}/instances/${request.instance}/updateAccessConfig',
    queryParameters: {
      if (request.networkInterface case final $1 when $1.isNotDefault)
        'networkInterface': $1,
      'requestId': ?request.requestId,
    },
  );
  final response = await _client.post(
    url,
    body: request.accessConfigResource,
  );
  return Operation.fromJson(response);
}