Output Only The rules that apply to the instance. Only rules that
target the specific VM instance are returned if target service accounts
or target secure tags are specified in the rules.
Output only. Output Only The type of the firewall policy. Can be one of HIERARCHY,
NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL.
Check the Type enum for the list of possible values.