rules property
Output Only The rules that apply to the instance. Only rules that
target the specific VM instance are returned if target service accounts
or target secure tags are specified in the rules.
Implementation
final List<FirewallPolicyRule> rules;