InstancesReportHostAsFaultyRequest_DisruptionSchedule class final

The disruption schedule for the VM. Required field, only allows IMMEDIATE.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const InstancesReportHostAsFaultyRequest_DisruptionSchedule
The default value for InstancesReportHostAsFaultyRequest_DisruptionSchedule.
disruptionScheduleUnspecified → const InstancesReportHostAsFaultyRequest_DisruptionSchedule
Not used. Required as per aip/126.
future → const InstancesReportHostAsFaultyRequest_DisruptionSchedule
Delay disruption for caller control. Will be default soon.
immediate → const InstancesReportHostAsFaultyRequest_DisruptionSchedule
Default value. Disrupt the VM immediately.
undefinedDisruptionSchedule → const InstancesReportHostAsFaultyRequest_DisruptionSchedule
A value indicating that the enum field is not set.