labelFingerprint property

String? labelFingerprint
final

Fingerprint of the previous set of labels for this resource, used to prevent conflicts. Provide the latest fingerprint value when making a request to add or change labels.

Implementation

final String? labelFingerprint;