guestAccelerators property
A list of the type and count of accelerator cards attached to the instance.
Implementation
final List<AcceleratorConfig> guestAccelerators;
A list of the type and count of accelerator cards attached to the instance.
final List<AcceleratorConfig> guestAccelerators;