currentName property
The current name of this resource, used to prevent conflicts. Provide the latest name when making a request to change name.
Implementation
final String? currentName;
The current name of this resource, used to prevent conflicts. Provide the latest name when making a request to change name.
final String? currentName;