networkInterfaces property

List<String> networkInterfaces
final

The network interfaces that the security policy will be applied to. Network interfaces use the nicN naming format. You can only set a security policy for network interfaces with an access config.

Implementation

final List<String> networkInterfaces;