params property
Input only. Additional params passed with the request, but not persisted as part of resource payload.
Implementation
final InstantSnapshotParams? params;
Input only. Additional params passed with the request, but not persisted as part of resource payload.
final InstantSnapshotParams? params;