status property
Output only. Output Only The status of the instantSnapshot. This can beCREATING, DELETING, FAILED, orREADY.
Check the Status enum for the list of possible values.
Implementation
final String? status;
Output only. Output Only The status of the instantSnapshot. This can beCREATING, DELETING, FAILED, orREADY.
Check the Status enum for the list of possible values.
final String? status;