toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (architecture != null) 'architecture=$architecture',
    if (creationTimestamp != null) 'creationTimestamp=$creationTimestamp',
    if (description != null) 'description=$description',
    if (diskSizeGb != null) 'diskSizeGb=$diskSizeGb',
    if (id != null) 'id=$id',
    if (kind != null) 'kind=$kind',
    if (labelFingerprint != null) 'labelFingerprint=$labelFingerprint',
    if (name != null) 'name=$name',
    if (region != null) 'region=$region',
    if (satisfiesPzi != null) 'satisfiesPzi=$satisfiesPzi',
    if (satisfiesPzs != null) 'satisfiesPzs=$satisfiesPzs',
    if (selfLink != null) 'selfLink=$selfLink',
    if (selfLinkWithId != null) 'selfLinkWithId=$selfLinkWithId',
    if (sourceDisk != null) 'sourceDisk=$sourceDisk',
    if (sourceDiskId != null) 'sourceDiskId=$sourceDiskId',
    if (sourceInstantSnapshotGroup != null)
      'sourceInstantSnapshotGroup=$sourceInstantSnapshotGroup',
    if (sourceInstantSnapshotGroupId != null)
      'sourceInstantSnapshotGroupId=$sourceInstantSnapshotGroupId',
    if (status != null) 'status=$status',
    if (zone != null) 'zone=$zone',
  ].join(',');
  return 'InstantSnapshot(${$contents})';
}