region property
Output only. Output Only URL of the region where the instant snapshot group resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Implementation
final String? region;