sourceInstantSnapshotGroup property
The source instant snapshot group used to create disks. You can provide this as a partial or full URL to the resource. For example, the following are valid values:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone/instantSnapshotGroups/instantSnapshotGroup
- projects/project/zones/zone/instantSnapshotGroups/instantSnapshotGroup
- zones/zone/instantSnapshotGroups/instantSnapshotGroup
Implementation
final String? sourceInstantSnapshotGroup;