InstantSnapshotGroupResourceStatus class final

Constructors

InstantSnapshotGroupResourceStatus({String? consistencyMembershipResolutionTime, InstantSnapshotGroupSourceInfo? sourceInfo})
InstantSnapshotGroupResourceStatus.fromJson(Object? j)
factory

Properties

consistencyMembershipResolutionTime String?
Output only. Output Only
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceInfo InstantSnapshotGroupSourceInfo?
Output only. Output Only
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String