InstantSnapshot_Architecture class final
Output only. Output Only The architecture of the instant snapshot. Valid values are
ARM64 or X86_64.
Constructors
- InstantSnapshot_Architecture(String value)
-
const
- InstantSnapshot_Architecture.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const InstantSnapshot_Architecture
- The default value for InstantSnapshot_Architecture.
- architectureUnspecified → const InstantSnapshot_Architecture
- Default value indicating Architecture is not set.
- arm64 → const InstantSnapshot_Architecture
- Machines with architecture ARM64
- undefinedArchitecture → const InstantSnapshot_Architecture
- A value indicating that the enum field is not set.
- x8664 → const InstantSnapshot_Architecture
- Machines with architecture X86_64