InstantSnapshot_Status class final

Output only. Output Only The status of the instantSnapshot. This can beCREATING, DELETING, FAILED, orREADY.

Constructors

InstantSnapshot_Status(String value)
const
InstantSnapshot_Status.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const InstantSnapshot_Status
The default value for InstantSnapshot_Status.
creating → const InstantSnapshot_Status
InstantSnapshot creation is in progress.
deleting → const InstantSnapshot_Status
InstantSnapshot is currently being deleted.
failed → const InstantSnapshot_Status
InstantSnapshot creation failed.
ready → const InstantSnapshot_Status
InstantSnapshot has been created successfully.
unavailable → const InstantSnapshot_Status
InstantSnapshot is currently unavailable and cannot be used for Disk restoration
undefinedStatus → const InstantSnapshot_Status
A value indicating that the enum field is not set.