setLabels method

Sets the labels on a instantSnapshot in the given zone. To learn more about labels, read the Labeling Resources documentation.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> setLabels(SetLabelsInstantSnapshotRequest request) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/zones/${request.zone}/instantSnapshots/${request.resource}/setLabels',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.post(
    url,
    body: request.zoneSetLabelsRequestResource,
  );
  return Operation.fromJson(response);
}