InstantSnapshotsScopedList class final

Constructors

InstantSnapshotsScopedList({List<InstantSnapshot> instantSnapshots = const [], Warning? warning})
InstantSnapshotsScopedList.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
instantSnapshots List<InstantSnapshot>
Output Only A list of instantSnapshots contained in this scope.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warning Warning?
Output Only Informational warning which replaces the list of instantSnapshots when the list is empty.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String