effectiveLocation property

String? effectiveLocation
final

Output only. URL of the InterconnectLocation object that represents where this connection is to be provisioned. By default it will be the same as the location field.

Implementation

final String? effectiveLocation;