googleIpAddress property
Output only. Output Only IP address configured on the Google side of the Interconnect
link. This can be used only for ping tests.
Implementation
final String? googleIpAddress;
Output only. Output Only IP address configured on the Google side of the Interconnect
link. This can be used only for ping tests.
final String? googleIpAddress;