googleReferenceId property

String? googleReferenceId
final

Output only. Output Only Google reference ID to be used when raising support tickets with Google or otherwise to debug backend connectivity issues.

Implementation

final String? googleReferenceId;