location property
URL of the InterconnectLocation object that represents where this connection is to be provisioned.
Implementation
final String? location;
URL of the InterconnectLocation object that represents where this connection is to be provisioned.
final String? location;