peerIpAddress property

String? peerIpAddress
final

Output only. Output Only IP address configured on the customer side of the Interconnect link. The customer should configure this IP address during turnup when prompted by Google NOC. This can be used only for ping tests.

Implementation

final String? peerIpAddress;