toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (aaiEnabled != null) 'aaiEnabled=$aaiEnabled',
    if (adminEnabled != null) 'adminEnabled=$adminEnabled',
    if (creationTimestamp != null) 'creationTimestamp=$creationTimestamp',
    if (customerName != null) 'customerName=$customerName',
    if (description != null) 'description=$description',
    if (effectiveLocation != null) 'effectiveLocation=$effectiveLocation',
    if (googleIpAddress != null) 'googleIpAddress=$googleIpAddress',
    if (googleReferenceId != null) 'googleReferenceId=$googleReferenceId',
    if (id != null) 'id=$id',
    if (interconnectType != null) 'interconnectType=$interconnectType',
    if (kind != null) 'kind=$kind',
    if (labelFingerprint != null) 'labelFingerprint=$labelFingerprint',
    if (linkType != null) 'linkType=$linkType',
    if (location != null) 'location=$location',
    if (macsecEnabled != null) 'macsecEnabled=$macsecEnabled',
    if (name != null) 'name=$name',
    if (nocContactEmail != null) 'nocContactEmail=$nocContactEmail',
    if (operationalStatus != null) 'operationalStatus=$operationalStatus',
    if (peerIpAddress != null) 'peerIpAddress=$peerIpAddress',
    if (provisionedLinkCount != null)
      'provisionedLinkCount=$provisionedLinkCount',
    if (remoteLocation != null) 'remoteLocation=$remoteLocation',
    if (requestedLinkCount != null) 'requestedLinkCount=$requestedLinkCount',
    if (satisfiesPzs != null) 'satisfiesPzs=$satisfiesPzs',
    if (selfLink != null) 'selfLink=$selfLink',
    if (state != null) 'state=$state',
    if (subzone != null) 'subzone=$subzone',
  ].join(',');
  return 'Interconnect(${$contents})';
}