InterconnectApplicationAwareInterconnect class final
Configuration information for application awareness on this Cloud Interconnect.
Constructors
-
InterconnectApplicationAwareInterconnect({InterconnectApplicationAwareInterconnectBandwidthPercentagePolicy? bandwidthPercentagePolicy, String? profileDescription, List<
InterconnectApplicationAwareInterconnectBandwidthPercentage> shapeAveragePercentages = const [], InterconnectApplicationAwareInterconnectStrictPriorityPolicy? strictPriorityPolicy}) - InterconnectApplicationAwareInterconnect.fromJson(Object? j)
-
factory
Properties
- bandwidthPercentagePolicy → InterconnectApplicationAwareInterconnectBandwidthPercentagePolicy?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- profileDescription → String?
-
Description for the application awareness profile on this Cloud
Interconnect.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
shapeAveragePercentages
→ List<
InterconnectApplicationAwareInterconnectBandwidthPercentage> -
Optional field to specify a list of shape average percentages to be
applied in conjunction with StrictPriorityPolicy or
BandwidthPercentagePolicy.
final
- strictPriorityPolicy → InterconnectApplicationAwareInterconnectStrictPriorityPolicy?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String