profileDescription property
Description for the application awareness profile on this Cloud Interconnect.
Implementation
final String? profileDescription;
Description for the application awareness profile on this Cloud Interconnect.
final String? profileDescription;