InterconnectAttachment class final

Represents an Interconnect Attachment (VLAN) resource.

You can use Interconnect attachments (VLANS) to connect your Virtual Private Cloud networks to your on-premises networks through an Interconnect. For more information, read Creating VLAN Attachments.

Constructors

InterconnectAttachment({bool? adminEnabled, String? attachmentGroup, String? bandwidth, String? candidateCloudRouterIpAddress, String? candidateCloudRouterIpv6Address, String? candidateCustomerRouterIpAddress, String? candidateCustomerRouterIpv6Address, List<String> candidateIpv6Subnets = const [], List<String> candidateSubnets = const [], String? cloudRouterIpAddress, String? cloudRouterIpv6Address, String? cloudRouterIpv6InterfaceId, InterconnectAttachmentConfigurationConstraints? configurationConstraints, String? creationTimestamp, String? customerRouterIpAddress, String? customerRouterIpv6Address, String? customerRouterIpv6InterfaceId, int? dataplaneVersion, String? description, String? edgeAvailabilityDomain, String? encryption, String? googleReferenceId, BigInt? id, String? interconnect, List<String> ipsecInternalAddresses = const [], String? kind, InterconnectAttachmentL2Forwarding? l2Forwarding, String? labelFingerprint, Map<String, String> labels = const {}, int? mtu, String? name, String? operationalStatus, String? pairingKey, InterconnectAttachmentParams? params, int? partnerAsn, InterconnectAttachmentPartnerMetadata? partnerMetadata, InterconnectAttachmentPrivateInfo? privateInterconnectInfo, String? region, String? remoteService, String? router, bool? satisfiesPzs, String? selfLink, String? stackType, String? state, int? subnetLength, String? type, int? vlanTag8021Q})
InterconnectAttachment.fromJson(Object? j)
factory

Properties

adminEnabled bool?
Determines whether this Attachment will carry packets. Not present for PARTNER_PROVIDER.
final
attachmentGroup String?
Output only. Output Only URL of the AttachmentGroup that includes this Attachment.
final
bandwidth String?
Provisioned bandwidth capacity for the interconnect attachment. For attachments of type DEDICATED, the user can set the bandwidth. For attachments of type PARTNER, the Google Partner that is operating the interconnect must set the bandwidth. Output only for PARTNER type, mutable for PARTNER_PROVIDER and DEDICATED, and can take one of the following values:
final
candidateCloudRouterIpAddress String?
Single IPv4 address + prefix length to be configured on the cloud router interface for this interconnect attachment.
final
candidateCloudRouterIpv6Address String?
Single IPv6 address + prefix length to be configured on the cloud router interface for this interconnect attachment.
final
candidateCustomerRouterIpAddress String?
Single IPv4 address + prefix length to be configured on the customer router interface for this interconnect attachment.
final
candidateCustomerRouterIpv6Address String?
Single IPv6 address + prefix length to be configured on the customer router interface for this interconnect attachment.
final
candidateIpv6Subnets List<String>
This field is not available.
final
candidateSubnets List<String>
Input only. Up to 16 candidate prefixes that can be used to restrict the allocation of cloudRouterIpAddress and customerRouterIpAddress for this attachment. All prefixes must be within link-local address space (169.254.0.0/16) and must be /29 or shorter (/28, /27, etc). Google will attempt to select an unused /29 from the supplied candidate prefix(es). The request will fail if all possible /29s are in use on Google's edge. If not supplied, Google will randomly select an unused /29 from all of link-local space.
final
cloudRouterIpAddress String?
Output only. Output Only IPv4 address + prefix length to be configured on Cloud Router Interface for this interconnect attachment.
final
cloudRouterIpv6Address String?
Output only. Output Only IPv6 address + prefix length to be configured on Cloud Router Interface for this interconnect attachment.
final
cloudRouterIpv6InterfaceId String?
This field is not available.
final
configurationConstraints InterconnectAttachmentConfigurationConstraints?
Output only. Output Only Constraints for this attachment, if any. The attachment does not work if these constraints are not met.
final
creationTimestamp String?
Output only. Output Only Creation timestamp inRFC3339 text format.
final
customerRouterIpAddress String?
Output only. Output Only IPv4 address + prefix length to be configured on the customer router subinterface for this interconnect attachment.
final
customerRouterIpv6Address String?
Output only. Output Only IPv6 address + prefix length to be configured on the customer router subinterface for this interconnect attachment.
final
customerRouterIpv6InterfaceId String?
This field is not available.
final
dataplaneVersion int?
Output only. Output Only Dataplane version for this InterconnectAttachment. This field is only present for Dataplane version 2 and higher. Absence of this field in the API output indicates that the Dataplane is version 1.
final
description String?
An optional description of this resource.
final
edgeAvailabilityDomain String?
Input only. Desired availability domain for the attachment. Only available for type PARTNER, at creation time, and can take one of the following values:
final
encryption String?
Indicates the user-supplied encryption option of this VLAN attachment (interconnectAttachment). Can only be specified at attachment creation for PARTNER or DEDICATED attachments. Possible values are:
final
googleReferenceId String?
Output only. Output Only Google reference ID, to be used when raising support tickets with Google or otherwise to debug backend connectivity issues. Deprecated This field is not used.
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output only. Output Only The unique identifier for the resource. This identifier is defined by the server.
final
interconnect String?
URL of the underlying Interconnect object that this attachment's traffic will traverse through.
final
ipsecInternalAddresses List<String>
A list of URLs of addresses that have been reserved for the VLAN attachment. Used only for the VLAN attachment that has the encryption option as IPSEC. The addresses must be regional internal IP address ranges. When creating an HA VPN gateway over the VLAN attachment, if the attachment is configured to use a regional internal IP address, then the VPN gateway's IP address is allocated from the IP address range specified here. For example, if the HA VPN gateway's interface 0 is paired to this VLAN attachment, then a regional internal IP address for the VPN gateway interface 0 will be allocated from the IP address specified for this VLAN attachment. If this field is not specified when creating the VLAN attachment, then later on when creating an HA VPN gateway on this VLAN attachment, the HA VPN gateway's IP address is allocated from the regional external IP address pool.
final
kind String?
Output only. Output Only Type of the resource. Alwayscompute#interconnectAttachment for interconnect attachments.
final
l2Forwarding InterconnectAttachmentL2Forwarding?
L2 Interconnect Attachment related config. This field is required if the type is L2_DEDICATED.
final
labelFingerprint String?
A fingerprint for the labels being applied to this InterconnectAttachment, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet.
final
labels Map<String, String>
Labels for this resource. These can only be added or modified by thesetLabels method. Each label key/value pair must comply withRFC1035. Label values may be empty.
final
mtu int?
Maximum Transmission Unit (MTU), in bytes, of packets passing through this interconnect attachment. Valid values are 1440, 1460, 1500, and 8896. If not specified, the value will default to 1440.
final
name String?
Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
operationalStatus String?
Output only. Output Only The current status of whether or not this interconnect attachment is functional, which can take one of the following values:
final
pairingKey String?
Output only for type PARTNER. Input only for PARTNER_PROVIDER. Not present for DEDICATED. The opaque identifier of a PARTNER attachment used to initiate provisioning with a selected partner. Of the form "XXXXX/region/domain"
final
params InterconnectAttachmentParams?
Input only. Input Only Additional params passed with the request, but not persisted as part of resource payload.
final
partnerAsn int?
Optional BGP ASN for the router supplied by a Layer 3 Partner if they configured BGP on behalf of the customer. Output only for PARTNER type, input only for PARTNER_PROVIDER, not available for DEDICATED.
final
partnerMetadata InterconnectAttachmentPartnerMetadata?
Informational metadata about Partner attachments from Partners to display to customers. Output only for PARTNER type, mutable for PARTNER_PROVIDER, not available for DEDICATED.
final
privateInterconnectInfo InterconnectAttachmentPrivateInfo?
Output only. Output Only Information specific to an InterconnectAttachment. This property is populated if the interconnect that this is attached to is of type DEDICATED.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
region String?
Output only. Output Only URL of the region where the regional interconnect attachment resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
final
remoteService String?
Output only. Output Only If the attachment is on a Cross-Cloud Interconnect connection, this field contains the interconnect's remote location service provider. Example values: "Amazon Web Services" "Microsoft Azure".
final
router String?
URL of the Cloud Router to be used for dynamic routing. This router must be in the same region as this InterconnectAttachment. The InterconnectAttachment will automatically connect the Interconnect to the network & region within which the Cloud Router is configured.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzs bool?
Output only. Output Only Reserved for future use.
final
Output only. Output Only Server-defined URL for the resource.
final
stackType String?
The stack type for this interconnect attachment to identify whether the IPv6 feature is enabled or not. If not specified, IPV4_ONLY will be used.
final
state String?
Output only. Output Only The current state of this attachment's functionality. Enum values ACTIVE and UNPROVISIONED are shared by DEDICATED/PRIVATE, PARTNER, and PARTNER_PROVIDER interconnect attachments, while enum values PENDING_PARTNER, PARTNER_REQUEST_RECEIVED, and PENDING_CUSTOMER are used for only PARTNER and PARTNER_PROVIDER interconnect attachments. This state can take one of the following values:
final
subnetLength int?
Input only. Length of the IPv4 subnet mask. Allowed values:
final
type String?
The type of interconnect attachment this is, which can take one of the following values:
final
vlanTag8021Q int?
The IEEE 802.1Q VLAN tag for this attachment, in the range 2-4093. Only specified at creation time.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String