candidateCloudRouterIpAddress property

String? candidateCloudRouterIpAddress
final

Single IPv4 address + prefix length to be configured on the cloud router interface for this interconnect attachment.

  • Both candidate_cloud_router_ip_address and candidate_customer_router_ip_address fields must be set or both must be unset.
  • Prefix length of both candidate_cloud_router_ip_address and candidate_customer_router_ip_address must be the same.
  • Max prefix length is 31.

Implementation

final String? candidateCloudRouterIpAddress;