candidateCustomerRouterIpAddress property
Single IPv4 address + prefix length to be configured on the customer router interface for this interconnect attachment.
Implementation
final String? candidateCustomerRouterIpAddress;
Single IPv4 address + prefix length to be configured on the customer router interface for this interconnect attachment.
final String? candidateCustomerRouterIpAddress;