dataplaneVersion property

int? dataplaneVersion
final

Output only. Output Only Dataplane version for this InterconnectAttachment. This field is only present for Dataplane version 2 and higher. Absence of this field in the API output indicates that the Dataplane is version 1.

Implementation

final int? dataplaneVersion;