interconnect property
URL of the underlying Interconnect object that this attachment's traffic will traverse through.
Implementation
final String? interconnect;
URL of the underlying Interconnect object that this attachment's traffic will traverse through.
final String? interconnect;