operationalStatus property
Output only. Output Only The current status of whether or not this interconnect
attachment is functional, which can take one of the following values:
- OS_ACTIVE: The attachment has been turned up and is ready to use.
- OS_UNPROVISIONED: The attachment is not ready to use yet, because turnup is not complete. Check the OperationalStatus enum for the list of possible values.
Implementation
final String? operationalStatus;