state property
Output only. Output Only The current state of this attachment's functionality.
Enum values ACTIVE and UNPROVISIONED are shared by DEDICATED/PRIVATE,
PARTNER, and PARTNER_PROVIDER interconnect attachments, while enum values
PENDING_PARTNER, PARTNER_REQUEST_RECEIVED, and PENDING_CUSTOMER are used
for only PARTNER and PARTNER_PROVIDER interconnect attachments.
This state can take one of the following values:
- ACTIVE: The attachment has been turned up and is ready to use.
- UNPROVISIONED: The attachment is not ready to use yet, because turnup is not complete.
- PENDING_PARTNER: A newly-created PARTNER attachment that has not yet been configured on the Partner side.
- PARTNER_REQUEST_RECEIVED: A PARTNER attachment is in the process of provisioning after a PARTNER_PROVIDER attachment was created that references it.
- PENDING_CUSTOMER: A PARTNER or PARTNER_PROVIDER attachment that is waiting for a customer to activate it.
- DEFUNCT: The attachment was deleted externally and is no longer functional. This could be because the associated Interconnect was removed, or because the other side of a Partner attachment was deleted. Check the State enum for the list of possible values.
Implementation
final String? state;