toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (adminEnabled != null) 'adminEnabled=$adminEnabled',
    if (attachmentGroup != null) 'attachmentGroup=$attachmentGroup',
    if (bandwidth != null) 'bandwidth=$bandwidth',
    if (candidateCloudRouterIpAddress != null)
      'candidateCloudRouterIpAddress=$candidateCloudRouterIpAddress',
    if (candidateCloudRouterIpv6Address != null)
      'candidateCloudRouterIpv6Address=$candidateCloudRouterIpv6Address',
    if (candidateCustomerRouterIpAddress != null)
      'candidateCustomerRouterIpAddress=$candidateCustomerRouterIpAddress',
    if (candidateCustomerRouterIpv6Address != null)
      'candidateCustomerRouterIpv6Address=$candidateCustomerRouterIpv6Address',
    if (cloudRouterIpAddress != null)
      'cloudRouterIpAddress=$cloudRouterIpAddress',
    if (cloudRouterIpv6Address != null)
      'cloudRouterIpv6Address=$cloudRouterIpv6Address',
    if (cloudRouterIpv6InterfaceId != null)
      'cloudRouterIpv6InterfaceId=$cloudRouterIpv6InterfaceId',
    if (creationTimestamp != null) 'creationTimestamp=$creationTimestamp',
    if (customerRouterIpAddress != null)
      'customerRouterIpAddress=$customerRouterIpAddress',
    if (customerRouterIpv6Address != null)
      'customerRouterIpv6Address=$customerRouterIpv6Address',
    if (customerRouterIpv6InterfaceId != null)
      'customerRouterIpv6InterfaceId=$customerRouterIpv6InterfaceId',
    if (dataplaneVersion != null) 'dataplaneVersion=$dataplaneVersion',
    if (description != null) 'description=$description',
    if (edgeAvailabilityDomain != null)
      'edgeAvailabilityDomain=$edgeAvailabilityDomain',
    if (encryption != null) 'encryption=$encryption',
    if (googleReferenceId != null) 'googleReferenceId=$googleReferenceId',
    if (id != null) 'id=$id',
    if (interconnect != null) 'interconnect=$interconnect',
    if (kind != null) 'kind=$kind',
    if (labelFingerprint != null) 'labelFingerprint=$labelFingerprint',
    if (mtu != null) 'mtu=$mtu',
    if (name != null) 'name=$name',
    if (operationalStatus != null) 'operationalStatus=$operationalStatus',
    if (pairingKey != null) 'pairingKey=$pairingKey',
    if (partnerAsn != null) 'partnerAsn=$partnerAsn',
    if (region != null) 'region=$region',
    if (remoteService != null) 'remoteService=$remoteService',
    if (router != null) 'router=$router',
    if (satisfiesPzs != null) 'satisfiesPzs=$satisfiesPzs',
    if (selfLink != null) 'selfLink=$selfLink',
    if (stackType != null) 'stackType=$stackType',
    if (state != null) 'state=$state',
    if (subnetLength != null) 'subnetLength=$subnetLength',
    if (type != null) 'type=$type',
    if (vlanTag8021Q != null) 'vlanTag8021q=$vlanTag8021Q',
  ].join(',');
  return 'InterconnectAttachment(${$contents})';
}