InterconnectAttachmentConfigurationConstraints class final

Properties

bgpMd5 String?
Output only. Output Only Whether the attachment's BGP session requires/allows/disallows BGP MD5 authentication. This can take one of the following values: MD5_OPTIONAL, MD5_REQUIRED, MD5_UNSUPPORTED.
final
bgpPeerAsnRanges List<InterconnectAttachmentConfigurationConstraintsBgpPeerAsnrange>
Output only. Output Only List of ASN ranges that the remote location is known to support. Formatted as an array of inclusive ranges {min: min-value, max: max-value}. For example, {min: 123, max: 123}, {min: 64512, max: 65534} allows the peer ASN to be 123 or anything in the range 64512-65534.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String