InterconnectAttachmentGroupConfiguredAvailabilitySla class final

Output Only Which SLA this group is configured to support, and why this group does or does not meet that SLA's requirements.

Properties

effectiveSla String?
Check the EffectiveSla enum for the list of possible values.
final
hashCode int
The hash code for this object.
no setterinherited
intendedSlaBlockers List<InterconnectAttachmentGroupConfiguredAvailabilitySlaintendedSlaBlockers>
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String