InterconnectAttachmentGroupLogicalStructureRegion class final
Output Only The regions Attachments in this group are in.
Constructors
-
InterconnectAttachmentGroupLogicalStructureRegion({List<
InterconnectAttachmentGroupLogicalStructureRegionMetro> metros = const [], String? region}) - InterconnectAttachmentGroupLogicalStructureRegion.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metros
→ List<
InterconnectAttachmentGroupLogicalStructureRegionMetro> -
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - region → String?
-
Output only.
Output OnlyThe name of a region, like "us-central1".final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String