InterconnectAttachmentGroupLogicalStructureRegionMetro class final

Output Only The metros of Attachments in this group in this region.

Properties

facilities List<InterconnectAttachmentGroupLogicalStructureRegionMetroFacility>
final
hashCode int
The hash code for this object.
no setterinherited
metro String?
Output only. Output Only The name of the metro, as a three-letter lowercase string like "iad". This is the first component of the location of an Interconnect.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String