metro property
Output only. Output Only The name of the metro, as a three-letter lowercase
string like "iad". This is the first component of the location of an
Interconnect.
Implementation
final String? metro;
Output only. Output Only The name of the metro, as a three-letter lowercase
string like "iad". This is the first component of the location of an
Interconnect.
final String? metro;