InterconnectAttachmentGroupLogicalStructureRegionMetroFacility class final

Output Only The facilities used for this group's Attachments' Interconnects.

Properties

facility String?
Output only. Output Only The name of a facility, like "iad-1234".
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zones List<InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String