InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone class final
Output Only The zones that Attachments in this group are present
in, in the given facilities. This is inherited from their
Interconnects.
Constructors
-
InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone({List<
String> attachments = const [], String? zone}) - InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone.fromJson(Object? j)
-
factory
Properties
-
attachments
→ List<
String> -
Output only.
Output OnlyURLs of Attachments in the given zone, to the given region, on Interconnects in the given facility and metro. Every Attachment in the AG has such an entry.final - hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- zone → String?
-
Output only.
Output OnlyThe name of a zone, either "zone1" or "zone2".final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String