attachments property

List<String> attachments
final

Output only. Output Only URLs of Attachments in the given zone, to the given region, on Interconnects in the given facility and metro. Every Attachment in the AG has such an entry.

Implementation

final List<String> attachments;