insert method

Creates a InterconnectAttachmentGroup in the specified project in the given scope using the parameters that are included in the request.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> insert(
  InsertInterconnectAttachmentGroupRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/global/interconnectAttachmentGroups',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.post(
    url,
    body: request.interconnectAttachmentGroupResource,
  );
  return Operation.fromJson(response);
}