patch method

Patches the specified InterconnectAttachmentGroup resource with the data included in the request. This method supports PATCH semantics and usesJSON merge patch format and processing rules.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> patch(
  PatchInterconnectAttachmentGroupRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/global/interconnectAttachmentGroups/${request.interconnectAttachmentGroup}',
    queryParameters: {
      'requestId': ?request.requestId,
      'updateMask': ?request.updateMask,
    },
  );
  final response = await _client.patch(
    url,
    body: request.interconnectAttachmentGroupResource,
  );
  return Operation.fromJson(response);
}