InterconnectAttachmentGroupsOperationalStatus class final

Properties

attachmentStatuses List<InterconnectAttachmentGroupsOperationalStatusAttachmentStatus>
final
configured InterconnectAttachmentGroupConfigured?
final
groupStatus String?
Output only. Summarizes the status of the group. Check the GroupStatus enum for the list of possible values.
final
hashCode int
The hash code for this object.
no setterinherited
intent InterconnectAttachmentGroupIntent?
final
operational InterconnectAttachmentGroupConfigured?
Output only. The operational state of the group, including only active Attachments.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String