adminEnabled property
Output only. Whether this Attachment is enabled. This becomes false when the customer drains their Attachment.
Implementation
final bool? adminEnabled;
Output only. Whether this Attachment is enabled. This becomes false when the customer drains their Attachment.
final bool? adminEnabled;