isActive property

String? isActive
final

Output only. Whether this Attachment is participating in the redundant configuration. This will be ACTIVE if and only if the status below is CONNECTION_UP. Any INACTIVE Attachments are excluded from the analysis that generates operational.availabilitySLA. Check the IsActive enum for the list of possible values.

Implementation

final String? isActive;