status property

String? status
final

Output only. Whether this Attachment is active, and if so, whether BGP is up. Check the Status enum for the list of possible values.

Implementation

final String? status;