tunnelEndpointIpAddress property

String? tunnelEndpointIpAddress
final

Required. A single IPv4 or IPv6 address. This address will be used as the source IP address for packets sent to the appliances, and must be used as the destination IP address for packets that should be sent out through this attachment.

Implementation

final String? tunnelEndpointIpAddress;