InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping class final

The inner VLAN-to-Appliance mapping.

Properties

hashCode int
The hash code for this object.
no setterinherited
innerApplianceIpAddress String?
Required in this object. A single IPv4 or IPv6 address used as the destination IP address for ingress packets that match on both VLAN tags.
final
innerVlanTags List<String>
Required in this object. Used to match the inner VLAN tag on the packet. Each entry can be a single number or a range of numbers in the range of 1 to 4094, e.g., "1", "4001-4094" is valid. Non-empty and Non-overlapping VLAN tag ranges are enforced, and violating operations will be rejected.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String