partnerName property

String? partnerName
final

Plain text name of the Partner providing this attachment. This value may be validated to match approved Partner values.

Implementation

final String? partnerName;