InterconnectAttachments class final

The InterconnectAttachments API.

Implementers

Constructors

InterconnectAttachments({required Client client, Uri? endPoint, String? gcclVersion})
Creates a InterconnectAttachments using client for transport.
InterconnectAttachments.fromApiKey([String? apiKey])
Creates a InterconnectAttachments that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(AggregatedListInterconnectAttachmentsRequest request) Future<InterconnectAttachmentAggregatedList>
Retrieves an aggregated list of interconnect attachments.
close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteInterconnectAttachmentRequest request) Future<Operation>
Deletes the specified interconnect attachment.
get(GetInterconnectAttachmentRequest request) Future<InterconnectAttachment>
Returns the specified interconnect attachment.
insert(InsertInterconnectAttachmentRequest request) Future<Operation>
Creates an InterconnectAttachment in the specified project using the data included in the request.
list(ListInterconnectAttachmentsRequest request) Future<InterconnectAttachmentList>
Retrieves the list of interconnect attachments contained within the specified region.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(PatchInterconnectAttachmentRequest request) Future<Operation>
Updates the specified interconnect attachment with the data included in the request. This method supportsPATCH semantics and uses theJSON merge patch format and processing rules.
setLabels(SetLabelsInterconnectAttachmentRequest request) Future<Operation>
Sets the labels on an InterconnectAttachment. To learn more about labels, read the Labeling Resources documentation.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited