interconnectAttachments property
A list of interconnect attachments contained in this scope.
Implementation
final List<InterconnectAttachment> interconnectAttachments;
A list of interconnect attachments contained in this scope.
final List<InterconnectAttachment> interconnectAttachments;