InterconnectDiagnosticsArpentry class final

Describing the ARP neighbor entries seen on this link

Properties

hashCode int
The hash code for this object.
no setterinherited
ipAddress String?
The IP address of this ARP neighbor.
final
macAddress String?
The MAC address of this ARP neighbor.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String