InterconnectDiagnosticsLinkLacpstatus class final

Constructors

InterconnectDiagnosticsLinkLacpstatus({String? googleSystemId, String? neighborSystemId, String? state})
InterconnectDiagnosticsLinkLacpstatus.fromJson(Object? j)
factory

Properties

googleSystemId String?
System ID of the port on Google's side of the LACP exchange.
final
hashCode int
The hash code for this object.
no setterinherited
neighborSystemId String?
System ID of the port on the neighbor's side of the LACP exchange.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
The state of a LACP link, which can take one of the following values:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String