state property

String? state
final

The status of the current value when compared to the warning and alarm levels for the receiving or transmitting transceiver. Possible states include:

- OK: The value has not crossed a warning threshold.
- LOW_WARNING: The value has crossed below the low
warning threshold.
  • HIGH_WARNING: The value has crossed above the high warning threshold. - LOW_ALARM: The value has crossed below the low alarm threshold. - HIGH_ALARM: The value has crossed above the high alarm threshold. Check the State enum for the list of possible values.

Implementation

final String? state;