ok constant
The value of the current optical power has not crossed a warning threshold.
Implementation
static const ok = InterconnectDiagnosticsLinkOpticalPower_State('OK');
The value of the current optical power has not crossed a warning threshold.
static const ok = InterconnectDiagnosticsLinkOpticalPower_State('OK');