InterconnectDiagnosticsLinkStatus class final

Properties

arpCaches List<InterconnectDiagnosticsArpentry>
A list of InterconnectDiagnostics.ARPEntry objects, describing the ARP neighbor entries seen on this link. This will be empty if the link is bundled
final
circuitId String?
The unique ID for this link assigned during turn up by Google.
final
googleDemarc String?
The Demarc address assigned by Google and provided in the LoA.
final
hashCode int
The hash code for this object.
no setterinherited
lacpStatus InterconnectDiagnosticsLinkLacpstatus?
final
macsec InterconnectDiagnosticsMacsecStatus?
Describes the status of MACsec encryption on this link.
final
operationalStatus String?
The operational status of the link. Check the OperationalStatus enum for the list of possible values.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
receivingOpticalPower InterconnectDiagnosticsLinkOpticalPower?
An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the received light level.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transmittingOpticalPower InterconnectDiagnosticsLinkOpticalPower?
An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the transmitted light level.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String