arpCaches property
A list of InterconnectDiagnostics.ARPEntry objects, describing the ARP neighbor entries seen on this link. This will be empty if the link is bundled
Implementation
final List<InterconnectDiagnosticsArpentry> arpCaches;
A list of InterconnectDiagnostics.ARPEntry objects, describing the ARP neighbor entries seen on this link. This will be empty if the link is bundled
final List<InterconnectDiagnosticsArpentry> arpCaches;