receivingOpticalPower property
An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the received light level.
Implementation
final InterconnectDiagnosticsLinkOpticalPower? receivingOpticalPower;
An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the received light level.
final InterconnectDiagnosticsLinkOpticalPower? receivingOpticalPower;