transmittingOpticalPower property
An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the transmitted light level.
Implementation
final InterconnectDiagnosticsLinkOpticalPower? transmittingOpticalPower;
An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the transmitted light level.
final InterconnectDiagnosticsLinkOpticalPower? transmittingOpticalPower;