InterconnectDiagnostics_BundleOperationalStatus class final

The operational status of the bundle interface.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const InterconnectDiagnostics_BundleOperationalStatus
The default value for InterconnectDiagnostics_BundleOperationalStatus.
bundleOperationalStatusDown → const InterconnectDiagnostics_BundleOperationalStatus
If bundleAggregationType is LACP: LACP is not established and/or all links in the bundle have DOWN operational status. If bundleAggregationType is STATIC: one or more links in the bundle has DOWN operational status.
bundleOperationalStatusUp → const InterconnectDiagnostics_BundleOperationalStatus
If bundleAggregationType is LACP: LACP is established and at least one link in the bundle has UP operational status. If bundleAggregationType is STATIC: all links in the bundle (typically just one) have UP operational status.
undefinedBundleOperationalStatus → const InterconnectDiagnostics_BundleOperationalStatus
A value indicating that the enum field is not set.