interconnects property

Map<String, InterconnectGroupInterconnect> interconnects
final

Interconnects in the InterconnectGroup. Keys are arbitrary user-specified strings. Users are encouraged, but not required, to use their preferred format for resource links as keys. Note that there are add-members and remove-members methods in gcloud. The size of this map is limited by an "Interconnects per group" quota.

Implementation

final Map<String, InterconnectGroupInterconnect> interconnects;