InterconnectGroupConfiguredTopologyCapability class final

Output Only How reliable this topology is configured to be, and why this group does or does not meet the requirements for the intended capability.

Properties

hashCode int
The hash code for this object.
no setterinherited
intendedCapabilityBlockers List<InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers>
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportedSla String?
Check the SupportedSla enum for the list of possible values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String