InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers class final

Output Only Reasons why configuration.topologyCapability.sla differs from intent.topologyCapability. This list is empty if and only if those are the same.

Constructors

InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers({String? blockerType, String? documentationLink, String? explanation, List<String> facilities = const [], List<String> interconnects = const [], List<String> metros = const [], List<String> zones = const []})
InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers.fromJson(Object? j)
factory

Properties

blockerType String?
Check the BlockerType enum for the list of possible values.
final
Output only. Output Only The url of Google Cloud public documentation explaining this requirement. This is set for every type of requirement.
final
explanation String?
Output only. Output Only A human-readable explanation of this requirement and why it's not met. This is set for every type of requirement.
final
facilities List<String>
Output only. Output Only Facilities used to explain this blocker in more detail. Like physicalStructure.metros.facilities.facility, this is a numeric string like "5467".
final
hashCode int
The hash code for this object.
no setterinherited
interconnects List<String>
Output only. Output Only Interconnects used to explain this blocker in more detail.
final
metros List<String>
Output only. Output Only Metros used to explain this blocker in more detail. These are three-letter lowercase strings like "iad". A blocker like INCOMPATIBLE_METROS will specify the problematic metros in this field.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zones List<String>
Output only. Output Only Zones used to explain this blocker in more detail. Zone names are "zone1" and/or "zone2".
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String