documentationLink property
Output only. Output Only The url of Google Cloud public documentation explaining
this requirement. This is set for every type of requirement.
Implementation
final String? documentationLink;
Output only. Output Only The url of Google Cloud public documentation explaining
this requirement. This is set for every type of requirement.
final String? documentationLink;