metros property

List<String> metros
final

Output only. Output Only Metros used to explain this blocker in more detail. These are three-letter lowercase strings like "iad". A blocker like INCOMPATIBLE_METROS will specify the problematic metros in this field.

Implementation

final List<String> metros;