InterconnectGroupIntent_TopologyCapability class final
Constructors
- InterconnectGroupIntent_TopologyCapability(String value)
-
const
- InterconnectGroupIntent_TopologyCapability.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const InterconnectGroupIntent_TopologyCapability
- The default value for InterconnectGroupIntent_TopologyCapability.
- noSla → const InterconnectGroupIntent_TopologyCapability
- productionCritical → const InterconnectGroupIntent_TopologyCapability
- productionNonCritical → const InterconnectGroupIntent_TopologyCapability
- undefinedTopologyCapability → const InterconnectGroupIntent_TopologyCapability
- A value indicating that the enum field is not set.
- unspecified → const InterconnectGroupIntent_TopologyCapability