InterconnectGroupPhysicalStructure class final

Output Only An analysis of the physical layout of Interconnects in this group. Every Interconnect in the group is shown once in this structure.

Properties

hashCode int
The hash code for this object.
no setterinherited
metros List<InterconnectGroupPhysicalStructureMetros>
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String