metro property
Output only. Output Only The name of the metro, as a three-letter lowercase string
like "iad". This is the first component of the location of
Interconnects underneath this.
Implementation
final String? metro;
Output only. Output Only The name of the metro, as a three-letter lowercase string
like "iad". This is the first component of the location of
Interconnects underneath this.
final String? metro;