InterconnectGroupPhysicalStructureMetrosFacilities class final

Output Only The facilities Interconnects in this metro are present in.

Properties

facility String?
Output only. Output Only The ID of this facility, as a numeric string like "5467". This is the third component of the location of Interconnects in this facility.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zones List<InterconnectGroupPhysicalStructureMetrosFacilitiesZones>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String