createMembers method

Create Interconnects with redundancy by creating them in a specified interconnect group.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> createMembers(
  CreateMembersInterconnectGroupRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/global/interconnectGroups/${request.interconnectGroup}/createMembers',
  );
  final response = await _client.post(
    url,
    body: request.interconnectGroupsCreateMembersRequestResource,
  );
  return Operation.fromJson(response);
}