insert method

Creates a InterconnectGroup in the specified project in the given scope using the parameters that are included in the request.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> insert(InsertInterconnectGroupRequest request) async {
  final url = _endPoint.replace(
    path: '/compute/v1/projects/${request.project}/global/interconnectGroups',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.post(
    url,
    body: request.interconnectGroupResource,
  );
  return Operation.fromJson(response);
}