InterconnectGroupsCreateMembers class final

Properties

hashCode int
The hash code for this object.
no setterinherited
intentMismatchBehavior String?
How to behave when configured.topologyCapability.supportedSLA would not equal intent.topologyCapability after this call. Check the IntentMismatchBehavior enum for the list of possible values.
final
interconnects List<InterconnectGroupsCreateMembersInterconnectInput>
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
templateInterconnect InterconnectGroupsCreateMembersInterconnectInput?
Parameters for the Interconnects to create.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String