customerName property
Customer name, to put in the Letter of Authorization as the party authorized to request a crossconnect.
Implementation
final String? customerName;
Customer name, to put in the Letter of Authorization as the party authorized to request a crossconnect.
final String? customerName;