requestedLinkCount property
Target number of physical links in the link bundle, as requested by the customer.
Implementation
final int? requestedLinkCount;
Target number of physical links in the link bundle, as requested by the customer.
final int? requestedLinkCount;