InterconnectGroupsCreateMembersInterconnectInput_RequestedFeatures class final
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const InterconnectGroupsCreateMembersInterconnectInput_RequestedFeatures
- The default value for InterconnectGroupsCreateMembersInterconnectInput_RequestedFeatures.
- ifCrossSiteNetwork → const InterconnectGroupsCreateMembersInterconnectInput_RequestedFeatures
- Cross-Site Networking
- ifL2Forwarding → const InterconnectGroupsCreateMembersInterconnectInput_RequestedFeatures
- L2 Interconnect Attachment Forwarding
- ifMacsec → const InterconnectGroupsCreateMembersInterconnectInput_RequestedFeatures
- Media Access Control security (MACsec)
- undefinedRequestedFeatures → const InterconnectGroupsCreateMembersInterconnectInput_RequestedFeatures
- A value indicating that the enum field is not set.