InterconnectGroupsOperationalStatus class final

Request to get the status of the interconnect group with extra detail.

Properties

configured InterconnectGroupConfigured?
Output only. The configuration analysis, as returned by Get.
final
groupStatus String?
Output only. Summarizes the status of the group. Check the GroupStatus enum for the list of possible values.
final
hashCode int
The hash code for this object.
no setterinherited
intent InterconnectGroupIntent?
Output only. The intent of the resource, as returned by Get.
final
interconnectStatuses List<InterconnectGroupsOperationalStatusInterconnectStatus>
final
operational InterconnectGroupConfigured?
Output only. The operational state of the group, including only active Interconnects.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String