diagnostics property
Output only. The diagnostics of the Interconnect, as returned by the existing get-diagnostics method.
Implementation
final InterconnectDiagnostics? diagnostics;
Output only. The diagnostics of the Interconnect, as returned by the existing get-diagnostics method.
final InterconnectDiagnostics? diagnostics;