isActive property
Output only. Whether this interconnect is participating in the redundant configuration. Check the IsActive enum for the list of possible values.
Implementation
final String? isActive;
Output only. Whether this interconnect is participating in the redundant configuration. Check the IsActive enum for the list of possible values.
final String? isActive;