InterconnectGroupsOperationalStatusInterconnectStatus_IsActive class final
Output only. Whether this interconnect is participating in the redundant configuration.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const InterconnectGroupsOperationalStatusInterconnectStatus_IsActive
- The default value for InterconnectGroupsOperationalStatusInterconnectStatus_IsActive.
- active → const InterconnectGroupsOperationalStatusInterconnectStatus_IsActive
- inactive → const InterconnectGroupsOperationalStatusInterconnectStatus_IsActive
- isActiveUnspecified → const InterconnectGroupsOperationalStatusInterconnectStatus_IsActive
- undefinedIsActive → const InterconnectGroupsOperationalStatusInterconnectStatus_IsActive
- A value indicating that the enum field is not set.