availableFeatures property

List<String> availableFeatures
final

Output only List of features available at this InterconnectLocation, which can take one of the following values:

  • IF_MACSEC
  • IF_CROSS_SITE_NETWORK Check the AvailableFeatures enum for the list of possible values.

Implementation

final List<String> availableFeatures;