facilityProvider property
Output only. Output Only The name of the provider for this facility (e.g., EQUINIX).
Implementation
final String? facilityProvider;
Output only. Output Only The name of the provider for this facility (e.g., EQUINIX).
final String? facilityProvider;