maxDynamicPathBandwidthGbps property
Output only. The maximum unmetered bandwidth for dynamic paths allowable per WireGroup for this metro.
Implementation
final int? maxDynamicPathBandwidthGbps;
Output only. The maximum unmetered bandwidth for dynamic paths allowable per WireGroup for this metro.
final int? maxDynamicPathBandwidthGbps;