maxFixedPathBandwidthGbps property
Output only. The maximum unmetered bandwidth for fixed paths allowable per WireGroup for this metro.
Implementation
final int? maxFixedPathBandwidthGbps;
Output only. The maximum unmetered bandwidth for fixed paths allowable per WireGroup for this metro.
final int? maxFixedPathBandwidthGbps;