InterconnectLocationRegionInfo class final

Information about any potential InterconnectAttachments between an Interconnect at a specific InterconnectLocation, and a specific Cloud Region.

Constructors

InterconnectLocationRegionInfo({int? expectedRttMs, bool? l2ForwardingEnabled, String? locationPresence, String? region})
InterconnectLocationRegionInfo.fromJson(Object? j)
factory

Properties

expectedRttMs int?
Output only. Expected round-trip time in milliseconds, from this InterconnectLocation to a VM in this region.
final
hashCode int
The hash code for this object.
no setterinherited
l2ForwardingEnabled bool?
Output only. Identifies whether L2 Interconnect Attachments can be created in this region for interconnects that are in this location.
final
locationPresence String?
Output only. Identifies the network presence of this location. Check the LocationPresence enum for the list of possible values.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
region String?
Output only. URL for the region of this location.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String