l2ForwardingEnabled property
Output only. Identifies whether L2 Interconnect Attachments can be created in this region for interconnects that are in this location.
Implementation
final bool? l2ForwardingEnabled;
Output only. Identifies whether L2 Interconnect Attachments can be created in this region for interconnects that are in this location.
final bool? l2ForwardingEnabled;