InterconnectLocation_AvailableFeatures class final

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const InterconnectLocation_AvailableFeatures
The default value for InterconnectLocation_AvailableFeatures.
ifCrossSiteNetwork → const InterconnectLocation_AvailableFeatures
Cross-Site Networking
ifL2Forwarding → const InterconnectLocation_AvailableFeatures
L2 Interconnect Attachment Forwarding
ifMacsec → const InterconnectLocation_AvailableFeatures
Media Access Control security (MACsec)
undefinedAvailableFeatures → const InterconnectLocation_AvailableFeatures
A value indicating that the enum field is not set.