InterconnectLocation_Status class final

Output Only The status of this InterconnectLocation, which can take one of the following values:

  • CLOSED: The InterconnectLocation is closed and is unavailable for provisioning new Interconnects.
  • AVAILABLE: The InterconnectLocation is available for provisioning new Interconnects.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const InterconnectLocation_Status
The default value for InterconnectLocation_Status.
available → const InterconnectLocation_Status
The InterconnectLocation is available for provisioning new Interconnects.
closed → const InterconnectLocation_Status
The InterconnectLocation is closed for provisioning new Interconnects.
undefinedStatus → const InterconnectLocation_Status
A value indicating that the enum field is not set.