InterconnectLocations class final
The InterconnectLocations API.
- Implementers
Constructors
- InterconnectLocations({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
InterconnectLocationsusingclientfor transport. - InterconnectLocations.fromApiKey([String? apiKey])
-
Creates a
InterconnectLocationsthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
get(
GetInterconnectLocationRequest request) → Future< InterconnectLocation> - Returns the details for the specified interconnect location. Gets a list of available interconnect locations by making a list() request.
-
list(
ListInterconnectLocationsRequest request) → Future< InterconnectLocationList> - Retrieves the list of interconnect locations available to the specified project.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited