get method

Returns the details for the specified interconnect location. Gets a list of available interconnect locations by making a list() request.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<InterconnectLocation> get(
  GetInterconnectLocationRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/global/interconnectLocations/${request.interconnectLocation}',
  );
  final response = await _client.get(url);
  return InterconnectLocation.fromJson(response);
}