InterconnectOutageNotification class final

Description of a planned outage on this Interconnect.

Constructors

InterconnectOutageNotification({List<String> affectedCircuits = const [], String? description, int? endTime, String? issueType, String? name, String? source, int? startTime, String? state})
InterconnectOutageNotification.fromJson(Object? j)
factory

Properties

affectedCircuits List<String>
If issue_type is IT_PARTIAL_OUTAGE, a list of the Google-side circuit IDs that will be affected.
final
description String?
A description about the purpose of the outage.
final
endTime int?
Scheduled end time for the outage (milliseconds since Unix epoch).
final
hashCode int
The hash code for this object.
no setterinherited
issueType String?
Form this outage is expected to take, which can take one of the following values:
final
name String?
Unique identifier for this outage notification.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String?
The party that generated this notification, which can take the following value:
final
startTime int?
Scheduled start time for the outage (milliseconds since Unix epoch).
final
state String?
State of this notification, which can take one of the following values:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String