InterconnectRemoteLocation class final
Represents a Cross-Cloud Interconnect Remote Location resource.
You can use this resource to find remote location details about an Interconnect attachment (VLAN).
Constructors
-
InterconnectRemoteLocation({String? address, InterconnectAttachmentConfigurationConstraints? attachmentConfigurationConstraints, String? city, InterconnectRemoteLocationConstraints? constraints, String? continent, String? creationTimestamp, String? description, String? facilityProvider, String? facilityProviderFacilityId, BigInt? id, String? kind, String? lacp, int? maxLagSize100Gbps, int? maxLagSize10Gbps, int? maxLagSize400Gbps, String? name, String? peeringdbFacilityId, List<
InterconnectRemoteLocationPermittedConnections> permittedConnections = const [], String? remoteService, String? selfLink, String? status}) - InterconnectRemoteLocation.fromJson(Object? j)
-
factory
Properties
- address → String?
-
Output only.
Output OnlyThe postal address of the Point of Presence, each line in the address is separated by a newline character.final - attachmentConfigurationConstraints → InterconnectAttachmentConfigurationConstraints?
-
Output only.
Output OnlySubset of fields from InterconnectAttachment's |configurationConstraints| field that apply to all attachments for this remote location.final - city → String?
-
Output only.
Output OnlyMetropolitan area designator that indicates which city an interconnect is located. For example: "Chicago, IL", "Amsterdam, Netherlands".final - constraints → InterconnectRemoteLocationConstraints?
-
Output only.
Output OnlyConstraints on the parameters for creating Cross-Cloud Interconnect and associated InterconnectAttachments.final - continent → String?
-
Output only.
Output OnlyContinent for this location, which can take one of the following values:final - creationTimestamp → String?
-
Output only.
Output OnlyCreation timestamp inRFC3339 text format.final - description → String?
-
Output only.
Output OnlyAn optional description of the resource.final - facilityProvider → String?
-
Output only.
Output OnlyThe name of the provider for this facility (e.g., EQUINIX).final - facilityProviderFacilityId → String?
-
Output only.
Output OnlyA provider-assigned Identifier for this facility (e.g., Ashburn-DC1).final - hashCode → int
-
The hash code for this object.
no setterinherited
- id → BigInt?
-
Output only.
Output OnlyThe unique identifier for the resource. This identifier is defined by the server.final - kind → String?
-
Output only.
Output OnlyType of the resource. Alwayscompute#interconnectRemoteLocation for interconnect remote locations.final - lacp → String?
-
Output only.
Output OnlyLink Aggregation Control Protocol (LACP) constraints, which can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED Check the Lacp enum for the list of possible values.final - maxLagSize100Gbps → int?
-
Output only.
Output OnlyThe maximum number of 100 Gbps ports supported in a link aggregation group (LAG). When linkType is 100 Gbps, requestedLinkCount cannot exceed max_lag_size_100_gbps.final - maxLagSize10Gbps → int?
-
Output only.
Output OnlyThe maximum number of 10 Gbps ports supported in a link aggregation group (LAG). When linkType is 10 Gbps, requestedLinkCount cannot exceed max_lag_size_10_gbps.final - maxLagSize400Gbps → int?
-
Output only.
Output OnlyThe maximum number of 400 Gbps ports supported in a link aggregation group (LAG). When linkType is 400 Gbps, requestedLinkCount cannot exceed max_lag_size_400_gbps.final - name → String?
-
Output only.
Output OnlyName of the resource.final - peeringdbFacilityId → String?
-
Output only.
Output OnlyThe peeringdb identifier for this facility (corresponding with a netfac type in peeringdb).final -
permittedConnections
→ List<
InterconnectRemoteLocationPermittedConnections> -
Output only.
Output OnlyPermitted connections.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - remoteService → String?
-
Output only.
Output OnlyIndicates the service provider present at the remote location. Example values: "Amazon Web Services", "Microsoft Azure".final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfLink → String?
-
Output only.
Output OnlyServer-defined URL for the resource.final - status → String?
-
Output only.
Output OnlyThe status of this InterconnectRemoteLocation, which can take one of the following values:final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String