continent property

String? continent
final

Output only. Output Only Continent for this location, which can take one of the following values:

  • AFRICA
  • ASIA_PAC
  • EUROPE
  • NORTH_AMERICA
  • SOUTH_AMERICA Check the Continent enum for the list of possible values.

Implementation

final String? continent;