lacp property

String? lacp
final

Output only. Output Only Link Aggregation Control Protocol (LACP) constraints, which can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED Check the Lacp enum for the list of possible values.

Implementation

final String? lacp;