peeringdbFacilityId property
Output only. Output Only The peeringdb identifier for this facility (corresponding
with a netfac type in peeringdb).
Implementation
final String? peeringdbFacilityId;
Output only. Output Only The peeringdb identifier for this facility (corresponding
with a netfac type in peeringdb).
final String? peeringdbFacilityId;