remoteService property
Output only. Output Only Indicates the service provider present at the remote
location. Example values: "Amazon Web Services", "Microsoft Azure".
Implementation
final String? remoteService;
Output only. Output Only Indicates the service provider present at the remote
location. Example values: "Amazon Web Services", "Microsoft Azure".
final String? remoteService;