InterconnectRemoteLocationConstraints_PortPairRemoteLocation class final

Output only. Output Only Port pair remote location constraints, which can take one of the following values: PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION, PORT_PAIR_MATCHING_REMOTE_LOCATION.

Google Cloud API refers only to individual ports, but the UI uses this field when ordering a pair of ports, to prevent users from accidentally ordering something that is incompatible with their cloud provider. Specifically, when ordering a redundant pair of Cross-Cloud Interconnect ports, and one of them uses a remote location with portPairMatchingRemoteLocation set to matching, the UI requires that both ports use the same remote location.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const InterconnectRemoteLocationConstraints_PortPairRemoteLocation
The default value for InterconnectRemoteLocationConstraints_PortPairRemoteLocation.
portPairMatchingRemoteLocation → const InterconnectRemoteLocationConstraints_PortPairRemoteLocation
If PORT_PAIR_MATCHING_REMOTE_LOCATION, the remote cloud provider allocates ports in pairs, and the user should choose the same remote location for both ports.
portPairUnconstrainedRemoteLocation → const InterconnectRemoteLocationConstraints_PortPairRemoteLocation
If PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION, a user may opt to provision a redundant pair of Cross-Cloud Interconnects using two different remote locations in the same city.
undefinedPortPairRemoteLocation → const InterconnectRemoteLocationConstraints_PortPairRemoteLocation
A value indicating that the enum field is not set.