InterconnectRemoteLocationConstraints_PortPairVlan class final

Output only. Output Only Port pair VLAN constraints, which can take one of the following values: PORT_PAIR_UNCONSTRAINED_VLAN, PORT_PAIR_MATCHING_VLAN

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const InterconnectRemoteLocationConstraints_PortPairVlan
The default value for InterconnectRemoteLocationConstraints_PortPairVlan.
portPairMatchingVlan → const InterconnectRemoteLocationConstraints_PortPairVlan
If PORT_PAIR_MATCHING_VLAN, the Interconnect for this attachment is part of a pair of ports that should have matching VLAN allocations. This occurs with Cross-Cloud Interconnect to Azure remote locations. While GCP's API does not explicitly group pairs of ports, the UI uses this field to ensure matching VLAN ids when configuring a redundant VLAN pair.
portPairUnconstrainedVlan → const InterconnectRemoteLocationConstraints_PortPairVlan
PORT_PAIR_UNCONSTRAINED_VLAN means there is no constraint.
undefinedPortPairVlan → const InterconnectRemoteLocationConstraints_PortPairVlan
A value indicating that the enum field is not set.