InterconnectRemoteLocationList class final

Response to the list request, and contains a list of interconnect remote locations.

Constructors

InterconnectRemoteLocationList({String? id, List<InterconnectRemoteLocation> items = const [], String? kind, String? nextPageToken, String? selfLink, Warning? warning})
InterconnectRemoteLocationList.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String?
Output Only Unique identifier for the resource; defined by the server.
final
items List<InterconnectRemoteLocation>
A list of InterconnectRemoteLocation resources.
final
kind String?
Output only. Output Only Type of resource. Alwayscompute#interconnectRemoteLocationList for lists of interconnect remote locations.
final
nextPageToken String?
Output Only This token lets you get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output only. Output Only Server-defined URL for this resource.
final
warning Warning?
Output Only Informational warning message.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String