nextPageToken property

String? nextPageToken
final

Output Only This token lets you get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.

Implementation

final String? nextPageToken;