interconnectLocation property
Output only. Output Only URL of an Interconnect location that is permitted to
connect to this Interconnect remote location.
Implementation
final String? interconnectLocation;
Output only. Output Only URL of an Interconnect location that is permitted to
connect to this Interconnect remote location.
final String? interconnectLocation;