InterconnectRemoteLocation_Continent class final
Output only. Output Only Continent for this location, which can take one of the
following values:
- AFRICA
- ASIA_PAC
- EUROPE
- NORTH_AMERICA
- SOUTH_AMERICA
Constructors
- InterconnectRemoteLocation_Continent(String value)
-
const
- InterconnectRemoteLocation_Continent.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const InterconnectRemoteLocation_Continent
- The default value for InterconnectRemoteLocation_Continent.
- africa → const InterconnectRemoteLocation_Continent
- asiaPac → const InterconnectRemoteLocation_Continent
- europe → const InterconnectRemoteLocation_Continent
- northAmerica → const InterconnectRemoteLocation_Continent
- southAmerica → const InterconnectRemoteLocation_Continent
- undefinedContinent → const InterconnectRemoteLocation_Continent
- A value indicating that the enum field is not set.