get method

Returns the details for the specified interconnect remote location. Gets a list of available interconnect remote locations by making alist() request.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<InterconnectRemoteLocation> get(
  GetInterconnectRemoteLocationRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/global/interconnectRemoteLocations/${request.interconnectRemoteLocation}',
  );
  final response = await _client.get(url);
  return InterconnectRemoteLocation.fromJson(response);
}