Interconnect_OperationalStatus class final

Output only. Output Only The current status of this Interconnect's functionality, which can take one of the following values:

  • OS_ACTIVE: A valid Interconnect, which is turned up and is ready to use. Attachments may be provisioned on this Interconnect.

  • OS_UNPROVISIONED: An Interconnect that has not completed turnup. No attachments may be provisioned on this Interconnect.

  • OS_UNDER_MAINTENANCE: An Interconnect that is undergoing internal maintenance. No attachments may be provisioned or updated on this Interconnect.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const Interconnect_OperationalStatus
The default value for Interconnect_OperationalStatus.
osActive → const Interconnect_OperationalStatus
The interconnect is valid, turned up, and ready to use. Attachments may be provisioned on this interconnect.
osUnprovisioned → const Interconnect_OperationalStatus
The interconnect has not completed turnup. No attachments may be provisioned on this interconnect.
undefinedOperationalStatus → const Interconnect_OperationalStatus
A value indicating that the enum field is not set.