Interconnect_RequestedFeatures class final

Additional supported values which may be not listed in the enum directly due to technical reasons: IF_CROSS_SITE_NETWORK IF_L2_FORWARDING IF_MACSEC

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const Interconnect_RequestedFeatures
The default value for Interconnect_RequestedFeatures.
undefinedRequestedFeatures → const Interconnect_RequestedFeatures
A value indicating that the enum field is not set.