Interconnect_State class final

Output only. Output Only The current state of Interconnect functionality, which can take one of the following values:

  • ACTIVE: The Interconnect is valid, turned up and ready to use. Attachments may be provisioned on this Interconnect.
  • UNPROVISIONED: The Interconnect has not completed turnup. No attachments may be provisioned on this Interconnect.
  • UNDER_MAINTENANCE: The Interconnect is undergoing internal maintenance. No attachments may be provisioned or updated on this Interconnect.

Constructors

Interconnect_State(String value)
const
Interconnect_State.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const Interconnect_State
The default value for Interconnect_State.
active → const Interconnect_State
The interconnect is valid, turned up, and ready to use. Attachments may be provisioned on this interconnect.
undefinedState → const Interconnect_State
A value indicating that the enum field is not set.
unprovisioned → const Interconnect_State
The interconnect has not completed turnup. No attachments may be provisioned on this interconnect.