Interconnect_Subzone class final

To be deprecated.

Constructors

Interconnect_Subzone(String value)
const
Interconnect_Subzone.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const Interconnect_Subzone
The default value for Interconnect_Subzone.
subzoneA → const Interconnect_Subzone
Subzone A.
subzoneB → const Interconnect_Subzone
Subzone B.
undefinedSubzone → const Interconnect_Subzone
A value indicating that the enum field is not set.