InterconnectsGetMacsecConfigResponse class final
Response for the InterconnectsGetMacsecConfigRequest.
Constructors
- InterconnectsGetMacsecConfigResponse({String? etag, InterconnectMacsecConfig? result})
- InterconnectsGetMacsecConfigResponse.fromJson(Object? j)
-
factory
Properties
- etag → String?
-
end_interface: MixerGetResponseWithEtagBuilder
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - result → InterconnectMacsecConfig?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String