startTime property
Optional. Inclusive start of the interval.
If specified, a Timestamp matching this interval will have to be the same or after the start.
Implementation
final String? startTime;
Optional. Inclusive start of the interval.
If specified, a Timestamp matching this interval will have to be the same or after the start.
final String? startTime;