appendableToDisk property
If true, this license can be appended to an existing disk's set of licenses.
Implementation
final bool? appendableToDisk;
If true, this license can be appended to an existing disk's set of licenses.
final bool? appendableToDisk;