licenseCode property
Output Only The unique code used to attach this license to images,
snapshots, and disks.
Implementation
final BigInt? licenseCode;
Output Only The unique code used to attach this license to images,
snapshots, and disks.
final BigInt? licenseCode;