params property
Input only. Additional params passed with the request, but not persisted as part of resource payload.
Implementation
final LicenseParams? params;
Input only. Additional params passed with the request, but not persisted as part of resource payload.
final LicenseParams? params;