toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (appendableToDisk != null) 'appendableToDisk=$appendableToDisk',
    if (chargesUseFee != null) 'chargesUseFee=$chargesUseFee',
    if (creationTimestamp != null) 'creationTimestamp=$creationTimestamp',
    if (description != null) 'description=$description',
    if (id != null) 'id=$id',
    if (kind != null) 'kind=$kind',
    if (licenseCode != null) 'licenseCode=$licenseCode',
    if (multiTenantOnly != null) 'multiTenantOnly=$multiTenantOnly',
    if (name != null) 'name=$name',
    if (osLicense != null) 'osLicense=$osLicense',
    if (removableFromDisk != null) 'removableFromDisk=$removableFromDisk',
    if (selfLink != null) 'selfLink=$selfLink',
    if (selfLinkWithId != null) 'selfLinkWithId=$selfLinkWithId',
    if (soleTenantOnly != null) 'soleTenantOnly=$soleTenantOnly',
    if (transferable != null) 'transferable=$transferable',
    if (updateTimestamp != null) 'updateTimestamp=$updateTimestamp',
  ].join(',');
  return 'License(${$contents})';
}