transferable property

bool? transferable
final

If false, licenses will not be copied from the source resource when creating an image from a disk, disk from snapshot, or snapshot from disk.

Implementation

final bool? transferable;