LicenseCode class final
Represents a License Code resource.
A License Code is a unique identifier used to represent alicense resource. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
Constructors
-
LicenseCode({List<
String> allowedReplacementLicenses = const [], bool? appendableToDisk, String? creationTimestamp, String? description, BigInt? id, List<String> incompatibleLicenses = const [], String? kind, List<LicenseCodeLicenseAlias> licenseAlias = const [], Duration? minimumRetention, bool? multiTenantOnly, String? name, bool? osLicense, bool? removableFromDisk, List<String> requiredCoattachedLicenses = const [], String? selfLink, bool? soleTenantOnly, String? state, bool? transferable, String? updateTimestamp}) - LicenseCode.fromJson(Object? j)
-
factory
Properties
-
allowedReplacementLicenses
→ List<
String> -
Specifies licenseCodes of licenses that can replace this license. Note:
such replacements are allowed even if removable_from_disk is false.
final
- appendableToDisk → bool?
-
If true, this license can be appended to an existing disk's set of
licenses.
final
- creationTimestamp → String?
-
Output only.
Output OnlyCreation timestamp inRFC3339 text format.final - description → String?
-
Output only.
Output OnlyDescription of this License Code.final - hashCode → int
-
The hash code for this object.
no setterinherited
- id → BigInt?
-
Output only.
Output OnlyThe unique identifier for the resource. This identifier is defined by the server.final -
incompatibleLicenses
→ List<
String> -
Specifies licenseCodes of licenses that are incompatible with this license.
If a license is incompatible with this license, it cannot be attached to
the same disk or image.
final
- kind → String?
-
Output only.
Output OnlyType of resource. Always compute#licenseCode for licenses.final -
licenseAlias
→ List<
LicenseCodeLicenseAlias> -
Output OnlyURL and description aliases of Licenses with the same License Code.final - minimumRetention → Duration?
-
If set, this license will be unable to be removed or replaced once attached
to a disk until the minimum_retention period has passed.
final
- multiTenantOnly → bool?
-
If true, this license can only be used on VMs on multi tenant nodes.
final
- name → String?
-
Output only.
Output OnlyName of the resource. The name is 1-20 characters long and must be a valid 64 bit integer.final - osLicense → bool?
-
If true, indicates this is an OS license. Only one OS license can be
attached to a disk or image at a time.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - removableFromDisk → bool?
-
If true, this license can be removed from a disk's set of licenses, with no
replacement license needed.
final
-
requiredCoattachedLicenses
→ List<
String> -
Specifies the set of permissible coattached licenseCodes of licenses that
satisfy the coattachment requirement of this license. At least one license
from the set must be attached to the same disk or image as this license.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfLink → String?
-
Output only.
Output OnlyServer-defined URL for the resource.final - soleTenantOnly → bool?
-
If true, this license can only be used on VMs on sole tenant nodes.
final
- state → String?
-
Output only.
Output OnlyCurrent state of this License Code. Check the State enum for the list of possible values.final - transferable → bool?
-
Output only.
Output OnlyIf true, the license will remain attached when creating images or snapshots from disks. Otherwise, the license is not transferred.final - updateTimestamp → String?
-
Output only.
Output OnlyLast update timestamp inRFC3339 text format.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String