licenseAlias property
Output Only URL and description aliases of Licenses with the same
License Code.
Implementation
final List<LicenseCodeLicenseAlias> licenseAlias;
Output Only URL and description aliases of Licenses with the same
License Code.
final List<LicenseCodeLicenseAlias> licenseAlias;