minimumRetention property
If set, this license will be unable to be removed or replaced once attached to a disk until the minimum_retention period has passed.
Implementation
final Duration? minimumRetention;
If set, this license will be unable to be removed or replaced once attached to a disk until the minimum_retention period has passed.
final Duration? minimumRetention;