osLicense property
If true, indicates this is an OS license. Only one OS license can be attached to a disk or image at a time.
Implementation
final bool? osLicense;
If true, indicates this is an OS license. Only one OS license can be attached to a disk or image at a time.
final bool? osLicense;