removableFromDisk property
If true, this license can be removed from a disk's set of licenses, with no replacement license needed.
Implementation
final bool? removableFromDisk;
If true, this license can be removed from a disk's set of licenses, with no replacement license needed.
final bool? removableFromDisk;