requiredCoattachedLicenses property

List<String> requiredCoattachedLicenses
final

Specifies the set of permissible coattached licenseCodes of licenses that satisfy the coattachment requirement of this license. At least one license from the set must be attached to the same disk or image as this license.

Implementation

final List<String> requiredCoattachedLicenses;