state property
Output only. Output Only Current state of this License Code.
Check the State enum for the list of possible values.
Implementation
final String? state;
Output only. Output Only Current state of this License Code.
Check the State enum for the list of possible values.
final String? state;