transferable property
Output only. Output Only If true, the license will remain attached when creating
images or snapshots from disks. Otherwise, the license is not transferred.
Implementation
final bool? transferable;
Output only. Output Only If true, the license will remain attached when creating
images or snapshots from disks. Otherwise, the license is not transferred.
final bool? transferable;