LicenseCodeLicenseAlias class final

Constructors

LicenseCodeLicenseAlias({String? description, String? selfLink})
LicenseCodeLicenseAlias.fromJson(Object? j)
factory

Properties

description String?
Output only. Output Only Description of this License Code.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output only. Output Only URL of license corresponding to this License Code.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String