disabled constant

LicenseCode_State const disabled

Machines are not allowed to attach boot disks with this License Code. Requests to create new resources with this license will be rejected.

Implementation

static const disabled = LicenseCode_State('DISABLED');