restricted constant
LicenseCode_State
const restricted
Use of this license is limited to a project whitelist.
Implementation
static const restricted = LicenseCode_State('RESTRICTED');
Use of this license is limited to a project whitelist.
static const restricted = LicenseCode_State('RESTRICTED');