setIamPolicy method
Sets the access control policy on the specified resource. Replaces any existing policy. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
Future<Policy> setIamPolicy(SetIamPolicyLicenseCodeRequest request) async {
final url = _endPoint.replace(
path:
'/compute/v1/projects/${request.project}/global/licenseCodes/${request.resource}/setIamPolicy',
);
final response = await _client.post(
url,
body: request.globalSetPolicyRequestResource,
);
return Policy.fromJson(response);
}