testIamPermissions method
Returns permissions that a caller has on the specified resource. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
Future<TestPermissionsResponse> testIamPermissions(
TestIamPermissionsLicenseCodeRequest request,
) async {
final url = _endPoint.replace(
path:
'/compute/v1/projects/${request.project}/global/licenseCodes/${request.resource}/testIamPermissions',
);
final response = await _client.post(
url,
body: request.testPermissionsRequestResource,
);
return TestPermissionsResponse.fromJson(response);
}