LicenseResourceCommitment class final

Commitment for a particular license resource.

Constructors

LicenseResourceCommitment({int? amount, String? coresPerLicense, String? license})
LicenseResourceCommitment.fromJson(Object? j)
factory

Properties

amount int?
The number of licenses you plan to purchase.
final
coresPerLicense String?
The number of cores per license.
final
hashCode int
The hash code for this object.
no setterinherited
license String?
The applicable license URI.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String