LicenseResourceRequirements class final

Constructors

LicenseResourceRequirements({int? minGuestCpuCount, int? minMemoryMb})
LicenseResourceRequirements.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
minGuestCpuCount int?
Input Only Deprecated. This field no longer reflects the minimum number of guest cpus required to use the Instance.
final
minMemoryMb int?
Input Only Deprecated. This field no longer reflects the minimum memory required to use the Instance.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String