get method

Future<License> get(
  1. GetLicenseRequest request
)

Returns the specified License resource. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<License> get(GetLicenseRequest request) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/global/licenses/${request.license}',
  );
  final response = await _client.get(url);
  return License.fromJson(response);
}