insert method

Create a License resource in the specified project. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> insert(InsertLicenseRequest request) async {
  final url = _endPoint.replace(
    path: '/compute/v1/projects/${request.project}/global/licenses',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.post(url, body: request.licenseResource);
  return Operation.fromJson(response);
}