ListAssociationsFirewallPolicyRequest class final

A request message for FirewallPolicies.ListAssociations. See the method description for details.

Constructors

ListAssociationsFirewallPolicyRequest({bool? includeInheritedPolicies, String? targetResource})
ListAssociationsFirewallPolicyRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
includeInheritedPolicies bool?
If set to "true", the response will contain a list of all associations for the containing folders and the containing organization of the target. The parameter has no effect if the target is an organization.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetResource String?
The target resource to list associations. It is an organization, or a folder.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String