ListBgpRoutesRoutersRequest_AddressFamily class final
(Required) limit results to this address family (either IPv4 or IPv6)
Constructors
- ListBgpRoutesRoutersRequest_AddressFamily(String value)
-
const
- ListBgpRoutesRoutersRequest_AddressFamily.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const ListBgpRoutesRoutersRequest_AddressFamily
- The default value for ListBgpRoutesRoutersRequest_AddressFamily.
- ipv4 → const ListBgpRoutesRoutersRequest_AddressFamily
- ipv6 → const ListBgpRoutesRoutersRequest_AddressFamily
- undefinedAddressFamily → const ListBgpRoutesRoutersRequest_AddressFamily
- A value indicating that the enum field is not set.
- unspecifiedIpVersion → const ListBgpRoutesRoutersRequest_AddressFamily