instanceGroup property
The name of the instance group from which you want to generate a list of included instances.
Implementation
final String instanceGroup;
The name of the instance group from which you want to generate a list of included instances.
final String instanceGroup;