networkEndpointGroup property
The name of the network endpoint group from which you want to generate a list of included network endpoints. It should comply with RFC1035.
Implementation
final String networkEndpointGroup;
The name of the network endpoint group from which you want to generate a list of included network endpoints. It should comply with RFC1035.
final String networkEndpointGroup;