instance property

String instance
final

Name of the target instance scoping this request, or '-' if the request should span over all instances in the container.

Implementation

final String instance;