maxResults property
The maximum number of results per page that should be returned.
If the number of available results is larger than maxResults,
Compute Engine returns a nextPageToken that can be used to get
the next page of results in subsequent list requests. Acceptable values are
0 to 500, inclusive. (Default: 500)
Implementation
final int? maxResults;