region property
Name of the region scoping this request. It must be a string that meets the requirements in RFC1035.
Implementation
final String region;
Name of the region scoping this request. It must be a string that meets the requirements in RFC1035.
final String region;