serviceProject property
The project id or project number in which the subnetwork is intended to be used. Only applied for Shared VPC. See Shared VPC documentation
Implementation
final String? serviceProject;
The project id or project number in which the subnetwork is intended to be used. Only applied for Shared VPC. See Shared VPC documentation
final String? serviceProject;