LocationPolicy class final

Configuration for location policy among multiple possible locations (e.g. preferences for zone selection among zones in a single region).

Constructors

LocationPolicy({Map<String, LocationPolicyLocation> locations = const {}, String? targetShape, List<LocationPolicyZoneConfiguration> zones = const []})
LocationPolicy.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
locations Map<String, LocationPolicyLocation>
Location configurations mapped by location name. Currently only zone names are supported and must be represented as valid internal URLs, such as zones/us-central1-a. The bulkInsert operation doesn't create instances in an AI zone, even if an AI zone is available in the specified region. For example, if you set a DENY preference for us-central1-a, Compute Engine will consider us-central1-b and us-central1-c for instance creation, but not us-central1-ai1a. Also, you can't use the locations[] configuration to allow instance creation in an AI zone. To include an AI zone in bulkInsert operations, use the locationPolicy.zones[] field.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetShape String?
Strategy for distributing VMs across zones in a region. Check the TargetShape enum for the list of possible values.
final
zones List<LocationPolicyZoneConfiguration>
The bulkInsert operation applies any preferences set in the locations field to the specific zones listed in the zones field if the same zones are specified in both fields.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String