zones property

The bulkInsert operation applies any preferences set in the locations field to the specific zones listed in the zones field if the same zones are specified in both fields.

Implementation

final List<LocationPolicyZoneConfiguration> zones;