LocationPolicyLocation class
final
Properties
-
constraints
→ LocationPolicyLocationConstraints?
-
Constraints that the caller requires on the result distribution
in this zone.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
preference
→ String?
-
Preference for a given location. Set to either ALLOW orDENY.
Check the Preference enum for the list of possible values.
final
-
qualifiedName
→ String
-
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or google.rpc.ErrorInfo.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited