constraints property
Constraints that the caller requires on the result distribution in this zone.
Implementation
final LocationPolicyLocationConstraints? constraints;
Constraints that the caller requires on the result distribution in this zone.
final LocationPolicyLocationConstraints? constraints;