LocationPolicyLocationConstraints class final

Per-zone constraints on location policy for this zone.

Properties

hashCode int
The hash code for this object.
no setterinherited
maxCount int?
Maximum number of items that are allowed to be placed in this zone. The value must be non-negative.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String