LocationPolicyLocation_Preference class final

Preference for a given location. Set to either ALLOW orDENY.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const LocationPolicyLocation_Preference
The default value for LocationPolicyLocation_Preference.
allow → const LocationPolicyLocation_Preference
Location is allowed for use.
deny → const LocationPolicyLocation_Preference
Location is prohibited.
preferenceUnspecified → const LocationPolicyLocation_Preference
Default value, unused.
undefinedPreference → const LocationPolicyLocation_Preference
A value indicating that the enum field is not set.