LocationPolicy_TargetShape class final
Strategy for distributing VMs across zones in a region.
Constructors
- LocationPolicy_TargetShape(String value)
-
const
- LocationPolicy_TargetShape.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const LocationPolicy_TargetShape
- The default value for LocationPolicy_TargetShape.
- any → const LocationPolicy_TargetShape
- GCE picks zones for creating VM instances to fulfill the requested number of VMs within present resource constraints and to maximize utilization of unused zonal reservations. Recommended for batch workloads that do not require high availability.
- anySingleZone → const LocationPolicy_TargetShape
- GCE always selects a single zone for all the VMs, optimizing for resource quotas, available reservations and general capacity. Recommended for batch workloads that cannot tollerate distribution over multiple zones. This the default shape in Bulk Insert and Capacity Advisor APIs.
- balanced → const LocationPolicy_TargetShape
- GCE prioritizes acquisition of resources, scheduling VMs in zones where resources are available while distributing VMs as evenly as possible across allowed zones to minimize the impact of zonal failure. Recommended for highly available serving workloads.
- undefinedTargetShape → const LocationPolicy_TargetShape
- A value indicating that the enum field is not set.