MachineImage class final

Represents a machine image resource.

A machine image is a Compute Engine resource that stores all the configuration, metadata, permissions, and data from one or more disks required to create a Virtual machine (VM) instance. For more information, seeMachine images.

Constructors

MachineImage({String? creationTimestamp, String? description, bool? guestFlush, BigInt? id, InstanceProperties? instanceProperties, String? kind, String? labelFingerprint, Map<String, String> labels = const {}, CustomerEncryptionKey? machineImageEncryptionKey, String? name, MachineImageParams? params, bool? satisfiesPzi, bool? satisfiesPzs, List<SavedDisk> savedDisks = const [], String? selfLink, List<SourceDiskEncryptionKey> sourceDiskEncryptionKeys = const [], String? sourceInstance, SourceInstanceProperties? sourceInstanceProperties, String? status, List<String> storageLocations = const [], int? totalStorageBytes})
MachineImage.fromJson(Object? j)
factory

Properties

creationTimestamp String?
Output only. Output Only The creation timestamp for this machine image inRFC3339 text format.
final
description String?
An optional description of this resource. Provide this property when you create the resource.
final
guestFlush bool?
Input Only Whether to attempt an application consistent machine image by informing the OS to prepare for the snapshot process.
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output only. Output Only A unique identifier for this machine image. The server defines this identifier.
final
instanceProperties InstanceProperties?
Output Only Properties of source instance
final
kind String?
Output only. Output Only The resource type, which is alwayscompute#machineImage for machine image.
final
labelFingerprint String?
A fingerprint for the labels being applied to this machine image, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels.
final
labels Map<String, String>
Labels to apply to this machine image. These can be later modified by the setLabels method.
final
machineImageEncryptionKey CustomerEncryptionKey?
Encrypts the machine image using acustomer-supplied encryption key.
final
name String?
Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
params MachineImageParams?
Input only. Input Only Additional parameters that are passed in the request, but are not persisted in the resource.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzi bool?
Output only. Reserved for future use.
final
satisfiesPzs bool?
Output only. Output Only Reserved for future use.
final
savedDisks List<SavedDisk>
Output only. An array of Machine Image specific properties for disks attached to the source instance
final
Output only. Output Only The URL for this machine image. The server defines this URL.
final
sourceDiskEncryptionKeys List<SourceDiskEncryptionKey>
Input Only Thecustomer-supplied encryption key of the disks attached to the source instance. Required if the source disk is protected by a customer-supplied encryption key.
final
sourceInstance String?
The source instance used to create the machine image. You can provide this as a partial or full URL to the resource. For example, the following are valid values:
final
sourceInstanceProperties SourceInstanceProperties?
Output only. Output Only DEPRECATED: Please use instance_properties instead for source instance related properties. New properties will not be added to this field.
final
status String?
Output only. Output Only The status of the machine image. One of the following values:INVALID, CREATING, READY,DELETING, and UPLOADING. Check the Status enum for the list of possible values.
final
storageLocations List<String>
The regional or multi-regional Cloud Storage bucket location where themachine image is stored.
final
totalStorageBytes int?
Output only. Output Only Total size of the storage used by the machine image.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String