creationTimestamp property
Output only. Output Only The creation timestamp for this machine image inRFC3339
text format.
Implementation
final String? creationTimestamp;
Output only. Output Only The creation timestamp for this machine image inRFC3339
text format.
final String? creationTimestamp;