guestFlush property
Input Only Whether to attempt an application consistent machine image by
informing the OS to prepare for the snapshot process.
Implementation
final bool? guestFlush;
Input Only Whether to attempt an application consistent machine image by
informing the OS to prepare for the snapshot process.
final bool? guestFlush;