id property
Output only. Output Only A unique identifier for this machine image. The server
defines this identifier.
Implementation
final BigInt? id;
Output only. Output Only A unique identifier for this machine image. The server
defines this identifier.
final BigInt? id;