params property

MachineImageParams? params
final

Input only. Input Only Additional parameters that are passed in the request, but are not persisted in the resource.

Implementation

final MachineImageParams? params;