sourceDiskEncryptionKeys property

List<SourceDiskEncryptionKey> sourceDiskEncryptionKeys
final

Input Only Thecustomer-supplied encryption key of the disks attached to the source instance. Required if the source disk is protected by a customer-supplied encryption key.

Implementation

final List<SourceDiskEncryptionKey> sourceDiskEncryptionKeys;