sourceInstance property

String? sourceInstance
final

The source instance used to create the machine image. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

 - https://www.googleapis.com/compute/v1/projects/project/zones/zone/instances/instance
  • projects/project/zones/zone/instances/instance

Implementation

final String? sourceInstance;