totalStorageBytes property
Output only. Output Only Total size of the storage used by the machine image.
Implementation
final int? totalStorageBytes;
Output only. Output Only Total size of the storage used by the machine image.
final int? totalStorageBytes;