MachineImageParams class final
Machine Image parameters
Constructors
-
MachineImageParams({Map<
String, String> resourceManagerTags = const {}}) - MachineImageParams.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited -
resourceManagerTags
→ Map<
String, String> -
Input only. Resource manager tags to be bound to the machine image. Tag keys and values
have the same definition as resource
manager tags. Keys and values can be either in numeric format,
such as
tagKeys/{tag_key_id}andtagValues/{tag_value_id}or in namespaced format such as{org_id|project_id}/{tag_key_short_name}and{tag_value_short_name}. The field is ignored (both PUT & PATCH) when empty.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String