MachineImage_Status class final

Output only. Output Only The status of the machine image. One of the following values:INVALID, CREATING, READY,DELETING, and UPLOADING.

Constructors

MachineImage_Status(String value)
const
MachineImage_Status.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const MachineImage_Status
The default value for MachineImage_Status.
creating → const MachineImage_Status
deleting → const MachineImage_Status
invalid → const MachineImage_Status
ready → const MachineImage_Status
undefinedStatus → const MachineImage_Status
A value indicating that the enum field is not set.
uploading → const MachineImage_Status