MachineType class final
Represents a Machine Type resource.
You can use specific machine types for your VM instances based on performance and pricing requirements. For more information, readMachine Types.
Constructors
-
MachineType({List<
Accelerators> accelerators = const [], String? architecture, BundledLocalSsds? bundledLocalSsds, String? creationTimestamp, DeprecationStatus? deprecated, String? description, int? guestCpus, BigInt? id, int? imageSpaceGb, String? kind, int? maximumPersistentDisks, int? maximumPersistentDisksSizeGb, int? memoryMb, String? name, String? selfLink, String? zone}) - MachineType.fromJson(Object? j)
-
factory
Properties
-
accelerators
→ List<
Accelerators> -
Output OnlyA list of accelerator configurations assigned to this machine type.final - architecture → String?
-
Output OnlyThe architecture of the machine type. Check the Architecture enum for the list of possible values.final - bundledLocalSsds → BundledLocalSsds?
-
Output OnlyThe configuration of bundled local SSD for the machine type.final - creationTimestamp → String?
-
Output OnlyCreation timestamp inRFC3339 text format.final - deprecated → DeprecationStatus?
-
Output OnlyThe deprecation status associated with this machine type. Only applicable if the machine type is unavailable.final - description → String?
-
Output OnlyAn optional textual description of the resource.final - guestCpus → int?
-
Output OnlyThe number of virtual CPUs that are available to the instance.final - hashCode → int
-
The hash code for this object.
no setterinherited
- id → BigInt?
-
Output OnlyThe unique identifier for the resource. This identifier is defined by the server.final - imageSpaceGb → int?
-
Deprecated This property is deprecated and will never be populated with
any relevant values.
final
-
Output OnlyWhether this machine type has a shared CPU. SeeShared-core machine types for more information.final - kind → String?
-
Output only.
Output OnlyThe type of the resource. Alwayscompute#machineType for machine types.final - maximumPersistentDisks → int?
-
Output OnlyMaximum persistent disks allowed.final - maximumPersistentDisksSizeGb → int?
-
Output OnlyMaximum total persistent disks size (GB) allowed.final - memoryMb → int?
-
Output OnlyThe amount of physical memory available to the instance, defined in MB.final - name → String?
-
Output OnlyName of the resource.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfLink → String?
-
Output OnlyServer-defined URL for the resource.final - zone → String?
-
Output OnlyThe name of the zone where the machine type resides, such as us-central1-a.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String