instanceHealth property
Output only. Output Only Health state of the instance per health-check.
Implementation
final List<ManagedInstanceInstanceHealth> instanceHealth;
Output only. Output Only Health state of the instance per health-check.
final List<ManagedInstanceInstanceHealth> instanceHealth;