preservedStateFromPolicy property
Output only. Output Only Preserved state generated based on stateful policy
for this instance.
Implementation
final PreservedState? preservedStateFromPolicy;
Output only. Output Only Preserved state generated based on stateful policy
for this instance.
final PreservedState? preservedStateFromPolicy;