scheduling property
Output only. Information about the termination timestamp of the instance, if applicable.
Implementation
final ManagedInstanceScheduling? scheduling;
Output only. Information about the termination timestamp of the instance, if applicable.
final ManagedInstanceScheduling? scheduling;