shutdownDetails property
Output only. Specifies the graceful shutdown details if the instance is in
PENDING_STOP state or there is a programmed stop scheduled.
Implementation
final ManagedInstanceShutdownDetails? shutdownDetails;
Output only. Specifies the graceful shutdown details if the instance is in
PENDING_STOP state or there is a programmed stop scheduled.
final ManagedInstanceShutdownDetails? shutdownDetails;