targetStatus property

String? targetStatus
final

Output only. The eventual status of the instance. The instance group manager will not be identified as stable till each managed instance reaches its targetStatus. Check the TargetStatus enum for the list of possible values.

Implementation

final String? targetStatus;