ManagedInstanceInstanceHealth class final

Constructors

ManagedInstanceInstanceHealth({String? detailedHealthState, String? healthCheck})
ManagedInstanceInstanceHealth.fromJson(Object? j)
factory

Properties

detailedHealthState String?
Output only. Output Only The current detailed instance health state. Check the DetailedHealthState enum for the list of possible values.
final
hashCode int
The hash code for this object.
no setterinherited
healthCheck String?
Output only. Output Only The URL for the health check that verifies whether the instance is healthy.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String