healthCheck property
Output only. Output Only The URL for the health check that verifies whether the
instance is healthy.
Implementation
final String? healthCheck;
Output only. Output Only The URL for the health check that verifies whether the
instance is healthy.
final String? healthCheck;