healthy constant

The instance is reachable i.e. a connection to the application health checking endpoint can be established, and conforms to the requirements defined by the health check.

Implementation

static const healthy = ManagedInstanceInstanceHealth_DetailedHealthState(
  'HEALTHY',
);