timeout constant

The instance is unreachable i.e. a connection to the application health checking endpoint cannot be established, or the server does not respond within the specified timeout.

Implementation

static const timeout = ManagedInstanceInstanceHealth_DetailedHealthState(
  'TIMEOUT',
);