ManagedInstanceLastAttempt class
final
Properties
-
errors
→ ManagedInstanceLastAttemptErrors?
-
Output only.
Output Only Encountered errors during the last attempt to create or
delete the instance.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
qualifiedName
→ String
-
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or google.rpc.ErrorInfo.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited