ManagedInstanceScheduling class final

Constructors

ManagedInstanceScheduling({String? gracefulShutdownTimestamp, String? terminationTimestamp})
ManagedInstanceScheduling.fromJson(Object? j)
factory

Properties

gracefulShutdownTimestamp String?
Output only. The timestamp at which the underlying instance will be triggered for graceful shutdown if it is configured. This is in RFC3339 text format.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terminationTimestamp String?
Output only. The timestamp at which the managed instance will be terminated. This is in RFC3339 text format.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String