gracefulShutdownTimestamp property
Output only. The timestamp at which the underlying instance will be triggered for graceful shutdown if it is configured. This is in RFC3339 text format.
Implementation
final String? gracefulShutdownTimestamp;
Output only. The timestamp at which the underlying instance will be triggered for graceful shutdown if it is configured. This is in RFC3339 text format.
final String? gracefulShutdownTimestamp;