terminationTimestamp property
Output only. The timestamp at which the managed instance will be terminated. This is in RFC3339 text format.
Implementation
final String? terminationTimestamp;
Output only. The timestamp at which the managed instance will be terminated. This is in RFC3339 text format.
final String? terminationTimestamp;