ManagedInstanceShutdownDetails class final

Constructors

ManagedInstanceShutdownDetails({Duration? maxDuration, String? requestTimestamp})
ManagedInstanceShutdownDetails.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
maxDuration Duration?
Output only. The duration for graceful shutdown. Only applicable when the instance is in PENDING_STOP state.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requestTimestamp String?
Output only. Past timestamp indicating the beginning of PENDING_STOP state of instance in RFC3339 text format.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String