ManagedInstance_CurrentAction class final
Output only. Output Only The current action that the managed instance group has
scheduled for the instance. Possible values:
- NONE The instance is running, and the managed instance group does not have any scheduled actions for this instance.
- CREATING The managed instance group is creating this instance. If the group fails to create this instance, it will try again until it is successful.
- CREATING_WITHOUT_RETRIES The managed instance group is attempting to create this instance only once. If the group fails to create this instance, it does not try again and the group'stargetSize value is decreased instead.
- RECREATING The managed instance group is recreating this instance.
- DELETING The managed instance group is permanently deleting this instance.
- ABANDONING The managed instance group is abandoning this instance. The instance will be removed from the instance group and from any target pools that are associated with this group.
- RESTARTING The managed instance group is restarting the instance.
- REFRESHING The managed instance group is applying configuration changes to the instance without stopping it. For example, the group can update the target pool list for an instance without stopping that instance.
- VERIFYING The managed instance group has created the instance and it is in the process of being verified. Additional supported values which may be not listed in the enum directly due to technical reasons: STOPPING SUSPENDING
Constructors
- ManagedInstance_CurrentAction(String value)
-
const
- ManagedInstance_CurrentAction.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const ManagedInstance_CurrentAction
- The default value for ManagedInstance_CurrentAction.
- abandoning → const ManagedInstance_CurrentAction
- The managed instance group is abandoning this instance. The instance will be removed from the instance group and from any target pools that are associated with this group.
- creating → const ManagedInstance_CurrentAction
- The managed instance group is creating this instance. If the group fails to create this instance, it will try again until it is successful.
- creatingWithoutRetries → const ManagedInstance_CurrentAction
- The managed instance group is attempting to create this instance only once. If the group fails to create this instance, it does not try again and the group's targetSize value is decreased.
- deleting → const ManagedInstance_CurrentAction
- The managed instance group is permanently deleting this instance.
- none → const ManagedInstance_CurrentAction
- The managed instance group has not scheduled any actions for this instance.
- recreating → const ManagedInstance_CurrentAction
- The managed instance group is recreating this instance.
- refreshing → const ManagedInstance_CurrentAction
- The managed instance group is applying configuration changes to the instance without stopping it. For example, the group can update the target pool list for an instance without stopping that instance.
- restarting → const ManagedInstance_CurrentAction
- The managed instance group is restarting this instance.
- resuming → const ManagedInstance_CurrentAction
- The managed instance group is resuming this instance.
- starting → const ManagedInstance_CurrentAction
- The managed instance group is starting this instance.
- undefinedCurrentAction → const ManagedInstance_CurrentAction
- A value indicating that the enum field is not set.
- verifying → const ManagedInstance_CurrentAction
- The managed instance group is verifying this already created instance. Verification happens every time the instance is (re)created or restarted and consists of: