creatingWithoutRetries constant

ManagedInstance_CurrentAction const creatingWithoutRetries

The managed instance group is attempting to create this instance only once. If the group fails to create this instance, it does not try again and the group's targetSize value is decreased.

Implementation

static const creatingWithoutRetries = ManagedInstance_CurrentAction(
  'CREATING_WITHOUT_RETRIES',
);