refreshing constant

The managed instance group is applying configuration changes to the instance without stopping it. For example, the group can update the target pool list for an instance without stopping that instance.

Implementation

static const refreshing = ManagedInstance_CurrentAction('REFRESHING');