verifying constant

The managed instance group is verifying this already created instance. Verification happens every time the instance is (re)created or restarted and consists of:

  1. Waiting until health check specified as part of this managed instance group's autohealing policy reports HEALTHY. Note: Applies only if autohealing policy has a health check specified
  2. Waiting for addition verification steps performed as post-instance creation (subject to future extensions).

Implementation

static const verifying = ManagedInstance_CurrentAction('VERIFYING');