MetadataFilterLabelMatch class final

MetadataFilter label name value pairs that are expected to match corresponding labels presented as metadata to the load balancer.

Properties

hashCode int
The hash code for this object.
no setterinherited
name String?
Name of metadata label.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String?
The value of the label must match the specified value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String