MoveGlobalAddressRequest class final

A request message for GlobalAddresses.Move. See the method description for details.

Constructors

MoveGlobalAddressRequest({required String address, required GlobalAddressesMoveRequest? globalAddressesMoveRequestResource, required String project, String? requestId})
MoveGlobalAddressRequest.fromJson(Object? j)
factory

Properties

address String
Name of the address resource to move.
final
globalAddressesMoveRequestResource GlobalAddressesMoveRequest?
The body resource for this request
final
hashCode int
The hash code for this object.
no setterinherited
project String
Source project ID which the Address is moved from.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requestId String?
An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String