NamedPort class final

The named port. For example: <"http", 80>.

Constructors

NamedPort({String? name, int? port})
NamedPort.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
name String?
The name for this named port. The name must be 1-63 characters long, and comply withRFC1035.
final
port int?
The port number, which can be a value between 1 and 65535.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String