NatIpInfoNatIpInfoMapping class final

Contains information of a NAT IP.

Constructors

NatIpInfoNatIpInfoMapping({String? mode, String? natIp, String? usage})
NatIpInfoNatIpInfoMapping.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
mode String?
Output only. Specifies whether NAT IP is auto or manual. Check the Mode enum for the list of possible values.
final
natIp String?
Output only. NAT IP address. For example: 203.0.113.11.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usage String?
Output only. Specifies whether NAT IP is currently serving at least one endpoint or not. Check the Usage enum for the list of possible values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String