mode property
Output only. Specifies whether NAT IP is auto or manual. Check the Mode enum for the list of possible values.
Implementation
final String? mode;
Output only. Specifies whether NAT IP is auto or manual. Check the Mode enum for the list of possible values.
final String? mode;