usage property

String? usage
final

Output only. Specifies whether NAT IP is currently serving at least one endpoint or not. Check the Usage enum for the list of possible values.

Implementation

final String? usage;