NatIpInfoNatIpInfoMapping_Mode class final
Output only. Specifies whether NAT IP is auto or manual.
Constructors
- NatIpInfoNatIpInfoMapping_Mode(String value)
-
const
- NatIpInfoNatIpInfoMapping_Mode.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const NatIpInfoNatIpInfoMapping_Mode
- The default value for NatIpInfoNatIpInfoMapping_Mode.
- auto → const NatIpInfoNatIpInfoMapping_Mode
- manual → const NatIpInfoNatIpInfoMapping_Mode
- undefinedMode → const NatIpInfoNatIpInfoMapping_Mode
- A value indicating that the enum field is not set.