NatIpInfoNatIpInfoMapping_Usage class final

Output only. Specifies whether NAT IP is currently serving at least one endpoint or not.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const NatIpInfoNatIpInfoMapping_Usage
The default value for NatIpInfoNatIpInfoMapping_Usage.
inUse → const NatIpInfoNatIpInfoMapping_Usage
undefinedUsage → const NatIpInfoNatIpInfoMapping_Usage
A value indicating that the enum field is not set.
unused → const NatIpInfoNatIpInfoMapping_Usage