Network class final
Represents a VPC Network resource.
Networks connect resources to each other and to the internet. For more information, readVirtual Private Cloud (VPC) Network.
Constructors
-
Network({String? iPv4Range, bool? autoCreateSubnetworks, String? creationTimestamp, String? description, bool? enableUlaInternalIpv6, String? firewallPolicy, String? gatewayIPv4, BigInt? id, String? internalIpv6Range, String? kind, int? mtu, String? name, String? networkFirewallPolicyEnforcementOrder, String? networkProfile, NetworkParams? params, List<
NetworkPeering> peerings = const [], NetworkRoutingConfig? routingConfig, String? selfLink, String? selfLinkWithId, List<String> subnetworks = const []}) - Network.fromJson(Object? j)
-
factory
Properties
- autoCreateSubnetworks → bool?
-
Must be set to create a VPC network. If not set, a legacy network is
created.
final
- creationTimestamp → String?
-
Output only.
Output OnlyCreation timestamp inRFC3339 text format.final - description → String?
-
An optional description of this resource. Provide this field when you
create the resource.
final
- enableUlaInternalIpv6 → bool?
-
Enable ULA internal ipv6 on this network. Enabling this feature will assign
a /48 from google defined ULA prefix fd20::/20.
.
final
- firewallPolicy → String?
-
Output only.
Output OnlyURL of the firewall policy the network is associated with.final - gatewayIPv4 → String?
-
Output OnlyThe gateway address for default routing out of the network, selected by Google Cloud.final - hashCode → int
-
The hash code for this object.
no setterinherited
- id → BigInt?
-
Output only.
Output OnlyThe unique identifier for the resource. This identifier is defined by the server.final - internalIpv6Range → String?
-
When enabling ula internal ipv6, caller optionally can specify the /48
range they want from the google defined ULA prefix fd20::/20. The input
must be a valid /48 ULA IPv6 address and must be within the fd20::/20.
Operation will fail if the speficied /48 is already in used by another
resource. If the field is not speficied, then a /48 range will be randomly
allocated from fd20::/20 and returned via this field.
.
final
- iPv4Range → String?
-
Deprecated in favor of subnet mode networks.
The range of internal addresses that are legal on this network. This
range is aCIDR specification, for example:192.168.0.0/16. Provided by the client when the network is
created.
final
- kind → String?
-
Output only.
Output OnlyType of the resource. Always compute#network for networks.final - mtu → int?
-
Maximum Transmission Unit in bytes.
The minimum value for this field is 1300 and the maximum value is 8896.
The suggested value is 1500, which is the default MTU used on the
Internet, or 8896 if you want to use Jumbo frames. If unspecified, the
value defaults to 1460.
final
- name → String?
-
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression
[a-z]([-a-z0-9]*[a-z0-9])?. The first character must be a lowercase letter, and all following characters (except for the last character) must be a dash, lowercase letter, or digit. The last character must be a lowercase letter or digit.final - networkFirewallPolicyEnforcementOrder → String?
-
The network firewall policy enforcement order. Can be either
AFTER_CLASSIC_FIREWALL or BEFORE_CLASSIC_FIREWALL. Defaults to
AFTER_CLASSIC_FIREWALL if the field is not specified.
Check the NetworkFirewallPolicyEnforcementOrder enum for the list of possible values.
final
- networkProfile → String?
-
A full or partial URL of the network profile to apply to this network.
This field can be set only at resource creation time. For example, the
following are valid URLs:
final
- params → NetworkParams?
-
Input only.
Input OnlyAdditional params passed with the request, but not persisted as part of resource payload.final -
peerings
→ List<
NetworkPeering> -
Output only.
Output OnlyA list of network peerings for the resource.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - routingConfig → NetworkRoutingConfig?
-
The network-level routing configuration for this network. Used by Cloud
Router to determine what type of network-wide routing behavior to enforce.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfLink → String?
-
Output OnlyServer-defined URL for the resource.final - selfLinkWithId → String?
-
Output only.
Output OnlyServer-defined URL for this resource with the resource id.final -
subnetworks
→ List<
String> -
Output OnlyServer-defined fully-qualified URLs for all subnetworks in this VPC network.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String