firewallPolicy property
Output only. Output Only URL of the firewall policy the network is associated with.
Implementation
final String? firewallPolicy;
Output only. Output Only URL of the firewall policy the network is associated with.
final String? firewallPolicy;