gatewayIPv4 property
Output Only The gateway address for default routing out of the network,
selected by Google Cloud.
Implementation
final String? gatewayIPv4;
Output Only The gateway address for default routing out of the network,
selected by Google Cloud.
final String? gatewayIPv4;