iPv4Range property

String? iPv4Range
final

Deprecated in favor of subnet mode networks. The range of internal addresses that are legal on this network. This range is aCIDR specification, for example:192.168.0.0/16. Provided by the client when the network is created.

Implementation

final String? iPv4Range;