networkProfile property

String? networkProfile
final

A full or partial URL of the network profile to apply to this network. This field can be set only at resource creation time. For example, the following are valid URLs:

Implementation

final String? networkProfile;