peerings property
Output only. Output Only A list of network peerings for the resource.
Implementation
final List<NetworkPeering> peerings;
Output only. Output Only A list of network peerings for the resource.
final List<NetworkPeering> peerings;