routingConfig property
The network-level routing configuration for this network. Used by Cloud Router to determine what type of network-wide routing behavior to enforce.
Implementation
final NetworkRoutingConfig? routingConfig;
The network-level routing configuration for this network. Used by Cloud Router to determine what type of network-wide routing behavior to enforce.
final NetworkRoutingConfig? routingConfig;