toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (iPv4Range != null) 'IPv4Range=$iPv4Range',
    if (autoCreateSubnetworks != null)
      'autoCreateSubnetworks=$autoCreateSubnetworks',
    if (creationTimestamp != null) 'creationTimestamp=$creationTimestamp',
    if (description != null) 'description=$description',
    if (enableUlaInternalIpv6 != null)
      'enableUlaInternalIpv6=$enableUlaInternalIpv6',
    if (firewallPolicy != null) 'firewallPolicy=$firewallPolicy',
    if (gatewayIPv4 != null) 'gatewayIPv4=$gatewayIPv4',
    if (id != null) 'id=$id',
    if (internalIpv6Range != null) 'internalIpv6Range=$internalIpv6Range',
    if (kind != null) 'kind=$kind',
    if (mtu != null) 'mtu=$mtu',
    if (name != null) 'name=$name',
    if (networkFirewallPolicyEnforcementOrder != null)
      'networkFirewallPolicyEnforcementOrder=$networkFirewallPolicyEnforcementOrder',
    if (networkProfile != null) 'networkProfile=$networkProfile',
    if (selfLink != null) 'selfLink=$selfLink',
    if (selfLinkWithId != null) 'selfLinkWithId=$selfLinkWithId',
  ].join(',');
  return 'Network(${$contents})';
}