connectionEndpoints property
Output only. Output Only An array of connections for all the producers connected
to this network attachment.
Implementation
final List<NetworkAttachmentConnectedEndpoint> connectionEndpoints;
Output only. Output Only An array of connections for all the producers connected
to this network attachment.
final List<NetworkAttachmentConnectedEndpoint> connectionEndpoints;