subnetworkCidrRange property
Output only. Output Only The CIDR range of the subnet from which the IPv4 internal
IP was allocated from.
Implementation
final String? subnetworkCidrRange;
Output only. Output Only The CIDR range of the subnet from which the IPv4 internal
IP was allocated from.
final String? subnetworkCidrRange;