NetworkAttachmentConnectedEndpoint_Status class final

The status of a connected endpoint to this network attachment.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const NetworkAttachmentConnectedEndpoint_Status
The default value for NetworkAttachmentConnectedEndpoint_Status.
accepted → const NetworkAttachmentConnectedEndpoint_Status
The consumer allows traffic from the producer to reach its VPC.
closed → const NetworkAttachmentConnectedEndpoint_Status
The consumer network attachment no longer exists.
needsAttention → const NetworkAttachmentConnectedEndpoint_Status
The consumer needs to take further action before traffic can be served.
pending → const NetworkAttachmentConnectedEndpoint_Status
The consumer neither allows nor prohibits traffic from the producer to reach its VPC.
rejected → const NetworkAttachmentConnectedEndpoint_Status
The consumer prohibits traffic from the producer to reach its VPC.
statusUnspecified → const NetworkAttachmentConnectedEndpoint_Status
undefinedStatus → const NetworkAttachmentConnectedEndpoint_Status
A value indicating that the enum field is not set.