warning property
Informational warning which replaces the list of network attachments when the list is empty.
Implementation
final Warning? warning;
Informational warning which replaces the list of network attachments when the list is empty.
final Warning? warning;