securityPolicy property
The resource URL for the network edge security service associated with this network edge security service.
Implementation
final String? securityPolicy;
The resource URL for the network edge security service associated with this network edge security service.
final String? securityPolicy;