NetworkEndpoint class final

The network endpoint.

Constructors

NetworkEndpoint({Map<String, String> annotations = const {}, int? clientDestinationPort, String? fqdn, String? instance, String? ipAddress, String? ipv6Address, int? port})
NetworkEndpoint.fromJson(Object? j)
factory

Properties

annotations Map<String, String>
Optional metadata defined as annotations on the network endpoint.
final
clientDestinationPort int?
Represents the port number to which PSC consumer sends packets.
final
fqdn String?
Optional fully qualified domain name of network endpoint. This can only be specified when NetworkEndpointGroup.network_endpoint_type isNON_GCP_FQDN_PORT.
final
hashCode int
The hash code for this object.
no setterinherited
instance String?
The name or a URL of VM instance of this network endpoint. Optional, the field presence depends on the network endpoint type. The field is required for network endpoints of type GCE_VM_IP andGCE_VM_IP_PORT.
final
ipAddress String?
Optional IPv4 address of network endpoint. The IP address must belong to a VM in Compute Engine (either the primary IP or as part of an aliased IP range). If the IP address is not specified, then the primary IP address for the VM instance in the network that the network endpoint group belongs to will be used.
final
ipv6Address String?
Optional IPv6 address of network endpoint.
final
port int?
Optional port number of network endpoint. If not specified, the defaultPort for the network endpoint group will be used.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String