port property

int? port
final

Optional port number of network endpoint. If not specified, the defaultPort for the network endpoint group will be used.

This field can not be set for network endpoints of typeGCE_VM_IP.

Implementation

final int? port;