NetworkEndpointGroup class final

Represents a collection of network endpoints.

A network endpoint group (NEG) defines how a set of endpoints should be reached, whether they are reachable, and where they are located. For more information about using NEGs for different use cases, seeNetwork endpoint groups overview.

Note: Use the following APIs to manage network endpoint groups:

To manage NEGs with zonal scope (such as zonal NEGs, hybrid connectivity NEGs): zonal API

To manage NEGs with regional scope (such as regional internet NEGs, serverless NEGs, Private Service Connect NEGs): regional API

To manage NEGs with global scope (such as global internet NEGs):global API

Constructors

NetworkEndpointGroup({Map<String, String> annotations = const {}, NetworkEndpointGroupAppEngine? appEngine, NetworkEndpointGroupCloudFunction? cloudFunction, NetworkEndpointGroupCloudRun? cloudRun, String? creationTimestamp, int? defaultPort, String? description, BigInt? id, String? kind, String? name, String? network, String? networkEndpointType, NetworkEndpointGroupPscData? pscData, String? pscTargetService, String? region, String? selfLink, int? size, String? subnetwork, String? zone})
NetworkEndpointGroup.fromJson(Object? j)
factory

Properties

annotations Map<String, String>
Optional. Metadata defined as annotations on the network endpoint group.
final
appEngine NetworkEndpointGroupAppEngine?
Optional. Only valid when networkEndpointType isSERVERLESS. Only one of cloudRun,appEngine or cloudFunction may be set.
final
cloudFunction NetworkEndpointGroupCloudFunction?
Optional. Only valid when networkEndpointType isSERVERLESS. Only one of cloudRun,appEngine or cloudFunction may be set.
final
cloudRun NetworkEndpointGroupCloudRun?
Optional. Only valid when networkEndpointType isSERVERLESS. Only one of cloudRun,appEngine or cloudFunction may be set.
final
creationTimestamp String?
Output only. Output Only Creation timestamp inRFC3339 text format.
final
defaultPort int?
The default port used if the port number is not specified in the network endpoint.
final
description String?
An optional description of this resource. Provide this property when you create the resource.
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output only. Output Only The unique identifier for the resource. This identifier is defined by the server.
final
kind String?
Output only. Output Only Type of the resource. Alwayscompute#networkEndpointGroup for network endpoint group.
final
name String?
Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
network String?
The URL of the network to which all network endpoints in the NEG belong. For networkEndpointType GCE_VM_IP_PORT,GCE_VM_IP_PORTMAP or NON_GCP_PRIVATE_IP_PORT, if this field is not specified, a default network will be used. This field cannot be set for NEGs with networkEndpointType set toSERVERLESS or PRIVATE_SERVICE_CONNECT and for global NEGs. For all other network endpoint types, this field is required.
final
networkEndpointType String?
Type of network endpoints in this network endpoint group. Can be one ofGCE_VM_IP, GCE_VM_IP_PORT,NON_GCP_PRIVATE_IP_PORT, INTERNET_FQDN_PORT,INTERNET_IP_PORT, SERVERLESS,PRIVATE_SERVICE_CONNECT, GCE_VM_IP_PORTMAP. Check the NetworkEndpointType enum for the list of possible values.
final
pscData NetworkEndpointGroupPscData?
Optional. Only valid when networkEndpointType isPRIVATE_SERVICE_CONNECT.
final
pscTargetService String?
The target service url used to set up private service connection to a Google API or a PSC Producer Service Attachment. An example value is: asia-northeast3-cloudkms.googleapis.com.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
region String?
Output only. Output Only The URL of theregion where the network endpoint group is located.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output only. Output Only Server-defined URL for the resource.
final
size int?
Output only. Output only Number of network endpoints in the network endpoint group.
final
subnetwork String?
Optional URL of the subnetwork to which all network endpoints in the NEG belong.
final
zone String?
Output only. Output Only The URL of thezone where the network endpoint group is located.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String