subnetwork property
Optional URL of the subnetwork to which all network endpoints in the NEG belong.
Implementation
final String? subnetwork;
Optional URL of the subnetwork to which all network endpoints in the NEG belong.
final String? subnetwork;