toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (creationTimestamp != null) 'creationTimestamp=$creationTimestamp',
    if (defaultPort != null) 'defaultPort=$defaultPort',
    if (description != null) 'description=$description',
    if (id != null) 'id=$id',
    if (kind != null) 'kind=$kind',
    if (name != null) 'name=$name',
    if (network != null) 'network=$network',
    if (networkEndpointType != null)
      'networkEndpointType=$networkEndpointType',
    if (pscTargetService != null) 'pscTargetService=$pscTargetService',
    if (region != null) 'region=$region',
    if (selfLink != null) 'selfLink=$selfLink',
    if (size != null) 'size=$size',
    if (subnetwork != null) 'subnetwork=$subnetwork',
    if (zone != null) 'zone=$zone',
  ].join(',');
  return 'NetworkEndpointGroup(${$contents})';
}