NetworkEndpointGroupCloudRun class final
Configuration for a Cloud Run network endpoint group (NEG). The service must be provided explicitly or in the URL mask. The tag is optional, may be provided explicitly or in the URL mask.
Note: Cloud Run service must be in the same project and located in the same region as the Serverless NEG.
Constructors
- NetworkEndpointGroupCloudRun({String? service, String? tag, String? urlMask})
- NetworkEndpointGroupCloudRun.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- service → String?
-
Cloud Run service is the main resource of Cloud Run.
final
- tag → String?
-
Optional Cloud Run tag represents the "named-revision" to provide additional
fine-grained traffic routing information.
final
- urlMask → String?
-
An URL
mask is one of the main components of the Cloud Function.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String