consumerPscAddress property

String? consumerPscAddress
final

Output only. Output Only Address allocated from given subnetwork for PSC. This IP address acts as a VIP for a PSC NEG, allowing it to act as an endpoint in L7 PSC-XLB.

Implementation

final String? consumerPscAddress;