needsAttention constant

The connection has been accepted by the producer, but the producer needs to take further action before the forwarding rule can serve traffic.

Implementation

static const needsAttention = NetworkEndpointGroupPscData_PscConnectionStatus(
  'NEEDS_ATTENTION',
);