delete method
Deletes the specified network endpoint group. The network endpoints in the NEG and the VM instances they belong to are not terminated when the NEG is deleted. Note that the NEG cannot be deleted if there are backend services referencing it.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
Future<Operation> delete(DeleteNetworkEndpointGroupRequest request) async {
final url = _endPoint.replace(
path:
'/compute/v1/projects/${request.project}/zones/${request.zone}/networkEndpointGroups/${request.networkEndpointGroup}',
queryParameters: {'requestId': ?request.requestId},
);
final response = await _client.delete(url);
return Operation.fromJson(response);
}