listNetworkEndpoints method

Lists the network endpoints in the specified network endpoint group.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<NetworkEndpointGroupsListNetworkEndpoints> listNetworkEndpoints(
  ListNetworkEndpointsNetworkEndpointGroupsRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/zones/${request.zone}/networkEndpointGroups/${request.networkEndpointGroup}/listNetworkEndpoints',
    queryParameters: {
      'filter': ?request.filter,
      if (request.maxResults case final $1?) 'maxResults': '${$1}',
      'orderBy': ?request.orderBy,
      'pageToken': ?request.pageToken,
      if (request.returnPartialSuccess case final $1?)
        'returnPartialSuccess': '${$1}',
    },
  );
  final response = await _client.post(
    url,
    body: request.networkEndpointGroupsListEndpointsRequestResource,
  );
  return NetworkEndpointGroupsListNetworkEndpoints.fromJson(response);
}