kind property
Output only. Output Only The resource type, which is alwayscompute#networkEndpointGroupsListNetworkEndpoints for the list
of network endpoints in the specified network endpoint group.
Implementation
final String? kind;
Output only. Output Only The resource type, which is alwayscompute#networkEndpointGroupsListNetworkEndpoints for the list
of network endpoints in the specified network endpoint group.
final String? kind;