NetworkEndpointGroupsScopedList class
final
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
networkEndpointGroups
→ List<NetworkEndpointGroup>
-
Output only.
Output Only The list ofnetwork
endpoint groups that are contained in this scope.
final
-
qualifiedName
→ String
-
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or google.rpc.ErrorInfo.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
warning
→ Warning?
-
Output only.
Output Only An informational warning that replaces the list of network
endpoint groups when the list is empty.
final