healths property
Output only. Output only The health status of network endpoint.
Optional. Displayed only if the network endpoint has centralized health checking configured.
Implementation
final List<HealthStatusForNetworkEndpoint> healths;
Output only. Output only The health status of network endpoint.
Optional. Displayed only if the network endpoint has centralized health checking configured.
final List<HealthStatusForNetworkEndpoint> healths;