NetworkFirewallPolicies class final

The NetworkFirewallPolicies API.

Implementers

Constructors

NetworkFirewallPolicies({required Client client, Uri? endPoint, String? gcclVersion})
Creates a NetworkFirewallPolicies using client for transport.
NetworkFirewallPolicies.fromApiKey([String? apiKey])
Creates a NetworkFirewallPolicies that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addAssociation(AddAssociationNetworkFirewallPolicyRequest request) Future<Operation>
Inserts an association for the specified firewall policy.
addPacketMirroringRule(AddPacketMirroringRuleNetworkFirewallPolicyRequest request) Future<Operation>
Inserts a packet mirroring rule into a firewall policy.
addRule(AddRuleNetworkFirewallPolicyRequest request) Future<Operation>
Inserts a rule into a firewall policy.
aggregatedList(AggregatedListNetworkFirewallPoliciesRequest request) Future<NetworkFirewallPolicyAggregatedList>
Retrieves an aggregated list of network firewall policies, listing network firewall policies from all applicable scopes (global and regional) and grouping the results per scope.
cloneRules(CloneRulesNetworkFirewallPolicyRequest request) Future<Operation>
Copies rules to the specified firewall policy.
close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteNetworkFirewallPolicyRequest request) Future<Operation>
Deletes the specified policy.
get(GetNetworkFirewallPolicyRequest request) Future<FirewallPolicy>
Returns the specified network firewall policy.
getAssociation(GetAssociationNetworkFirewallPolicyRequest request) Future<FirewallPolicyAssociation>
Gets an association with the specified name.
getIamPolicy(GetIamPolicyNetworkFirewallPolicyRequest request) Future<Policy>
Gets the access control policy for a resource. May be empty if no such policy or resource exists.
getPacketMirroringRule(GetPacketMirroringRuleNetworkFirewallPolicyRequest request) Future<FirewallPolicyRule>
Gets a packet mirroring rule of the specified priority.
getRule(GetRuleNetworkFirewallPolicyRequest request) Future<FirewallPolicyRule>
Gets a rule of the specified priority.
insert(InsertNetworkFirewallPolicyRequest request) Future<Operation>
Creates a new policy in the specified project using the data included in the request.
list(ListNetworkFirewallPoliciesRequest request) Future<FirewallPolicyList>
Lists all the policies that have been configured for the specified project.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(PatchNetworkFirewallPolicyRequest request) Future<Operation>
Patches the specified policy with the data included in the request.
patchPacketMirroringRule(PatchPacketMirroringRuleNetworkFirewallPolicyRequest request) Future<Operation>
Patches a packet mirroring rule of the specified priority.
patchRule(PatchRuleNetworkFirewallPolicyRequest request) Future<Operation>
Patches a rule of the specified priority.
removeAssociation(RemoveAssociationNetworkFirewallPolicyRequest request) Future<Operation>
Removes an association for the specified firewall policy.
removePacketMirroringRule(RemovePacketMirroringRuleNetworkFirewallPolicyRequest request) Future<Operation>
Deletes a packet mirroring rule of the specified priority.
removeRule(RemoveRuleNetworkFirewallPolicyRequest request) Future<Operation>
Deletes a rule of the specified priority.
setIamPolicy(SetIamPolicyNetworkFirewallPolicyRequest request) Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy.
testIamPermissions(TestIamPermissionsNetworkFirewallPolicyRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited