aliasIpRanges property
An array of alias IP ranges for this network interface. You can only specify this field for network interfaces in VPC networks.
Implementation
final List<AliasIpRange> aliasIpRanges;
An array of alias IP ranges for this network interface. You can only specify this field for network interfaces in VPC networks.
final List<AliasIpRange> aliasIpRanges;