aliasIpv6Ranges property
An array of alias IPv6 ranges for this network interface. You can only specify this field for network interfaces in VPC networks.
Implementation
final List<AliasIpRange> aliasIpv6Ranges;
An array of alias IPv6 ranges for this network interface. You can only specify this field for network interfaces in VPC networks.
final List<AliasIpRange> aliasIpv6Ranges;