serviceClassId property

String? serviceClassId
final

Optional. Producer Service's Service class Id for the region of this network interface. Can only be used with network_attachment. It is not possible to use on its own however, network_attachment can be used without service_class_id.

Implementation

final String? serviceClassId;