toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (enableVpcScopedDns != null) 'enableVpcScopedDns=$enableVpcScopedDns',
    if (fingerprint != null) 'fingerprint=$fingerprint',
    if (igmpQuery != null) 'igmpQuery=$igmpQuery',
    if (internalIpv6PrefixLength != null)
      'internalIpv6PrefixLength=$internalIpv6PrefixLength',
    if (ipv6AccessType != null) 'ipv6AccessType=$ipv6AccessType',
    if (ipv6Address != null) 'ipv6Address=$ipv6Address',
    if (kind != null) 'kind=$kind',
    if (name != null) 'name=$name',
    if (network != null) 'network=$network',
    if (networkAttachment != null) 'networkAttachment=$networkAttachment',
    if (networkIP != null) 'networkIP=$networkIP',
    if (nicType != null) 'nicType=$nicType',
    if (parentNicName != null) 'parentNicName=$parentNicName',
    if (queueCount != null) 'queueCount=$queueCount',
    if (serviceClassId != null) 'serviceClassId=$serviceClassId',
    if (stackType != null) 'stackType=$stackType',
    if (subnetwork != null) 'subnetwork=$subnetwork',
    if (vlan != null) 'vlan=$vlan',
  ].join(',');
  return 'NetworkInterface(${$contents})';
}