vlan property
VLAN tag of a dynamic network interface, must be an integer in the range from 2 to 255 inclusively.
Implementation
final int? vlan;
VLAN tag of a dynamic network interface, must be an integer in the range from 2 to 255 inclusively.
final int? vlan;