NetworkInterface_IgmpQuery class final

Indicate whether igmp query is enabled on the network interface or not. If enabled, also indicates the version of IGMP supported.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const NetworkInterface_IgmpQuery
The default value for NetworkInterface_IgmpQuery.
igmpQueryDisabled → const NetworkInterface_IgmpQuery
The network interface has disabled IGMP query.
igmpQueryV2 → const NetworkInterface_IgmpQuery
The network interface has enabled IGMP query - v2.
undefinedIgmpQuery → const NetworkInterface_IgmpQuery
A value indicating that the enum field is not set.