connectionStatus property
Output only. Output Only The effective state of the peering connection
as a whole.
Implementation
final NetworkPeeringConnectionStatus? connectionStatus;
Output only. Output Only The effective state of the peering connection
as a whole.
final NetworkPeeringConnectionStatus? connectionStatus;