exportCustomRoutes property
Whether to export the custom routes to peer network. The default value is false.
Implementation
final bool? exportCustomRoutes;
Whether to export the custom routes to peer network. The default value is false.
final bool? exportCustomRoutes;