importCustomRoutes property
Whether to import the custom routes from peer network. The default value is false.
Implementation
final bool? importCustomRoutes;
Whether to import the custom routes from peer network. The default value is false.
final bool? importCustomRoutes;