state property
Output only. Output Only State for the peering.
Check the State enum for the list of possible values.
Implementation
final String? state;
Output only. Output Only State for the peering.
Check the State enum for the list of possible values.
final String? state;