toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (autoCreateRoutes != null) 'autoCreateRoutes=$autoCreateRoutes',
    if (exchangeSubnetRoutes != null)
      'exchangeSubnetRoutes=$exchangeSubnetRoutes',
    if (exportCustomRoutes != null) 'exportCustomRoutes=$exportCustomRoutes',
    if (exportSubnetRoutesWithPublicIp != null)
      'exportSubnetRoutesWithPublicIp=$exportSubnetRoutesWithPublicIp',
    if (importCustomRoutes != null) 'importCustomRoutes=$importCustomRoutes',
    if (importSubnetRoutesWithPublicIp != null)
      'importSubnetRoutesWithPublicIp=$importSubnetRoutesWithPublicIp',
    if (name != null) 'name=$name',
    if (network != null) 'network=$network',
    if (peerMtu != null) 'peerMtu=$peerMtu',
    if (stackType != null) 'stackType=$stackType',
    if (state != null) 'state=$state',
    if (stateDetails != null) 'stateDetails=$stateDetails',
    if (updateStrategy != null) 'updateStrategy=$updateStrategy',
  ].join(',');
  return 'NetworkPeering(${$contents})';
}