consensusState property
The consensus state contains information about the status of update and delete for a consensus peering connection.
Implementation
final NetworkPeeringConnectionStatusConsensusState? consensusState;
The consensus state contains information about the status of update and delete for a consensus peering connection.
final NetworkPeeringConnectionStatusConsensusState? consensusState;