trafficConfiguration property
The active connectivity settings for the peering connection based on the settings of the network peerings.
Implementation
final NetworkPeeringConnectionStatusTrafficConfiguration?
trafficConfiguration;
The active connectivity settings for the peering connection based on the settings of the network peerings.
final NetworkPeeringConnectionStatusTrafficConfiguration?
trafficConfiguration;