NetworkPeeringConnectionStatusConsensusState class final
The status of update/delete for a consensus peering connection. Only set when connection_status.update_strategy isCONSENSUS or a network peering is proposing to update the strategy to CONSENSUS.
Constructors
- NetworkPeeringConnectionStatusConsensusState({String? deleteStatus, String? updateStatus})
- NetworkPeeringConnectionStatusConsensusState.fromJson(Object? j)
-
factory
Properties
- deleteStatus → String?
-
The status of the delete request.
Check the DeleteStatus enum for the list of possible values.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updateStatus → String?
-
The status of the update request.
Check the UpdateStatus enum for the list of possible values.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String