NetworkPeeringConnectionStatusConsensusState_UpdateStatus class final

The status of the update request.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const NetworkPeeringConnectionStatusConsensusState_UpdateStatus
The default value for NetworkPeeringConnectionStatusConsensusState_UpdateStatus.
inSync → const NetworkPeeringConnectionStatusConsensusState_UpdateStatus
No pending configuration update proposals to the peering connection.
pendingLocalAcknowledment → const NetworkPeeringConnectionStatusConsensusState_UpdateStatus
The peer network admin has made an updatePeering call. The change is awaiting acknowledgment from this peering's network admin.
pendingPeerAcknowledgement → const NetworkPeeringConnectionStatusConsensusState_UpdateStatus
The local network admin has made an updatePeering call. The change is awaiting acknowledgment from the peer network admin.
undefinedUpdateStatus → const NetworkPeeringConnectionStatusConsensusState_UpdateStatus
A value indicating that the enum field is not set.
updateStatusUnspecified → const NetworkPeeringConnectionStatusConsensusState_UpdateStatus