exportCustomRoutesToPeer property
Whether custom routes are being exported to the peer network.
Implementation
final bool? exportCustomRoutesToPeer;
Whether custom routes are being exported to the peer network.
final bool? exportCustomRoutesToPeer;