consensus constant
NetworkPeeringConnectionStatus_UpdateStrategy
const consensus
Updates are reflected in the local peering but aren't applied to the peering connection until a complementary change is made to the matching peering. To delete a peering with the consensus update strategy, both the peerings must request the deletion of the peering before the peering can be deleted.
Implementation
static const consensus = NetworkPeeringConnectionStatus_UpdateStrategy(
'CONSENSUS',
);