NetworkPeering_State class final

Output only. Output Only State for the peering.

Constructors

NetworkPeering_State(String value)
const
NetworkPeering_State.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const NetworkPeering_State
The default value for NetworkPeering_State.
active → const NetworkPeering_State
Matching configuration exists on the peer.
inactive → const NetworkPeering_State
There is no matching configuration on the peer, including the case when peer does not exist.
undefinedState → const NetworkPeering_State
A value indicating that the enum field is not set.