independent constant

NetworkPeering_UpdateStrategy const independent

In this mode, changes to the peering configuration can be unilaterally altered by changing either side of the peering. This is the default value if the field is unspecified.

Implementation

static const independent = NetworkPeering_UpdateStrategy('INDEPENDENT');