NetworkProfile class final

NetworkProfile represents a Google managed network profile resource.

Constructors

NetworkProfile({String? creationTimestamp, String? description, NetworkProfileNetworkFeatures? features, BigInt? id, String? kind, NetworkProfileLocation? location, String? name, NetworkProfileProfileType? profileType, String? selfLink, String? selfLinkWithId, String? zone})
NetworkProfile.fromJson(Object? j)
factory

Properties

creationTimestamp String?
Output only. Output Only Creation timestamp inRFC3339 text format.
final
description String?
Output only. Output Only An optional description of this resource.
final
features NetworkProfileNetworkFeatures?
Output only. Output Only Features supported by the network.
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output only. Output Only The unique identifier for the resource. This identifier is defined by the server.
final
kind String?
Output only. Output Only Type of the resource. Alwayscompute#networkProfile for network profiles.
final
location NetworkProfileLocation?
Output only. Output Only Location to which the network is restricted.
final
name String?
Output only. Output Only Name of the resource.
final
profileType NetworkProfileProfileType?
Output only. Output Only Type of the network profile.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output only. Output Only Server-defined URL for the resource.
final
selfLinkWithId String?
Output only. Output Only Server-defined URL for this resource with the resource id.
final
zone String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String