location property
Output only. Output Only Location to which the network is restricted.
Implementation
final NetworkProfileLocation? location;
Output only. Output Only Location to which the network is restricted.
final NetworkProfileLocation? location;