NetworkProfileLocation class final

Constructors

NetworkProfileLocation({String? name, String? scope})
NetworkProfileLocation.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
name String?
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope String?
Check the Scope enum for the list of possible values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String