allowClassDFirewalls property
Specifies whether firewalls for Class D address ranges are supported. Check the AllowClassDFirewalls enum for the list of possible values.
Implementation
final String? allowClassDFirewalls;
Specifies whether firewalls for Class D address ranges are supported. Check the AllowClassDFirewalls enum for the list of possible values.
final String? allowClassDFirewalls;