allowFirewallPolicy property
Specifies whether firewall policy can be attached to the network. Check the AllowFirewallPolicy enum for the list of possible values.
Implementation
final String? allowFirewallPolicy;
Specifies whether firewall policy can be attached to the network. Check the AllowFirewallPolicy enum for the list of possible values.
final String? allowFirewallPolicy;