allowSameNetworkUnicast property
Specifies whether unicast within the same network is allowed. Check the AllowSameNetworkUnicast enum for the list of possible values.
Implementation
final String? allowSameNetworkUnicast;
Specifies whether unicast within the same network is allowed. Check the AllowSameNetworkUnicast enum for the list of possible values.
final String? allowSameNetworkUnicast;