allowVpcFirewallRules property
Specifies whether VPC firewall rules can be created under the network. Check the AllowVpcFirewallRules enum for the list of possible values.
Implementation
final String? allowVpcFirewallRules;
Specifies whether VPC firewall rules can be created under the network. Check the AllowVpcFirewallRules enum for the list of possible values.
final String? allowVpcFirewallRules;