multicast property
Specifies which type of multicast is supported. Check the Multicast enum for the list of possible values.
Implementation
final String? multicast;
Specifies which type of multicast is supported. Check the Multicast enum for the list of possible values.
final String? multicast;