unicast property
Specifies which type of unicast is supported. Check the Unicast enum for the list of possible values.
Implementation
final String? unicast;
Specifies which type of unicast is supported. Check the Unicast enum for the list of possible values.
final String? unicast;