NetworkProfileNetworkFeatures_AllowCloudRouter class final
Specifies whether cloud router creation is allowed.
Constructors
- NetworkProfileNetworkFeatures_AllowCloudRouter(String value)
-
const
- NetworkProfileNetworkFeatures_AllowCloudRouter.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const NetworkProfileNetworkFeatures_AllowCloudRouter
- The default value for NetworkProfileNetworkFeatures_AllowCloudRouter.
- cloudRouterAllowed → const NetworkProfileNetworkFeatures_AllowCloudRouter
- cloudRouterBlocked → const NetworkProfileNetworkFeatures_AllowCloudRouter
- undefinedAllowCloudRouter → const NetworkProfileNetworkFeatures_AllowCloudRouter
- A value indicating that the enum field is not set.