NetworkProfileNetworkFeatures_AllowExternalIpAccess class final
Specifies whether VMs are allowed to have external IP access on network interfaces connected to this VPC.
Constructors
- NetworkProfileNetworkFeatures_AllowExternalIpAccess(String value)
-
const
- NetworkProfileNetworkFeatures_AllowExternalIpAccess.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const NetworkProfileNetworkFeatures_AllowExternalIpAccess
- The default value for NetworkProfileNetworkFeatures_AllowExternalIpAccess.
- externalIpAccessAllowed → const NetworkProfileNetworkFeatures_AllowExternalIpAccess
- externalIpAccessBlocked → const NetworkProfileNetworkFeatures_AllowExternalIpAccess
- undefinedAllowExternalIpAccess → const NetworkProfileNetworkFeatures_AllowExternalIpAccess
- A value indicating that the enum field is not set.