NetworkProfileNetworkFeatures_AllowFirewallPolicy class final
Specifies whether firewall policy can be attached to the network.
Constructors
- NetworkProfileNetworkFeatures_AllowFirewallPolicy(String value)
-
const
- NetworkProfileNetworkFeatures_AllowFirewallPolicy.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const NetworkProfileNetworkFeatures_AllowFirewallPolicy
- The default value for NetworkProfileNetworkFeatures_AllowFirewallPolicy.
- firewallPolicyAllowed → const NetworkProfileNetworkFeatures_AllowFirewallPolicy
- firewallPolicyBlocked → const NetworkProfileNetworkFeatures_AllowFirewallPolicy
- undefinedAllowFirewallPolicy → const NetworkProfileNetworkFeatures_AllowFirewallPolicy
- A value indicating that the enum field is not set.