NetworkProfileNetworkFeatures_AllowSameNetworkUnicast class final
Specifies whether unicast within the same network is allowed.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const NetworkProfileNetworkFeatures_AllowSameNetworkUnicast
- The default value for NetworkProfileNetworkFeatures_AllowSameNetworkUnicast.
- sameNetworkUnicastAllowed → const NetworkProfileNetworkFeatures_AllowSameNetworkUnicast
- sameNetworkUnicastBlocked → const NetworkProfileNetworkFeatures_AllowSameNetworkUnicast
- undefinedAllowSameNetworkUnicast → const NetworkProfileNetworkFeatures_AllowSameNetworkUnicast
- A value indicating that the enum field is not set.