peerMigration constant

Subnetwork will be used for Migration from one peered VPC to another. (a transient state of subnetwork while migrating resources from one project to another).

Implementation

static const peerMigration = NetworkProfileNetworkFeatures_SubnetworkPurposes(
  'PEER_MIGRATION',
);