NetworkProfileNetworkFeatures_Unicast class final
Specifies which type of unicast is supported.
Constructors
- NetworkProfileNetworkFeatures_Unicast(String value)
-
const
- NetworkProfileNetworkFeatures_Unicast.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const NetworkProfileNetworkFeatures_Unicast
- The default value for NetworkProfileNetworkFeatures_Unicast.
- undefinedUnicast → const NetworkProfileNetworkFeatures_Unicast
- A value indicating that the enum field is not set.
- unicastSdn → const NetworkProfileNetworkFeatures_Unicast
- unicastUll → const NetworkProfileNetworkFeatures_Unicast