NetworkProfiles class final

The NetworkProfiles API.

Implementers

Constructors

NetworkProfiles({required Client client, Uri? endPoint, String? gcclVersion})
Creates a NetworkProfiles using client for transport.
NetworkProfiles.fromApiKey([String? apiKey])
Creates a NetworkProfiles that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
get(GetNetworkProfileRequest request) Future<NetworkProfile>
Returns the specified network profile.
list(ListNetworkProfilesRequest request) Future<NetworkProfilesListResponse>
Retrieves a list of network profiles available to the specified project.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited