NetworkRoutingConfig class final
A routing configuration attached to a network resource. The message includes the list of routers associated with the network, and a flag indicating the type of routing behavior to enforce network-wide.
Constructors
- NetworkRoutingConfig({bool? bgpAlwaysCompareMed, String? bgpBestPathSelectionMode, String? bgpInterRegionCost, bool? effectiveBgpAlwaysCompareMed, String? effectiveBgpInterRegionCost, String? routingMode})
- NetworkRoutingConfig.fromJson(Object? j)
-
factory
Properties
- bgpAlwaysCompareMed → bool?
-
Enable comparison of Multi-Exit Discriminators (MED) across routes with
different neighbor ASNs when using the STANDARD BGP best path selection
algorithm.
final
- bgpBestPathSelectionMode → String?
-
The BGP best path selection algorithm to be employed within this network
for dynamic routes learned by Cloud Routers. Can be LEGACY
(default) or STANDARD.
Check the BgpBestPathSelectionMode enum for the list of possible values.
final
- bgpInterRegionCost → String?
-
Allows to define a preferred approach for handling inter-region cost in
the selection process when using the STANDARD BGP best path
selection algorithm. Can be DEFAULT orADD_COST_TO_MED.
Check the BgpInterRegionCost enum for the list of possible values.
final
- effectiveBgpAlwaysCompareMed → bool?
-
Output only.
Output OnlyEffective value of the bgp_always_compare_med field.final - effectiveBgpInterRegionCost → String?
-
Output only.
Output OnlyEffective value of the bgp_inter_region_cost field. Check the EffectiveBgpInterRegionCost enum for the list of possible values.final - hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - routingMode → String?
-
The network-wide routing mode to use. If set to REGIONAL,
this network's Cloud Routers will only advertise routes with subnets
of this network in the same region as the router. If set toGLOBAL, this network's Cloud Routers will advertise
routes with all subnets of this network, across regions.
Check the RoutingMode enum for the list of possible values.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String