bgpBestPathSelectionMode property

String? bgpBestPathSelectionMode
final

The BGP best path selection algorithm to be employed within this network for dynamic routes learned by Cloud Routers. Can be LEGACY (default) or STANDARD. Check the BgpBestPathSelectionMode enum for the list of possible values.

Implementation

final String? bgpBestPathSelectionMode;