Networks class final
The Networks API.
- Implementers
Constructors
- Networks({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
Networksusingclientfor transport. - Networks.fromApiKey([String? apiKey])
-
Creates a
Networksthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addPeering(
AddPeeringNetworkRequest request) → Future< Operation> - Adds a peering to the specified network.
-
cancelRequestRemovePeering(
CancelRequestRemovePeeringNetworkRequest request) → Future< Operation> - Cancel requests to remove a peering from the specified network. Applicable only for PeeringConnection with update_strategy=CONSENSUS. Cancels a request to remove a peering from the specified network.
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteNetworkRequest request) → Future< Operation> - Deletes the specified network.
-
get(
GetNetworkRequest request) → Future< Network> - Returns the specified network.
-
getEffectiveFirewalls(
GetEffectiveFirewallsNetworkRequest request) → Future< NetworksGetEffectiveFirewallsResponse> - Returns the effective firewalls on a given network.
-
insert(
InsertNetworkRequest request) → Future< Operation> - Creates a network in the specified project using the data included in the request.
-
list(
ListNetworksRequest request) → Future< NetworkList> - Retrieves the list of networks available to the specified project.
-
listPeeringRoutes(
ListPeeringRoutesNetworksRequest request) → Future< ExchangedPeeringRoutesList> - Lists the peering routes exchanged over peering connection.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchNetworkRequest request) → Future< Operation> - Patches the specified network with the data included in the request. Only routingConfig can be modified.
-
removePeering(
RemovePeeringNetworkRequest request) → Future< Operation> - Removes a peering from the specified network.
-
requestRemovePeering(
RequestRemovePeeringNetworkRequest request) → Future< Operation> - Requests to remove a peering from the specified network. Applicable only for PeeringConnection with update_strategy=CONSENSUS.
-
switchToCustomMode(
SwitchToCustomModeNetworkRequest request) → Future< Operation> - Switches the network mode from auto subnet mode to custom subnet mode.
-
toString(
) → String -
A string representation of this object.
inherited
-
updatePeering(
UpdatePeeringNetworkRequest request) → Future< Operation> - Updates the specified network peering with the data included in the request. You can only modify the NetworkPeering.export_custom_routes field and the NetworkPeering.import_custom_routes field.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited