cancelRequestRemovePeering method

Future<Operation> cancelRequestRemovePeering(
  1. CancelRequestRemovePeeringNetworkRequest request
)

Cancel requests to remove a peering from the specified network. Applicable only for PeeringConnection with update_strategy=CONSENSUS. Cancels a request to remove a peering from the specified network.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> cancelRequestRemovePeering(
  CancelRequestRemovePeeringNetworkRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/global/networks/${request.network}/cancelRequestRemovePeering',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.post(
    url,
    body: request.networksCancelRequestRemovePeeringRequestResource,
  );
  return Operation.fromJson(response);
}