insert method

Creates a network in the specified project using the data included in the request.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> insert(InsertNetworkRequest request) async {
  final url = _endPoint.replace(
    path: '/compute/v1/projects/${request.project}/global/networks',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.post(url, body: request.networkResource);
  return Operation.fromJson(response);
}