patch method

Patches the specified network with the data included in the request. Only routingConfig can be modified.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> patch(PatchNetworkRequest request) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/global/networks/${request.network}',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.patch(url, body: request.networkResource);
  return Operation.fromJson(response);
}