requestRemovePeering method

Future<Operation> requestRemovePeering(
  1. RequestRemovePeeringNetworkRequest request
)

Requests to remove a peering from the specified network. Applicable only for PeeringConnection with update_strategy=CONSENSUS.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> requestRemovePeering(
  RequestRemovePeeringNetworkRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/global/networks/${request.network}/requestRemovePeering',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.post(
    url,
    body: request.networksRequestRemovePeeringRequestResource,
  );
  return Operation.fromJson(response);
}