switchToCustomMode method

Future<Operation> switchToCustomMode(
  1. SwitchToCustomModeNetworkRequest request
)

Switches the network mode from auto subnet mode to custom subnet mode.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> switchToCustomMode(
  SwitchToCustomModeNetworkRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/global/networks/${request.network}/switchToCustomMode',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.post(url);
  return Operation.fromJson(response);
}