updatePeering method

Future<Operation> updatePeering(
  1. UpdatePeeringNetworkRequest request
)

Updates the specified network peering with the data included in the request. You can only modify the NetworkPeering.export_custom_routes field and the NetworkPeering.import_custom_routes field.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> updatePeering(UpdatePeeringNetworkRequest request) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/global/networks/${request.network}/updatePeering',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.patch(
    url,
    body: request.networksUpdatePeeringRequestResource,
  );
  return Operation.fromJson(response);
}