NetworksGetEffectiveFirewallsResponse class final
Constructors
-
NetworksGetEffectiveFirewallsResponse({List<
NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy> firewallPolicys = const [], List<Firewall> firewalls = const []}) - NetworksGetEffectiveFirewallsResponse.fromJson(Object? j)
-
factory
Properties
-
firewallPolicys
→ List<
NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy> -
Output OnlyEffective firewalls from firewall policy. It returns Global Network Firewall Policies and Hierarchical Firewall Policies. UseregionNetworkFirewallPolicies.getEffectiveFirewalls to get Regional Network Firewall Policies as well.final -
firewalls
→ List<
Firewall> -
Effective firewalls on the network.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String