packetMirroringRules property
Output only. Output Only The packet mirroring rules that apply to the network.
Implementation
final List<FirewallPolicyRule> packetMirroringRules;
Output only. Output Only The packet mirroring rules that apply to the network.
final List<FirewallPolicyRule> packetMirroringRules;