NodeGroup class final

Represents a sole-tenant Node Group resource.

A sole-tenant node is a physical server that is dedicated to hosting VM instances only for your specific project. Use sole-tenant nodes to keep your instances physically separated from instances in other projects, or to group your instances together on the same host hardware. For more information, readSole-tenant nodes.

Constructors

NodeGroup({NodeGroupAutoscalingPolicy? autoscalingPolicy, String? creationTimestamp, String? description, String? fingerprint, BigInt? id, String? kind, String? locationHint, String? maintenanceInterval, String? maintenancePolicy, NodeGroupMaintenanceWindow? maintenanceWindow, String? name, String? nodeTemplate, String? selfLink, ShareSettings? shareSettings, int? size, String? status, String? zone})
NodeGroup.fromJson(Object? j)
factory

Properties

autoscalingPolicy NodeGroupAutoscalingPolicy?
Specifies how autoscaling should behave.
final
creationTimestamp String?
Output only. Output Only Creation timestamp inRFC3339 text format.
final
description String?
An optional description of this resource. Provide this property when you create the resource.
final
fingerprint String?
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output only. Output Only The unique identifier for the resource. This identifier is defined by the server.
final
kind String?
Output only. Output Only The type of the resource. Alwayscompute#nodeGroup for node group.
final
locationHint String?
An opaque location hint used to place the Node close to other resources. This field is for use by internal tools that use the public API. The location hint here on the NodeGroup overrides any location_hint present in the NodeTemplate.
final
maintenanceInterval String?
Specifies the frequency of planned maintenance events. The accepted values are: AS_NEEDED and RECURRENT. Check the MaintenanceInterval enum for the list of possible values.
final
maintenancePolicy String?
Specifies how to handle instances when a node in the group undergoes maintenance. Set to one of: DEFAULT,RESTART_IN_PLACE, or MIGRATE_WITHIN_NODE_GROUP. The default value is DEFAULT. For more information, see Maintenance policies. Check the MaintenancePolicy enum for the list of possible values.
final
maintenanceWindow NodeGroupMaintenanceWindow?
final
name String?
The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
nodeTemplate String?
URL of the node template to create the node group from.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output only. Output Only Server-defined URL for the resource.
final
shareSettings ShareSettings?
Share-settings for the node group
final
size int?
Output only. Output Only The total number of nodes in the node group.
final
status String?
Check the Status enum for the list of possible values.
final
zone String?
Output only. Output Only The name of the zone where the node group resides, such as us-central1-a.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String