zone property
Output only. Output Only The name of the zone where the node group resides,
such as us-central1-a.
Implementation
final String? zone;
Output only. Output Only The name of the zone where the node group resides,
such as us-central1-a.
final String? zone;