NodeGroupAutoscalingPolicy class
final
Properties
hashCode
→ int
The hash code for this object.
no setter inherited
maxNodes
→ int ?
The maximum number of nodes that the group should have. Must be set if
autoscaling is enabled. Maximum value allowed is 100.
final
minNodes
→ int ?
The minimum number of nodes that the group should have.
final
mode
→ String ?
The autoscaling mode. Set to one of: ON, OFF,
or ONLY_SCALE_OUT. For more information, see
Autoscaler modes.
Check the Mode enum for the list of possible values.
final
qualifiedName
→ String
The fully qualified name of this message, i.e., google.protobuf.Duration
or google.rpc.ErrorInfo.
final inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
google_cloud_compute_v1 0.1.1