maxNodes property
The maximum number of nodes that the group should have. Must be set if autoscaling is enabled. Maximum value allowed is 100.
Implementation
final int? maxNodes;
The maximum number of nodes that the group should have. Must be set if autoscaling is enabled. Maximum value allowed is 100.
final int? maxNodes;