NodeGroupAutoscalingPolicy_Mode class final

The autoscaling mode. Set to one of: ON, OFF, or ONLY_SCALE_OUT. For more information, see Autoscaler modes.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const NodeGroupAutoscalingPolicy_Mode
The default value for NodeGroupAutoscalingPolicy_Mode.
modeUnspecified → const NodeGroupAutoscalingPolicy_Mode
off → const NodeGroupAutoscalingPolicy_Mode
Autoscaling is disabled.
on → const NodeGroupAutoscalingPolicy_Mode
Autocaling is fully enabled.
onlyScaleOut → const NodeGroupAutoscalingPolicy_Mode
Autoscaling will only scale out and will not remove nodes.
undefinedMode → const NodeGroupAutoscalingPolicy_Mode
A value indicating that the enum field is not set.