NodeGroupNode class final

Constructors

NodeGroupNode({List<AcceleratorConfig> accelerators = const [], InstanceConsumptionInfo? consumedResources, String? cpuOvercommitType, List<LocalDisk> disks = const [], List<InstanceConsumptionData> instanceConsumptionData = const [], List<String> instances = const [], String? name, String? nodeType, bool? satisfiesPzs, ServerBinding? serverBinding, String? serverId, String? status, InstanceConsumptionInfo? totalResources, UpcomingMaintenance? upcomingMaintenance})
NodeGroupNode.fromJson(Object? j)
factory

Properties

accelerators List<AcceleratorConfig>
Accelerators for this node.
final
consumedResources InstanceConsumptionInfo?
Output only. Node resources that are reserved by all instances.
final
cpuOvercommitType String?
CPU overcommit. Check the CpuOvercommitType enum for the list of possible values.
final
disks List<LocalDisk>
Local disk configurations.
final
hashCode int
The hash code for this object.
no setterinherited
instanceConsumptionData List<InstanceConsumptionData>
Output only. Instance data that shows consumed resources on the node.
final
instances List<String>
Instances scheduled on this node.
final
name String?
The name of the node.
final
nodeType String?
The type of this node.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzs bool?
Output only. Output Only Reserved for future use.
final
serverBinding ServerBinding?
Binding properties for the physical server.
final
serverId String?
Server ID associated with this node.
final
status String?
Check the Status enum for the list of possible values.
final
totalResources InstanceConsumptionInfo?
Output only. Total amount of available resources on the node.
final
upcomingMaintenance UpcomingMaintenance?
Output only. Output Only The information about an upcoming maintenance event.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String