NodeGroupNode_Status class final

Constructors

NodeGroupNode_Status(String value)
const
NodeGroupNode_Status.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const NodeGroupNode_Status
The default value for NodeGroupNode_Status.
creating → const NodeGroupNode_Status
deleting → const NodeGroupNode_Status
invalid → const NodeGroupNode_Status
ready → const NodeGroupNode_Status
repairing → const NodeGroupNode_Status
undefinedStatus → const NodeGroupNode_Status
A value indicating that the enum field is not set.