NodeGroup_MaintenanceInterval class final
Specifies the frequency of planned maintenance events. The accepted values
are: AS_NEEDED and RECURRENT.
Constructors
- NodeGroup_MaintenanceInterval(String value)
-
const
- NodeGroup_MaintenanceInterval.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const NodeGroup_MaintenanceInterval
- The default value for NodeGroup_MaintenanceInterval.
- asNeeded → const NodeGroup_MaintenanceInterval
- VMs are eligible to receive infrastructure and hypervisor updates as they become available. This may result in more maintenance operations (live migrations or terminations) for the VM than the PERIODIC andRECURRENT options.
- recurrent → const NodeGroup_MaintenanceInterval
- VMs receive infrastructure and hypervisor updates on a periodic basis, minimizing the number of maintenance operations (live migrations or terminations) on an individual VM. This may mean a VM will take longer to receive an update than if it was configured forAS_NEEDED. Security updates will still be applied as soon as they are available. RECURRENT is used for GEN3 and Slice of Hardware VMs.
- undefinedMaintenanceInterval → const NodeGroup_MaintenanceInterval
- A value indicating that the enum field is not set.