NodeGroup_MaintenancePolicy class final

Specifies how to handle instances when a node in the group undergoes maintenance. Set to one of: DEFAULT,RESTART_IN_PLACE, or MIGRATE_WITHIN_NODE_GROUP. The default value is DEFAULT. For more information, see Maintenance policies.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const NodeGroup_MaintenancePolicy
The default value for NodeGroup_MaintenancePolicy.
default$ → const NodeGroup_MaintenancePolicy
Allow the node and corresponding instances to retain default maintenance behavior.
maintenancePolicyUnspecified → const NodeGroup_MaintenancePolicy
migrateWithinNodeGroup → const NodeGroup_MaintenancePolicy
When maintenance must be done on a node, the instances on that node will be moved to other nodes in the group. Instances with onHostMaintenance = MIGRATE will live migrate to their destinations while instances with onHostMaintenance = TERMINATE will terminate and then restart on their destination nodes if automaticRestart = true.
restartInPlace → const NodeGroup_MaintenancePolicy
Instances in this group will restart on the same node when maintenance has completed. Instances must have onHostMaintenance = TERMINATE, and they will only restart if automaticRestart = true.
undefinedMaintenancePolicy → const NodeGroup_MaintenancePolicy
A value indicating that the enum field is not set.