migrateWithinNodeGroup constant

NodeGroup_MaintenancePolicy const migrateWithinNodeGroup

When maintenance must be done on a node, the instances on that node will be moved to other nodes in the group. Instances with onHostMaintenance = MIGRATE will live migrate to their destinations while instances with onHostMaintenance = TERMINATE will terminate and then restart on their destination nodes if automaticRestart = true.

Implementation

static const migrateWithinNodeGroup = NodeGroup_MaintenancePolicy(
  'MIGRATE_WITHIN_NODE_GROUP',
);