NodeGroup_Status class final

Constructors

NodeGroup_Status(String value)
const
NodeGroup_Status.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const NodeGroup_Status
The default value for NodeGroup_Status.
creating → const NodeGroup_Status
deleting → const NodeGroup_Status
invalid → const NodeGroup_Status
ready → const NodeGroup_Status
undefinedStatus → const NodeGroup_Status
A value indicating that the enum field is not set.