addNodes method

Adds specified number of nodes to the node group.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> addNodes(AddNodesNodeGroupRequest request) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/zones/${request.zone}/nodeGroups/${request.nodeGroup}/addNodes',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.post(
    url,
    body: request.nodeGroupsAddNodesRequestResource,
  );
  return Operation.fromJson(response);
}