insert method

Creates a NodeGroup resource in the specified project using the data included in the request.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> insert(InsertNodeGroupRequest request) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/zones/${request.zone}/nodeGroups',
    queryParameters: {
      if (request.initialNodeCount case final $1 when $1.isNotDefault)
        'initialNodeCount': '${$1}',
      'requestId': ?request.requestId,
    },
  );
  final response = await _client.post(url, body: request.nodeGroupResource);
  return Operation.fromJson(response);
}