simulateMaintenanceEvent method

Future<Operation> simulateMaintenanceEvent(
  1. SimulateMaintenanceEventNodeGroupRequest request
)

Simulates maintenance event on specified nodes from the node group.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> simulateMaintenanceEvent(
  SimulateMaintenanceEventNodeGroupRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/zones/${request.zone}/nodeGroups/${request.nodeGroup}/simulateMaintenanceEvent',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.post(
    url,
    body: request.nodeGroupsSimulateMaintenanceEventRequestResource,
  );
  return Operation.fromJson(response);
}