NodeGroupsScopedList class
final
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
nodeGroups
→ List<NodeGroup>
-
Output Only A list of node groups contained in this scope.
final
-
qualifiedName
→ String
-
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or google.rpc.ErrorInfo.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
warning
→ Warning?
-
Output Only An informational warning that appears when the nodeGroup
list is empty.
final