warning property
Output Only An informational warning that appears when the nodeGroup
list is empty.
Implementation
final Warning? warning;
Output Only An informational warning that appears when the nodeGroup
list is empty.
final Warning? warning;