nodeTemplate property
Full or partial URL of the node template resource to be updated for this node group.
Implementation
final String? nodeTemplate;
Full or partial URL of the node template resource to be updated for this node group.
final String? nodeTemplate;