region property
Output only. Output Only The name of the region where the node template resides,
such as us-central1.
Implementation
final String? region;
Output only. Output Only The name of the region where the node template resides,
such as us-central1.
final String? region;