status property
Output only. Output Only The status of the node template. One of the following values:CREATING, READY, and DELETING.
Check the Status enum for the list of possible values.
Implementation
final String? status;
Output only. Output Only The status of the node template. One of the following values:CREATING, READY, and DELETING.
Check the Status enum for the list of possible values.
final String? status;