NodeTemplate_Status class final

Output only. Output Only The status of the node template. One of the following values:CREATING, READY, and DELETING.

Constructors

NodeTemplate_Status(String value)
const
NodeTemplate_Status.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const NodeTemplate_Status
The default value for NodeTemplate_Status.
creating → const NodeTemplate_Status
Resources are being allocated.
deleting → const NodeTemplate_Status
The node template is currently being deleted.
invalid → const NodeTemplate_Status
Invalid status.
ready → const NodeTemplate_Status
The node template is ready.
undefinedStatus → const NodeTemplate_Status
A value indicating that the enum field is not set.