NodeTemplates class final

The NodeTemplates API.

Implementers

Constructors

NodeTemplates({required Client client, Uri? endPoint, String? gcclVersion})
Creates a NodeTemplates using client for transport.
NodeTemplates.fromApiKey([String? apiKey])
Creates a NodeTemplates that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(AggregatedListNodeTemplatesRequest request) Future<NodeTemplateAggregatedList>
Retrieves an aggregated list of node templates.
close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteNodeTemplateRequest request) Future<Operation>
Deletes the specified NodeTemplate resource.
get(GetNodeTemplateRequest request) Future<NodeTemplate>
Returns the specified node template.
getIamPolicy(GetIamPolicyNodeTemplateRequest request) Future<Policy>
Gets the access control policy for a resource. May be empty if no such policy or resource exists.
insert(InsertNodeTemplateRequest request) Future<Operation>
Creates a NodeTemplate resource in the specified project using the data included in the request.
list(ListNodeTemplatesRequest request) Future<NodeTemplateList>
Retrieves a list of node templates available to the specified project.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setIamPolicy(SetIamPolicyNodeTemplateRequest request) Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy.
testIamPermissions(TestIamPermissionsNodeTemplateRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited