NodeType class final

Represent a sole-tenant Node Type resource.

Each node within a node group must have a node type. A node type specifies the total amount of cores and memory for that node. Currently, the only available node type is n1-node-96-624 node type that has 96 vCPUs and 624 GB of memory, available in multiple zones. For more information readNode types.

Constructors

NodeType({String? cpuPlatform, String? creationTimestamp, DeprecationStatus? deprecated, String? description, int? guestCpus, BigInt? id, String? kind, int? localSsdGb, int? maxVms, int? memoryMb, String? name, String? selfLink, String? zone})
NodeType.fromJson(Object? j)
factory

Properties

cpuPlatform String?
Output Only The CPU platform used by this node type.
final
creationTimestamp String?
Output Only Creation timestamp inRFC3339 text format.
final
deprecated DeprecationStatus?
Output Only The deprecation status associated with this node type.
final
description String?
Output Only An optional textual description of the resource.
final
guestCpus int?
Output Only The number of virtual CPUs that are available to the node type.
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output Only The unique identifier for the resource. This identifier is defined by the server.
final
kind String?
Output only. Output Only The type of the resource. Alwayscompute#nodeType for node types.
final
localSsdGb int?
Output Only Local SSD available to the node type, defined in GB.
final
maxVms int?
Output only. Output Only Maximum number of VMs that can be created for this node type.
final
memoryMb int?
Output Only The amount of physical memory available to the node type, defined in MB.
final
name String?
Output Only Name of the resource.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output only. Output Only Server-defined URL for the resource.
final
zone String?
Output only. Output Only The name of the zone where the node type resides, such as us-central1-a.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String