NodeTypes class final
The NodeTypes API.
- Implementers
Constructors
- NodeTypes({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
NodeTypesusingclientfor transport. - NodeTypes.fromApiKey([String? apiKey])
-
Creates a
NodeTypesthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
aggregatedList(
AggregatedListNodeTypesRequest request) → Future< NodeTypeAggregatedList> - Retrieves an aggregated list of node types.
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
get(
GetNodeTypeRequest request) → Future< NodeType> - Returns the specified node type.
-
list(
ListNodeTypesRequest request) → Future< NodeTypeList> - Retrieves a list of node types available to the specified project.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited