region property

String? region
final

Output only. Output Only URL of the region where the notification endpoint resides. This field applies only to the regional resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.

Implementation

final String? region;