NotificationEndpointGrpcSettings class final

Represents a gRPC setting that describes one gRPC notification endpoint and the retry duration attempting to send notification to this endpoint.

Constructors

NotificationEndpointGrpcSettings({String? authority, String? endpoint, String? payloadName, Duration? resendInterval, int? retryDurationSec})
NotificationEndpointGrpcSettings.fromJson(Object? j)
factory

Properties

authority String?
Optional. If specified, this field is used to set the authority header by the sender of notifications. See https://tools.ietf.org/html/rfc7540#section-8.1.2.3
final
endpoint String?
Endpoint to which gRPC notifications are sent. This must be a valid gRPCLB DNS name.
final
hashCode int
The hash code for this object.
no setterinherited
payloadName String?
Optional. If specified, this field is used to populate the "name" field in gRPC requests.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
resendInterval Duration?
Optional. This field is used to configure how often to send a full update of all non-healthy backends. If unspecified, full updates are not sent. If specified, must be in the range between 600 seconds to 3600 seconds. Nanos are disallowed. Can only be set for regional notification endpoints.
final
retryDurationSec int?
How much time (in seconds) is spent attempting notification retries until a successful response is received. Default is 30s. Limit is 20m (1200s). Must be a positive number.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String