payloadName property
Optional. If specified, this field is used to populate the "name" field in gRPC requests.
Implementation
final String? payloadName;
Optional. If specified, this field is used to populate the "name" field in gRPC requests.
final String? payloadName;