description property
Output Only A textual description of the operation, which is
set when the operation is created.
Implementation
final String? description;
Output Only A textual description of the operation, which is
set when the operation is created.
final String? description;