endTime property
Output Only The time that this operation was completed. This value is inRFC3339
text format.
Implementation
final String? endTime;
Output Only The time that this operation was completed. This value is inRFC3339
text format.
final String? endTime;