error property
Output Only If errors are generated during processing of the operation,
this field will be populated.
Implementation
final Error? error;
Output Only If errors are generated during processing of the operation,
this field will be populated.
final Error? error;