httpErrorMessage property

String? httpErrorMessage
final

Output Only If the operation fails, this field contains the HTTP error message that was returned, such as NOT FOUND.

Implementation

final String? httpErrorMessage;