httpErrorStatusCode property
Output Only If the operation fails, this field contains the HTTP error
status code that was returned. For example, a 404 means the
resource was not found.
Implementation
final int? httpErrorStatusCode;
Output Only If the operation fails, this field contains the HTTP error
status code that was returned. For example, a 404 means the
resource was not found.
final int? httpErrorStatusCode;