insertTime property
Output Only The time that this operation was requested.
This value is inRFC3339
text format.
Implementation
final String? insertTime;
Output Only The time that this operation was requested.
This value is inRFC3339
text format.
final String? insertTime;