operationGroupId property

String? operationGroupId
final

Output only. Output Only An ID that represents a group of operations, such as when a group of operations results from a bulkInsert API request.

Implementation

final String? operationGroupId;