status property
Output Only The status of the operation, which can be one of the
following:
PENDING, RUNNING, or DONE.
Implementation
final Operation_Status? status;
Output Only The status of the operation, which can be one of the
following:
PENDING, RUNNING, or DONE.
final Operation_Status? status;