statusMessage property
Output Only An optional textual description of the current status of the
operation.
Implementation
final String? statusMessage;
Output Only An optional textual description of the current status of the
operation.
final String? statusMessage;