targetLink property

String? targetLink
final

Output Only The URL of the resource that the operation modifies. For operations related to creating a snapshot, this points to the disk that the snapshot was created from.

Implementation

final String? targetLink;