warnings property

List<Warnings> warnings
final

Output Only If warning messages are generated during processing of the operation, this field will be populated.

Implementation

final List<Warnings> warnings;