OperationAggregatedList class final

Constructors

OperationAggregatedList({String? id, Map<String, OperationsScopedList> items = const {}, String? kind, String? nextPageToken, String? selfLink, List<String> unreachables = const [], Warning? warning})
OperationAggregatedList.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String?
Output Only The unique identifier for the resource. This identifier is defined by the server.
final
items Map<String, OperationsScopedList>
Output Only A map of scoped operation lists.
final
kind String?
Output only. Output Only Type of resource. Always compute#operationAggregatedList for aggregated lists of operations.
final
nextPageToken String?
Output Only This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output Only Server-defined URL for this resource.
final
unreachables List<String>
Output only. Output Only Unreachable resources.
final
warning Warning?
Output Only Informational warning message.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String