Operation_Status class final
Output Only The status of the operation, which can be one of the
following:
PENDING, RUNNING, or DONE.
Constructors
- Operation_Status(String value)
-
const
- Operation_Status.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const Operation_Status
- The default value for Operation_Status.
- done → const Operation_Status
- The operation has completed processing successfully or with an error.
- pending → const Operation_Status
- The operation is waiting to be processed.
- running → const Operation_Status
- The operation is actively being processed.
- undefinedStatus → const Operation_Status
- A value indicating that the enum field is not set.