done constant
Operation_Status
const done
The operation has completed processing successfully or with an error.
Implementation
static const done = Operation_Status('DONE');
The operation has completed processing successfully or with an error.
static const done = Operation_Status('DONE');