warning property
Output Only Informational warning which replaces the list of operations
when the list is empty.
Implementation
final Warning? warning;
Output Only Informational warning which replaces the list of operations
when the list is empty.
final Warning? warning;