get method

List all of the ordered rules present in a single specified policy.

Use this API to read Cloud Armor policies. Previously, alpha and beta versions of this API were used to read firewall policies. This usage is now disabled for most organizations. Use firewallPolicies.get instead.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<SecurityPolicy> get(
  GetOrganizationSecurityPolicyRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/locations/global/securityPolicies/${request.securityPolicy}',
  );
  final response = await _client.get(url);
  return SecurityPolicy.fromJson(response);
}