list method

List all the policies that have been configured for the specified organization.

Use this API to read Cloud Armor policies. Previously, alpha and beta versions of this API were used to read firewall policies. This usage is now disabled for most organizations. Use firewallPolicies.list instead.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<SecurityPolicyList> list(
  ListOrganizationSecurityPoliciesRequest request,
) async {
  final url = _endPoint.replace(
    path: '/compute/v1/locations/global/securityPolicies',
    queryParameters: {
      'filter': ?request.filter,
      if (request.maxResults case final $1?) 'maxResults': '${$1}',
      'orderBy': ?request.orderBy,
      'pageToken': ?request.pageToken,
      'parentId': ?request.parentId,
      if (request.returnPartialSuccess case final $1?)
        'returnPartialSuccess': '${$1}',
    },
  );
  final response = await _client.get(url);
  return SecurityPolicyList.fromJson(response);
}