patch method

Patches the specified policy with the data included in the request.

Use this API to modify Cloud Armor policies. Previously, alpha and beta versions of this API were used to modify firewall policies. This usage is now disabled for most organizations. Use firewallPolicies.patch instead.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> patch(
  PatchOrganizationSecurityPolicyRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/locations/global/securityPolicies/${request.securityPolicy}',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.patch(
    url,
    body: request.securityPolicyResource,
  );
  return Operation.fromJson(response);
}