enforcingConsecutiveErrors property

int? enforcingConsecutiveErrors
final

The percentage chance that a backend endpoint will be ejected when an outlier status is detected through consecutive 5xx. This setting can be used to disable ejection or to ramp it up slowly. Defaults to 0.

Implementation

final int? enforcingConsecutiveErrors;