enforcingConsecutiveGatewayFailure property

int? enforcingConsecutiveGatewayFailure
final

The percentage chance that a backend endpoint will be ejected when an outlier status is detected through consecutive gateway failures. This setting can be used to disable ejection or to ramp it up slowly. Defaults to 100.

Implementation

final int? enforcingConsecutiveGatewayFailure;