maxEjectionPercent property

int? maxEjectionPercent
final

Maximum percentage of backend endpoints in the load balancing pool for the backend service that can be ejected if the ejection conditions are met. Defaults to 50%.

Implementation

final int? maxEjectionPercent;