PacketIntervals class final

Next free: 7

Constructors

PacketIntervals({int? avgMs, String? duration, int? maxMs, int? minMs, int? numIntervals, String? type})
PacketIntervals.fromJson(Object? j)
factory

Properties

avgMs int?
Average observed inter-packet interval in milliseconds.
final
duration String?
From how long ago in the past these intervals were observed. Check the Duration enum for the list of possible values.
final
hashCode int
The hash code for this object.
no setterinherited
maxMs int?
Maximum observed inter-packet interval in milliseconds.
final
minMs int?
Minimum observed inter-packet interval in milliseconds.
final
numIntervals int?
Number of inter-packet intervals from which these statistics were derived.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
The type of packets for which inter-packet intervals were computed. Check the Type enum for the list of possible values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String