PacketMirroring class final
Represents a Packet Mirroring resource.
Packet Mirroring clones the traffic of specified instances in your Virtual Private Cloud (VPC) network and forwards it to a collector destination, such as an instance group of an internal TCP/UDP load balancer, for analysis or examination. For more information about setting up Packet Mirroring, seeUsing Packet Mirroring.
Constructors
- PacketMirroring({PacketMirroringForwardingRuleInfo? collectorIlb, String? creationTimestamp, String? description, String? enable, PacketMirroringFilter? filter, BigInt? id, String? kind, PacketMirroringMirroredResourceInfo? mirroredResources, String? name, PacketMirroringNetworkInfo? network, int? priority, String? region, String? selfLink})
- PacketMirroring.fromJson(Object? j)
-
factory
Properties
- collectorIlb → PacketMirroringForwardingRuleInfo?
-
The Forwarding Rule resource of typeloadBalancingScheme=INTERNAL that will be used as collector
for mirrored traffic.
The specified forwarding rule must have isMirroringCollector
set to true.
final
- creationTimestamp → String?
-
Output only.
Output OnlyCreation timestamp inRFC3339 text format.final - description → String?
-
An optional description of this resource. Provide this property when you
create the resource.
final
- enable → String?
-
Indicates whether or not this packet mirroring takes effect.
If set to FALSE, this packet mirroring policy will not be enforced on the
network.
final
- filter → PacketMirroringFilter?
-
Filter for mirrored traffic. If unspecified, all IPv4 traffic is mirrored.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → BigInt?
-
Output only.
Output OnlyThe unique identifier for the resource. This identifier is defined by the server.final - kind → String?
-
Output only.
Output OnlyType of the resource. Alwayscompute#packetMirroring for packet mirrorings.final - mirroredResources → PacketMirroringMirroredResourceInfo?
-
PacketMirroring mirroredResourceInfos.
MirroredResourceInfo specifies a set of mirrored VM instances, subnetworks
and/or tags for which traffic from/to all VM instances will be mirrored.
final
- name → String?
-
Name of the resource; provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression
[a-z]([-a-z0-9]*[a-z0-9])?which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.final - network → PacketMirroringNetworkInfo?
-
Specifies the mirrored VPC network. Only packets in this network will be
mirrored. All mirrored VMs should have a NIC in the given network.
All mirrored subnetworks should belong to the given network.
final
- priority → int?
-
The priority of applying this configuration. Priority is used to break ties
in cases where there is more than one matching rule. In the case of two
rules that apply for a given Instance, the one with the lowest-numbered
priority value wins.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - region → String?
-
Output OnlyURI of the region where the packetMirroring resides.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfLink → String?
-
Output only.
Output OnlyServer-defined URL for the resource.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String