PacketMirroringMirroredResourceInfo class final

Properties

hashCode int
The hash code for this object.
no setterinherited
instances List<PacketMirroringMirroredResourceInfoInstanceInfo>
A set of virtual machine instances that are being mirrored. They must live in zones contained in the same region as this packetMirroring.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subnetworks List<PacketMirroringMirroredResourceInfoSubnetInfo>
A set of subnetworks for which traffic from/to all VM instances will be mirrored. They must live in the same region as this packetMirroring.
final
tags List<String>
A set of mirrored tags. Traffic from/to all VM instances that have one or more of these tags will be mirrored.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String