PacketMirroringNetworkInfo class final

Constructors

PacketMirroringNetworkInfo({String? canonicalUrl, String? url})
PacketMirroringNetworkInfo.fromJson(Object? j)
factory

Properties

canonicalUrl String?
Output only. Output Only Unique identifier for the network; defined by the server.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String?
URL of the network resource.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String