PacketMirroring_Enable class final

Indicates whether or not this packet mirroring takes effect. If set to FALSE, this packet mirroring policy will not be enforced on the network.

The default is TRUE.

Constructors

PacketMirroring_Enable(String value)
const
PacketMirroring_Enable.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const PacketMirroring_Enable
The default value for PacketMirroring_Enable.
false$ → const PacketMirroring_Enable
true$ → const PacketMirroring_Enable
undefinedEnable → const PacketMirroring_Enable
A value indicating that the enum field is not set.