PatchBackendBucketRequest class final

A request message for BackendBuckets.Patch. See the method description for details.

Constructors

PatchBackendBucketRequest({required String backendBucket, required BackendBucket? backendBucketResource, required String project, String? requestId})
PatchBackendBucketRequest.fromJson(Object? j)
factory

Properties

backendBucket String
Name of the BackendBucket resource to patch.
final
backendBucketResource BackendBucket?
The body resource for this request
final
hashCode int
The hash code for this object.
no setterinherited
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requestId String?
An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String