PatchRegionUrlMapRequest class final

A request message for RegionUrlMaps.Patch. See the method description for details.

Constructors

PatchRegionUrlMapRequest({required String project, required String region, String? requestId, required String urlMap, required UrlMap? urlMapResource})
PatchRegionUrlMapRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
region String
Name of the region scoping this request.
final
requestId String?
begin_interface: MixerMutationRequestBuilder Request ID to support idempotency.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
urlMap String
Name of the UrlMap resource to patch.
final
urlMapResource UrlMap?
The body resource for this request
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String