PatchRuleRegionSecurityPolicyRequest class final

A request message for RegionSecurityPolicies.PatchRule. See the method description for details.

Constructors

PatchRuleRegionSecurityPolicyRequest({int? priority, required String project, required String region, required String securityPolicy, required SecurityPolicyRule? securityPolicyRuleResource, String? updateMask, bool? validateOnly})
PatchRuleRegionSecurityPolicyRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
priority int?
The priority of the rule to patch.
final
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
region String
Name of the region scoping this request.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
securityPolicy String
Name of the security policy to update.
final
securityPolicyRuleResource SecurityPolicyRule?
The body resource for this request
final
updateMask String?
Indicates fields to be cleared as part of this request.
final
validateOnly bool?
If true, the request will not be committed.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String