PatchServiceAttachmentRequest class final

A request message for ServiceAttachments.Patch. See the method description for details.

Constructors

PatchServiceAttachmentRequest({required String project, required String region, String? requestId, required String serviceAttachment, required ServiceAttachment? serviceAttachmentResource})
PatchServiceAttachmentRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
region String
The region scoping this request and should conform to RFC1035.
final
requestId String?
An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceAttachment String
The resource id of the ServiceAttachment to patch. It should conform to RFC1035 resource name or be a string form on an unsigned long number.
final
serviceAttachmentResource ServiceAttachment?
The body resource for this request
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String