PatchWireGroupRequest class final
A request message for WireGroups.Patch. See the method description for details.
Constructors
- PatchWireGroupRequest({required String crossSiteNetwork, required String project, String? requestId, String? updateMask, bool? validateOnly, required String wireGroup, required WireGroup? wireGroupResource})
- PatchWireGroupRequest.fromJson(Object? j)
-
factory
Properties
- crossSiteNetwork → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- project → String
-
Project ID for this request.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - requestId → String?
-
An optional request ID to identify requests. Specify a unique request ID so
that if you must retry your request, the server will know to ignore the
request if it has already been completed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updateMask → String?
-
update_mask indicates fields to be updated as part of this request.
final
- validateOnly → bool?
-
Input OnlyValidate the new configuration, but don't update it.final - wireGroup → String
-
Name of the WireGroups resource to patch.
final
- wireGroupResource → WireGroup?
-
The body resource for this request
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String