pathRules property
The list of path rules. Use this list instead of routeRules when routing based on simple path matching is all that's required. A path rule can only include a wildcard character (*) after a forward slash character ("/").
The order by which path rules are specified does not matter. Matches are always done on the longest-path-first basis.
For example: a pathRule with a path /a/b/c/* will match before /a/b/* irrespective of the order in which those paths appear in this list.
Within a given pathMatcher, only one ofpathRules or routeRules must be set.
Implementation
final List<PathRule> pathRules;