routeRules property

List<HttpRouteRule> routeRules
final

The list of HTTP route rules. Use this list instead ofpathRules when advanced route matching and routing actions are desired. routeRules are evaluated in order of priority, from the lowest to highest number.

Within a given pathMatcher, you can set only one ofpathRules or routeRules.

Implementation

final List<HttpRouteRule> routeRules;