Fingerprint of this per-instance config. This field can be used in
optimistic locking. It is ignored when inserting a per-instance
config. An up-to-date fingerprint must be provided in order to update an
existing per-instance configuration or the field needs to be unset.
The name of a per-instance configuration and its corresponding instance.
Serves as a merge key during UpdatePerInstanceConfigs
operations, that is, if a per-instance configuration with the same name
exists then it will be updated, otherwise a new one will be created for the
VM instance with the same name. An attempt to create a per-instance
configuration for a VM instance that either doesn't exist or is not part
of the group will result in an error.