preservedState property
The intended preserved state for the given instance. Does not contain preserved state generated from a stateful policy.
Implementation
final PreservedState? preservedState;
The intended preserved state for the given instance. Does not contain preserved state generated from a stateful policy.
final PreservedState? preservedState;