status property
The status of applying this per-instance configuration on the corresponding managed instance. Check the Status enum for the list of possible values.
Implementation
final String? status;
The status of applying this per-instance configuration on the corresponding managed instance. Check the Status enum for the list of possible values.
final String? status;