deleting constant

PerInstanceConfig_Status const deleting

The per-instance configuration deletion is being applied on the instance, possibly waiting for the instance to, for example, REFRESH.

Implementation

static const deleting = PerInstanceConfig_Status('DELETING');