effective constant

PerInstanceConfig_Status const effective

The per-instance configuration is effective on the instance, meaning that all disks, ips and metadata specified in this configuration are attached or set on the instance.

Implementation

static const effective = PerInstanceConfig_Status('EFFECTIVE');