PerformMaintenanceReservationBlockRequest class final

A request message for ReservationBlocks.PerformMaintenance. See the method description for details.

Constructors

PerformMaintenanceReservationBlockRequest({required String project, String? requestId, required String reservation, required String reservationBlock, required ReservationsBlocksPerformMaintenanceRequest? reservationsBlocksPerformMaintenanceRequestResource, required String zone})
PerformMaintenanceReservationBlockRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requestId String?
An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
final
reservation String
The name of the reservation. Name should conform to RFC1035 or be a resource ID.
final
reservationBlock String
The name of the reservation block. Name should conform to RFC1035 or be a resource ID.
final
reservationsBlocksPerformMaintenanceRequestResource ReservationsBlocksPerformMaintenanceRequest?
The body resource for this request
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zone String
Name of the zone for this request. Zone name should conform to RFC1035.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String