PerformMaintenanceReservationSubBlockRequest class final

A request message for ReservationSubBlocks.PerformMaintenance. See the method description for details.

Constructors

PerformMaintenanceReservationSubBlockRequest({required String parentName, required String project, String? requestId, required String reservationSubBlock, required String zone})
PerformMaintenanceReservationSubBlockRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
parentName String
The name of the parent reservation and parent block. In the format of reservations/{reservation_name}/reservationBlocks/{reservation_block_name}
final
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requestId String?
An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
final
reservationSubBlock String
The name of the reservation subBlock. Name should conform to RFC1035 or be a resource ID.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zone String
Name of the zone for this request. Zone name should conform to RFC1035.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String