PeriodicPartialMaintenanceSchedule class final

The periodic partial maintenance schedule includes 52 weeks worth of maintenance windows. LINT.IfChange(PeriodicPartialMaintenanceSchedule)

Constructors

PeriodicPartialMaintenanceSchedule({String? subType, String? targetResource, String? type, DateTime? windowEndTime, DateTime? windowStartTime})
PeriodicPartialMaintenanceSchedule.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subType String?
The maintenance type in which the zone is during the given window. Check the SubType enum for the list of possible values.
final
targetResource String?
The target resource that the maintenance window is for. For example, "projects/my-project/zones/us-central1-a".
final
type String?
Check the Type enum for the list of possible values.
final
windowEndTime DateTime?
The end civil timestamp of the window (not inclusive). This contains a time zone.
final
windowStartTime DateTime?
The start civil timestamp of the window. This contains a time zone.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String