expressionSets property
List of entities that are currently supported for WAF rules.
Implementation
final List<WafExpressionSet> expressionSets;
List of entities that are currently supported for WAF rules.
final List<WafExpressionSet> expressionSets;