PreservedState class final
Preserved state for a given instance.
Constructors
-
PreservedState({Map<
String, PreservedStatePreservedDisk> disks = const {}, Map<String, PreservedStatePreservedNetworkIp> externalIPs = const {}, Map<String, PreservedStatePreservedNetworkIp> internalIPs = const {}, Map<String, String> metadata = const {}}) - PreservedState.fromJson(Object? j)
-
factory
Properties
-
disks
→ Map<
String, PreservedStatePreservedDisk> -
Preserved disks defined for this instance.
This map is keyed with the device names of the disks.
final
-
externalIPs
→ Map<
String, PreservedStatePreservedNetworkIp> -
Preserved external IPs defined for this instance.
This map is keyed with the name of the network interface.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
internalIPs
→ Map<
String, PreservedStatePreservedNetworkIp> -
Preserved internal IPs defined for this instance.
This map is keyed with the name of the network interface.
final
-
metadata
→ Map<
String, String> -
Preserved metadata defined for this instance.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String