disks property
Preserved disks defined for this instance. This map is keyed with the device names of the disks.
Implementation
final Map<String, PreservedStatePreservedDisk> disks;
Preserved disks defined for this instance. This map is keyed with the device names of the disks.
final Map<String, PreservedStatePreservedDisk> disks;