externalIPs property
Preserved external IPs defined for this instance. This map is keyed with the name of the network interface.
Implementation
final Map<String, PreservedStatePreservedNetworkIp> externalIPs;
Preserved external IPs defined for this instance. This map is keyed with the name of the network interface.
final Map<String, PreservedStatePreservedNetworkIp> externalIPs;