source property
The URL of the disk resource that is stateful and should be attached to the VM instance.
Implementation
final String? source;
The URL of the disk resource that is stateful and should be attached to the VM instance.
final String? source;