PreservedStatePreservedDisk_Mode class final

The mode in which to attach this disk, either READ_WRITE orREAD_ONLY. If not specified, the default is to attach the disk in READ_WRITE mode.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const PreservedStatePreservedDisk_Mode
The default value for PreservedStatePreservedDisk_Mode.
readOnly → const PreservedStatePreservedDisk_Mode
Attaches this disk in read-only mode. Multiple VM instances can use a disk in READ_ONLY mode at a time.
readWrite → const PreservedStatePreservedDisk_Mode
Default Attaches this disk in READ_WRITE mode. Only one VM instance at a time can be attached to a disk inREAD_WRITE mode.
undefinedMode → const PreservedStatePreservedDisk_Mode
A value indicating that the enum field is not set.