PreservedStatePreservedNetworkIpIpAddress class final

Properties

address String?
The URL of the reservation for this IP address.
final
hashCode int
The hash code for this object.
no setterinherited
literal String?
An IPv4 internal network address to assign to the instance for this network interface.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String