PreviewFeatureRolloutOperationRolloutInput class final
Represents the input for the rollout operation.
Constructors
- PreviewFeatureRolloutOperationRolloutInput({String? name, String? predefinedRolloutPlan})
- PreviewFeatureRolloutOperationRolloutInput.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String?
-
The name of the rollout plan
Ex.
organizations//locations/global/rolloutPlans/
Ex.
folders//locations/global/rolloutPlans/
Ex.
projects//locations/global/rolloutPlans/.
final
- predefinedRolloutPlan → String?
-
Predefined rollout plan.
Check the PredefinedRolloutPlan enum for the list of possible values.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String