PreviewFeatureStatus class final

Output Only The status of the feature.

Constructors

PreviewFeatureStatus({String? description, String? helpLink, PreviewFeatureStatusReleaseStatus? releaseStatus})
PreviewFeatureStatus.fromJson(Object? j)
factory

Properties

description String?
Output only. Output Only The description of the feature.
final
hashCode int
The hash code for this object.
no setterinherited
Output only. Output Only Link to the public documentation for the feature.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
releaseStatus PreviewFeatureStatusReleaseStatus?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String