PreviewFeatureStatusReleaseStatus class final

Output Only The release status of the feature.

Properties

hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stage String?
Output only. Output Only The stage of the feature. Check the Stage enum for the list of possible values.
final
updateDate Date?
Output only. The last date when a feature transitioned between ReleaseStatuses.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String