PreviewFeature_ActivationStatus class final
Specifies whether the feature is enabled or disabled.
Constructors
- PreviewFeature_ActivationStatus(String value)
-
const
- PreviewFeature_ActivationStatus.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const PreviewFeature_ActivationStatus
- The default value for PreviewFeature_ActivationStatus.
- activationStateUnspecified → const PreviewFeature_ActivationStatus
- disabled → const PreviewFeature_ActivationStatus
- enabled → const PreviewFeature_ActivationStatus
- undefinedActivationStatus → const PreviewFeature_ActivationStatus
- A value indicating that the enum field is not set.