PreviewFeatures class final
The PreviewFeatures API.
- Implementers
Constructors
- PreviewFeatures({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
PreviewFeaturesusingclientfor transport. - PreviewFeatures.fromApiKey([String? apiKey])
-
Creates a
PreviewFeaturesthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
get(
GetPreviewFeatureRequest request) → Future< PreviewFeature> - Returns the details of the given PreviewFeature.
-
list(
ListPreviewFeaturesRequest request) → Future< PreviewFeatureList> - Returns the details of the given PreviewFeature.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
UpdatePreviewFeatureRequest request) → Future< Operation> - Patches the given PreviewFeature. This method is used to enable or disable a PreviewFeature.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited