update method

Patches the given PreviewFeature. This method is used to enable or disable a PreviewFeature.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> update(UpdatePreviewFeatureRequest request) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/global/previewFeatures/${request.previewFeature}',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.patch(
    url,
    body: request.previewFeatureResource,
  );
  return Operation.fromJson(response);
}