Project class final
Represents a Project resource.
A project is used to organize resources in a Google Cloud Platform environment. For more information, read about the Resource Hierarchy.
Constructors
-
Project({String? cloudArmorTier, Metadata? commonInstanceMetadata, String? creationTimestamp, String? defaultNetworkTier, String? defaultServiceAccount, String? description, List<
String> enabledFeatures = const [], BigInt? id, String? kind, String? name, List<Quota> quotas = const [], String? selfLink, UsageExportLocation? usageExportLocation, String? vmDnsSetting, String? xpnProjectStatus}) - Project.fromJson(Object? j)
-
factory
Properties
- cloudArmorTier → String?
-
Output only.
Output OnlyThe Cloud Armor tier for this project. It can be one of the following values: CA_STANDARD,CA_ENTERPRISE_PAYGO.final - commonInstanceMetadata → Metadata?
-
Metadata key/value pairs available to all instances contained in this
project. See Custom
metadata for more information.
final
- creationTimestamp → String?
-
Output OnlyCreation timestamp inRFC3339 text format.final - defaultNetworkTier → String?
-
This signifies the default network tier used for configuring resources of
the project and can only take the following values:PREMIUM, STANDARD. Initially the default network
tier is PREMIUM.
Check the DefaultNetworkTier enum for the list of possible values.
final
- defaultServiceAccount → String?
-
Output OnlyDefault service account used by VMs running in this project.final - description → String?
-
An optional textual description of the resource.
final
-
enabledFeatures
→ List<
String> -
An optional list of restricted features enabled for use on this project.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → BigInt?
-
Output OnlyThe unique identifier for the resource. This identifier is defined by the server. This is not the project ID, and is just a unique ID used by Compute Engine to identify resources.final - kind → String?
-
Output only.
Output OnlyType of the resource. Always compute#project for projects.final - name → String?
-
The project ID. For example: my-example-project. Use the
project ID to make requests to Compute Engine.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited -
quotas
→ List<
Quota> -
Output OnlyQuotas assigned to this project.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfLink → String?
-
Output OnlyServer-defined URL for the resource.final - usageExportLocation → UsageExportLocation?
-
An optional naming prefix for daily usage reports and the Google Cloud
Storage bucket where they are stored.
final
- vmDnsSetting → String?
-
Output only.
Output OnlyDefault internal DNS setting used by VMs running in this project. Check the VmDnsSetting enum for the list of possible values.final - xpnProjectStatus → String?
-
Output OnlyThe role this project has in a shared VPC configuration. Currently, only projects with the host role, which is specified by the value HOST, are differentiated. Check the XpnProjectStatus enum for the list of possible values.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String