cloudArmorTier property

String? cloudArmorTier
final

Output only. Output Only The Cloud Armor tier for this project. It can be one of the following values: CA_STANDARD,CA_ENTERPRISE_PAYGO.

If this field is not specified, it is assumed to beCA_STANDARD. Check the CloudArmorTier enum for the list of possible values.

Implementation

final String? cloudArmorTier;