usageExportLocation property

UsageExportLocation? usageExportLocation
final

An optional naming prefix for daily usage reports and the Google Cloud Storage bucket where they are stored.

Implementation

final UsageExportLocation? usageExportLocation;