xpnProjectStatus property
Output Only The role this project has in a shared VPC configuration.
Currently, only projects with the host role, which is specified by the
value HOST, are differentiated.
Check the XpnProjectStatus enum for the list of possible values.
Implementation
final String? xpnProjectStatus;