ProjectView class final

Represents a ProjectView resource.

A ProjectView resource contains read-only project data which is available globally.

Constructors

ProjectView({Project? project})
ProjectView.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
project Project?
The project data. The returned Project data does not contain regional or zonal quota usage data. Global quota limits are present. For accurate, real-time quota usage numbers, query the global projects.get endpoint.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String