Project_DefaultNetworkTier class final

This signifies the default network tier used for configuring resources of the project and can only take the following values:PREMIUM, STANDARD. Initially the default network tier is PREMIUM.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const Project_DefaultNetworkTier
The default value for Project_DefaultNetworkTier.
fixedStandard → const Project_DefaultNetworkTier
Public internet quality with fixed bandwidth.
premium → const Project_DefaultNetworkTier
High quality, Google-grade network tier, support for all networking products.
standard → const Project_DefaultNetworkTier
Public internet quality, only limited support for other networking products.
standardOverridesFixedStandard → const Project_DefaultNetworkTier
(Output only) Temporary tier for FIXED_STANDARD when fixed standard tier is expired or not configured.
undefinedDefaultNetworkTier → const Project_DefaultNetworkTier
A value indicating that the enum field is not set.