Project_XpnProjectStatus class final

Output Only The role this project has in a shared VPC configuration. Currently, only projects with the host role, which is specified by the value HOST, are differentiated.

Constructors

Project_XpnProjectStatus(String value)
const
Project_XpnProjectStatus.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const Project_XpnProjectStatus
The default value for Project_XpnProjectStatus.
host → const Project_XpnProjectStatus
undefinedXpnProjectStatus → const Project_XpnProjectStatus
A value indicating that the enum field is not set.
unspecifiedXpnProjectStatus → const Project_XpnProjectStatus