listXpnHosts method

Lists all shared VPC host projects visible to the user in an organization.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<XpnHostList> listXpnHosts(ListXpnHostsProjectsRequest request) async {
  final url = _endPoint.replace(
    path: '/compute/v1/projects/${request.project}/listXpnHosts',
    queryParameters: {
      'filter': ?request.filter,
      if (request.maxResults case final $1?) 'maxResults': '${$1}',
      'orderBy': ?request.orderBy,
      'pageToken': ?request.pageToken,
      if (request.returnPartialSuccess case final $1?)
        'returnPartialSuccess': '${$1}',
    },
  );
  final response = await _client.post(
    url,
    body: request.projectsListXpnHostsRequestResource,
  );
  return XpnHostList.fromJson(response);
}