setCommonInstanceMetadata method
Sets metadata common to all instances within the specified project using the data included in the request.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
Future<Operation> setCommonInstanceMetadata(
SetCommonInstanceMetadataProjectRequest request,
) async {
final url = _endPoint.replace(
path: '/compute/v1/projects/${request.project}/setCommonInstanceMetadata',
queryParameters: {'requestId': ?request.requestId},
);
final response = await _client.post(url, body: request.metadataResource);
return Operation.fromJson(response);
}