organization property

String? organization
final

Optional organization ID managed by Cloud Resource Manager, for which to list shared VPC host projects. If not specified, the organization will be inferred from the project.

Implementation

final String? organization;