ProjectsSetCloudArmorTierRequest_CloudArmorTier class final

Managed protection tier to be set.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const ProjectsSetCloudArmorTierRequest_CloudArmorTier
The default value for ProjectsSetCloudArmorTierRequest_CloudArmorTier.
caEnterpriseAnnual → const ProjectsSetCloudArmorTierRequest_CloudArmorTier
Enterprise tier protection billed annually.
caEnterprisePaygo → const ProjectsSetCloudArmorTierRequest_CloudArmorTier
Enterprise tier protection billed monthly.
caStandard → const ProjectsSetCloudArmorTierRequest_CloudArmorTier
Standard protection.
undefinedCloudArmorTier → const ProjectsSetCloudArmorTierRequest_CloudArmorTier
A value indicating that the enum field is not set.