ProjectsSetDefaultNetworkTierRequest_NetworkTier class final
Default network tier to be set.
Constructors
- ProjectsSetDefaultNetworkTierRequest_NetworkTier(String value)
-
const
- ProjectsSetDefaultNetworkTierRequest_NetworkTier.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const ProjectsSetDefaultNetworkTierRequest_NetworkTier
- The default value for ProjectsSetDefaultNetworkTierRequest_NetworkTier.
- fixedStandard → const ProjectsSetDefaultNetworkTierRequest_NetworkTier
- Public internet quality with fixed bandwidth.
- High quality, Google-grade network tier, support for all networking products.
- standard → const ProjectsSetDefaultNetworkTierRequest_NetworkTier
- Public internet quality, only limited support for other networking products.
- standardOverridesFixedStandard → const ProjectsSetDefaultNetworkTierRequest_NetworkTier
- (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier is expired or not configured.
- undefinedNetworkTier → const ProjectsSetDefaultNetworkTierRequest_NetworkTier
- A value indicating that the enum field is not set.