PublicAdvertisedPrefix class final

A public advertised prefix represents an aggregated IP prefix or netblock which customers bring to cloud. The IP prefix is a single unit of route advertisement and is announced globally to the internet.

Constructors

PublicAdvertisedPrefix({String? byoipApiVersion, String? creationTimestamp, String? description, String? dnsVerificationIp, String? fingerprint, BigInt? id, String? ipCidrRange, String? ipv6AccessType, String? kind, String? name, String? pdpScope, List<PublicAdvertisedPrefixPublicDelegatedPrefix> publicDelegatedPrefixs = const [], String? selfLink, String? sharedSecret, String? status})
PublicAdvertisedPrefix.fromJson(Object? j)
factory

Properties

byoipApiVersion String?
Output only. Output Only The version of BYOIP API. Check the ByoipApiVersion enum for the list of possible values.
final
creationTimestamp String?
Output only. Output Only Creation timestamp inRFC3339 text format.
final
description String?
An optional description of this resource. Provide this property when you create the resource.
final
dnsVerificationIp String?
The address to be used for reverse DNS verification.
final
fingerprint String?
Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a new PublicAdvertisedPrefix. An up-to-date fingerprint must be provided in order to update thePublicAdvertisedPrefix, otherwise the request will fail with error 412 conditionNotMet.
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output only. Output Only The unique identifier for the resource type. The server generates this identifier.
final
ipCidrRange String?
The address range, in CIDR format, represented by this public advertised prefix.
final
ipv6AccessType String?
The internet access type for IPv6 Public Advertised Prefixes. Check the Ipv6AccessType enum for the list of possible values.
final
kind String?
Output only. Output Only Type of the resource. Alwayscompute#publicAdvertisedPrefix for public advertised prefixes.
final
name String?
Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
pdpScope String?
Specifies how child public delegated prefix will be scoped. It could be one of following values:
final
publicDelegatedPrefixs List<PublicAdvertisedPrefixPublicDelegatedPrefix>
Output only. Output Only The list of public delegated prefixes that exist for this public advertised prefix.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output only. Output Only Server-defined URL for the resource.
final
sharedSecret String?
Output Only The shared secret to be used for reverse DNS verification.
final
status String?
The status of the public advertised prefix. Possible values include:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String