PublicAdvertisedPrefix_ByoipApiVersion class final

Output only. Output Only The version of BYOIP API.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const PublicAdvertisedPrefix_ByoipApiVersion
The default value for PublicAdvertisedPrefix_ByoipApiVersion.
undefinedByoipApiVersion → const PublicAdvertisedPrefix_ByoipApiVersion
A value indicating that the enum field is not set.
v1 → const PublicAdvertisedPrefix_ByoipApiVersion
This public advertised prefix can be used to create both regional and global public delegated prefixes. It usually takes 4 weeks to create or delete a public delegated prefix. The BGP status cannot be changed.
v2 → const PublicAdvertisedPrefix_ByoipApiVersion
This public advertised prefix can only be used to create regional public delegated prefixes. Public delegated prefix creation and deletion takes minutes and the BGP status can be modified.