PublicAdvertisedPrefix_PdpScope class final

Specifies how child public delegated prefix will be scoped. It could be one of following values:

 - `REGIONAL`: The public delegated prefix is regional only. The
 provisioning will take a few minutes.
 - `GLOBAL`: The public delegated prefix is global only. The
 provisioning will take ~4 weeks.
 - `GLOBAL_AND_REGIONAL` [output only]: The public delegated prefixes is
  BYOIP V1 legacy prefix. This is output only value and no longer
  supported in BYOIP V2.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const PublicAdvertisedPrefix_PdpScope
The default value for PublicAdvertisedPrefix_PdpScope.
global → const PublicAdvertisedPrefix_PdpScope
The public delegated prefix is global only. The provisioning will take ~4 weeks.
globalAndRegional → const PublicAdvertisedPrefix_PdpScope
The public delegated prefixes is BYOIP V1 legacy prefix. This is output only value and no longer supported in BYOIP V2.
regional → const PublicAdvertisedPrefix_PdpScope
The public delegated prefix is regional only. The provisioning will take a few minutes.
undefinedPdpScope → const PublicAdvertisedPrefix_PdpScope
A value indicating that the enum field is not set.