PublicAdvertisedPrefix_Status class final

The status of the public advertised prefix. Possible values include:

 - `INITIAL`: RPKI validation is complete.
 - `PTR_CONFIGURED`: User has configured the PTR.
 - `VALIDATED`: Reverse DNS lookup is successful.
 - `REVERSE_DNS_LOOKUP_FAILED`: Reverse DNS lookup failed.
 - `PREFIX_CONFIGURATION_IN_PROGRESS`: The prefix is being
 configured.
 - `PREFIX_CONFIGURATION_COMPLETE`: The prefix is fully configured.
 - `PREFIX_REMOVAL_IN_PROGRESS`: The prefix is being removed.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const PublicAdvertisedPrefix_Status
The default value for PublicAdvertisedPrefix_Status.
announcedToInternet → const PublicAdvertisedPrefix_Status
The prefix is announced to Internet.
initial → const PublicAdvertisedPrefix_Status
RPKI validation is complete.
prefixConfigurationComplete → const PublicAdvertisedPrefix_Status
The prefix is fully configured.
prefixConfigurationInProgress → const PublicAdvertisedPrefix_Status
The prefix is being configured.
prefixRemovalInProgress → const PublicAdvertisedPrefix_Status
The prefix is being removed.
ptrConfigured → const PublicAdvertisedPrefix_Status
User has configured the PTR.
readyToAnnounce → const PublicAdvertisedPrefix_Status
The prefix is currently withdrawn but ready to be announced.
reverseDnsLookupFailed → const PublicAdvertisedPrefix_Status
Reverse DNS lookup failed.
undefinedStatus → const PublicAdvertisedPrefix_Status
A value indicating that the enum field is not set.
validated → const PublicAdvertisedPrefix_Status
Reverse DNS lookup is successful.