PublicAdvertisedPrefixes class final

The PublicAdvertisedPrefixes API.

Implementers

Constructors

PublicAdvertisedPrefixes({required Client client, Uri? endPoint, String? gcclVersion})
Creates a PublicAdvertisedPrefixes using client for transport.
PublicAdvertisedPrefixes.fromApiKey([String? apiKey])
Creates a PublicAdvertisedPrefixes that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

announce(AnnouncePublicAdvertisedPrefixeRequest request) Future<Operation>
Announces the specified PublicAdvertisedPrefix
close() → void
Closes the client and cleans up any resources associated with it.
delete(DeletePublicAdvertisedPrefixeRequest request) Future<Operation>
Deletes the specified PublicAdvertisedPrefix
get(GetPublicAdvertisedPrefixeRequest request) Future<PublicAdvertisedPrefix>
Returns the specified PublicAdvertisedPrefix resource.
insert(InsertPublicAdvertisedPrefixeRequest request) Future<Operation>
Creates a PublicAdvertisedPrefix in the specified project using the parameters that are included in the request.
list(ListPublicAdvertisedPrefixesRequest request) Future<PublicAdvertisedPrefixList>
Lists the PublicAdvertisedPrefixes for a project.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(PatchPublicAdvertisedPrefixeRequest request) Future<Operation>
Patches the specified Router resource with the data included in the request. This method supportsPATCH semantics and usesJSON merge patch format and processing rules.
toString() String
A string representation of this object.
inherited
withdraw(WithdrawPublicAdvertisedPrefixeRequest request) Future<Operation>
Withdraws the specified PublicAdvertisedPrefix

Operators

operator ==(Object other) bool
The equality operator.
inherited