PublicDelegatedPrefix class final
A PublicDelegatedPrefix resource represents an IP block within a PublicAdvertisedPrefix that is configured within a single cloud scope (global or region). IPs in the block can be allocated to resources within that scope. Public delegated prefixes may be further broken up into smaller IP blocks in the same scope as the parent block.
Constructors
-
PublicDelegatedPrefix({int? allocatablePrefixLength, String? byoipApiVersion, String? creationTimestamp, String? description, bool? enableEnhancedIpv4Allocation, String? fingerprint, BigInt? id, String? ipCidrRange, String? ipv6AccessType, bool? isLiveMigration, String? kind, String? mode, String? name, String? parentPrefix, List<
PublicDelegatedPrefixPublicDelegatedSubPrefix> publicDelegatedSubPrefixs = const [], String? region, String? selfLink, String? status}) - PublicDelegatedPrefix.fromJson(Object? j)
-
factory
Properties
- allocatablePrefixLength → int?
-
The allocatable prefix length supported by this public delegated prefix.
This field is optional and cannot be set for prefixes in DELEGATION mode.
It cannot be set for IPv4 prefixes either, and it always defaults to 32.
final
- byoipApiVersion → String?
-
Output only.
Output OnlyThe version of BYOIP API. Check the ByoipApiVersion enum for the list of possible values.final - creationTimestamp → String?
-
Output only.
Output OnlyCreation timestamp inRFC3339 text format.final - description → String?
-
An optional description of this resource. Provide this property when you
create the resource.
final
- enableEnhancedIpv4Allocation → bool?
-
Output only.
Output OnlyWhether this PDP supports enhanced IPv4 allocations. Applicable for IPv4 PDPs only.final - fingerprint → String?
-
Fingerprint of this resource. A hash of the contents stored in this object.
This field is used in optimistic locking. This field will be ignored when
inserting a new PublicDelegatedPrefix. An up-to-date
fingerprint must be provided in order to update thePublicDelegatedPrefix, otherwise the request will fail with
error 412 conditionNotMet.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → BigInt?
-
Output only.
Output OnlyThe unique identifier for the resource type. The server generates this identifier.final - ipCidrRange → String?
-
The IP address range, in CIDR format, represented by this public
delegated prefix.
final
- ipv6AccessType → String?
-
Output only.
Output OnlyThe internet access type for IPv6 Public Delegated Prefixes. Inherited from parent prefix. Check the Ipv6AccessType enum for the list of possible values.final - isLiveMigration → bool?
-
If true, the prefix will be live migrated.
final
- kind → String?
-
Output only.
Output OnlyType of the resource. Alwayscompute#publicDelegatedPrefix for public delegated prefixes.final - mode → String?
-
The public delegated prefix mode for IPv6 only.
Check the Mode enum for the list of possible values.
final
- name → String?
-
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression
[a-z]([-a-z0-9]*[a-z0-9])?which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.final - parentPrefix → String?
-
The URL of parent prefix. Either PublicAdvertisedPrefix or
PublicDelegatedPrefix.
final
-
publicDelegatedSubPrefixs
→ List<
PublicDelegatedPrefixPublicDelegatedSubPrefix> -
The list of sub public delegated prefixes that exist for this public
delegated prefix.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - region → String?
-
Output only.
Output OnlyURL of the region where the public delegated prefix resides. This field applies only to the region resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfLink → String?
-
Output only.
Output OnlyServer-defined URL for the resource.final - status → String?
-
Output OnlyThe status of the public delegated prefix, which can be one of following values:final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String