mode property
The public delegated prefix mode for IPv6 only. Check the Mode enum for the list of possible values.
Implementation
final String? mode;
The public delegated prefix mode for IPv6 only. Check the Mode enum for the list of possible values.
final String? mode;