status property

String? status
final

Output Only The status of the public delegated prefix, which can be one of following values:

 - `INITIALIZING` The public delegated prefix is being initialized and
 addresses cannot be created yet.
 - `READY_TO_ANNOUNCE` The public delegated prefix is a live migration
 prefix and is active.
 - `ANNOUNCED` The public delegated prefix is announced and ready to
 use.
 - `DELETING` The public delegated prefix is being deprovsioned.
 - `ACTIVE` The public delegated prefix is ready to use.

Check the Status enum for the list of possible values.

Implementation

final String? status;