PublicDelegatedPrefix_Mode class final

The public delegated prefix mode for IPv6 only.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const PublicDelegatedPrefix_Mode
The default value for PublicDelegatedPrefix_Mode.
delegation → const PublicDelegatedPrefix_Mode
The public delegated prefix is used for further sub-delegation only. Such prefixes cannot set allocatablePrefixLength.
externalIpv6ForwardingRuleCreation → const PublicDelegatedPrefix_Mode
The public delegated prefix is used for creating forwarding rules only. Such prefixes cannot set publicDelegatedSubPrefixes. Parent public delegated prefix must have IPv6 access type as EXTERNAL.
externalIpv6SubnetworkCreation → const PublicDelegatedPrefix_Mode
The public delegated prefix is used for creating dual-mode subnetworks only. Such prefixes cannot set publicDelegatedSubPrefixes. Parent public delegated prefix must have IPv6 access type as EXTERNAL.
internalIpv6SubnetworkCreation → const PublicDelegatedPrefix_Mode
The public delegated prefix is used for creating dual stack or IPv6-only subnetwork with internal access only. Such prefixes cannot set publicDelegatedSubPrefixes and allocatablePrefixLength. Parent public delegated prefix must have IPv6 access type as INTERNAL.
undefinedMode → const PublicDelegatedPrefix_Mode
A value indicating that the enum field is not set.