PublicDelegatedPrefix_Status class final
Output Only The status of the public delegated prefix, which can be one
of following values:
- `INITIALIZING` The public delegated prefix is being initialized and
addresses cannot be created yet.
- `READY_TO_ANNOUNCE` The public delegated prefix is a live migration
prefix and is active.
- `ANNOUNCED` The public delegated prefix is announced and ready to
use.
- `DELETING` The public delegated prefix is being deprovsioned.
- `ACTIVE` The public delegated prefix is ready to use.
Constructors
- PublicDelegatedPrefix_Status(String value)
-
const
- PublicDelegatedPrefix_Status.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const PublicDelegatedPrefix_Status
- The default value for PublicDelegatedPrefix_Status.
- active → const PublicDelegatedPrefix_Status
- The public delegated prefix is ready to use.
- announced → const PublicDelegatedPrefix_Status
- The public delegated prefix is announced and ready to use.
- announcedToGoogle → const PublicDelegatedPrefix_Status
- The prefix is announced within Google network.
- announcedToInternet → const PublicDelegatedPrefix_Status
- The prefix is announced to Internet and within Google.
- deleting → const PublicDelegatedPrefix_Status
- The public delegated prefix is being deprovsioned.
- initializing → const PublicDelegatedPrefix_Status
- The public delegated prefix is being initialized and addresses cannot be created yet.
- readyToAnnounce → const PublicDelegatedPrefix_Status
- The public delegated prefix is currently withdrawn but ready to be announced.
- undefinedStatus → const PublicDelegatedPrefix_Status
- A value indicating that the enum field is not set.