Quota class final

A quotas entry.

Constructors

Quota({double? limit, String? metric, String? owner, double? usage})
Quota.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
limit double?
Output Only Quota limit for this metric.
final
metric String?
Output Only Name of the quota metric. Check the Metric enum for the list of possible values.
final
owner String?
Output Only Owning resource. This is the resource on which this quota is applied.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usage double?
Output Only Current usage of this metric.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String