metric property
Output Only Name of the quota metric.
Check the Metric enum for the list of possible values.
Implementation
final String? metric;
Output Only Name of the quota metric.
Check the Metric enum for the list of possible values.
final String? metric;