QuotaExceededInfo class final

Additional details for quota exceeded error for resource quota.

Constructors

QuotaExceededInfo({Map<String, String> dimensions = const {}, double? futureLimit, double? limit, String? limitName, String? metricName, String? rolloutStatus})
QuotaExceededInfo.fromJson(Object? j)
factory

Properties

dimensions Map<String, String>
The map holding related quota dimensions.
final
futureLimit double?
Future quota limit being rolled out. The limit's unit depends on the quota type or metric.
final
hashCode int
The hash code for this object.
no setterinherited
limit double?
Current effective quota limit. The limit's unit depends on the quota type or metric.
final
limitName String?
The name of the quota limit.
final
metricName String?
The Compute Engine quota metric name.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
rolloutStatus String?
Rollout status of the future quota limit. Check the RolloutStatus enum for the list of possible values.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String