QuotaExceededInfo_RolloutStatus class final

Rollout status of the future quota limit.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const QuotaExceededInfo_RolloutStatus
The default value for QuotaExceededInfo_RolloutStatus.
inProgress → const QuotaExceededInfo_RolloutStatus
IN_PROGRESS - A rollout is in process which will change the limit value to future limit.
rolloutStatusUnspecified → const QuotaExceededInfo_RolloutStatus
ROLLOUT_STATUS_UNSPECIFIED - Rollout status is not specified. The default value.
undefinedRolloutStatus → const QuotaExceededInfo_RolloutStatus
A value indicating that the enum field is not set.