QuotaStatusWarning_Code class final
Output Only A warning code, if applicable. For example, Compute
Engine returns NO_RESULTS_ON_PAGE if there
are no results in the response.
Constructors
- QuotaStatusWarning_Code(String value)
-
const
- QuotaStatusWarning_Code.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const QuotaStatusWarning_Code
- The default value for QuotaStatusWarning_Code.
- cleanupFailed → const QuotaStatusWarning_Code
- Warning about failed cleanup of transient changes made by a failed operation.
- deprecatedResourceUsed → const QuotaStatusWarning_Code
- A link to a deprecated resource was created.
- deprecatedTypeUsed → const QuotaStatusWarning_Code
- When deploying and at least one of the resources has a type marked as deprecated
- diskSizeLargerThanImageSize → const QuotaStatusWarning_Code
- The user created a boot disk that is larger than image size.
- experimentalTypeUsed → const QuotaStatusWarning_Code
- When deploying and at least one of the resources has a type marked as experimental
- externalApiWarning → const QuotaStatusWarning_Code
- Warning that is present in an external api call
- fieldValueOverriden → const QuotaStatusWarning_Code
- Warning that value of a field has been overridden. Deprecated unused field.
- injectedKernelsDeprecated → const QuotaStatusWarning_Code
- The operation involved use of an injected kernel, which is deprecated.
- invalidHealthCheckForDynamicWieghtedLb → const QuotaStatusWarning_Code
- A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.
- largeDeploymentWarning → const QuotaStatusWarning_Code
- When deploying a deployment with a exceedingly large number of resources
- listOverheadQuotaExceed → const QuotaStatusWarning_Code
- Resource can't be retrieved due to list overhead quota exceed which captures the amount of resources filtered out by user-defined list filter.
- missingTypeDependency → const QuotaStatusWarning_Code
- A resource depends on a missing type
- nextHopAddressNotAssigned → const QuotaStatusWarning_Code
- The route's nextHopIp address is not assigned to an instance on the network.
- nextHopCannotIpForward → const QuotaStatusWarning_Code
- The route's next hop instance cannot ip forward.
- nextHopInstanceHasNoIpv6Interface → const QuotaStatusWarning_Code
- The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.
- nextHopInstanceNotFound → const QuotaStatusWarning_Code
- The route's nextHopInstance URL refers to an instance that does not exist.
- nextHopInstanceNotOnNetwork → const QuotaStatusWarning_Code
- The route's nextHopInstance URL refers to an instance that is not on the same network as the route.
- nextHopNotRunning → const QuotaStatusWarning_Code
- The route's next hop instance does not have a status of RUNNING.
- noResultsOnPage → const QuotaStatusWarning_Code
- No results are present on a particular list page.
- notCriticalError → const QuotaStatusWarning_Code
- Error which is not critical. We decided to continue the process despite the mentioned error.
- partialSuccess → const QuotaStatusWarning_Code
- Success is reported, but some results may be missing due to errors
- Quota information is not available to client requests (e.g: regions.list).
- requiredTosAgreement → const QuotaStatusWarning_Code
- The user attempted to use a resource that requires a TOS they have not accepted.
- resourceInUseByOtherResourceWarning → const QuotaStatusWarning_Code
- Warning that a resource is in use.
- resourceNotDeleted → const QuotaStatusWarning_Code
- One or more of the resources set to auto-delete could not be deleted because they were in use.
- schemaValidationIgnored → const QuotaStatusWarning_Code
- When a resource schema validation is ignored.
- singleInstancePropertyTemplate → const QuotaStatusWarning_Code
- Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.
- undeclaredProperties → const QuotaStatusWarning_Code
- When undeclared properties in the schema are present
- undefinedCode → const QuotaStatusWarning_Code
- A value indicating that the enum field is not set.
- unreachable → const QuotaStatusWarning_Code
- A given scope cannot be reached.