sha1Checksum property

String? sha1Checksum
final

Deprecated This field is deprecated. An optional SHA1 checksum of the disk image before unpackaging provided by the client when the disk image is created.

Implementation

final String? sha1Checksum;