source property

String? source
final

The full Google Cloud Storage URL or Artifact Registry path where the raw disk image archive is stored. The following are valid formats:

In order to create an image, you must provide the full or partial URL of one of the following:

  • The rawDisk.source URL
  • The sourceDisk URL
  • The sourceImage URL
  • The sourceSnapshot URL

Implementation

final String? source;