RegexRewrite class final
The spec for modifying the path using a regular expression.
Constructors
- RegexRewrite({String? pathPattern, String? pathSubstitution})
- RegexRewrite.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- pathPattern → String?
-
Required. The regular expression used to match against the URL path.
It uses RE2 syntax with the following constraints:
final
- pathSubstitution → String?
-
Required. Required when path pattern is specified. Used to rewrite matching parts of
the path.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String