quotaStatusWarning property
Output only. Output Only Warning of fetching the quotas field for this region. This
field is populated only if fetching of the quotas field fails.
Implementation
final QuotaStatusWarning? quotaStatusWarning;
Output only. Output Only Warning of fetching the quotas field for this region. This
field is populated only if fetching of the quotas field fails.
final QuotaStatusWarning? quotaStatusWarning;