status property
Output Only Status of the region, either UP orDOWN.
Check the Status enum for the list of possible values.
Implementation
final String? status;
Output Only Status of the region, either UP orDOWN.
Check the Status enum for the list of possible values.
final String? status;