description property
An optional destination address description if intended to be different from the source.
Implementation
final String? description;
An optional destination address description if intended to be different from the source.
final String? description;