RegionBackendServices class final

The RegionBackendServices API.

Implementers

Constructors

RegionBackendServices({required Client client, Uri? endPoint, String? gcclVersion})
Creates a RegionBackendServices using client for transport.
RegionBackendServices.fromApiKey([String? apiKey])
Creates a RegionBackendServices that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteRegionBackendServiceRequest request) Future<Operation>
Deletes the specified regional BackendService resource.
get(GetRegionBackendServiceRequest request) Future<BackendService>
Returns the specified regional BackendService resource.
getHealth(GetHealthRegionBackendServiceRequest request) Future<BackendServiceGroupHealth>
Gets the most recent health check results for this regional BackendService.
getIamPolicy(GetIamPolicyRegionBackendServiceRequest request) Future<Policy>
Gets the access control policy for a resource. May be empty if no such policy or resource exists.
insert(InsertRegionBackendServiceRequest request) Future<Operation>
Creates a regional BackendService resource in the specified project using the data included in the request. For more information, see Backend services overview.
list(ListRegionBackendServicesRequest request) Future<BackendServiceList>
Retrieves the list of regional BackendService resources available to the specified project in the given region.
listUsable(ListUsableRegionBackendServicesRequest request) Future<BackendServiceListUsable>
Retrieves a list of all usable backend services for Application Load Balancers and Proxy Network Load Balancers in the specified project in the given region. Backend services for external and internal passthrough Network Load Balancers are not included in the response.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(PatchRegionBackendServiceRequest request) Future<Operation>
Updates the specified regional BackendService resource with the data included in the request. For more information, see Understanding backend services This method supports PATCH semantics and uses the JSON merge patch format and processing rules.
setIamPolicy(SetIamPolicyRegionBackendServiceRequest request) Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy.
setSecurityPolicy(SetSecurityPolicyRegionBackendServiceRequest request) Future<Operation>
Sets the Google Cloud Armor security policy for the specified backend service. For more information, seeGoogle Cloud Armor Overview
testIamPermissions(TestIamPermissionsRegionBackendServiceRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
toString() String
A string representation of this object.
inherited
update(UpdateRegionBackendServiceRequest request) Future<Operation>
Updates the specified regional BackendService resource with the data included in the request. For more information, see Backend services overview.

Operators

operator ==(Object other) bool
The equality operator.
inherited