getHealth method

Gets the most recent health check results for this regional BackendService.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<BackendServiceGroupHealth> getHealth(
  GetHealthRegionBackendServiceRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/regions/${request.region}/backendServices/${request.backendService}/getHealth',
  );
  final response = await _client.post(
    url,
    body: request.resourceGroupReferenceResource,
  );
  return BackendServiceGroupHealth.fromJson(response);
}