patch method
Updates the specified regional BackendService resource with the data included in the request. For more information, see Understanding backend services This method supports PATCH semantics and uses the JSON merge patch format and processing rules.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
Future<Operation> patch(PatchRegionBackendServiceRequest request) async {
final url = _endPoint.replace(
path:
'/compute/v1/projects/${request.project}/regions/${request.region}/backendServices/${request.backendService}',
queryParameters: {'requestId': ?request.requestId},
);
final response = await _client.patch(
url,
body: request.backendServiceResource,
);
return Operation.fromJson(response);
}