update method

Updates the specified regional BackendService resource with the data included in the request. For more information, see Backend services overview.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> update(UpdateRegionBackendServiceRequest request) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/regions/${request.region}/backendServices/${request.backendService}',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.put(
    url,
    body: request.backendServiceResource,
  );
  return Operation.fromJson(response);
}