RegionCommitments class final
The RegionCommitments API.
- Implementers
Constructors
- RegionCommitments({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
RegionCommitmentsusingclientfor transport. - RegionCommitments.fromApiKey([String? apiKey])
-
Creates a
RegionCommitmentsthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
aggregatedList(
AggregatedListRegionCommitmentsRequest request) → Future< CommitmentAggregatedList> - Retrieves an aggregated list of commitments by region.
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
get(
GetRegionCommitmentRequest request) → Future< Commitment> - Returns the specified commitment resource.
-
insert(
InsertRegionCommitmentRequest request) → Future< Operation> - Creates a commitment in the specified project using the data included in the request.
-
list(
ListRegionCommitmentsRequest request) → Future< CommitmentList> - Retrieves a list of commitments contained within the specified region.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
UpdateRegionCommitmentRequest request) → Future< Operation> - Updates the specified commitment with the data included in the request. Update is performed only on selected fields included as part of update-mask. Only the following fields can be updated: auto_renew and plan.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited