RegionCompositeHealthChecks class final

The RegionCompositeHealthChecks API.

Implementers

Constructors

RegionCompositeHealthChecks({required Client client, Uri? endPoint, String? gcclVersion})
Creates a RegionCompositeHealthChecks using client for transport.
RegionCompositeHealthChecks.fromApiKey([String? apiKey])
Creates a RegionCompositeHealthChecks that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(AggregatedListRegionCompositeHealthChecksRequest request) Future<CompositeHealthCheckAggregatedList>
Retrieves the list of all CompositeHealthCheck resources (all regional) available to the specified project.
close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteRegionCompositeHealthCheckRequest request) Future<Operation>
Deletes the specified CompositeHealthCheck in the given region
get(GetRegionCompositeHealthCheckRequest request) Future<CompositeHealthCheck>
Returns the specified CompositeHealthCheck resource in the given region.
getHealth(GetHealthRegionCompositeHealthCheckRequest request) Future<CompositeHealthCheckHealth>
Gets the most recent health check results for this regional CompositeHealthCheck.
insert(InsertRegionCompositeHealthCheckRequest request) Future<Operation>
Create a CompositeHealthCheck in the specified project in the given region using the parameters that are included in the request.
list(ListRegionCompositeHealthChecksRequest request) Future<CompositeHealthCheckList>
Lists the CompositeHealthChecks for a project in the given region.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(PatchRegionCompositeHealthCheckRequest request) Future<Operation>
Updates the specified regional CompositeHealthCheck resource with the data included in the request. This method supportsPATCH semantics and uses theJSON merge patch format and processing rules.
testIamPermissions(TestIamPermissionsRegionCompositeHealthCheckRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited