getHealth method

Gets the most recent health check results for this regional CompositeHealthCheck.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<CompositeHealthCheckHealth> getHealth(
  GetHealthRegionCompositeHealthCheckRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/regions/${request.region}/compositeHealthChecks/${request.compositeHealthCheck}/getHealth',
  );
  final response = await _client.get(url);
  return CompositeHealthCheckHealth.fromJson(response);
}