RegionDiskTypes class final

The RegionDiskTypes API.

Implementers

Constructors

RegionDiskTypes({required Client client, Uri? endPoint, String? gcclVersion})
Creates a RegionDiskTypes using client for transport.
RegionDiskTypes.fromApiKey([String? apiKey])
Creates a RegionDiskTypes that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
get(GetRegionDiskTypeRequest request) Future<DiskType>
Returns the specified regional disk type.
list(ListRegionDiskTypesRequest request) Future<RegionDiskTypeList>
Retrieves a list of regional disk types available to the specified project.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited