menu
google_cloud_compute_v1 package
documentation
compute.dart
RegionDiskUpdateKmsKeyRequest class
RegionDiskUpdateKmsKeyRequest class
dark_mode
light_mode
RegionDiskUpdateKmsKeyRequest
class
final
Constructors
RegionDiskUpdateKmsKeyRequest
({
String
?
kmsKeyName
})
RegionDiskUpdateKmsKeyRequest.fromJson
(
Object
?
j
)
factory
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
kmsKeyName
→
String
?
Optional. The new KMS key to replace the current one on the disk. If empty, the disk will be re-encrypted using the primary version of the disk's current KMS key.
final
qualifiedName
→
String
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or
google.rpc.ErrorInfo
.
final
inherited
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson
(
)
→
Object
toString
(
)
→
String
A string representation of this object.
override
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
Constants
fullyQualifiedName
→ const
String
google_cloud_compute_v1 package
documentation
compute
RegionDiskUpdateKmsKeyRequest class
compute library