stopGroupAsyncReplication method
Stops asynchronous replication for a consistency group of disks. Can be invoked either in the primary or secondary scope.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
Future<Operation> stopGroupAsyncReplication(
StopGroupAsyncReplicationRegionDiskRequest request,
) async {
final url = _endPoint.replace(
path:
'/compute/v1/projects/${request.project}/regions/${request.region}/disks/stopGroupAsyncReplication',
queryParameters: {'requestId': ?request.requestId},
);
final response = await _client.post(
url,
body: request.disksStopGroupAsyncReplicationResourceResource,
);
return Operation.fromJson(response);
}