RegionHealthAggregationPolicies class final

The RegionHealthAggregationPolicies API.

Implementers

Constructors

RegionHealthAggregationPolicies({required Client client, Uri? endPoint, String? gcclVersion})
Creates a RegionHealthAggregationPolicies using client for transport.
RegionHealthAggregationPolicies.fromApiKey([String? apiKey])
Creates a RegionHealthAggregationPolicies that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(AggregatedListRegionHealthAggregationPoliciesRequest request) Future<HealthAggregationPolicyAggregatedList>
Retrieves the list of all HealthAggregationPolicy resources, regional and global, available to the specified project.
close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteRegionHealthAggregationPolicyRequest request) Future<Operation>
Deletes the specified HealthAggregationPolicy in the given region.
get(GetRegionHealthAggregationPolicyRequest request) Future<HealthAggregationPolicy>
Returns the specified HealthAggregationPolicy resource in the given region.
insert(InsertRegionHealthAggregationPolicyRequest request) Future<Operation>
Create a HealthAggregationPolicy in the specified project in the given region using the parameters that are included in the request.
list(ListRegionHealthAggregationPoliciesRequest request) Future<HealthAggregationPolicyList>
Lists the HealthAggregationPolicies for a project in the given region.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(PatchRegionHealthAggregationPolicyRequest request) Future<Operation>
Updates the specified regional HealthAggregationPolicy resource with the data included in the request. This method supportsPATCH semantics and uses theJSON merge patch format and processing rules.
testIamPermissions(TestIamPermissionsRegionHealthAggregationPolicyRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited