list method

Lists all the HealthCheckService resources that have been configured for the specified project in the given region.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<HealthCheckServicesList> list(
  ListRegionHealthCheckServicesRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/regions/${request.region}/healthCheckServices',
    queryParameters: {
      'filter': ?request.filter,
      if (request.maxResults case final $1?) 'maxResults': '${$1}',
      'orderBy': ?request.orderBy,
      'pageToken': ?request.pageToken,
      if (request.returnPartialSuccess case final $1?)
        'returnPartialSuccess': '${$1}',
    },
  );
  final response = await _client.get(url);
  return HealthCheckServicesList.fromJson(response);
}