RegionHealthChecks class final

The RegionHealthChecks API.

Implementers

Constructors

RegionHealthChecks({required Client client, Uri? endPoint, String? gcclVersion})
Creates a RegionHealthChecks using client for transport.
RegionHealthChecks.fromApiKey([String? apiKey])
Creates a RegionHealthChecks that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteRegionHealthCheckRequest request) Future<Operation>
Deletes the specified HealthCheck resource.
get(GetRegionHealthCheckRequest request) Future<HealthCheck>
Returns the specified HealthCheck resource.
insert(InsertRegionHealthCheckRequest request) Future<Operation>
Creates a HealthCheck resource in the specified project using the data included in the request.
list(ListRegionHealthChecksRequest request) Future<HealthCheckList>
Retrieves the list of HealthCheck resources available to the specified project.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(PatchRegionHealthCheckRequest request) Future<Operation>
Updates a HealthCheck resource in the specified project using the data included in the request. This method supportsPATCH semantics and uses theJSON merge patch format and processing rules.
testIamPermissions(TestIamPermissionsRegionHealthCheckRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
toString() String
A string representation of this object.
inherited
update(UpdateRegionHealthCheckRequest request) Future<Operation>
Updates a HealthCheck resource in the specified project using the data included in the request.

Operators

operator ==(Object other) bool
The equality operator.
inherited