RegionHealthSources class final
The RegionHealthSources API.
- Implementers
Constructors
- RegionHealthSources({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
RegionHealthSourcesusingclientfor transport. - RegionHealthSources.fromApiKey([String? apiKey])
-
Creates a
RegionHealthSourcesthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
aggregatedList(
AggregatedListRegionHealthSourcesRequest request) → Future< HealthSourceAggregatedList> - Retrieves the list of all HealthSource resources (all regional) available to the specified project.
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteRegionHealthSourceRequest request) → Future< Operation> - Deletes the specified HealthSource in the given region
-
get(
GetRegionHealthSourceRequest request) → Future< HealthSource> - Returns the specified HealthSource resource in the given region.
-
getHealth(
GetHealthRegionHealthSourceRequest request) → Future< HealthSourceHealth> - Gets the most recent health check results for this regional HealthSource.
-
insert(
InsertRegionHealthSourceRequest request) → Future< Operation> - Create a HealthSource in the specified project in the given region using the parameters that are included in the request.
-
list(
ListRegionHealthSourcesRequest request) → Future< HealthSourceList> - Lists the HealthSources for a project in the given region.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchRegionHealthSourceRequest request) → Future< Operation> - Updates the specified regional HealthSource resource with the data included in the request. This method supportsPATCH semantics and uses theJSON merge patch format and processing rules.
-
testIamPermissions(
TestIamPermissionsRegionHealthSourceRequest request) → Future< TestPermissionsResponse> - Returns permissions that a caller has on the specified resource.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited