getHealth method

Gets the most recent health check results for this regional HealthSource.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<HealthSourceHealth> getHealth(
  GetHealthRegionHealthSourceRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/regions/${request.region}/healthSources/${request.healthSource}/getHealth',
  );
  final response = await _client.get(url);
  return HealthSourceHealth.fromJson(response);
}