kind property
Output only. The resource type, which is always compute#instanceGroupManagerList for a list of managed instance groups that exist in th regional scope.
Implementation
final String? kind;
Output only. The resource type, which is always compute#instanceGroupManagerList for a list of managed instance groups that exist in th regional scope.
final String? kind;