RegionInstanceGroupManagerResizeRequests class final

The RegionInstanceGroupManagerResizeRequests API.

Implementers

Constructors

RegionInstanceGroupManagerResizeRequests({required Client client, Uri? endPoint, String? gcclVersion})
Creates a RegionInstanceGroupManagerResizeRequests using client for transport.
RegionInstanceGroupManagerResizeRequests.fromApiKey([String? apiKey])
Creates a RegionInstanceGroupManagerResizeRequests that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel(CancelRegionInstanceGroupManagerResizeRequestRequest request) Future<Operation>
Cancels the specified resize request. Cancelled resize request no longer waits for the resources to be provisioned. Cancel is only possible for requests that are in accepted state.
close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteRegionInstanceGroupManagerResizeRequestRequest request) Future<Operation>
Deletes the specified, inactive resize request. Requests that are still active cannot be deleted. Deleting request does not delete instances that were provisioned previously.
get(GetRegionInstanceGroupManagerResizeRequestRequest request) Future<InstanceGroupManagerResizeRequest>
Returns all of the details about the specified resize request.
insert(InsertRegionInstanceGroupManagerResizeRequestRequest request) Future<Operation>
Creates a new Resize Request that starts provisioning VMs immediately or queues VM creation.
list(ListRegionInstanceGroupManagerResizeRequestsRequest request) Future<RegionInstanceGroupManagerResizeRequestsListResponse>
Retrieves a list of Resize Requests that are contained in the managed instance group.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited