get method

Returns all of the details about the specified resize request.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<InstanceGroupManagerResizeRequest> get(
  GetRegionInstanceGroupManagerResizeRequestRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/regions/${request.region}/instanceGroupManagers/${request.instanceGroupManager}/resizeRequests/${request.resizeRequest}',
  );
  final response = await _client.get(url);
  return InstanceGroupManagerResizeRequest.fromJson(response);
}