applyUpdatesToInstances method

Apply updates to selected instances the managed instance group.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> applyUpdatesToInstances(
  ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/regions/${request.region}/instanceGroupManagers/${request.instanceGroupManager}/applyUpdatesToInstances',
  );
  final response = await _client.post(
    url,
    body: request.regionInstanceGroupManagersApplyUpdatesRequestResource,
  );
  return Operation.fromJson(response);
}