delete method

Deletes the specified managed instance group and all of the instances in that group.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> delete(
  DeleteRegionInstanceGroupManagerRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/regions/${request.region}/instanceGroupManagers/${request.instanceGroupManager}',
    queryParameters: {
      if (request.noGracefulShutdown case final $1?)
        'noGracefulShutdown': '${$1}',
      'requestId': ?request.requestId,
    },
  );
  final response = await _client.delete(url);
  return Operation.fromJson(response);
}