listManagedInstances method

Lists the instances in the managed instance group and instances that are scheduled to be created. The list includes any current actions that the group has scheduled for its instances. The orderBy query parameter is not supported. The pageToken query parameter is supported only if the group's listManagedInstancesResults field is set to PAGINATED.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<RegionInstanceGroupManagersListInstancesResponse> listManagedInstances(
  ListManagedInstancesRegionInstanceGroupManagersRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/regions/${request.region}/instanceGroupManagers/${request.instanceGroupManager}/listManagedInstances',
    queryParameters: {
      'filter': ?request.filter,
      if (request.maxResults case final $1?) 'maxResults': '${$1}',
      'orderBy': ?request.orderBy,
      'pageToken': ?request.pageToken,
      if (request.returnPartialSuccess case final $1?)
        'returnPartialSuccess': '${$1}',
    },
  );
  final response = await _client.post(url);
  return RegionInstanceGroupManagersListInstancesResponse.fromJson(response);
}