setTargetPools method

Modifies the target pools to which all new instances in this group are assigned. Existing instances in the group are not affected.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> setTargetPools(
  SetTargetPoolsRegionInstanceGroupManagerRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/regions/${request.region}/instanceGroupManagers/${request.instanceGroupManager}/setTargetPools',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.post(
    url,
    body: request.regionInstanceGroupManagersSetTargetPoolsRequestResource,
  );
  return Operation.fromJson(response);
}