RegionInstanceGroupManagersApplyUpdatesRequest class final
RegionInstanceGroupManagers.applyUpdatesToInstances
Constructors
-
RegionInstanceGroupManagersApplyUpdatesRequest({bool? allInstances, List<
String> instances = const [], String? minimalAction, String? mostDisruptiveAllowedAction}) - RegionInstanceGroupManagersApplyUpdatesRequest.fromJson(Object? j)
-
factory
Properties
- allInstances → bool?
-
Flag to update all instances instead of specified list of "instances".
If the flag is set to true then the instances may not be specified
in the request.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
instances
→ List<
String> -
The list of URLs of one or more instances for which you want to apply
updates. Each URL can be a full URL or a partial URL, such aszones/
ZONE/instances/INSTANCE_NAME.final - minimalAction → String?
-
The minimal action that you want to perform on each instance during the
update:
final
- mostDisruptiveAllowedAction → String?
-
The most disruptive action that you want to perform on each instance during
the update:
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String