RegionInstanceGroupManagersApplyUpdatesRequest_MinimalAction class final
The minimal action that you want to perform on each instance during the update:
- REPLACE: At minimum, delete the instance and create it
again.
- RESTART: Stop the instance and start it again.
- REFRESH: Do not stop the instance and limit disruption as much as possible.
- NONE: Do not disrupt the instance at all.
By default, the minimum action is NONE. If your update requires a more disruptive action than you set with this flag, the necessary action is performed to execute the update. Additional supported values which may be not listed in the enum directly due to technical reasons: NONE REFRESH REPLACE RESTART
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const RegionInstanceGroupManagersApplyUpdatesRequest_MinimalAction
- The default value for RegionInstanceGroupManagersApplyUpdatesRequest_MinimalAction.
- undefinedMinimalAction → const RegionInstanceGroupManagersApplyUpdatesRequest_MinimalAction
- A value indicating that the enum field is not set.