fingerprint property

String? fingerprint
final

Fingerprint of the target pools information, which is a hash of the contents. This field is used for optimistic locking when you update the target pool entries. This field is optional.

Implementation

final String? fingerprint;