instanceTemplate property
URL of the InstanceTemplate resource from which all new instances will be created.
Implementation
final String? instanceTemplate;
URL of the InstanceTemplate resource from which all new instances will be created.
final String? instanceTemplate;