RegionInstanceGroupManagersSuspendInstancesRequest class final

Properties

forceSuspend bool?
If this flag is set to true, the Instance Group Manager will proceed to suspend the instances, skipping initialization on them.
final
hashCode int
The hash code for this object.
no setterinherited
instances List<String>
The URLs of one or more instances to suspend. This can be a full URL or a partial URL, such as zones/ZONE/instances/INSTANCE_NAME.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String