forceSuspend property
If this flag is set to true, the Instance Group Manager will proceed to suspend the instances, skipping initialization on them.
Implementation
final bool? forceSuspend;
If this flag is set to true, the Instance Group Manager will proceed to suspend the instances, skipping initialization on them.
final bool? forceSuspend;