RegionInstanceGroups class final

The RegionInstanceGroups API.

Implementers

Constructors

RegionInstanceGroups({required Client client, Uri? endPoint, String? gcclVersion})
Creates a RegionInstanceGroups using client for transport.
RegionInstanceGroups.fromApiKey([String? apiKey])
Creates a RegionInstanceGroups that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
get(GetRegionInstanceGroupRequest request) Future<InstanceGroup>
Returns the specified instance group resource.
list(ListRegionInstanceGroupsRequest request) Future<RegionInstanceGroupList>
Retrieves the list of instance group resources contained within the specified region.
listInstances(ListInstancesRegionInstanceGroupsRequest request) Future<RegionInstanceGroupsListInstances>
Lists the instances in the specified instance group and displays information about the named ports. Depending on the specified options, this method can list all instances or only the instances that are running. The orderBy query parameter is not supported.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setNamedPorts(SetNamedPortsRegionInstanceGroupRequest request) Future<Operation>
Sets the named ports for the specified regional instance group.
testIamPermissions(TestIamPermissionsRegionInstanceGroupRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited