listInstances method
Lists the instances in the specified instance group and displays information about the named ports. Depending on the specified options, this method can list all instances or only the instances that are running. The orderBy query parameter is not supported.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
Future<RegionInstanceGroupsListInstances> listInstances(
ListInstancesRegionInstanceGroupsRequest request,
) async {
final url = _endPoint.replace(
path:
'/compute/v1/projects/${request.project}/regions/${request.region}/instanceGroups/${request.instanceGroup}/listInstances',
queryParameters: {
'filter': ?request.filter,
if (request.maxResults case final $1?) 'maxResults': '${$1}',
'orderBy': ?request.orderBy,
'pageToken': ?request.pageToken,
if (request.returnPartialSuccess case final $1?)
'returnPartialSuccess': '${$1}',
},
);
final response = await _client.post(
url,
body: request.regionInstanceGroupsListInstancesRequestResource,
);
return RegionInstanceGroupsListInstances.fromJson(response);
}