RegionInstanceGroupsListInstancesRequest_InstanceState class final

Instances in which state should be returned. Valid options are: 'ALL', 'RUNNING'. By default, it lists all instances.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const RegionInstanceGroupsListInstancesRequest_InstanceState
The default value for RegionInstanceGroupsListInstancesRequest_InstanceState.
all → const RegionInstanceGroupsListInstancesRequest_InstanceState
Matches any status of the instances, running, non-running and others.
running → const RegionInstanceGroupsListInstancesRequest_InstanceState
Instance is in RUNNING state if it is running.
undefinedInstanceState → const RegionInstanceGroupsListInstancesRequest_InstanceState
A value indicating that the enum field is not set.