RegionInstances class final

The RegionInstances API.

Implementers

Constructors

RegionInstances({required Client client, Uri? endPoint, String? gcclVersion})
Creates a RegionInstances using client for transport.
RegionInstances.fromApiKey([String? apiKey])
Creates a RegionInstances that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bulkInsert(BulkInsertRegionInstanceRequest request) Future<Operation>
Creates multiple instances in a given region. Count specifies the number of instances to create.
close() → void
Closes the client and cleans up any resources associated with it.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited