RegionInstantSnapshotGroups class final
The RegionInstantSnapshotGroups API.
- Implementers
Constructors
- RegionInstantSnapshotGroups({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
RegionInstantSnapshotGroupsusingclientfor transport. - RegionInstantSnapshotGroups.fromApiKey([String? apiKey])
-
Creates a
RegionInstantSnapshotGroupsthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteRegionInstantSnapshotGroupRequest request) → Future< Operation> - deletes a Regional InstantSnapshotGroup resource
-
get(
GetRegionInstantSnapshotGroupRequest request) → Future< InstantSnapshotGroup> - returns the specified InstantSnapshotGroup resource in the specified region.
-
getIamPolicy(
GetIamPolicyRegionInstantSnapshotGroupRequest request) → Future< Policy> - Gets the access control policy for a resource. May be empty if no such policy or resource exists.
-
insert(
InsertRegionInstantSnapshotGroupRequest request) → Future< Operation> - creates a Regional InstantSnapshotGroup resource
-
list(
ListRegionInstantSnapshotGroupsRequest request) → Future< ListInstantSnapshotGroups> - retrieves the list of InstantSnapshotGroup resources contained within the specified region.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setIamPolicy(
SetIamPolicyRegionInstantSnapshotGroupRequest request) → Future< Policy> - Sets the access control policy on the specified resource. Replaces any existing policy.
-
testIamPermissions(
TestIamPermissionsRegionInstantSnapshotGroupRequest request) → Future< TestPermissionsResponse> - Returns permissions that a caller has on the specified resource.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited