attachNetworkEndpoints method

Attach a list of network endpoints to the specified network endpoint group.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> attachNetworkEndpoints(
  AttachNetworkEndpointsRegionNetworkEndpointGroupRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/regions/${request.region}/networkEndpointGroups/${request.networkEndpointGroup}/attachNetworkEndpoints',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.post(
    url,
    body: request.regionNetworkEndpointGroupsAttachEndpointsRequestResource,
  );
  return Operation.fromJson(response);
}