addAssociation method

Inserts an association for the specified network firewall policy.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> addAssociation(
  AddAssociationRegionNetworkFirewallPolicyRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/regions/${request.region}/firewallPolicies/${request.firewallPolicy}/addAssociation',
    queryParameters: {
      if (request.replaceExistingAssociation case final $1?)
        'replaceExistingAssociation': '${$1}',
      'requestId': ?request.requestId,
    },
  );
  final response = await _client.post(
    url,
    body: request.firewallPolicyAssociationResource,
  );
  return Operation.fromJson(response);
}