insert method

Creates a new network firewall policy in the specified project and region.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> insert(
  InsertRegionNetworkFirewallPolicyRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/regions/${request.region}/firewallPolicies',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.post(
    url,
    body: request.firewallPolicyResource,
  );
  return Operation.fromJson(response);
}