RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy class
final
Properties
displayName
→ String ?
Output only. Output Only The display name of the firewall policy.
final
hashCode
→ int
The hash code for this object.
no setter inherited
name
→ String ?
Output only. Output Only The name of the firewall policy.
final
packetMirroringRules
→ List <FirewallPolicyRule >
Output only. Output only The packet mirroring rules that apply to the network.
final
priority
→ int ?
Output only. Output only Priority of firewall policy association. Not applicable for
type=HIERARCHY.
final
qualifiedName
→ String
The fully qualified name of this message, i.e., google.protobuf.Duration
or google.rpc.ErrorInfo.
final inherited
rules
→ List <FirewallPolicyRule >
Output only. Output only The rules that apply to the network.
final
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
type
→ String ?
Output only. Output Only The type of the firewall policy. Can be one of HIERARCHY,
NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL.
Check the Type enum for the list of possible values.
final
google_cloud_compute_v1 0.1.1