RegionSecurityPolicies class final

The RegionSecurityPolicies API.

Implementers

Constructors

RegionSecurityPolicies({required Client client, Uri? endPoint, String? gcclVersion})
Creates a RegionSecurityPolicies using client for transport.
RegionSecurityPolicies.fromApiKey([String? apiKey])
Creates a RegionSecurityPolicies that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRule(AddRuleRegionSecurityPolicyRequest request) Future<Operation>
Inserts a rule into a security policy.
close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteRegionSecurityPolicyRequest request) Future<Operation>
Deletes the specified policy.
get(GetRegionSecurityPolicyRequest request) Future<SecurityPolicy>
List all of the ordered rules present in a single specified policy.
getRule(GetRuleRegionSecurityPolicyRequest request) Future<SecurityPolicyRule>
Gets a rule at the specified priority.
insert(InsertRegionSecurityPolicyRequest request) Future<Operation>
Creates a new policy in the specified project using the data included in the request.
list(ListRegionSecurityPoliciesRequest request) Future<SecurityPolicyList>
List all the policies that have been configured for the specified project and region.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(PatchRegionSecurityPolicyRequest request) Future<Operation>
Patches the specified policy with the data included in the request. To clear fields in the policy, leave the fields empty and specify them in the updateMask. This cannot be used to be update the rules in the policy. Please use the per rule methods like addRule, patchRule, and removeRule instead.
patchRule(PatchRuleRegionSecurityPolicyRequest request) Future<Operation>
Patches a rule at the specified priority. To clear fields in the rule, leave the fields empty and specify them in the updateMask.
removeRule(RemoveRuleRegionSecurityPolicyRequest request) Future<Operation>
Deletes a rule at the specified priority.
setLabels(SetLabelsRegionSecurityPolicyRequest request) Future<Operation>
Sets the labels on a security policy. To learn more about labels, read the Labeling Resources documentation.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited