insert method

Creates a new policy in the specified project using the data included in the request.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> insert(InsertRegionSecurityPolicyRequest request) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/regions/${request.region}/securityPolicies',
    queryParameters: {
      'requestId': ?request.requestId,
      if (request.validateOnly case final $1?) 'validateOnly': '${$1}',
    },
  );
  final response = await _client.post(
    url,
    body: request.securityPolicyResource,
  );
  return Operation.fromJson(response);
}