patchRule method

Patches a rule at the specified priority. To clear fields in the rule, leave the fields empty and specify them in the updateMask.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> patchRule(
  PatchRuleRegionSecurityPolicyRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/regions/${request.region}/securityPolicies/${request.securityPolicy}/patchRule',
    queryParameters: {
      if (request.priority case final $1?) 'priority': '${$1}',
      'updateMask': ?request.updateMask,
      if (request.validateOnly case final $1?) 'validateOnly': '${$1}',
    },
  );
  final response = await _client.post(
    url,
    body: request.securityPolicyRuleResource,
  );
  return Operation.fromJson(response);
}