RegionSslCertificates class final

The RegionSslCertificates API.

Implementers

Constructors

RegionSslCertificates({required Client client, Uri? endPoint, String? gcclVersion})
Creates a RegionSslCertificates using client for transport.
RegionSslCertificates.fromApiKey([String? apiKey])
Creates a RegionSslCertificates that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteRegionSslCertificateRequest request) Future<Operation>
Deletes the specified SslCertificate resource in the region.
get(GetRegionSslCertificateRequest request) Future<SslCertificate>
Returns the specified SslCertificate resource in the specified region. Get a list of available SSL certificates by making a list() request.
insert(InsertRegionSslCertificateRequest request) Future<Operation>
Creates a SslCertificate resource in the specified project and region using the data included in the request
list(ListRegionSslCertificatesRequest request) Future<SslCertificateList>
Retrieves the list of SslCertificate resources available to the specified project in the specified region.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited