RegionSslPolicies class final

The RegionSslPolicies API.

Implementers

Constructors

RegionSslPolicies({required Client client, Uri? endPoint, String? gcclVersion})
Creates a RegionSslPolicies using client for transport.
RegionSslPolicies.fromApiKey([String? apiKey])
Creates a RegionSslPolicies that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteRegionSslPolicyRequest request) Future<Operation>
Deletes the specified SSL policy. The SSL policy resource can be deleted only if it is not in use by any TargetHttpsProxy or TargetSslProxy resources.
get(GetRegionSslPolicyRequest request) Future<SslPolicy>
Lists all of the ordered rules present in a single specified policy.
insert(InsertRegionSslPolicyRequest request) Future<Operation>
Creates a new policy in the specified project and region using the data included in the request.
list(ListRegionSslPoliciesRequest request) Future<SslPoliciesList>
Lists all the SSL policies that have been configured for the specified project and region.
listAvailableFeatures(ListAvailableFeaturesRegionSslPoliciesRequest request) Future<SslPoliciesListAvailableFeaturesResponse>
Lists all features that can be specified in the SSL policy when using custom profile.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(PatchRegionSslPolicyRequest request) Future<Operation>
Patches the specified SSL policy with the data included in the request.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited