RegionTargetHttpProxies class final

The RegionTargetHttpProxies API.

Implementers

Constructors

RegionTargetHttpProxies({required Client client, Uri? endPoint, String? gcclVersion})
Creates a RegionTargetHttpProxies using client for transport.
RegionTargetHttpProxies.fromApiKey([String? apiKey])
Creates a RegionTargetHttpProxies that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteRegionTargetHttpProxyRequest request) Future<Operation>
Deletes the specified TargetHttpProxy resource.
get(GetRegionTargetHttpProxyRequest request) Future<TargetHttpProxy>
Returns the specified TargetHttpProxy resource in the specified region.
insert(InsertRegionTargetHttpProxyRequest request) Future<Operation>
Creates a TargetHttpProxy resource in the specified project and region using the data included in the request.
list(ListRegionTargetHttpProxiesRequest request) Future<TargetHttpProxyList>
Retrieves the list of TargetHttpProxy resources available to the specified project in the specified region.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setUrlMap(SetUrlMapRegionTargetHttpProxyRequest request) Future<Operation>
Changes the URL map for TargetHttpProxy.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited