RegionTargetTcpProxies class final

The RegionTargetTcpProxies API.

Implementers

Constructors

RegionTargetTcpProxies({required Client client, Uri? endPoint, String? gcclVersion})
Creates a RegionTargetTcpProxies using client for transport.
RegionTargetTcpProxies.fromApiKey([String? apiKey])
Creates a RegionTargetTcpProxies that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteRegionTargetTcpProxyRequest request) Future<Operation>
Deletes the specified TargetTcpProxy resource.
get(GetRegionTargetTcpProxyRequest request) Future<TargetTcpProxy>
Returns the specified TargetTcpProxy resource.
insert(InsertRegionTargetTcpProxyRequest request) Future<Operation>
Creates a TargetTcpProxy resource in the specified project and region using the data included in the request.
list(ListRegionTargetTcpProxiesRequest request) Future<TargetTcpProxyList>
Retrieves a list of TargetTcpProxy resources available to the specified project in a given region.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited