RegionUrlMaps class final
The RegionUrlMaps API.
- Implementers
Constructors
- RegionUrlMaps({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
RegionUrlMapsusingclientfor transport. - RegionUrlMaps.fromApiKey([String? apiKey])
-
Creates a
RegionUrlMapsthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteRegionUrlMapRequest request) → Future< Operation> - Deletes the specified UrlMap resource.
-
get(
GetRegionUrlMapRequest request) → Future< UrlMap> - Returns the specified UrlMap resource.
-
insert(
InsertRegionUrlMapRequest request) → Future< Operation> - Creates a UrlMap resource in the specified project using the data included in the request.
-
list(
ListRegionUrlMapsRequest request) → Future< UrlMapList> - Retrieves the list of UrlMap resources available to the specified project in the specified region.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchRegionUrlMapRequest request) → Future< Operation> - Patches the specified UrlMap resource with the data included in the request. This method supportsPATCH semantics and usesJSON merge patch format and processing rules.
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
UpdateRegionUrlMapRequest request) → Future< Operation> - Updates the specified UrlMap resource with the data included in the request.
-
validate(
ValidateRegionUrlMapRequest request) → Future< UrlMapsValidateResponse> - Runs static validation for the UrlMap. In particular, the tests of the provided UrlMap will be run. Calling this method does NOT create the UrlMap.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited