RegionZones class final

The RegionZones API.

Implementers

Constructors

RegionZones({required Client client, Uri? endPoint, String? gcclVersion})
Creates a RegionZones using client for transport.
RegionZones.fromApiKey([String? apiKey])
Creates a RegionZones that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
list(ListRegionZonesRequest request) Future<ZoneList>
Retrieves the list of Zone resources under the specific region available to the specified project.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited