Region_Status class final

Output Only Status of the region, either UP orDOWN.

Constructors

Region_Status(String value)
const
Region_Status.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const Region_Status
The default value for Region_Status.
down → const Region_Status
undefinedStatus → const Region_Status
A value indicating that the enum field is not set.
up → const Region_Status