Regions class final

The Regions API.

Implementers

Constructors

Regions({required Client client, Uri? endPoint, String? gcclVersion})
Creates a Regions using client for transport.
Regions.fromApiKey([String? apiKey])
Creates a Regions that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
get(GetRegionRequest request) Future<Region>
Returns the specified Region resource.
list(ListRegionsRequest request) Future<RegionList>
Retrieves the list of region resources available to the specified project.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited