get method
Returns the specified Region resource.
To decrease latency for this method, you can optionally omit any unneeded
information from the response by using a field mask. This practice is
especially recommended for unused quota information (the quotas field).
To exclude one or more fields, set your request's fields query parameter
to only include the fields you need. For example, to only include the id
and selfLink fields, add the query parameter ?fields=id,selfLink to
your request.
This method fails if the quota information is unavailable for the region
and if the organization policy constraint
compute.requireBasicQuotaInResponse is enforced. This
constraint, when enforced, disables the fail-open behaviour when quota
information (the items.quotas field) is unavailable for the region.
It is recommended to use the default setting
for the constraint unless your application requires the fail-closed
behaviour for this method.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
Future<Region> get(GetRegionRequest request) async {
final url = _endPoint.replace(
path: '/compute/v1/projects/${request.project}/regions/${request.region}',
);
final response = await _client.get(url);
return Region.fromJson(response);
}