ReliabilityRisk class final

Represents a ReliabilityRisk resource.

Constructors

ReliabilityRisk({String? creationTimestamp, String? description, RiskDetails? details, BigInt? id, String? kind, String? name, RiskRecommendation? recommendation, String? selfLink, String? selfLinkWithId})
ReliabilityRisk.fromJson(Object? j)
factory

Properties

creationTimestamp String?
Output only. Output Only Creation timestamp in RFC3339 text format.
final
description String?
An optional textual description of the resource; provided when the resource is created.
final
details RiskDetails?
Output Only Details of the reliability risk resource
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output Only The unique identifier for the resource. This identifier is defined by the server.
final
kind String?
Output only. Output Only Type of resource. Always compute#reliabilityRisk for reliability risks.
final
name String?
Name of the resource. The name must be 1-63 characters long and comply with RFC1035.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
recommendation RiskRecommendation?
The recommendation to mitigate the risk.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output only. Output Only Server-defined URL for the resource.
final
selfLinkWithId String?
Output only. Output Only Server-defined URL for this resource with the resource id.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String