ReliabilityRisks class final

The ReliabilityRisks API.

Implementers

Constructors

ReliabilityRisks({required Client client, Uri? endPoint, String? gcclVersion})
Creates a ReliabilityRisks using client for transport.
ReliabilityRisks.fromApiKey([String? apiKey])
Creates a ReliabilityRisks that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
get(GetReliabilityRiskRequest request) Future<ReliabilityRisk>
Returns the specified ReliabilityRisk resource.
list(ListReliabilityRisksRequest request) Future<ReliabilityRisksListResponse>
Retrieves the list of reliabilityRisks available in the specified project.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited