ReliabilityRisksListResponse class final
Response message for the List method of ReliabilityRisksService.
Constructors
-
ReliabilityRisksListResponse({String? etag, String? id, List<
ReliabilityRisk> items = const [], String? nextPageToken, String? selfLink, List<String> unreachables = const [], Warning? warning}) - ReliabilityRisksListResponse.fromJson(Object? j)
-
factory
Properties
- etag → String?
-
Output OnlyAn ETag of the resource.final - hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
Output OnlyUnique identifier for the resource; defined by the server.final -
items
→ List<
ReliabilityRisk> -
A list of ReliabilityRisk resources.
final
- nextPageToken → String?
-
Output OnlyThis token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfLink → String?
-
Output only.
Output OnlyServer-defined URL for this resource.final -
unreachables
→ List<
String> -
Output only.
Output OnlyUnreachable resources. end_interface: MixerListResponseWithEtagBuilderfinal - warning → Warning?
-
Output OnlyInformational warning message.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String