instanceGroup property
The name of the instance group where the specified instances will be removed.
Implementation
final String instanceGroup;
The name of the instance group where the specified instances will be removed.
final String instanceGroup;