RemoveRuleRegionSecurityPolicyRequest class final

A request message for RegionSecurityPolicies.RemoveRule. See the method description for details.

Constructors

RemoveRuleRegionSecurityPolicyRequest({int? priority, required String project, required String region, required String securityPolicy})
RemoveRuleRegionSecurityPolicyRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
priority int?
The priority of the rule to remove from the security policy.
final
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
region String
Name of the region scoping this request.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
securityPolicy String
Name of the security policy to update.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String