RequestMirrorPolicy class final

A policy that specifies how requests intended for the route's backends are shadowed to a separate mirrored backend service. The load balancer doesn't wait for responses from the shadow service. Before sending traffic to the shadow service, the host or authority header is suffixed with-shadow.

Constructors

RequestMirrorPolicy({String? backendService, double? mirrorPercent})
RequestMirrorPolicy.fromJson(Object? j)
factory

Properties

backendService String?
The full or partial URL to the BackendService resource being mirrored to.
final
hashCode int
The hash code for this object.
no setterinherited
mirrorPercent double?
The percentage of requests to be mirrored to backend_service.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String