advancedDeploymentControl property
Advanced control for cluster management, applicable only to DENSE deployment type reservations.
Implementation
final ReservationAdvancedDeploymentControl? advancedDeploymentControl;
Advanced control for cluster management, applicable only to DENSE deployment type reservations.
final ReservationAdvancedDeploymentControl? advancedDeploymentControl;