commitment property
Output only. Output Only Full or partial URL to a parent commitment. This field
displays for reservations that are tied to a commitment.
Implementation
final String? commitment;
Output only. Output Only Full or partial URL to a parent commitment. This field
displays for reservations that are tied to a commitment.
final String? commitment;