earlyAccessMaintenance property

String? earlyAccessMaintenance
final

Indicates the early access maintenance for the reservation. If this field is absent or set to NO_EARLY_ACCESS, the reservation is not enrolled in early access maintenance and the standard notice applies. Check the EarlyAccessMaintenance enum for the list of possible values.

Implementation

final String? earlyAccessMaintenance;