params property
Input only. Additional params passed with the request, but not persisted as part of resource payload.
Implementation
final ReservationParams? params;
Input only. Additional params passed with the request, but not persisted as part of resource payload.
final ReservationParams? params;