reservationSharingPolicy property
Specify the reservation sharing policy. If unspecified, the reservation will not be shared with Google Cloud managed services.
Implementation
final AllocationReservationSharingPolicy? reservationSharingPolicy;
Specify the reservation sharing policy. If unspecified, the reservation will not be shared with Google Cloud managed services.
final AllocationReservationSharingPolicy? reservationSharingPolicy;