ReservationAdvancedDeploymentControl class final
Advance control for cluster management, applicable only to DENSE deployment type reservations.
Constructors
- ReservationAdvancedDeploymentControl({String? reservationOperationalMode})
- ReservationAdvancedDeploymentControl.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - reservationOperationalMode → String?
-
Indicates chosen reservation operational mode for the reservation.
Check the ReservationOperationalMode enum for the list of possible values.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String