allCapacity constant

Google Cloud does not manage the failure of machines, but provides additional capacity, which is not guaranteed to be available.

Implementation

static const allCapacity =
    ReservationAdvancedDeploymentControl_ReservationOperationalMode(
      'ALL_CAPACITY',
    );