ReservationAffinity class final
Specifies the reservations that this instance can consume from.
Constructors
-
ReservationAffinity({String? consumeReservationType, String? key, List<
String> values = const []}) - ReservationAffinity.fromJson(Object? j)
-
factory
Properties
- consumeReservationType → String?
-
Specifies the type of reservation from which this instance can consume
resources: ANY_RESERVATION (default),SPECIFIC_RESERVATION, or NO_RESERVATION. See
Consuming reserved instances for examples.
Check the ConsumeReservationType enum for the list of possible values.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String?
-
Corresponds to the label key of a reservation resource. To target aSPECIFIC_RESERVATION by name, specifygoogleapis.com/reservation-name as the key and specify
the name of your reservation as its value.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
values
→ List<
String> -
Corresponds to the label values of a reservation resource. This can be
either a name to a reservation in the same project or
"projects/different-project/reservations/some-reservation-name" to target a
shared reservation in the same zone but in a different project.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String