ReservationBlock class final

Represents a reservation block resource.

Constructors

ReservationBlock({int? count, String? creationTimestamp, ReservationBlockHealthInfo? healthInfo, BigInt? id, int? inUseCount, int? inUseHostCount, String? kind, String? name, ReservationBlockPhysicalTopology? physicalTopology, GroupMaintenanceInfo? reservationMaintenance, int? reservationSubBlockCount, int? reservationSubBlockInUseCount, String? selfLink, String? selfLinkWithId, String? status, String? zone})
ReservationBlock.fromJson(Object? j)
factory

Properties

count int?
Output only. Output Only The number of resources that are allocated in this reservation block.
final
creationTimestamp String?
Output only. Output Only Creation timestamp inRFC3339 text format.
final
hashCode int
The hash code for this object.
no setterinherited
healthInfo ReservationBlockHealthInfo?
Output only. Output Only Health information for the reservation block.
final
id BigInt?
Output only. Output Only The unique identifier for the resource. This identifier is defined by the server.
final
inUseCount int?
Output only. Output Only The number of instances that are currently in use on this reservation block.
final
inUseHostCount int?
Output only. Number of hosts currently in use. If there is one or more Instances running on the host, it is considered in use.
final
kind String?
Output only. Output Only Type of the resource. Alwayscompute#reservationBlock for reservation blocks.
final
name String?
Output only. Output Only The name of this reservation block generated by Google Compute Engine. The name must be 1-63 characters long, and comply with RFC1035 @pattern a-z?
final
physicalTopology ReservationBlockPhysicalTopology?
Output only. Output Only The physical topology of the reservation block.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
reservationMaintenance GroupMaintenanceInfo?
Output only. Output Only Maintenance information for this reservation block.
final
reservationSubBlockCount int?
Output only. Output Only The number of reservation subBlocks associated with this reservation block.
final
reservationSubBlockInUseCount int?
Output only. Output Only The number of in-use reservation subBlocks associated with this reservation block. If at least one VM is running on a subBlock, it is considered in-use.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output only. Output Only Server-defined fully-qualified URL for this resource.
final
selfLinkWithId String?
Output only. Output Only Server-defined URL for this resource with the resource id.
final
status String?
Output only. Output Only Status of the reservation block. Check the Status enum for the list of possible values.
final
zone String?
Output only. Output Only Zone in which the reservation block resides.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String