count property
Output only. Output Only The number of resources that are allocated in this
reservation block.
Implementation
final int? count;
Output only. Output Only The number of resources that are allocated in this
reservation block.
final int? count;