inUseCount property
Output only. Output Only The number of instances that are currently in use on this
reservation block.
Implementation
final int? inUseCount;
Output only. Output Only The number of instances that are currently in use on this
reservation block.
final int? inUseCount;