toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (count != null) 'count=$count',
    if (creationTimestamp != null) 'creationTimestamp=$creationTimestamp',
    if (id != null) 'id=$id',
    if (inUseCount != null) 'inUseCount=$inUseCount',
    if (inUseHostCount != null) 'inUseHostCount=$inUseHostCount',
    if (kind != null) 'kind=$kind',
    if (name != null) 'name=$name',
    if (reservationSubBlockCount != null)
      'reservationSubBlockCount=$reservationSubBlockCount',
    if (reservationSubBlockInUseCount != null)
      'reservationSubBlockInUseCount=$reservationSubBlockInUseCount',
    if (selfLink != null) 'selfLink=$selfLink',
    if (selfLinkWithId != null) 'selfLinkWithId=$selfLinkWithId',
    if (status != null) 'status=$status',
    if (zone != null) 'zone=$zone',
  ].join(',');
  return 'ReservationBlock(${$contents})';
}