ReservationBlockHealthInfo class final

Health information for the reservation block.

Constructors

ReservationBlockHealthInfo({int? degradedSubBlockCount, String? healthStatus, int? healthySubBlockCount})
ReservationBlockHealthInfo.fromJson(Object? j)
factory

Properties

degradedSubBlockCount int?
The number of subBlocks that are degraded.
final
hashCode int
The hash code for this object.
no setterinherited
healthStatus String?
The health status of the reservation block. Check the HealthStatus enum for the list of possible values.
final
healthySubBlockCount int?
The number of subBlocks that are healthy.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String