ReservationBlockPhysicalTopology class final

Properties

block String?
The hash of the capacity block within the cluster.
final
cluster String?
The cluster name of the reservation block.
final
hashCode int
The hash code for this object.
no setterinherited
instances List<ReservationBlockPhysicalTopologyInstance>
Output only. The detailed instances information for a given Block
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String