ReservationBlock_Status class final

Output only. Output Only Status of the reservation block.

Constructors

ReservationBlock_Status(String value)
const
ReservationBlock_Status.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const ReservationBlock_Status
The default value for ReservationBlock_Status.
creating → const ReservationBlock_Status
Resources are being allocated for the reservation block.
deleting → const ReservationBlock_Status
Reservation block is currently being deleted.
invalid → const ReservationBlock_Status
ready → const ReservationBlock_Status
Reservation block has allocated all its resources.
undefinedStatus → const ReservationBlock_Status
A value indicating that the enum field is not set.