ReservationSlot class final

Represents a reservation slot resource.

Constructors

ReservationSlot({String? creationTimestamp, BigInt? id, String? kind, String? name, ReservationSlotPhysicalTopology? physicalTopology, String? selfLink, String? selfLinkWithId, ShareSettings? shareSettings, String? state, ReservationSlotStatus? status, String? zone})
ReservationSlot.fromJson(Object? j)
factory

Properties

creationTimestamp String?
Output only. Output Only The creation timestamp, formatted asRFC3339 text.
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output only. Output Only The unique identifier for this resource. This identifier is defined by the server.
final
kind String?
Output only. Output Only The type of resource. Alwayscompute#reservationSlot for reservation slots.
final
name String?
Output only. Output Only The name of the reservation slot.
final
physicalTopology ReservationSlotPhysicalTopology?
Output only. Output Only The physical topology of the reservation slot.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output only. Output Only A server-defined fully-qualified URL for this resource.
final
selfLinkWithId String?
Output only. Output Only A server-defined URL for this resource with the resource ID.
final
shareSettings ShareSettings?
Specify share settings to create a shared slot. Set to empty to inherit the share settings from a parent resource.
final
state String?
Output only. Output Only The state of the reservation slot. Check the State enum for the list of possible values.
final
status ReservationSlotStatus?
Output only. Output Only The status of the reservation slot.
final
zone String?
Output only. Output Only The zone in which the reservation slot resides.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String