physicalTopology property
Output only. Output Only The physical topology of the reservation slot.
Implementation
final ReservationSlotPhysicalTopology? physicalTopology;
Output only. Output Only The physical topology of the reservation slot.
final ReservationSlotPhysicalTopology? physicalTopology;