shareSettings property
Specify share settings to create a shared slot. Set to empty to inherit the share settings from a parent resource.
Implementation
final ShareSettings? shareSettings;
Specify share settings to create a shared slot. Set to empty to inherit the share settings from a parent resource.
final ShareSettings? shareSettings;