state property
Output only. Output Only The state of the reservation slot.
Check the State enum for the list of possible values.
Implementation
final String? state;
Output only. Output Only The state of the reservation slot.
Check the State enum for the list of possible values.
final String? state;