ReservationSlotPhysicalTopology class final

Constructors

ReservationSlotPhysicalTopology({String? block, String? cluster, String? host, String? subBlock})
ReservationSlotPhysicalTopology.fromJson(Object? j)
factory

Properties

block String?
The unique identifier of the capacity block within the cluster.
final
cluster String?
The cluster name of the reservation sub-block.
final
hashCode int
The hash code for this object.
no setterinherited
host String?
The unique identifier of the capacity host within the capacity sub-block.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subBlock String?
The unique identifier of the capacity sub-block within the capacity block.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String