physicalTopology property
Output only. Output Only The physical topology of the reservation sub-block.
Implementation
final ReservationSlotPhysicalTopology? physicalTopology;
Output only. Output Only The physical topology of the reservation sub-block.
final ReservationSlotPhysicalTopology? physicalTopology;