ReservationSlot_State class final
Output only. Output Only The state of the reservation slot.
Constructors
- ReservationSlot_State(String value)
-
const
- ReservationSlot_State.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const ReservationSlot_State
- The default value for ReservationSlot_State.
- active → const ReservationSlot_State
- The reservation slot has allocated all its resources.
- creating → const ReservationSlot_State
- The resources are being allocated for the reservation slot.
- deleting → const ReservationSlot_State
- The reservation slot is currently being deleted.
- stateUnspecified → const ReservationSlot_State
- The reservation slot is currently unavailable.
- undefinedState → const ReservationSlot_State
- A value indicating that the enum field is not set.