creating constant
ReservationSlot_State
const creating
The resources are being allocated for the reservation slot.
Implementation
static const creating = ReservationSlot_State('CREATING');
The resources are being allocated for the reservation slot.
static const creating = ReservationSlot_State('CREATING');