ReservationSlotsListResponse class final

A list of reservation slots within a single reservation.

Constructors

ReservationSlotsListResponse({String? id, List<ReservationSlot> items = const [], String? kind, String? nextPageToken, String? selfLink, Warning? warning})
ReservationSlotsListResponse.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String?
The unique identifier for the resource; defined by the server.
final
items List<ReservationSlot>
A list of reservation slot resources.
final
kind String?
The type of resource. Alwayscompute#reservationSlot for a list of reservation slots.
final
nextPageToken String?
This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
The server-defined URL for this resource.
final
warning Warning?
An informational warning message.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String