ReservationSubBlock class final

Represents a reservation subBlock resource.

Constructors

ReservationSubBlock({AcceleratorTopologiesInfo? acceleratorTopologiesInfo, int? count, String? creationTimestamp, ReservationSubBlockHealthInfo? healthInfo, BigInt? id, int? inUseCount, int? inUseHostCount, String? kind, String? name, ReservationSubBlockPhysicalTopology? physicalTopology, GroupMaintenanceInfo? reservationSubBlockMaintenance, String? selfLink, String? selfLinkWithId, String? status, String? zone})
ReservationSubBlock.fromJson(Object? j)
factory

Properties

acceleratorTopologiesInfo AcceleratorTopologiesInfo?
Output only. Output Only Slice info for the reservation subBlock.
final
count int?
Output only. Output Only The number of hosts that are allocated in this reservation subBlock.
final
creationTimestamp String?
Output only. Output Only Creation timestamp inRFC3339 text format.
final
hashCode int
The hash code for this object.
no setterinherited
healthInfo ReservationSubBlockHealthInfo?
Output only. Output Only Health information for the reservation subBlock.
final
id BigInt?
Output only. Output Only The unique identifier for the resource. This identifier is defined by the server.
final
inUseCount int?
Output only. Output Only The number of instances that are currently in use on this reservation subBlock.
final
inUseHostCount int?
Output only. Number of hosts currently in use. If there is one or more Instances running on the host, it is considered in use.
final
kind String?
Output only. Output Only Type of the resource. Alwayscompute#reservationSubBlock for reservation subBlocks.
final
name String?
Output only. Output Only The name of this reservation subBlock generated by Google Compute Engine. The name must be 1-63 characters long, and comply with RFC1035 @pattern a-z?
final
physicalTopology ReservationSubBlockPhysicalTopology?
Output only. Output Only The physical topology of the reservation subBlock.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
reservationSubBlockMaintenance GroupMaintenanceInfo?
Output only. Maintenance information for this reservation subBlock.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output only. Output Only Server-defined fully-qualified URL for this resource.
final
selfLinkWithId String?
Output only. Output Only Server-defined URL for this resource with the resource id.
final
status String?
Output only. Output Only Status of the reservation subBlock. Check the Status enum for the list of possible values.
final
zone String?
Output only. Output Only Zone in which the reservation subBlock resides.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String