count property
Output only. Output Only The number of hosts that are allocated in this
reservation subBlock.
Implementation
final int? count;
Output only. Output Only The number of hosts that are allocated in this
reservation subBlock.
final int? count;