inUseCount property
Output only. Output Only The number of instances that are currently in use on this
reservation subBlock.
Implementation
final int? inUseCount;
Output only. Output Only The number of instances that are currently in use on this
reservation subBlock.
final int? inUseCount;