inUseHostCount property
Output only. Number of hosts currently in use. If there is one or more Instances running on the host, it is considered in use.
Implementation
final int? inUseHostCount;
Output only. Number of hosts currently in use. If there is one or more Instances running on the host, it is considered in use.
final int? inUseHostCount;