ReservationSubBlockHealthInfo class final

Health information for the reservation subBlock.

Constructors

ReservationSubBlockHealthInfo({int? degradedHostCount, int? degradedInfraCount, String? healthStatus, int? healthyHostCount, int? healthyInfraCount})
ReservationSubBlockHealthInfo.fromJson(Object? j)
factory

Properties

degradedHostCount int?
The number of degraded hosts in the reservation subBlock.
final
degradedInfraCount int?
The number of degraded infrastructure (e.g NV link domain) in the reservation subblock.
final
hashCode int
The hash code for this object.
no setterinherited
healthStatus String?
The health status of the reservation subBlock. Check the HealthStatus enum for the list of possible values.
final
healthyHostCount int?
The number of healthy hosts in the reservation subBlock.
final
healthyInfraCount int?
The number of healthy infrastructure (e.g NV link domain) in the reservation subblock.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String