ReservationSubBlockPhysicalTopology class
final
Properties
-
block
→ String?
-
The hash of the capacity block within the cluster.
final
-
cluster
→ String?
-
The cluster name of the reservation subBlock.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
qualifiedName
→ String
-
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or google.rpc.ErrorInfo.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
subBlock
→ String?
-
The hash of the capacity sub-block within the capacity block.
final