ReservationSubBlock_Status class final

Output only. Output Only Status of the reservation subBlock.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const ReservationSubBlock_Status
The default value for ReservationSubBlock_Status.
creating → const ReservationSubBlock_Status
Resources are being allocated for the reservation subBlock.
deleting → const ReservationSubBlock_Status
Reservation subBlock is currently being deleted.
invalid → const ReservationSubBlock_Status
ready → const ReservationSubBlock_Status
Reservation subBlock has allocated all its resources.
undefinedStatus → const ReservationSubBlock_Status
A value indicating that the enum field is not set.