ReservationSubBlocks class final

The ReservationSubBlocks API.

Implementers

Constructors

ReservationSubBlocks({required Client client, Uri? endPoint, String? gcclVersion})
Creates a ReservationSubBlocks using client for transport.
ReservationSubBlocks.fromApiKey([String? apiKey])
Creates a ReservationSubBlocks that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
get(GetReservationSubBlockRequest request) Future<ReservationSubBlocksGetResponse>
Retrieves information about the specified reservation subBlock.
getIamPolicy(GetIamPolicyReservationSubBlockRequest request) Future<Policy>
Gets the access control policy for a resource. May be empty if no such policy or resource exists.
getVersion(GetVersionReservationSubBlockRequest request) Future<Operation>
Allows customers to get SBOM versions of a reservation subBlock.
list(ListReservationSubBlocksRequest request) Future<ReservationSubBlocksListResponse>
Retrieves a list of reservation subBlocks under a single reservation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
performMaintenance(PerformMaintenanceReservationSubBlockRequest request) Future<Operation>
Allows customers to perform maintenance on a reservation subBlock
reportFaulty(ReportFaultyReservationSubBlockRequest request) Future<Operation>
Allows customers to report a faulty subBlock.
setIamPolicy(SetIamPolicyReservationSubBlockRequest request) Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy.
testIamPermissions(TestIamPermissionsReservationSubBlockRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited