performMaintenance method

Allows customers to perform maintenance on a reservation subBlock

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> performMaintenance(
  PerformMaintenanceReservationSubBlockRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/zones/${request.zone}/${request.parentName}/reservationSubBlocks/${request.reservationSubBlock}/performMaintenance',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.post(url);
  return Operation.fromJson(response);
}