ReservationSubBlocksReportFaultyRequest class final

Properties

disruptionSchedule String?
The disruption schedule for the subBlock. Check the DisruptionSchedule enum for the list of possible values.
final
failureComponent String?
The component that experienced the fault. Check the FailureComponent enum for the list of possible values.
final
faultReasons List<ReservationSubBlocksReportFaultyRequestFaultReason>
The reasons for the fault experienced with the subBlock.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String