faultReasons property
The reasons for the fault experienced with the subBlock.
Implementation
final List<ReservationSubBlocksReportFaultyRequestFaultReason> faultReasons;
The reasons for the fault experienced with the subBlock.
final List<ReservationSubBlocksReportFaultyRequestFaultReason> faultReasons;