behavior property
The behavior of the fault experienced with the subBlock. Check the Behavior enum for the list of possible values.
Implementation
final String? behavior;
The behavior of the fault experienced with the subBlock. Check the Behavior enum for the list of possible values.
final String? behavior;