ReservationSubBlocksReportFaultyRequestFaultReason_Behavior class final
The behavior of the fault experienced with the subBlock.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const ReservationSubBlocksReportFaultyRequestFaultReason_Behavior
- The default value for ReservationSubBlocksReportFaultyRequestFaultReason_Behavior.
- faultBehaviorUnspecified → const ReservationSubBlocksReportFaultyRequestFaultReason_Behavior
- gpuError → const ReservationSubBlocksReportFaultyRequestFaultReason_Behavior
- The subBlock experienced a GPU error.
- performance → const ReservationSubBlocksReportFaultyRequestFaultReason_Behavior
- The subBlock experienced performance issues.
- silentDataCorruption → const ReservationSubBlocksReportFaultyRequestFaultReason_Behavior
- The subBlock experienced silent data corruption.
- switchFailure → const ReservationSubBlocksReportFaultyRequestFaultReason_Behavior
- The subBlock experienced a switch failure.
- undefinedBehavior → const ReservationSubBlocksReportFaultyRequestFaultReason_Behavior
- A value indicating that the enum field is not set.