ready constant
Reservation_Status
const ready
Reservation resources have been allocated, and the reservation is ready for use.
Implementation
static const ready = Reservation_Status('READY');
Reservation resources have been allocated, and the reservation is ready for use.
static const ready = Reservation_Status('READY');