maintenanceScope property
Specifies if all, running or unused hosts are in scope for this request. Check the MaintenanceScope enum for the list of possible values.
Implementation
final String? maintenanceScope;
Specifies if all, running or unused hosts are in scope for this request. Check the MaintenanceScope enum for the list of possible values.
final String? maintenanceScope;