ReservationsPerformMaintenanceRequest_MaintenanceScope class final

Specifies if all, running or unused hosts are in scope for this request.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const ReservationsPerformMaintenanceRequest_MaintenanceScope
The default value for ReservationsPerformMaintenanceRequest_MaintenanceScope.
all → const ReservationsPerformMaintenanceRequest_MaintenanceScope
Trigger maintenance for all hosts belonging to this reservation irrespective of whether VMs are running on them or not.
maintenanceScopeUnspecified → const ReservationsPerformMaintenanceRequest_MaintenanceScope
Internal only
runningVms → const ReservationsPerformMaintenanceRequest_MaintenanceScope
Trigger maintenance only on the hosts belonging to this reservation which have VMs running on them.
undefinedMaintenanceScope → const ReservationsPerformMaintenanceRequest_MaintenanceScope
A value indicating that the enum field is not set.
unusedCapacity → const ReservationsPerformMaintenanceRequest_MaintenanceScope
Trigger maintenance only on the hosts belonging to this reservation which do not have any VMs running on them. This is not allowed for Standard ExR