all constant
Trigger maintenance for all hosts belonging to this reservation irrespective of whether VMs are running on them or not.
Implementation
static const all = ReservationsPerformMaintenanceRequest_MaintenanceScope(
'ALL',
);
Trigger maintenance for all hosts belonging to this reservation irrespective of whether VMs are running on them or not.
static const all = ReservationsPerformMaintenanceRequest_MaintenanceScope(
'ALL',
);