specificSkuCount property
Number of allocated resources can be resized with minimum = 1 and maximum = 1000.
Implementation
final int? specificSkuCount;
Number of allocated resources can be resized with minimum = 1 and maximum = 1000.
final int? specificSkuCount;