ResourceCommitment class final

Commitment for a particular hardware resource (a commitment is composed of one or more of these).

Constructors

ResourceCommitment({String? acceleratorType, int? amount, String? type})
ResourceCommitment.fromJson(Object? j)
factory

Properties

acceleratorType String?
Name of the accelerator type or GPU resource. Specify this field only when the type of hardware resource is ACCELERATOR.
final
amount int?
The quantity of the hardware resource that you want to commit to purchasing (in a type-dependent unit).
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
The type of hardware resource that you want to specify. You can specify any of the following values:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String