group property
A URI referencing one of the instance groups or network endpoint groups listed in the backend service.
Implementation
final String? group;
A URI referencing one of the instance groups or network endpoint groups listed in the backend service.
final String? group;