ResourcePolicies class final

The ResourcePolicies API.

Implementers

Constructors

ResourcePolicies({required Client client, Uri? endPoint, String? gcclVersion})
Creates a ResourcePolicies using client for transport.
ResourcePolicies.fromApiKey([String? apiKey])
Creates a ResourcePolicies that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(AggregatedListResourcePoliciesRequest request) Future<ResourcePolicyAggregatedList>
Retrieves an aggregated list of resource policies.
close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteResourcePolicyRequest request) Future<Operation>
Deletes the specified resource policy.
get(GetResourcePolicyRequest request) Future<ResourcePolicy>
Retrieves all information of the specified resource policy.
getIamPolicy(GetIamPolicyResourcePolicyRequest request) Future<Policy>
Gets the access control policy for a resource. May be empty if no such policy or resource exists.
insert(InsertResourcePolicyRequest request) Future<Operation>
Creates a new resource policy.
list(ListResourcePoliciesRequest request) Future<ResourcePolicyList>
A list all the resource policies that have been configured for the specified project in specified region.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(PatchResourcePolicyRequest request) Future<Operation>
Modify the specified resource policy.
setIamPolicy(SetIamPolicyResourcePolicyRequest request) Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy.
testIamPermissions(TestIamPermissionsResourcePolicyRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited