ResourcePolicy class final

Represents a Resource Policy resource. You can use resource policies to schedule actions for some Compute Engine resources. For example, you can use them toschedule persistent disk snapshots.

Constructors

ResourcePolicy({String? creationTimestamp, String? description, ResourcePolicyDiskConsistencyGroupPolicy? diskConsistencyGroupPolicy, ResourcePolicyGroupPlacementPolicy? groupPlacementPolicy, BigInt? id, ResourcePolicyInstanceSchedulePolicy? instanceSchedulePolicy, String? kind, String? name, String? region, ResourcePolicyResourceStatus? resourceStatus, String? selfLink, ResourcePolicySnapshotSchedulePolicy? snapshotSchedulePolicy, String? status, ResourcePolicyWorkloadPolicy? workloadPolicy})
ResourcePolicy.fromJson(Object? j)
factory

Properties

creationTimestamp String?
Output only. Output Only Creation timestamp inRFC3339 text format.
final
description String?
final
diskConsistencyGroupPolicy ResourcePolicyDiskConsistencyGroupPolicy?
Resource policy for disk consistency groups.
final
groupPlacementPolicy ResourcePolicyGroupPlacementPolicy?
Resource policy for instances for placement configuration.
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output only. Output Only The unique identifier for the resource. This identifier is defined by the server.
final
instanceSchedulePolicy ResourcePolicyInstanceSchedulePolicy?
Resource policy for scheduling instance operations.
final
kind String?
Output only. Output Only Type of the resource. Alwayscompute#resource_policies for resource policies.
final
name String?
The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
region String?
final
resourceStatus ResourcePolicyResourceStatus?
Output only. Output Only The system status of the resource policy.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output only. Output Only Server-defined fully-qualified URL for this resource.
final
snapshotSchedulePolicy ResourcePolicySnapshotSchedulePolicy?
Resource policy for persistent disks for creating snapshots.
final
status String?
Output only. Output Only The status of resource policy creation. Check the Status enum for the list of possible values.
final
workloadPolicy ResourcePolicyWorkloadPolicy?
Resource policy for defining instance placement for MIGs.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String