ResourcePolicyDailyCycle class final

Time window specified for daily operations.

Constructors

ResourcePolicyDailyCycle({int? daysInCycle, String? duration, String? startTime})
ResourcePolicyDailyCycle.fromJson(Object? j)
factory

Properties

daysInCycle int?
Defines a schedule with units measured in days. The value determines how many days pass between the start of each cycle.
final
duration String?
Output only. Output only A predetermined duration for the window, automatically chosen to be the smallest possible in the given scenario.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime String?
Start time of the window. This must be in UTC format that resolves to one of 00:00, 04:00, 08:00,12:00, 16:00, or 20:00. For example, both 13:00-5 and 08:00 are valid.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String