daysInCycle property
Defines a schedule with units measured in days. The value determines how many days pass between the start of each cycle.
Implementation
final int? daysInCycle;
Defines a schedule with units measured in days. The value determines how many days pass between the start of each cycle.
final int? daysInCycle;