duration property

String? duration
final

Output only. Output only A predetermined duration for the window, automatically chosen to be the smallest possible in the given scenario.

Implementation

final String? duration;