ResourcePolicyGroupPlacementPolicy class final
A GroupPlacementPolicy specifies resource placement configuration. It specifies the failure bucket separation
Constructors
- ResourcePolicyGroupPlacementPolicy({String? acceleratorTopologyMode, int? availabilityDomainCount, String? collocation, String? gpuTopology, int? vmCount})
- ResourcePolicyGroupPlacementPolicy.fromJson(Object? j)
-
factory
Properties
- acceleratorTopologyMode → String?
-
Specifies the connection mode for the accelerator topology. If not
specified, the default is AUTO_CONNECT.
Check the AcceleratorTopologyMode enum for the list of possible values.
final
- availabilityDomainCount → int?
-
The number of availability domains to spread instances across. If two
instances are in different availability domain, they are not in the same
low latency network.
final
- collocation → String?
-
Specifies network collocation
Check the Collocation enum for the list of possible values.
final
- gpuTopology → String?
-
Specifies the shape of the GPU slice, in slice based GPU families eg.
A4X.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- vmCount → int?
-
Number of VMs in this placement group. Google does not recommend that you
use this field unless you use a compact policy and you want your policy
to work only if it contains this exact number of VMs.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String