availabilityDomainCount property
The number of availability domains to spread instances across. If two instances are in different availability domain, they are not in the same low latency network.
Implementation
final int? availabilityDomainCount;
The number of availability domains to spread instances across. If two instances are in different availability domain, they are not in the same low latency network.
final int? availabilityDomainCount;