collocation property
Specifies network collocation Check the Collocation enum for the list of possible values.
Implementation
final String? collocation;
Specifies network collocation Check the Collocation enum for the list of possible values.
final String? collocation;