vmCount property

int? vmCount
final

Number of VMs in this placement group. Google does not recommend that you use this field unless you use a compact policy and you want your policy to work only if it contains this exact number of VMs.

Implementation

final int? vmCount;