ResourcePolicyHourlyCycle class final

Time window specified for hourly operations.

Constructors

ResourcePolicyHourlyCycle({String? duration, int? hoursInCycle, String? startTime})
ResourcePolicyHourlyCycle.fromJson(Object? j)
factory

Properties

duration String?
Output only. Output only Duration of the time window, automatically chosen to be smallest possible in the given scenario.
final
hashCode int
The hash code for this object.
no setterinherited
hoursInCycle int?
Defines a schedule with units measured in hours. The value determines how many hours pass between the start of each cycle.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime String?
Time within the window to start the operations. It must be in format "HH:MM", where HH : 00-23 and MM : 00-00 GMT.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String