duration property

String? duration
final

Output only. Output only Duration of the time window, automatically chosen to be smallest possible in the given scenario.

Implementation

final String? duration;