hoursInCycle property
Defines a schedule with units measured in hours. The value determines how many hours pass between the start of each cycle.
Implementation
final int? hoursInCycle;
Defines a schedule with units measured in hours. The value determines how many hours pass between the start of each cycle.
final int? hoursInCycle;