timeZone property

String? timeZone
final

Specifies the time zone to be used in interpreting Schedule.schedule. The value of this field must be a time zone name from the tz database: https://wikipedia.org/wiki/Tz_database.

Implementation

final String? timeZone;