ResourcePolicyResourceStatusInstanceSchedulePolicyStatus class final

Properties

hashCode int
The hash code for this object.
no setterinherited
lastRunStartTime String?
Output only. Output Only The last time the schedule successfully ran. The timestamp is an RFC3339 string.
final
nextRunStartTime String?
Output only. Output Only The next time the schedule is planned to run. The actual time might be slightly different. The timestamp is an RFC3339 string.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String