lastRunStartTime property
Output only. Output Only The last time the schedule successfully ran.
The timestamp is an RFC3339 string.
Implementation
final String? lastRunStartTime;
Output only. Output Only The last time the schedule successfully ran.
The timestamp is an RFC3339 string.
final String? lastRunStartTime;