nextRunStartTime property
Output only. Output Only The next time the schedule is planned to run.
The actual time might be slightly different.
The timestamp is an RFC3339 string.
Implementation
final String? nextRunStartTime;
Output only. Output Only The next time the schedule is planned to run.
The actual time might be slightly different.
The timestamp is an RFC3339 string.
final String? nextRunStartTime;