ResourcePolicySnapshotSchedulePolicy class final

A snapshot schedule policy specifies when and how frequently snapshots are to be created for the target disk. Also specifies how many and how long these scheduled snapshots should be retained.

Properties

hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
retentionPolicy ResourcePolicySnapshotSchedulePolicyRetentionPolicy?
Retention policy applied to snapshots created by this resource policy.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schedule ResourcePolicySnapshotSchedulePolicySchedule?
A Vm Maintenance Policy specifies what kind of infrastructure maintenance we are allowed to perform on this VM and when. Schedule that is applied to disks covered by this policy.
final
snapshotProperties ResourcePolicySnapshotSchedulePolicySnapshotProperties?
Properties with which snapshots are created such as labels, encryption keys.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String