snapshotProperties property
Properties with which snapshots are created such as labels, encryption keys.
Implementation
final ResourcePolicySnapshotSchedulePolicySnapshotProperties?
snapshotProperties;
Properties with which snapshots are created such as labels, encryption keys.
final ResourcePolicySnapshotSchedulePolicySnapshotProperties?
snapshotProperties;