ResourcePolicySnapshotSchedulePolicyRetentionPolicy class final

Policy for retention of scheduled snapshots.

Properties

hashCode int
The hash code for this object.
no setterinherited
maxRetentionDays int?
Maximum age of the snapshot that is allowed to be kept.
final
onSourceDiskDelete String?
Specifies the behavior to apply to scheduled snapshots when the source disk is deleted. Check the OnSourceDiskDelete enum for the list of possible values.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String