onSourceDiskDelete property
Specifies the behavior to apply to scheduled snapshots when the source disk is deleted. Check the OnSourceDiskDelete enum for the list of possible values.
Implementation
final String? onSourceDiskDelete;
Specifies the behavior to apply to scheduled snapshots when the source disk is deleted. Check the OnSourceDiskDelete enum for the list of possible values.
final String? onSourceDiskDelete;