ResourcePolicySnapshotSchedulePolicyRetentionPolicy_OnSourceDiskDelete class final
Specifies the behavior to apply to scheduled snapshots when the source disk is deleted.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const ResourcePolicySnapshotSchedulePolicyRetentionPolicy_OnSourceDiskDelete
- The default value for ResourcePolicySnapshotSchedulePolicyRetentionPolicy_OnSourceDiskDelete.
- applyRetentionPolicy → const ResourcePolicySnapshotSchedulePolicyRetentionPolicy_OnSourceDiskDelete
- keepAutoSnapshots → const ResourcePolicySnapshotSchedulePolicyRetentionPolicy_OnSourceDiskDelete
- undefinedOnSourceDiskDelete → const ResourcePolicySnapshotSchedulePolicyRetentionPolicy_OnSourceDiskDelete
- A value indicating that the enum field is not set.
- unspecifiedOnSourceDiskDelete → const ResourcePolicySnapshotSchedulePolicyRetentionPolicy_OnSourceDiskDelete