ResourcePolicySnapshotSchedulePolicySchedule class final

A schedule for disks where the schedueled operations are performed.

Properties

dailySchedule ResourcePolicyDailyCycle?
final
hashCode int
The hash code for this object.
no setterinherited
hourlySchedule ResourcePolicyHourlyCycle?
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
weeklySchedule ResourcePolicyWeeklyCycle?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String