ResourcePolicySnapshotSchedulePolicySnapshotProperties class final

Specified snapshot properties for scheduled snapshots created by this policy.

Constructors

ResourcePolicySnapshotSchedulePolicySnapshotProperties({String? chainName, bool? guestFlush, Map<String, String> labels = const {}, List<String> storageLocations = const []})
ResourcePolicySnapshotSchedulePolicySnapshotProperties.fromJson(Object? j)
factory

Properties

chainName String?
Chain name that the snapshot is created in.
final
guestFlush bool?
Indication to perform a 'guest aware' snapshot.
final
hashCode int
The hash code for this object.
no setterinherited
labels Map<String, String>
Labels to apply to scheduled snapshots. These can be later modified by the setLabels method. Label values may be empty.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storageLocations List<String>
Cloud Storage bucket storage location of the auto snapshot (regional or multi-regional).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String