menu
google_cloud_compute_v1 package
documentation
compute.dart
ResourcePolicyWeeklyCycleDayOfWeek class
ResourcePolicyWeeklyCycleDayOfWeek class
dark_mode
light_mode
ResourcePolicyWeeklyCycleDayOfWeek
class
final
Constructors
ResourcePolicyWeeklyCycleDayOfWeek
({
String
?
day
,
String
?
duration
,
String
?
startTime
})
ResourcePolicyWeeklyCycleDayOfWeek.fromJson
(
Object
?
j
)
factory
Properties
day
→
String
?
Defines a schedule that runs on specific days of the week. Specify one or more days. The following options are available: MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY. Check the Day enum for the list of possible values.
final
duration
→
String
?
Output only.
Output only
Duration of the time window, automatically chosen to be smallest possible in the given scenario.
final
hashCode
→
int
The hash code for this object.
no setter
inherited
qualifiedName
→
String
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or
google.rpc.ErrorInfo
.
final
inherited
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
startTime
→
String
?
Time within the window to start the operations. It must be in format "HH:MM", where HH :
00-23
and MM :
00-00
GMT.
final
Methods
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson
(
)
→
Object
toString
(
)
→
String
A string representation of this object.
override
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
Constants
fullyQualifiedName
→ const
String
google_cloud_compute_v1 package
documentation
compute
ResourcePolicyWeeklyCycleDayOfWeek class
compute library