duration property
Output only. Output only Duration of the time window, automatically chosen to be
smallest possible in the given scenario.
Implementation
final String? duration;
Output only. Output only Duration of the time window, automatically chosen to be
smallest possible in the given scenario.
final String? duration;