ResourcePolicyWorkloadPolicy class final

Represents the workload policy.

Constructors

ResourcePolicyWorkloadPolicy({String? acceleratorTopology, String? acceleratorTopologyMode, String? maxTopologyDistance, String? type})
ResourcePolicyWorkloadPolicy.fromJson(Object? j)
factory

Properties

acceleratorTopology String?
Specifies the topology required to create a partition for VMs that have interconnected GPUs.
final
acceleratorTopologyMode String?
Specifies the connection mode for the accelerator topology. If not specified, the default is AUTO_CONNECT. Check the AcceleratorTopologyMode enum for the list of possible values.
final
hashCode int
The hash code for this object.
no setterinherited
maxTopologyDistance String?
Specifies the maximum distance between instances. Check the MaxTopologyDistance enum for the list of possible values.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
Specifies the intent of the instance placement in the MIG. Check the Type enum for the list of possible values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String