acceleratorTopology property
Specifies the topology required to create a partition for VMs that have interconnected GPUs.
Implementation
final String? acceleratorTopology;
Specifies the topology required to create a partition for VMs that have interconnected GPUs.
final String? acceleratorTopology;