ResourcePolicyWorkloadPolicy_MaxTopologyDistance class final

Specifies the maximum distance between instances.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const ResourcePolicyWorkloadPolicy_MaxTopologyDistance
The default value for ResourcePolicyWorkloadPolicy_MaxTopologyDistance.
block → const ResourcePolicyWorkloadPolicy_MaxTopologyDistance
VMs must be provisioned in the same block.
cluster → const ResourcePolicyWorkloadPolicy_MaxTopologyDistance
VMs must be provisioned in the same cluster.
subblock → const ResourcePolicyWorkloadPolicy_MaxTopologyDistance
VMs must be provisioned in the same subblock.
undefinedMaxTopologyDistance → const ResourcePolicyWorkloadPolicy_MaxTopologyDistance
A value indicating that the enum field is not set.