ResourcePolicy_Status class final

Output only. Output Only The status of resource policy creation.

Constructors

ResourcePolicy_Status(String value)
const
ResourcePolicy_Status.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const ResourcePolicy_Status
The default value for ResourcePolicy_Status.
creating → const ResourcePolicy_Status
Resource policy is being created.
deleting → const ResourcePolicy_Status
Resource policy is being deleted.
expired → const ResourcePolicy_Status
Resource policy is expired and will not run again.
invalid → const ResourcePolicy_Status
ready → const ResourcePolicy_Status
Resource policy is ready to be used.
undefinedStatus → const ResourcePolicy_Status
A value indicating that the enum field is not set.