expired constant
ResourcePolicy_Status
const expired
Resource policy is expired and will not run again.
Implementation
static const expired = ResourcePolicy_Status('EXPIRED');
Resource policy is expired and will not run again.
static const expired = ResourcePolicy_Status('EXPIRED');