physicalHostTopology property

ResourceStatusPhysicalHostTopology? physicalHostTopology
final

Output only. Output Only A series of fields containing the global name of the Compute Engine cluster, as well as the ID of the block, sub-block, and host on which the running instance is located.

Implementation

final ResourceStatusPhysicalHostTopology? physicalHostTopology;