ResourceStatusPhysicalHostTopology class final

Represents the physical host topology of the host on which the VM is running.

Properties

additionalAttributes ResourceStatusPhysicalHostTopologyAdditionalAttributes?
Output only. Output Only Additional location information of the running instance.
final
block String?
Output Only The ID of the block in which the running instance is located. Instances within the same block experience low network latency.
final
cluster String?
Output Only The global name of the Compute Engine cluster where the running instance is located.
final
hashCode int
The hash code for this object.
no setterinherited
host String?
Output Only The ID of the host on which the running instance is located. Instances on the same host experience the lowest possible network latency.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subblock String?
Output Only The ID of the sub-block in which the running instance is located. Instances in the same sub-block experience lower network latency than instances in the same block.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String