cluster property
Output Only The global name of the Compute Engine cluster where the
running instance is located.
Implementation
final String? cluster;
Output Only The global name of the Compute Engine cluster where the
running instance is located.
final String? cluster;