host property

String? host
final

Output Only The ID of the host on which the running instance is located. Instances on the same host experience the lowest possible network latency.

Implementation

final String? host;