consumedReservation property
Output only. Output Only The full resource name of the reservation that this
instance is consuming from.
Implementation
final String? consumedReservation;
Output only. Output Only The full resource name of the reservation that this
instance is consuming from.
final String? consumedReservation;