consumedReservationBlock property
Output only. Output Only The full resource name of the reservation block that this
instance is consuming from.
Implementation
final String? consumedReservationBlock;
Output only. Output Only The full resource name of the reservation block that this
instance is consuming from.
final String? consumedReservationBlock;