consumedReservationSubBlock property
Output only. Output Only The full resource name of the reservation sub-block that
this instance is consuming from.
Implementation
final String? consumedReservationSubBlock;
Output only. Output Only The full resource name of the reservation sub-block that
this instance is consuming from.
final String? consumedReservationSubBlock;