ResourceStatusScheduling class final

Constructors

ResourceStatusScheduling({int? availabilityDomain, String? gracefulShutdownTimestamp, String? terminationTimestamp})
ResourceStatusScheduling.fromJson(Object? j)
factory

Properties

availabilityDomain int?
Specifies the availability domain to place the instance in. The value must be a number between 1 and the number of availability domains specified in the spread placement policy attached to the instance.
final
gracefulShutdownTimestamp String?
Output only. Specifies the timestamp, when the instance will start graceful shutdown process, in RFC3339 text format.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terminationTimestamp String?
Time in future when the instance will be terminated inRFC3339 text format.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String