gracefulShutdownTimestamp property
Output only. Specifies the timestamp, when the instance will start graceful shutdown process, in RFC3339 text format.
Implementation
final String? gracefulShutdownTimestamp;
Output only. Specifies the timestamp, when the instance will start graceful shutdown process, in RFC3339 text format.
final String? gracefulShutdownTimestamp;