terminationTimestamp property
Time in future when the instance will be terminated inRFC3339 text format.
Implementation
final String? terminationTimestamp;
Time in future when the instance will be terminated inRFC3339 text format.
final String? terminationTimestamp;