ResourceStatusShutdownDetails class final
Specifies if the instance is in PENDING_STOP state or there is a
programmed stop scheduled.
Constructors
- ResourceStatusShutdownDetails({Duration? maxDuration, String? requestTimestamp, String? stopState, String? targetState})
- ResourceStatusShutdownDetails.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxDuration → Duration?
-
The duration for graceful shutdown. Only applicable when
stop_state=PENDING_STOP.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - requestTimestamp → String?
-
Past timestamp indicating the beginning of current
stopStatein RFC3339 text format.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stopState → String?
-
Current stopping state of the instance.
Check the StopState enum for the list of possible values.
final
- targetState → String?
-
Target instance state.
Check the TargetState enum for the list of possible values.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String