ResumeRolloutRequest class final

A request message for Rollouts.Resume. See the method description for details.

Constructors

ResumeRolloutRequest({String? etag, required String project, String? requestId, required String rollout})
ResumeRolloutRequest.fromJson(Object? j)
factory

Properties

etag String?
The etag of the Rollout. If this is provided, the request will only succeed if the etag matches the current etag of the Rollout.
final
hashCode int
The hash code for this object.
no setterinherited
project String
Required. Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requestId String?
An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
final
rollout String
Required. Name of the Rollout resource to resume.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String