RiskDetails class final

Detailed insights and metrics about a detected reliability risk.

Constructors

RiskDetails({String? duration, RiskDetailsGlobalDnsInsight? globalDnsInsight, String? lastUpdateTimestamp, String? severity, String? type})
RiskDetails.fromJson(Object? j)
factory

Properties

duration String?
The duration of the risk since it was detected.
final
globalDnsInsight RiskDetailsGlobalDnsInsight?
Insight details for global DNS risk.
final
hashCode int
The hash code for this object.
no setterinherited
lastUpdateTimestamp String?
The last time the risk was updated.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity String?
The severity of the risk. Check the Severity enum for the list of possible values.
final
type String?
The type of risk. Check the Type enum for the list of possible values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String