RiskDetailsGlobalDnsInsight class final

Detailed insights for a global DNS reliability risk.

Constructors

RiskDetailsGlobalDnsInsight({bool? projectDefaultIsGlobalDns, String? queryObservationWindow, int? riskyQueryCount, int? totalQueryCount})
RiskDetailsGlobalDnsInsight.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
projectDefaultIsGlobalDns bool?
Indicates whether the project's default DNS setting is global DNS.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
queryObservationWindow String?
The observation window for the query counts.
final
riskyQueryCount int?
The number of queries that are risky. This is always less than or equal to total_query_count.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalQueryCount int?
The total number of queries in the observation window.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String