riskyQueryCount property
The number of queries that are risky. This is always less than or equal to total_query_count.
Implementation
final int? riskyQueryCount;
The number of queries that are risky. This is always less than or equal to total_query_count.
final int? riskyQueryCount;