RiskDetails_Severity class final

The severity of the risk.

Constructors

RiskDetails_Severity(String value)
const
RiskDetails_Severity.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const RiskDetails_Severity
The default value for RiskDetails_Severity.
critical → const RiskDetails_Severity
Critical severity.
high → const RiskDetails_Severity
High severity.
low → const RiskDetails_Severity
Low severity.
medium → const RiskDetails_Severity
Medium severity.
severityUnspecified → const RiskDetails_Severity
No severity specified. The default value.
undefinedSeverity → const RiskDetails_Severity
A value indicating that the enum field is not set.