RiskRecommendation class final

Recommendation for mitigating a reliability risk, including a reference URL.

Constructors

RiskRecommendation({String? content, String? referenceUrl})
RiskRecommendation.fromJson(Object? j)
factory

Properties

content String?
Mitigation guide for the risk.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
referenceUrl String?
URL referencing a more detailed mitigation guide.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String