state property
Output only. The current state of the Rollout. Check the State enum for the list of possible values.
Implementation
final String? state;
Output only. The current state of the Rollout. Check the State enum for the list of possible values.
final String? state;