RolloutPlan class final

RolloutPlan resource.

A RolloutPlan is the customer-defined strategy to divide a large-scale change into smaller increments, referred to as "waves". Each wave targets a specific portion of the overall affected area and defines criteria that must be met before progressing to the subsequent wave.

Constructors

RolloutPlan({String? creationTimestamp, String? description, BigInt? id, String? kind, String? locationScope, String? name, String? selfLink, String? selfLinkWithId, List<RolloutPlanWave> waves = const []})
RolloutPlan.fromJson(Object? j)
factory

Properties

creationTimestamp String?
Output only. Output Only Creation timestamp inRFC3339 text format.
final
description String?
An optional description of this resource. Provide this property when you create the resource.
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output only. Output Only The unique identifier for the resource. This identifier is defined by the server.
final
kind String?
Output only. Output Only Type of the resource. Always compute#rolloutPlan for rolloutPlans.
final
locationScope String?
The location scope of the rollout plan. If not specified, the location scope is considered as ZONAL. Check the LocationScope enum for the list of possible values.
final
name String?
Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output only. Output Only Server-defined fully-qualified URL for this resource.
final
selfLinkWithId String?
Output only. Output Only Server-defined URL for this resource's resource id.
final
waves List<RolloutPlanWave>
Required. The waves included in this rollout plan.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String