RolloutPlanWave class final

A single wave in a rollout plan.

Constructors

RolloutPlanWave({String? displayName, int? number, RolloutPlanWaveOrchestrationOptions? orchestrationOptions, List<RolloutPlanWaveSelector> selectors = const [], RolloutPlanWaveValidation? validation})
RolloutPlanWave.fromJson(Object? j)
factory

Properties

displayName String?
Optional. The display name of this wave of the rollout plan.
final
hashCode int
The hash code for this object.
no setterinherited
number int?
Output only. The wave number.
final
orchestrationOptions RolloutPlanWaveOrchestrationOptions?
Optional. The orchestration options for this wave.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectors List<RolloutPlanWaveSelector>
Required. The selectors for this wave. There is a logical AND between each selector defined in a wave, so a resource must satisfy the criteria of all the specified selectors to be in scope for the wave.
final
validation RolloutPlanWaveValidation?
Required. The validation to be performed at the end of this wave.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String