maxConcurrentResourcesPerLocation property
Optional. Maximum number of resources to be orchestrated per location in parallel.
Implementation
final int? maxConcurrentResourcesPerLocation;
Optional. Maximum number of resources to be orchestrated per location in parallel.
final int? maxConcurrentResourcesPerLocation;