RolloutPlanWaveOrchestrationOptionsDelay_Delimiter class final

Optional. Controls whether the delay should only be added between batches of projects corresponding to different locations, or also between batches of projects corresponding to the same location.

Must be set to DELIMITER_UNSPECIFIED if no delay is to be added.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const RolloutPlanWaveOrchestrationOptionsDelay_Delimiter
The default value for RolloutPlanWaveOrchestrationOptionsDelay_Delimiter.
delimiterBatch → const RolloutPlanWaveOrchestrationOptionsDelay_Delimiter
The delay will also be added between batches of projects corresponding to the same location.
delimiterLocation → const RolloutPlanWaveOrchestrationOptionsDelay_Delimiter
The delay will only be added between batches of projects corresponding to different locations.
delimiterUnspecified → const RolloutPlanWaveOrchestrationOptionsDelay_Delimiter
No delay will be added between batches of projects. Processing will continue with the next batch as soon as the previous batch of LROs is done.
undefinedDelimiter → const RolloutPlanWaveOrchestrationOptionsDelay_Delimiter
A value indicating that the enum field is not set.