RolloutPlanWaveSelector class final

A selector which specifies what resource(s) are included in a given wave.

Properties

hashCode int
The hash code for this object.
no setterinherited
locationSelector RolloutPlanWaveSelectorLocationSelector?
Optional. Roll out to resources by Cloud locations.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
resourceHierarchySelector RolloutPlanWaveSelectorResourceHierarchySelector?
Optional. Roll out to resources by Cloud Resource Manager resource hierarchy.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String