waitDuration property

String? waitDuration
final

Optional. The duration that the system waits in between waves. This wait starts after all changes in the wave are rolled out.

Implementation

final String? waitDuration;