RolloutPlan_LocationScope class final

The location scope of the rollout plan. If not specified, the location scope is considered as ZONAL.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const RolloutPlan_LocationScope
The default value for RolloutPlan_LocationScope.
locationScopeUnspecified → const RolloutPlan_LocationScope
Unspecified value. Considered as ZONAL.
regional → const RolloutPlan_LocationScope
Regional scope.
undefinedLocationScope → const RolloutPlan_LocationScope
A value indicating that the enum field is not set.
zonal → const RolloutPlan_LocationScope
Zonal scope.