orchestratedEntity property
Optional. Entity details for products using the Orchestrated Integration model.
Implementation
final RolloutRolloutEntityOrchestratedEntity? orchestratedEntity;
Optional. Entity details for products using the Orchestrated Integration model.
final RolloutRolloutEntityOrchestratedEntity? orchestratedEntity;