advance method

Future<Operation> advance(
  1. AdvanceRolloutRequest request
)

Advances a Rollout to the next wave, or completes it if no waves remain.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> advance(AdvanceRolloutRequest request) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/global/rollouts/${request.rollout}/advance',
    queryParameters: {
      if (request.currentWaveNumber case final $1?)
        'currentWaveNumber': '${$1}',
      'requestId': ?request.requestId,
    },
  );
  final response = await _client.post(url);
  return Operation.fromJson(response);
}