Route class final

Represents a Route resource.

A route defines a path from VM instances in the VPC network to a specific destination. This destination can be inside or outside the VPC network. For more information, read theRoutes overview.

Constructors

Route({List<RouteAsPath> asPaths = const [], String? creationTimestamp, String? description, String? destRange, BigInt? id, String? kind, String? name, String? network, String? nextHopGateway, String? nextHopHub, String? nextHopIlb, String? nextHopInstance, int? nextHopInterRegionCost, String? nextHopInterconnectAttachment, String? nextHopIp, int? nextHopMed, String? nextHopNetwork, String? nextHopOrigin, String? nextHopPeering, String? nextHopVpnTunnel, RouteParams? params, int? priority, String? routeStatus, String? routeType, String? selfLink, List<String> tags = const [], List<Warnings> warnings = const []})
Route.fromJson(Object? j)
factory

Properties

asPaths List<RouteAsPath>
Output only. Output Only AS path.
final
creationTimestamp String?
Output only. Output Only Creation timestamp inRFC3339 text format.
final
description String?
An optional description of this resource. Provide this field when you create the resource.
final
destRange String?
The destination range of outgoing packets that this route applies to. Both IPv4 and IPv6 are supported. Must specify an IPv4 range (e.g. 192.0.2.0/24) or an IPv6 range in RFC 4291 format (e.g. 2001:db8::/32). IPv6 range will be displayed using RFC 5952 compressed format.
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output only. Output Only The unique identifier for the resource. This identifier is defined by the server.
final
kind String?
Output only. Output Only Type of this resource. Always compute#routes for Route resources.
final
name String?
Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])?. The first character must be a lowercase letter, and all following characters (except for the last character) must be a dash, lowercase letter, or digit. The last character must be a lowercase letter or digit.
final
network String?
Fully-qualified URL of the network that this route applies to.
final
nextHopGateway String?
The URL to a gateway that should handle matching packets. You can only specify the internet gateway using a full or partial valid URL: projects/project/global/gateways/default-internet-gateway
final
nextHopHub String?
Output only. Output Only The full resource name of the Network Connectivity Center hub that will handle matching packets.
final
nextHopIlb String?
The URL to a forwarding rule of typeloadBalancingScheme=INTERNAL that should handle matching packets or the IP address of the forwarding Rule. For example, the following are all valid URLs:
final
nextHopInstance String?
The URL to an instance that should handle matching packets. You can specify this as a full or partial URL. For example: https://www.googleapis.com/compute/v1/projects/project/zones/zone/instances/
final
nextHopInterconnectAttachment String?
Output only. Output Only The URL to an InterconnectAttachment which is the next hop for the route. This field will only be populated for dynamic routes generated by Cloud Router with a linked interconnectAttachment or the static route generated by each L2 Interconnect Attachment.
final
nextHopInterRegionCost int?
Output only. Output only Internal fixed region-to-region cost that Google Cloud calculates based on factors such as network performance, distance, and available bandwidth between regions.
final
nextHopIp String?
The network IP address of an instance that should handle matching packets. Both IPv6 address and IPv4 addresses are supported. Must specify an IPv4 address in dot-decimal notation (e.g. 192.0.2.99) or an IPv6 address in RFC 4291 format (e.g. 2001:db8::2d9:51:0:0 or 2001:db8:0:0:2d9:51:0:0). IPv6 addresses will be displayed using RFC 5952 compressed format (e.g. 2001:db8::2d9:51:0:0). Should never be an IPv4-mapped IPv6 address.
final
nextHopMed int?
Output only. Output Only Multi-Exit Discriminator, a BGP route metric that indicates the desirability of a particular route in a network.
final
nextHopNetwork String?
The URL of the local network if it should handle matching packets.
final
nextHopOrigin String?
Output only. Output Only Indicates the origin of the route. Can be IGP (Interior Gateway Protocol), EGP (Exterior Gateway Protocol), or INCOMPLETE. Check the NextHopOrigin enum for the list of possible values.
final
nextHopPeering String?
Output only. Output Only The network peering name that should handle matching packets, which should conform to RFC1035.
final
nextHopVpnTunnel String?
The URL to a VpnTunnel that should handle matching packets.
final
params RouteParams?
Input only. Input Only Additional params passed with the request, but not persisted as part of resource payload.
final
priority int?
The priority of this route. Priority is used to break ties in cases where there is more than one matching route of equal prefix length. In cases where multiple routes have equal prefix length, the one with the lowest-numbered priority value wins. The default value is 1000. The priority value must be from 0 to 65535, inclusive.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
routeStatus String?
Output only The status of the route. This status applies to dynamic routes learned by Cloud Routers. It is also applicable to routes undergoing migration. Check the RouteStatus enum for the list of possible values.
final
routeType String?
Output only. Output Only The type of this route, which can be one of the following values:
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output Only Server-defined fully-qualified URL for this resource.
final
tags List<String>
A list of instance tags to which this route applies.
final
warnings List<Warnings>
Output only. Output Only If potential misconfigurations are detected for this route, this field will be populated with warning messages.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String