nextHopHub property
Output only. Output Only The full resource name of the Network Connectivity Center hub
that will handle matching packets.
Implementation
final String? nextHopHub;
Output only. Output Only The full resource name of the Network Connectivity Center hub
that will handle matching packets.
final String? nextHopHub;