nextHopInstance property

String? nextHopInstance
final

The URL to an instance that should handle matching packets. You can specify this as a full or partial URL. For example: https://www.googleapis.com/compute/v1/projects/project/zones/zone/instances/

Implementation

final String? nextHopInstance;