nextHopInterRegionCost property

int? nextHopInterRegionCost
final

Output only. Output only Internal fixed region-to-region cost that Google Cloud calculates based on factors such as network performance, distance, and available bandwidth between regions.

Implementation

final int? nextHopInterRegionCost;