nextHopInterconnectAttachment property

String? nextHopInterconnectAttachment
final

Output only. Output Only The URL to an InterconnectAttachment which is the next hop for the route. This field will only be populated for dynamic routes generated by Cloud Router with a linked interconnectAttachment or the static route generated by each L2 Interconnect Attachment.

Implementation

final String? nextHopInterconnectAttachment;