nextHopMed property
Output only. Output Only Multi-Exit Discriminator, a BGP route metric that indicates
the desirability of a particular route in a network.
Implementation
final int? nextHopMed;
Output only. Output Only Multi-Exit Discriminator, a BGP route metric that indicates
the desirability of a particular route in a network.
final int? nextHopMed;