nextHopPeering property
Output only. Output Only The network peering name that should handle matching packets,
which should conform to RFC1035.
Implementation
final String? nextHopPeering;
Output only. Output Only The network peering name that should handle matching packets,
which should conform to RFC1035.
final String? nextHopPeering;