toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (creationTimestamp != null) 'creationTimestamp=$creationTimestamp',
    if (description != null) 'description=$description',
    if (destRange != null) 'destRange=$destRange',
    if (id != null) 'id=$id',
    if (kind != null) 'kind=$kind',
    if (name != null) 'name=$name',
    if (network != null) 'network=$network',
    if (nextHopGateway != null) 'nextHopGateway=$nextHopGateway',
    if (nextHopHub != null) 'nextHopHub=$nextHopHub',
    if (nextHopIlb != null) 'nextHopIlb=$nextHopIlb',
    if (nextHopInstance != null) 'nextHopInstance=$nextHopInstance',
    if (nextHopInterRegionCost != null)
      'nextHopInterRegionCost=$nextHopInterRegionCost',
    if (nextHopInterconnectAttachment != null)
      'nextHopInterconnectAttachment=$nextHopInterconnectAttachment',
    if (nextHopIp != null) 'nextHopIp=$nextHopIp',
    if (nextHopMed != null) 'nextHopMed=$nextHopMed',
    if (nextHopNetwork != null) 'nextHopNetwork=$nextHopNetwork',
    if (nextHopOrigin != null) 'nextHopOrigin=$nextHopOrigin',
    if (nextHopPeering != null) 'nextHopPeering=$nextHopPeering',
    if (nextHopVpnTunnel != null) 'nextHopVpnTunnel=$nextHopVpnTunnel',
    if (priority != null) 'priority=$priority',
    if (routeStatus != null) 'routeStatus=$routeStatus',
    if (routeType != null) 'routeType=$routeType',
    if (selfLink != null) 'selfLink=$selfLink',
  ].join(',');
  return 'Route(${$contents})';
}