RouteAsPath class final

Constructors

RouteAsPath({List<int> asLists = const [], String? pathSegmentType})
RouteAsPath.fromJson(Object? j)
factory

Properties

asLists List<int>
Output Only The AS numbers of the AS Path.
final
hashCode int
The hash code for this object.
no setterinherited
pathSegmentType String?
Output Only The type of the AS Path, which can be one of the following values:
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String