RoutePolicy class final

Constructors

RoutePolicy({String? description, String? fingerprint, String? name, List<RoutePolicyPolicyTerm> terms = const [], String? type})
RoutePolicy.fromJson(Object? j)
factory

Properties

description String?
An optional description of route policy.
final
fingerprint String?
A fingerprint for the Route Policy being applied to this Router, which is essentially a hash of the Route Policy used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update Route Policy. You must always provide an up-to-date fingerprint hash in order to update or change labels.
final
hashCode int
The hash code for this object.
no setterinherited
name String?
Route Policy name, which must be a resource ID segment and unique within all the router's Route Policies. Name should conform to RFC1035.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terms List<RoutePolicyPolicyTerm>
List of terms (the order in the list is not important, they are evaluated in order of priority). Order of policies is not retained and might change when getting policy later.
final
type String?
Check the Type enum for the list of possible values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String