name property
Route Policy name, which must be a resource ID segment and unique within all the router's Route Policies. Name should conform to RFC1035.
Implementation
final String? name;
Route Policy name, which must be a resource ID segment and unique within all the router's Route Policies. Name should conform to RFC1035.
final String? name;