terms property
List of terms (the order in the list is not important, they are evaluated in order of priority). Order of policies is not retained and might change when getting policy later.
Implementation
final List<RoutePolicyPolicyTerm> terms;
List of terms (the order in the list is not important, they are evaluated in order of priority). Order of policies is not retained and might change when getting policy later.
final List<RoutePolicyPolicyTerm> terms;