RoutePolicyPolicyTerm class
final
Properties
-
actions
→ List<Expr>
-
CEL expressions to evaluate to modify a route when this term matches.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
match
→ Expr?
-
CEL expression evaluated against a route to determine if this term
applies. When not set, the term applies to all
routes.
final
-
priority
→ int?
-
The evaluation priority for this term, which must be between 0
(inclusive) and 2^31 (exclusive), and unique within the list.
final
-
qualifiedName
→ String
-
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or google.rpc.ErrorInfo.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited