Route_RouteStatus class final

Output only The status of the route. This status applies to dynamic routes learned by Cloud Routers. It is also applicable to routes undergoing migration.

Constructors

Route_RouteStatus(String value)
const
Route_RouteStatus.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const Route_RouteStatus
The default value for Route_RouteStatus.
active → const Route_RouteStatus
This route is processed and active.
dropped → const Route_RouteStatus
The route is dropped due to the VPC exceeding the dynamic route limit. For dynamic route limit, please refer to the Learned route example
inactive → const Route_RouteStatus
This route is processed but inactive due to failure from the backend. The backend may have rejected the route
pending → const Route_RouteStatus
This route is being processed internally. The status will change once processed.
undefinedRouteStatus → const Route_RouteStatus
A value indicating that the enum field is not set.