Router class final

Represents a Cloud Router resource.

For more information about Cloud Router, read theCloud Router overview.

Constructors

Router({RouterBgp? bgp, List<RouterBgpPeer> bgpPeers = const [], String? creationTimestamp, String? description, bool? encryptedInterconnectRouter, BigInt? id, List<RouterInterface> interfaces = const [], String? kind, List<RouterMd5AuthenticationKey> md5AuthenticationKeys = const [], String? name, List<RouterNat> nats = const [], String? nccGateway, String? network, RouterParams? params, String? region, String? selfLink})
Router.fromJson(Object? j)
factory

Properties

bgp RouterBgp?
BGP information specific to this router.
final
bgpPeers List<RouterBgpPeer>
BGP information that must be configured into the routing stack to establish BGP peering. This information must specify the peer ASN and either the interface name, IP address, or peer IP address. Please refer toRFC4273.
final
creationTimestamp String?
Output only. Output Only Creation timestamp inRFC3339 text format.
final
description String?
An optional description of this resource. Provide this property when you create the resource.
final
encryptedInterconnectRouter bool?
Indicates if a router is dedicated for use with encrypted VLAN attachments (interconnectAttachments).
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output Only The unique identifier for the resource. This identifier is defined by the server.
final
interfaces List<RouterInterface>
Router interfaces. To create a BGP peer that uses a router interface, the interface must have one of the following fields specified:
final
kind String?
Output only. Output Only Type of resource. Always compute#router for routers.
final
md5AuthenticationKeys List<RouterMd5AuthenticationKey>
Keys used for MD5 authentication.
final
name String?
Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
nats List<RouterNat>
A list of NAT services created in this router.
final
nccGateway String?
URI of the ncc_gateway to which this router associated.
final
network String?
URI of the network to which this router belongs.
final
params RouterParams?
Input only. Input Only Additional params passed with the request, but not persisted as part of resource payload.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
region String?
Output Only URI of the region where the router resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output Only Server-defined URL for the resource.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String