encryptedInterconnectRouter property
Indicates if a router is dedicated for use with encrypted VLAN attachments (interconnectAttachments).
Implementation
final bool? encryptedInterconnectRouter;
Indicates if a router is dedicated for use with encrypted VLAN attachments (interconnectAttachments).
final bool? encryptedInterconnectRouter;