RouterAdvertisedIpRange class final

Description-tagged IP ranges for the router to advertise.

Constructors

RouterAdvertisedIpRange({String? description, String? range})
RouterAdvertisedIpRange.fromJson(Object? j)
factory

Properties

description String?
User-specified description for the IP range.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
range String?
The IP range to advertise. The value must be a CIDR-formatted string.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String