advertiseMode property
User-specified flag to indicate which mode to use for advertisement. The options are DEFAULT or CUSTOM. Check the AdvertiseMode enum for the list of possible values.
Implementation
final String? advertiseMode;
User-specified flag to indicate which mode to use for advertisement. The options are DEFAULT or CUSTOM. Check the AdvertiseMode enum for the list of possible values.
final String? advertiseMode;