RouterBgpPeer class final

Constructors

RouterBgpPeer({String? advertiseMode, List<String> advertisedGroups = const [], List<RouterAdvertisedIpRange> advertisedIpRanges = const [], int? advertisedRoutePriority, RouterBgpPeerBfd? bfd, List<RouterBgpPeerCustomLearnedIpRange> customLearnedIpRanges = const [], int? customLearnedRoutePriority, String? enable, bool? enableIpv4, bool? enableIpv6, List<String> exportPolicies = const [], List<String> importPolicies = const [], String? interfaceName, String? ipAddress, String? ipv4NexthopAddress, String? ipv6NexthopAddress, String? managementType, String? md5AuthenticationKeyName, String? name, int? peerAsn, String? peerIpAddress, String? peerIpv4NexthopAddress, String? peerIpv6NexthopAddress, String? routerApplianceInstance})
RouterBgpPeer.fromJson(Object? j)
factory

Properties

advertisedGroups List<String>
User-specified list of prefix groups to advertise in custom mode, which currently supports the following option:
final
advertisedIpRanges List<RouterAdvertisedIpRange>
User-specified list of individual IP ranges to advertise in custom mode. This field can only be populated if advertise_mode is CUSTOM and overrides the list defined for the router (in the "bgp" message). These IP ranges are advertised in addition to any specified groups. Leave this field blank to advertise no custom IP ranges.
final
advertisedRoutePriority int?
The priority of routes advertised to this BGP peer. Where there is more than one matching route of maximum length, the routes with the lowest priority value win.
final
advertiseMode String?
User-specified flag to indicate which mode to use for advertisement. Check the AdvertiseMode enum for the list of possible values.
final
bfd RouterBgpPeerBfd?
BFD configuration for the BGP peering.
final
customLearnedIpRanges List<RouterBgpPeerCustomLearnedIpRange>
A list of user-defined custom learned route IP address ranges for a BGP session.
final
customLearnedRoutePriority int?
The user-defined custom learned route priority for a BGP session. This value is applied to all custom learned route ranges for the session. You can choose a value from 0 to 65335. If you don't provide a value, Google Cloud assigns a priority of 100 to the ranges.
final
enable String?
The status of the BGP peer connection.
final
enableIpv4 bool?
Enable IPv4 traffic over BGP Peer. It is enabled by default if the peerIpAddress is version 4.
final
enableIpv6 bool?
Enable IPv6 traffic over BGP Peer. It is enabled by default if the peerIpAddress is version 6.
final
exportPolicies List<String>
List of export policies applied to this peer, in the order they must be evaluated. The name must correspond to an existing policy that has ROUTE_POLICY_TYPE_EXPORT type.
final
hashCode int
The hash code for this object.
no setterinherited
importPolicies List<String>
List of import policies applied to this peer, in the order they must be evaluated. The name must correspond to an existing policy that has ROUTE_POLICY_TYPE_IMPORT type.
final
interfaceName String?
Name of the interface the BGP peer is associated with.
final
ipAddress String?
IP address of the interface inside Google Cloud Platform.
final
ipv4NexthopAddress String?
IPv4 address of the interface inside Google Cloud Platform.
final
ipv6NexthopAddress String?
IPv6 address of the interface inside Google Cloud Platform.
final
managementType String?
Output only. Output Only The resource that configures and manages this BGP peer.
final
md5AuthenticationKeyName String?
Present if MD5 authentication is enabled for the peering. Must be the name of one of the entries in the Router.md5_authentication_keys. The field must comply with RFC1035.
final
name String?
Name of this BGP peer. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
peerAsn int?
Peer BGP Autonomous System Number (ASN). Each BGP interface may use a different value.
final
peerIpAddress String?
IP address of the BGP interface outside Google Cloud Platform.
final
peerIpv4NexthopAddress String?
IPv4 address of the BGP interface outside Google Cloud Platform.
final
peerIpv6NexthopAddress String?
IPv6 address of the BGP interface outside Google Cloud Platform.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
routerApplianceInstance String?
URI of the VM instance that is used as third-party router appliances such as Next Gen Firewalls, Virtual Routers, or Router Appliances. The VM instance must be located in zones contained in the same region as this Cloud Router. The VM instance is the peer side of the BGP session.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String