enable property
The status of the BGP peer connection.
If set to FALSE, any active session with the peer is terminated and all associated routing information is removed. If set to TRUE, the peer connection can be established with routing information. The default is TRUE. Check the Enable enum for the list of possible values.
Implementation
final String? enable;