importPolicies property

List<String> importPolicies
final

List of import policies applied to this peer, in the order they must be evaluated. The name must correspond to an existing policy that has ROUTE_POLICY_TYPE_IMPORT type.

Implementation

final List<String> importPolicies;