toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (advertiseMode != null) 'advertiseMode=$advertiseMode',
    if (advertisedRoutePriority != null)
      'advertisedRoutePriority=$advertisedRoutePriority',
    if (customLearnedRoutePriority != null)
      'customLearnedRoutePriority=$customLearnedRoutePriority',
    if (enable != null) 'enable=$enable',
    if (enableIpv4 != null) 'enableIpv4=$enableIpv4',
    if (enableIpv6 != null) 'enableIpv6=$enableIpv6',
    if (interfaceName != null) 'interfaceName=$interfaceName',
    if (ipAddress != null) 'ipAddress=$ipAddress',
    if (ipv4NexthopAddress != null) 'ipv4NexthopAddress=$ipv4NexthopAddress',
    if (ipv6NexthopAddress != null) 'ipv6NexthopAddress=$ipv6NexthopAddress',
    if (managementType != null) 'managementType=$managementType',
    if (md5AuthenticationKeyName != null)
      'md5AuthenticationKeyName=$md5AuthenticationKeyName',
    if (name != null) 'name=$name',
    if (peerAsn != null) 'peerAsn=$peerAsn',
    if (peerIpAddress != null) 'peerIpAddress=$peerIpAddress',
    if (peerIpv4NexthopAddress != null)
      'peerIpv4NexthopAddress=$peerIpv4NexthopAddress',
    if (peerIpv6NexthopAddress != null)
      'peerIpv6NexthopAddress=$peerIpv6NexthopAddress',
    if (routerApplianceInstance != null)
      'routerApplianceInstance=$routerApplianceInstance',
  ].join(',');
  return 'RouterBgpPeer(${$contents})';
}