RouterBgpPeerBfd class final

Constructors

RouterBgpPeerBfd({int? minReceiveInterval, int? minTransmitInterval, int? multiplier, String? sessionInitializationMode})
RouterBgpPeerBfd.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
minReceiveInterval int?
The minimum interval, in milliseconds, between BFD control packets received from the peer router. The actual value is negotiated between the two routers and is equal to the greater of this value and the transmit interval of the other router.
final
minTransmitInterval int?
The minimum interval, in milliseconds, between BFD control packets transmitted to the peer router. The actual value is negotiated between the two routers and is equal to the greater of this value and the corresponding receive interval of the other router.
final
multiplier int?
The number of consecutive BFD packets that must be missed before BFD declares that a peer is unavailable.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionInitializationMode String?
The BFD session initialization mode for this BGP peer.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String