multiplier property
The number of consecutive BFD packets that must be missed before BFD declares that a peer is unavailable.
If set, the value must be a value between 5 and 16.
The default is 5.
Implementation
final int? multiplier;
The number of consecutive BFD packets that must be missed before BFD declares that a peer is unavailable.
If set, the value must be a value between 5 and 16.
The default is 5.
final int? multiplier;