RouterBgpPeerBfd_SessionInitializationMode class final
The BFD session initialization mode for this BGP peer.
If set to ACTIVE, the Cloud Router will initiate the BFD session for this BGP peer. If set to PASSIVE, the Cloud Router will wait for the peer router to initiate the BFD session for this BGP peer. If set to DISABLED, BFD is disabled for this BGP peer. The default is DISABLED.
Constructors
- RouterBgpPeerBfd_SessionInitializationMode(String value)
-
const
- RouterBgpPeerBfd_SessionInitializationMode.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const RouterBgpPeerBfd_SessionInitializationMode
- The default value for RouterBgpPeerBfd_SessionInitializationMode.
- active → const RouterBgpPeerBfd_SessionInitializationMode
- disabled → const RouterBgpPeerBfd_SessionInitializationMode
- passive → const RouterBgpPeerBfd_SessionInitializationMode
- undefinedSessionInitializationMode → const RouterBgpPeerBfd_SessionInitializationMode
- A value indicating that the enum field is not set.