RouterBgpPeer_AdvertisedGroups class final
Constructors
- RouterBgpPeer_AdvertisedGroups(String value)
-
const
- RouterBgpPeer_AdvertisedGroups.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const RouterBgpPeer_AdvertisedGroups
- The default value for RouterBgpPeer_AdvertisedGroups.
- allSubnets → const RouterBgpPeer_AdvertisedGroups
- Advertise all available subnets (including peer VPC subnets).
- undefinedAdvertisedGroups → const RouterBgpPeer_AdvertisedGroups
- A value indicating that the enum field is not set.