RouterBgpPeer_Enable class final
The status of the BGP peer connection.
If set to FALSE, any active session with the peer is terminated and all associated routing information is removed. If set to TRUE, the peer connection can be established with routing information. The default is TRUE.
Constructors
- RouterBgpPeer_Enable(String value)
-
const
- RouterBgpPeer_Enable.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const RouterBgpPeer_Enable
- The default value for RouterBgpPeer_Enable.
- false$ → const RouterBgpPeer_Enable
- true$ → const RouterBgpPeer_Enable
- undefinedEnable → const RouterBgpPeer_Enable
- A value indicating that the enum field is not set.