linkedVpnTunnel property

String? linkedVpnTunnel
final

URI of the linked VPN tunnel, which must be in the same region as the router. Each interface can have one linked resource, which can be a VPN tunnel, an Interconnect attachment, or a subnetwork.

Implementation

final String? linkedVpnTunnel;