enableDynamicPortAllocation property
Enable Dynamic Port Allocation.
If not specified, it is disabled by default.
If set to true,
- Dynamic Port Allocation will be enabled on this NAT config.
- enableEndpointIndependentMapping cannot be set to true.
- If minPorts is set, minPortsPerVm must be set to a power of two greater than or equal to 32. If minPortsPerVm is not set, a minimum of 32 ports will be allocated to a VM from this NAT config.
Implementation
final bool? enableDynamicPortAllocation;