toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (autoNetworkTier != null) 'autoNetworkTier=$autoNetworkTier',
    if (effectiveTcpTimeWaitTimeoutSec != null)
      'effectiveTcpTimeWaitTimeoutSec=$effectiveTcpTimeWaitTimeoutSec',
    if (enableDynamicPortAllocation != null)
      'enableDynamicPortAllocation=$enableDynamicPortAllocation',
    if (enableEndpointIndependentMapping != null)
      'enableEndpointIndependentMapping=$enableEndpointIndependentMapping',
    if (icmpIdleTimeoutSec != null) 'icmpIdleTimeoutSec=$icmpIdleTimeoutSec',
    if (maxPortsPerVm != null) 'maxPortsPerVm=$maxPortsPerVm',
    if (minPortsPerVm != null) 'minPortsPerVm=$minPortsPerVm',
    if (name != null) 'name=$name',
    if (natIpAllocateOption != null)
      'natIpAllocateOption=$natIpAllocateOption',
    if (sourceSubnetworkIpRangesToNat != null)
      'sourceSubnetworkIpRangesToNat=$sourceSubnetworkIpRangesToNat',
    if (sourceSubnetworkIpRangesToNat64 != null)
      'sourceSubnetworkIpRangesToNat64=$sourceSubnetworkIpRangesToNat64',
    if (tcpEstablishedIdleTimeoutSec != null)
      'tcpEstablishedIdleTimeoutSec=$tcpEstablishedIdleTimeoutSec',
    if (tcpTimeWaitTimeoutSec != null)
      'tcpTimeWaitTimeoutSec=$tcpTimeWaitTimeoutSec',
    if (tcpTransitoryIdleTimeoutSec != null)
      'tcpTransitoryIdleTimeoutSec=$tcpTransitoryIdleTimeoutSec',
    if (type != null) 'type=$type',
    if (udpIdleTimeoutSec != null) 'udpIdleTimeoutSec=$udpIdleTimeoutSec',
  ].join(',');
  return 'RouterNat(${$contents})';
}