CEL expression that specifies the match condition that egress traffic
from a VM is evaluated against. If it evaluates to true, the
corresponding action is enforced.
An integer uniquely identifying a rule in the list. The rule number
must be a positive value between 0 and 65000, and
must be unique among rules within a NAT.