sourceNatDrainRanges property

List<String> sourceNatDrainRanges
final

A list of URLs of subnetworks representing source ranges to be drained. This is only supported on patch/update, and these subnetworks must have previously been used as active ranges in this NAT Rule. This field is used for private NAT.

Implementation

final List<String> sourceNatDrainRanges;