RouterNatSubnetworkToNat class final

Defines the IP ranges that want to use NAT for a subnetwork.

Constructors

RouterNatSubnetworkToNat({String? name, List<String> secondaryIpRangeNames = const [], List<String> sourceIpRangesToNat = const []})
RouterNatSubnetworkToNat.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
name String?
URL for the subnetwork resource that will use NAT.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryIpRangeNames List<String>
A list of the secondary ranges of the Subnetwork that are allowed to use NAT. This can be populated only if "LIST_OF_SECONDARY_IP_RANGES" is one of the values in source_ip_ranges_to_nat.
final
sourceIpRangesToNat List<String>
Specify the options for NAT ranges in the Subnetwork. All options of a single value are valid except NAT_IP_RANGE_OPTION_UNSPECIFIED. The only valid option with multiple values is: "PRIMARY_IP_RANGE", "LIST_OF_SECONDARY_IP_RANGES" Default: ALL_IP_RANGES Check the SourceIpRangesToNat enum for the list of possible values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String