RouterNat_AutoNetworkTier class final

The network tier to use when automatically reserving NAT IP addresses. Must be one of: PREMIUM, STANDARD. If not specified, then the current project-level default tier is used.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const RouterNat_AutoNetworkTier
The default value for RouterNat_AutoNetworkTier.
fixedStandard → const RouterNat_AutoNetworkTier
Public internet quality with fixed bandwidth.
premium → const RouterNat_AutoNetworkTier
High quality, Google-grade network tier, support for all networking products.
standard → const RouterNat_AutoNetworkTier
Public internet quality, only limited support for other networking products.
standardOverridesFixedStandard → const RouterNat_AutoNetworkTier
(Output only) Temporary tier for FIXED_STANDARD when fixed standard tier is expired or not configured.
undefinedAutoNetworkTier → const RouterNat_AutoNetworkTier
A value indicating that the enum field is not set.