RouterNat_SourceSubnetworkIpRangesToNat class final

Specify the Nat option, which can take one of the following values:

  • ALL_SUBNETWORKS_ALL_IP_RANGES: All of the IP ranges in every Subnetwork are allowed to Nat.
  • ALL_SUBNETWORKS_ALL_PRIMARY_IP_RANGES: All of the primary IP ranges in every Subnetwork are allowed to Nat.
  • LIST_OF_SUBNETWORKS: A list of Subnetworks are allowed to Nat (specified in the field subnetwork below)

The default is SUBNETWORK_IP_RANGE_TO_NAT_OPTION_UNSPECIFIED. Note that if this field contains ALL_SUBNETWORKS_ALL_IP_RANGES then there should not be any other Router.Nat section in any Router for this network in this region.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const RouterNat_SourceSubnetworkIpRangesToNat
The default value for RouterNat_SourceSubnetworkIpRangesToNat.
allSubnetworksAllIpRanges → const RouterNat_SourceSubnetworkIpRangesToNat
All the IP ranges in every Subnetwork are allowed to Nat.
allSubnetworksAllPrimaryIpRanges → const RouterNat_SourceSubnetworkIpRangesToNat
All the primary IP ranges in every Subnetwork are allowed to Nat.
listOfSubnetworks → const RouterNat_SourceSubnetworkIpRangesToNat
A list of Subnetworks are allowed to Nat (specified in the field subnetwork below)
undefinedSourceSubnetworkIpRangesToNat → const RouterNat_SourceSubnetworkIpRangesToNat
A value indicating that the enum field is not set.