RouterParams class final
Additional router parameters.
Constructors
-
RouterParams({Map<
String, String> resourceManagerTags = const {}}) - RouterParams.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited -
resourceManagerTags
→ Map<
String, String> -
Tag keys/values directly bound to this resource.
The field is allowed for INSERT
only. The keys/values to set on the resource should be specified in
either ID { : } or Namespaced format
{ : }.
For example the following are valid inputs:
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String