RouterStatus class final

Constructors

RouterStatus({List<Route> bestRoutes = const [], List<Route> bestRoutesForRouter = const [], List<RouterStatusBgpPeerStatus> bgpPeerStatus = const [], List<RouterStatusNatStatus> natStatus = const [], String? nccGateway, String? network})
RouterStatus.fromJson(Object? j)
factory

Properties

bestRoutes List<Route>
A list of the best dynamic routes for this Cloud Router's Virtual Private Cloud (VPC) network in the same region as this Cloud Router.
final
bestRoutesForRouter List<Route>
A list of the best BGP routes learned by this Cloud Router.
final
bgpPeerStatus List<RouterStatusBgpPeerStatus>
final
hashCode int
The hash code for this object.
no setterinherited
natStatus List<RouterStatusNatStatus>
final
nccGateway String?
URI of the ncc_gateway to which this router associated.
final
network String?
URI of the network to which this router belongs.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String