bestRoutesForRouter property

List<Route> bestRoutesForRouter
final

A list of the best BGP routes learned by this Cloud Router.

It is possible that routes listed might not be programmed into the data plane, if the Google Cloud control plane finds a more optimal route for a prefix than a route learned by this Cloud Router.

Implementation

final List<Route> bestRoutesForRouter;