routerApplianceInstance property

String? routerApplianceInstance
final

Output only. Output only URI of the VM instance that is used as third-party router appliances such as Next Gen Firewalls, Virtual Routers, or Router Appliances. The VM instance is the peer side of the BGP session.

Implementation

final String? routerApplianceInstance;