state property
Output only. The state of the BGP session. For a list of possible values for this field, seeBGP session states.
Implementation
final String? state;
Output only. The state of the BGP session. For a list of possible values for this field, seeBGP session states.
final String? state;