status property
Output only. Status of the BGP peer: {UP, DOWN} Check the Status enum for the list of possible values.
Implementation
final String? status;
Output only. Status of the BGP peer: {UP, DOWN} Check the Status enum for the list of possible values.
final String? status;