RouterStatusBgpPeerStatus_StatusReason class final

Indicates why particular status was returned.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const RouterStatusBgpPeerStatus_StatusReason
The default value for RouterStatusBgpPeerStatus_StatusReason.
ipv4PeerOnIpv6OnlyConnection → const RouterStatusBgpPeerStatus_StatusReason
BGP peer disabled because it requires IPv4 but the underlying connection is IPv6-only.
ipv6PeerOnIpv4OnlyConnection → const RouterStatusBgpPeerStatus_StatusReason
BGP peer disabled because it requires IPv6 but the underlying connection is IPv4-only.
md5AuthInternalProblem → const RouterStatusBgpPeerStatus_StatusReason
Indicates internal problems with configuration of MD5 authentication. This particular reason can only be returned when md5AuthEnabled is true and status is DOWN.
statusReasonUnspecified → const RouterStatusBgpPeerStatus_StatusReason
undefinedStatusReason → const RouterStatusBgpPeerStatus_StatusReason
A value indicating that the enum field is not set.