Routes class final

The Routes API.

Implementers

Constructors

Routes({required Client client, Uri? endPoint, String? gcclVersion})
Creates a Routes using client for transport.
Routes.fromApiKey([String? apiKey])
Creates a Routes that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteRouteRequest request) Future<Operation>
Deletes the specified Route resource.
get(GetRouteRequest request) Future<Route>
Returns the specified Route resource.
insert(InsertRouteRequest request) Future<Operation>
Creates a Route resource in the specified project using the data included in the request.
list(ListRoutesRequest request) Future<RouteList>
Retrieves the list of Route resources available to the specified project.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
testIamPermissions(TestIamPermissionsRouteRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited