insert method

Future<Operation> insert(
  1. InsertRouteRequest request
)

Creates a Route resource in the specified project using the data included in the request.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> insert(InsertRouteRequest request) async {
  final url = _endPoint.replace(
    path: '/compute/v1/projects/${request.project}/global/routes',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.post(url, body: request.routeResource);
  return Operation.fromJson(response);
}