index property
Output only. Specifies zero-based index of the disk that is attached to the source instance.
Implementation
final int? index;
Output only. Specifies zero-based index of the disk that is attached to the source instance.
final int? index;