autoDelete property
Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance).
Implementation
final bool? autoDelete;
Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance).
final bool? autoDelete;