boot property
Indicates that this is a boot disk. The virtual machine will use the first partition of the disk for its root filesystem.
Implementation
final bool? boot;
Indicates that this is a boot disk. The virtual machine will use the first partition of the disk for its root filesystem.
final bool? boot;