mode property

String? mode
final

The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. Check the Mode enum for the list of possible values.

Implementation

final String? mode;