storageBytes property
Output only. Output Only A size of the storage used by the disk's snapshot by this
machine image.
Implementation
final int? storageBytes;
Output only. Output Only A size of the storage used by the disk's snapshot by this
machine image.
final int? storageBytes;