toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (autoDelete != null) 'autoDelete=$autoDelete',
    if (boot != null) 'boot=$boot',
    if (deviceName != null) 'deviceName=$deviceName',
    if (diskSizeGb != null) 'diskSizeGb=$diskSizeGb',
    if (diskType != null) 'diskType=$diskType',
    if (index != null) 'index=$index',
    if (interface != null) 'interface=$interface',
    if (kind != null) 'kind=$kind',
    if (mode != null) 'mode=$mode',
    if (source != null) 'source=$source',
    if (storageBytes != null) 'storageBytes=$storageBytes',
    if (storageBytesStatus != null) 'storageBytesStatus=$storageBytesStatus',
    if (type != null) 'type=$type',
  ].join(',');
  return 'SavedAttachedDisk(${$contents})';
}