SavedAttachedDisk_Interface class final

Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const SavedAttachedDisk_Interface
The default value for SavedAttachedDisk_Interface.
nvme → const SavedAttachedDisk_Interface
scsi → const SavedAttachedDisk_Interface
undefinedInterface → const SavedAttachedDisk_Interface
A value indicating that the enum field is not set.