SavedDisk class final
An instance-attached disk resource.
Constructors
Properties
- architecture → String?
-
Output only.
Output OnlyThe architecture of the attached disk. Check the Architecture enum for the list of possible values.final - hashCode → int
-
The hash code for this object.
no setterinherited
- kind → String?
-
Output only.
Output OnlyType of the resource. Always compute#savedDisk for attached disks.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceDisk → String?
-
Output only. Specifies a URL of the disk attached to the source instance.
final
- storageBytes → int?
-
Output only.
Output OnlySize of the individual disk snapshot used by this machine image.final - storageBytesStatus → String?
-
Output only.
Output OnlyAn indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be UPDATING, meaning the size of the snapshot is being updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date. Check the StorageBytesStatus enum for the list of possible values.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String