architecture property
Output only. Output Only The architecture of the attached disk.
Check the Architecture enum for the list of possible values.
Implementation
final String? architecture;
Output only. Output Only The architecture of the attached disk.
Check the Architecture enum for the list of possible values.
final String? architecture;