storageBytes property
Output only. Output Only Size of the individual disk snapshot used by this machine
image.
Implementation
final int? storageBytes;
Output only. Output Only Size of the individual disk snapshot used by this machine
image.
final int? storageBytes;