SavedDisk_Architecture class final

Output only. Output Only The architecture of the attached disk.

Constructors

SavedDisk_Architecture(String value)
const
SavedDisk_Architecture.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const SavedDisk_Architecture
The default value for SavedDisk_Architecture.
architectureUnspecified → const SavedDisk_Architecture
Default value indicating Architecture is not set.
arm64 → const SavedDisk_Architecture
Machines with architecture ARM64
undefinedArchitecture → const SavedDisk_Architecture
A value indicating that the enum field is not set.
x8664 → const SavedDisk_Architecture
Machines with architecture X86_64