SavedDisk_StorageBytesStatus class final

Output only. Output Only An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be UPDATING, meaning the size of the snapshot is being updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const SavedDisk_StorageBytesStatus
The default value for SavedDisk_StorageBytesStatus.
undefinedStorageBytesStatus → const SavedDisk_StorageBytesStatus
A value indicating that the enum field is not set.
updating → const SavedDisk_StorageBytesStatus
upToDate → const SavedDisk_StorageBytesStatus