ScalingScheduleStatus class final

Constructors

ScalingScheduleStatus({String? lastStartTime, String? nextStartTime, String? state})
ScalingScheduleStatus.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
lastStartTime String?
Output Only The last time the scaling schedule became active. Note: this is a timestamp when a schedule actually became active, not when it was planned to do so. The timestamp is in RFC3339 text format.
final
nextStartTime String?
Output Only The next time the scaling schedule is to become active. Note: this is a timestamp when a schedule is planned to run, but the actual time might be slightly different. The timestamp is in RFC3339 text format.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
Output Only The current state of a scaling schedule. Check the State enum for the list of possible values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String