state property
Output Only The current state of a scaling schedule.
Check the State enum for the list of possible values.
Implementation
final String? state;
Output Only The current state of a scaling schedule.
Check the State enum for the list of possible values.
final String? state;