ScalingScheduleStatus_State class final

Output Only The current state of a scaling schedule.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const ScalingScheduleStatus_State
The default value for ScalingScheduleStatus_State.
active → const ScalingScheduleStatus_State
The current autoscaling recommendation is influenced by this scaling schedule.
disabled → const ScalingScheduleStatus_State
This scaling schedule has been disabled by the user.
obsolete → const ScalingScheduleStatus_State
This scaling schedule will never become active again.
ready → const ScalingScheduleStatus_State
The current autoscaling recommendation is not influenced by this scaling schedule.
undefinedState → const ScalingScheduleStatus_State
A value indicating that the enum field is not set.