disabled constant
ScalingScheduleStatus_State
const disabled
This scaling schedule has been disabled by the user.
Implementation
static const disabled = ScalingScheduleStatus_State('DISABLED');
This scaling schedule has been disabled by the user.
static const disabled = ScalingScheduleStatus_State('DISABLED');