Scheduling class final

Sets the scheduling options for an Instance.

Constructors

Scheduling({bool? automaticRestart, int? availabilityDomain, SchedulingGracefulShutdown? gracefulShutdown, int? hostErrorTimeoutSeconds, String? instanceTerminationAction, Duration? localSsdRecoveryTimeout, String? locationHint, Duration? maxRunDuration, int? minNodeCpus, List<SchedulingNodeAffinity> nodeAffinities = const [], String? onHostMaintenance, SchedulingOnInstanceStopAction? onInstanceStopAction, bool? preemptible, Duration? preemptionNoticeDuration, String? provisioningModel, bool? skipGuestOsShutdown, String? terminationTime})
Scheduling.fromJson(Object? j)
factory

Properties

automaticRestart bool?
Specifies whether the instance should be automatically restarted if it is terminated by Compute Engine (not terminated by a user). You can only set the automatic restart option for standard instances.Preemptible instances cannot be automatically restarted.
final
availabilityDomain int?
Specifies the availability domain to place the instance in. The value must be a number between 1 and the number of availability domains specified in the spread placement policy attached to the instance.
final
gracefulShutdown SchedulingGracefulShutdown?
final
hashCode int
The hash code for this object.
no setterinherited
hostErrorTimeoutSeconds int?
Specify the time in seconds for host error detection, the value must be within the range of 90, 330 with the increment of 30, if unset, the default behavior of host error recovery will be used.
final
instanceTerminationAction String?
Specifies the termination action for the instance. Check the InstanceTerminationAction enum for the list of possible values.
final
localSsdRecoveryTimeout Duration?
Specifies the maximum amount of time a Local Ssd Vm should wait while recovery of the Local Ssd state is attempted. Its value should be in between 0 and 168 hours with hour granularity and the default value being 1 hour.
final
locationHint String?
An opaque location hint used to place the instance close to other resources. This field is for use by internal tools that use the public API.
final
maxRunDuration Duration?
Specifies the max run duration for the given instance. If specified, the instance termination action will be performed at the end of the run duration.
final
minNodeCpus int?
The minimum number of virtual CPUs this instance will consume when running on a sole-tenant node.
final
nodeAffinities List<SchedulingNodeAffinity>
A set of node affinity and anti-affinity configurations. Refer toConfiguring node affinity for more information. Overrides reservationAffinity.
final
onHostMaintenance String?
Defines the maintenance behavior for this instance. For standard instances, the default behavior is MIGRATE. Forpreemptible instances, the default and only possible behavior is TERMINATE. For more information, see Set VM host maintenance policy. Check the OnHostMaintenance enum for the list of possible values.
final
onInstanceStopAction SchedulingOnInstanceStopAction?
final
preemptible bool?
Defines whether the instance is preemptible. This can only be set during instance creation or while the instance isstopped and therefore, in a TERMINATED state. SeeInstance Life Cycle for more information on the possible instance states.
final
preemptionNoticeDuration Duration?
Specifies the Metadata Service preemption notice duration before the GCE ACPI G2 Soft Off signal is triggered for Spot VMs only. If not specified, there will be no wait before the G2 Soft Off signal is triggered.
final
provisioningModel String?
Specifies the provisioning model of the instance. Check the ProvisioningModel enum for the list of possible values.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skipGuestOsShutdown bool?
Default is false and there will be 120 seconds between GCE ACPI G2 Soft Off and ACPI G3 Mechanical Off for Standard VMs and 30 seconds for Spot VMs.
final
terminationTime String?
Specifies the timestamp, when the instance will be terminated, inRFC3339 text format. If specified, the instance termination action will be performed at the termination time.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String