availabilityDomain property

int? availabilityDomain
final

Specifies the availability domain to place the instance in. The value must be a number between 1 and the number of availability domains specified in the spread placement policy attached to the instance.

Implementation

final int? availabilityDomain;