exposeHostTopology property
This optional flag exposes the hashed physical host ID in the ResourceStatus resource of the VM.
Implementation
final bool? exposeHostTopology;
This optional flag exposes the hashed physical host ID in the ResourceStatus resource of the VM.
final bool? exposeHostTopology;