hostErrorTimeoutSeconds property

int? hostErrorTimeoutSeconds
final

Specify the time in seconds for host error detection, the value must be within the range of 90, 330 with the increment of 30, if unset, the default behavior of host error recovery will be used.

Implementation

final int? hostErrorTimeoutSeconds;