maxRunDuration property

Duration? maxRunDuration
final

Specifies the max run duration for the given instance. If specified, the instance termination action will be performed at the end of the run duration.

Implementation

final Duration? maxRunDuration;