preemptionNoticeDuration property

Duration? preemptionNoticeDuration
final

Specifies the Metadata Service preemption notice duration before the GCE ACPI G2 Soft Off signal is triggered for Spot VMs only. If not specified, there will be no wait before the G2 Soft Off signal is triggered.

Implementation

final Duration? preemptionNoticeDuration;