toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (automaticRestart != null) 'automaticRestart=$automaticRestart',
    if (availabilityDomain != null) 'availabilityDomain=$availabilityDomain',
    if (hostErrorTimeoutSeconds != null)
      'hostErrorTimeoutSeconds=$hostErrorTimeoutSeconds',
    if (instanceTerminationAction != null)
      'instanceTerminationAction=$instanceTerminationAction',
    if (locationHint != null) 'locationHint=$locationHint',
    if (minNodeCpus != null) 'minNodeCpus=$minNodeCpus',
    if (onHostMaintenance != null) 'onHostMaintenance=$onHostMaintenance',
    if (preemptible != null) 'preemptible=$preemptible',
    if (provisioningModel != null) 'provisioningModel=$provisioningModel',
    if (skipGuestOsShutdown != null)
      'skipGuestOsShutdown=$skipGuestOsShutdown',
    if (terminationTime != null) 'terminationTime=$terminationTime',
  ].join(',');
  return 'Scheduling(${$contents})';
}