SchedulingGracefulShutdown class final

The configuration for gracefully shutting down the instance.

Constructors

SchedulingGracefulShutdown({bool? enabled, Duration? maxDuration})
SchedulingGracefulShutdown.fromJson(Object? j)
factory

Properties

enabled bool?
Opts-in for graceful shutdown.
final
hashCode int
The hash code for this object.
no setterinherited
maxDuration Duration?
The time allotted for the instance to gracefully shut down. If the graceful shutdown isn't complete after this time, then the instance transitions to the STOPPING state.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String