SchedulingNodeAffinity class final

Node Affinity: the configuration of desired nodes onto which this Instance could be scheduled.

Constructors

SchedulingNodeAffinity({String? key, String? operator, List<String> values = const []})
SchedulingNodeAffinity.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
key String?
Corresponds to the label key of Node resource.
final
operator String?
Defines the operation of node selection. Valid operators areIN for affinity and NOT_IN for anti-affinity. Check the Operator enum for the list of possible values.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List<String>
Corresponds to the label values of Node resource.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String