operator property
Defines the operation of node selection. Valid operators areIN for affinity and NOT_IN for anti-affinity. Check the Operator enum for the list of possible values.
Implementation
final String? operator;
Defines the operation of node selection. Valid operators areIN for affinity and NOT_IN for anti-affinity. Check the Operator enum for the list of possible values.
final String? operator;