SchedulingNodeAffinity_Operator class final
Defines the operation of node selection. Valid operators areIN for affinity and NOT_IN for anti-affinity.
Constructors
- SchedulingNodeAffinity_Operator(String value)
-
const
- SchedulingNodeAffinity_Operator.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const SchedulingNodeAffinity_Operator
- The default value for SchedulingNodeAffinity_Operator.
- in$ → const SchedulingNodeAffinity_Operator
- Requires Compute Engine to seek for matched nodes.
- notIn → const SchedulingNodeAffinity_Operator
- Requires Compute Engine to avoid certain nodes.
- operatorUnspecified → const SchedulingNodeAffinity_Operator
- undefinedOperator → const SchedulingNodeAffinity_Operator
- A value indicating that the enum field is not set.