Scheduling_OnHostMaintenance class final

Defines the maintenance behavior for this instance. For standard instances, the default behavior is MIGRATE. Forpreemptible instances, the default and only possible behavior is TERMINATE. For more information, see Set VM host maintenance policy.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const Scheduling_OnHostMaintenance
The default value for Scheduling_OnHostMaintenance.
migrate → const Scheduling_OnHostMaintenance
Default Allows Compute Engine to automatically migrate instances out of the way of maintenance events.
terminate → const Scheduling_OnHostMaintenance
Tells Compute Engine to terminate and (optionally) restart the instance away from the maintenance activity. If you would like your instance to be restarted, set the automaticRestart flag to true. Your instance may be restarted more than once, and it may be restarted outside the window of maintenance events.
undefinedOnHostMaintenance → const Scheduling_OnHostMaintenance
A value indicating that the enum field is not set.