SecurityPolicies class final
The SecurityPolicies API.
- Implementers
Constructors
- SecurityPolicies({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
SecurityPoliciesusingclientfor transport. - SecurityPolicies.fromApiKey([String? apiKey])
-
Creates a
SecurityPoliciesthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRule(
AddRuleSecurityPolicyRequest request) → Future< Operation> - Inserts a rule into a security policy.
-
aggregatedList(
AggregatedListSecurityPoliciesRequest request) → Future< SecurityPoliciesAggregatedList> - Retrieves the list of all SecurityPolicy resources, regional and global, available to the specified project.
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteSecurityPolicyRequest request) → Future< Operation> - Deletes the specified policy.
-
get(
GetSecurityPolicyRequest request) → Future< SecurityPolicy> - List all of the ordered rules present in a single specified policy.
-
getRule(
GetRuleSecurityPolicyRequest request) → Future< SecurityPolicyRule> - Gets a rule at the specified priority.
-
insert(
InsertSecurityPolicyRequest request) → Future< Operation> - Creates a new policy in the specified project using the data included in the request.
-
list(
ListSecurityPoliciesRequest request) → Future< SecurityPolicyList> - List all the policies that have been configured for the specified project.
-
listPreconfiguredExpressionSets(
ListPreconfiguredExpressionSetsSecurityPoliciesRequest request) → Future< SecurityPoliciesListPreconfiguredExpressionSetsResponse> - Gets the current list of preconfigured Web Application Firewall (WAF) expressions.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchSecurityPolicyRequest request) → Future< Operation> - Patches the specified policy with the data included in the request. To clear fields in the policy, leave the fields empty and specify them in the updateMask. This cannot be used to be update the rules in the policy. Please use the per rule methods like addRule, patchRule, and removeRule instead.
-
patchRule(
PatchRuleSecurityPolicyRequest request) → Future< Operation> - Patches a rule at the specified priority. To clear fields in the rule, leave the fields empty and specify them in the updateMask.
-
removeRule(
RemoveRuleSecurityPolicyRequest request) → Future< Operation> - Deletes a rule at the specified priority.
-
setLabels(
SetLabelsSecurityPolicyRequest request) → Future< Operation> - Sets the labels on a security policy. To learn more about labels, read the Labeling Resources documentation.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited