SecurityPolicy class final

Represents a Google Cloud Armor security policy resource.

Only external backend services that use load balancers can reference a security policy. For more information, see Google Cloud Armor security policy overview.

Constructors

SecurityPolicy({SecurityPolicyAdaptiveProtectionConfig? adaptiveProtectionConfig, SecurityPolicyAdvancedOptionsConfig? advancedOptionsConfig, List<SecurityPolicyAssociation> associations = const [], String? creationTimestamp, SecurityPolicyDdosProtectionConfig? ddosProtectionConfig, String? description, String? fingerprint, BigInt? id, String? kind, String? labelFingerprint, Map<String, String> labels = const {}, String? name, String? parent, SecurityPolicyRecaptchaOptionsConfig? recaptchaOptionsConfig, String? region, List<SecurityPolicyRule> rules = const [], String? selfLink, String? shortName, String? type, List<SecurityPolicyUserDefinedField> userDefinedFields = const []})
SecurityPolicy.fromJson(Object? j)
factory

Properties

adaptiveProtectionConfig SecurityPolicyAdaptiveProtectionConfig?
final
advancedOptionsConfig SecurityPolicyAdvancedOptionsConfig?
final
associations List<SecurityPolicyAssociation>
A list of associations that belong to this policy.
final
creationTimestamp String?
Output only. Output Only Creation timestamp inRFC3339 text format.
final
ddosProtectionConfig SecurityPolicyDdosProtectionConfig?
final
description String?
An optional description of this resource. Provide this property when you create the resource.
final
fingerprint String?
Specifies a fingerprint for this resource, which is essentially a hash of the metadata's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update metadata. You must always provide an up-to-date fingerprint hash in order to update or change metadata, otherwise the request will fail with error412 conditionNotMet.
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output only. Output Only The unique identifier for the resource. This identifier is defined by the server.
final
kind String?
Output only. Output only Type of the resource. Alwayscompute#securityPolicyfor security policies
final
labelFingerprint String?
A fingerprint for the labels being applied to this security policy, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels.
final
labels Map<String, String>
Labels for this resource. These can only be added or modified by thesetLabels method. Each label key/value pair must comply withRFC1035. Label values may be empty.
final
name String?
Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
parent String?
Output only. Output Only The parent of the security policy.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
recaptchaOptionsConfig SecurityPolicyRecaptchaOptionsConfig?
final
region String?
Output only. Output Only URL of the region where the regional security policy resides. This field is not applicable to global security policies.
final
rules List<SecurityPolicyRule>
A list of rules that belong to this policy. There must always be a default rule which is a rule with priority 2147483647 and match all condition (for the match condition this means match "" for srcIpRanges and for the networkMatch condition every field must be either match "" or not set). If no rules are provided when creating a security policy, a default rule with action "allow" will be added.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output only. Output Only Server-defined URL for the resource.
final
shortName String?
User-provided name of the organization security policy. The name should be unique in the organization in which the security policy is created. This should only be used when SecurityPolicyType is CLOUD_ARMOR. The name must be 1-63 characters long, and comply with https://www.ietf.org/rfc/rfc1035.txt. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
type String?
The type indicates the intended use of the security policy.
final
userDefinedFields List<SecurityPolicyUserDefinedField>
Definitions of user-defined fields for CLOUD_ARMOR_NETWORK policies. A user-defined field consists of up to 4 bytes extracted from a fixed offset in the packet, relative to the IPv4, IPv6, TCP, or UDP header, with an optional mask to select certain bits. Rules may then specify matching values for these fields.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String