region property

String? region
final

Output only. Output Only URL of the region where the regional security policy resides. This field is not applicable to global security policies.

Implementation

final String? region;