name property
The name must be 1-63 characters long, and comply withRFC1035. The name must be unique within the security policy.
Implementation
final String? name;
The name must be 1-63 characters long, and comply withRFC1035. The name must be unique within the security policy.
final String? name;