toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (autoDeployConfidenceThreshold != null)
      'autoDeployConfidenceThreshold=$autoDeployConfidenceThreshold',
    if (autoDeployExpirationSec != null)
      'autoDeployExpirationSec=$autoDeployExpirationSec',
    if (autoDeployImpactedBaselineThreshold != null)
      'autoDeployImpactedBaselineThreshold=$autoDeployImpactedBaselineThreshold',
    if (autoDeployLoadThreshold != null)
      'autoDeployLoadThreshold=$autoDeployLoadThreshold',
    if (detectionAbsoluteQps != null)
      'detectionAbsoluteQps=$detectionAbsoluteQps',
    if (detectionLoadThreshold != null)
      'detectionLoadThreshold=$detectionLoadThreshold',
    if (detectionRelativeToBaselineQps != null)
      'detectionRelativeToBaselineQps=$detectionRelativeToBaselineQps',
    if (name != null) 'name=$name',
  ].join(',');
  return 'SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig(${$contents})';
}