enableEachUniqueValue property

bool? enableEachUniqueValue
final

If enabled, traffic matching each unique value for the specified type constitutes a separate traffic unit. It can only be set to true if value is empty.

Implementation

final bool? enableEachUniqueValue;