SecurityPolicyAdvancedOptionsConfig class final

Constructors

SecurityPolicyAdvancedOptionsConfig({SecurityPolicyAdvancedOptionsConfigJsonCustomConfig? jsonCustomConfig, String? jsonParsing, String? logLevel, String? requestBodyInspectionSize, List<String> userIpRequestHeaders = const []})
SecurityPolicyAdvancedOptionsConfig.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
jsonCustomConfig SecurityPolicyAdvancedOptionsConfigJsonCustomConfig?
Custom configuration to apply the JSON parsing. Only applicable when json_parsing is set to STANDARD.
final
jsonParsing String?
Check the JsonParsing enum for the list of possible values.
final
logLevel String?
Check the LogLevel enum for the list of possible values.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requestBodyInspectionSize String?
The maximum request size chosen by the customer with Waf enabled. Values supported are "8KB", "16KB, "32KB", "48KB" and "64KB". Values are case insensitive.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userIpRequestHeaders List<String>
An optional list of case-insensitive request header names to use for resolving the callers client IP address.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String