SecurityPolicyAssociation class final

Constructors

SecurityPolicyAssociation({String? attachmentId, String? displayName, List<String> excludedFolders = const [], List<String> excludedProjects = const [], String? name, String? securityPolicyId, String? shortName})
SecurityPolicyAssociation.fromJson(Object? j)
factory

Properties

attachmentId String?
The resource that the security policy is attached to.
final
displayName String?
Output only. Output Only The display name of the security policy of the association.
final
excludedFolders List<String>
A list of folders to exclude from the security policy.
final
excludedProjects List<String>
A list of projects to exclude from the security policy.
final
hashCode int
The hash code for this object.
no setterinherited
name String?
The name for an association.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
securityPolicyId String?
Output only. Output Only The security policy ID of the association.
final
shortName String?
Output only. Output Only The short name of the security policy of the association.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String