displayName property
Output only. Output Only The display name of the security policy of the association.
Implementation
final String? displayName;
Output only. Output Only The display name of the security policy of the association.
final String? displayName;