shortName property
Output only. Output Only The short name of the security policy of the association.
Implementation
final String? shortName;
Output only. Output Only The short name of the security policy of the association.
final String? shortName;