SecurityPolicyDdosProtectionConfig class final

Constructors

SecurityPolicyDdosProtectionConfig({String? ddosAdaptiveProtection, double? ddosImpactedBaselineThreshold, String? ddosProtection})
SecurityPolicyDdosProtectionConfig.fromJson(Object? j)
factory

Properties

ddosAdaptiveProtection String?
Check the DdosAdaptiveProtection enum for the list of possible values.
final
ddosImpactedBaselineThreshold double?
DDoS Protection for Network Load Balancers (and VMs with public IPs) builds DDoS mitigations that minimize collateral damage. It quantifies this as the fraction of a non-abuse baseline that's inadvertently blocked.
final
ddosProtection String?
Check the DdosProtection enum for the list of possible values.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String