SecurityPolicyDdosProtectionConfig_DdosProtection class final
Constructors
- SecurityPolicyDdosProtectionConfig_DdosProtection(String value)
-
const
- SecurityPolicyDdosProtectionConfig_DdosProtection.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const SecurityPolicyDdosProtectionConfig_DdosProtection
- The default value for SecurityPolicyDdosProtectionConfig_DdosProtection.
- advanced → const SecurityPolicyDdosProtectionConfig_DdosProtection
- advancedPreview → const SecurityPolicyDdosProtectionConfig_DdosProtection
- standard → const SecurityPolicyDdosProtectionConfig_DdosProtection
- undefinedDdosProtection → const SecurityPolicyDdosProtectionConfig_DdosProtection
- A value indicating that the enum field is not set.