SecurityPolicyRule class final
Represents a rule that describes one or more match conditions along with the action to be taken when traffic matches this condition (allow or deny).
Constructors
- SecurityPolicyRule({String? action, String? description, SecurityPolicyRuleHttpHeaderAction? headerAction, String? kind, SecurityPolicyRuleMatcher? match, SecurityPolicyRuleNetworkMatcher? networkMatch, SecurityPolicyRulePreconfiguredWafConfig? preconfiguredWafConfig, bool? preview, int? priority, SecurityPolicyRuleRateLimitOptions? rateLimitOptions, SecurityPolicyRuleRedirectOptions? redirectOptions})
- SecurityPolicyRule.fromJson(Object? j)
-
factory
Properties
- action → String?
-
The Action to perform when the rule is matched.
The following are the valid actions:
final
- description → String?
-
An optional description of this resource. Provide this property when you
create the resource.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerAction → SecurityPolicyRuleHttpHeaderAction?
-
Optional, additional actions that are performed on headers.
This field is only supported in Global Security Policies of type
CLOUD_ARMOR.
final
- kind → String?
-
Output only.
Output onlyType of the resource. Alwayscompute#securityPolicyRule for security policy rulesfinal - match → SecurityPolicyRuleMatcher?
-
A match condition that incoming traffic is evaluated against.
If it evaluates to true, the corresponding 'action' is enforced.
final
- networkMatch → SecurityPolicyRuleNetworkMatcher?
-
A match condition that incoming packets are evaluated against for
CLOUD_ARMOR_NETWORK security policies. If it matches, the corresponding
'action' is enforced.
final
- preconfiguredWafConfig → SecurityPolicyRulePreconfiguredWafConfig?
-
Preconfigured WAF configuration to be applied for the rule. If the rule
does not evaluate preconfigured WAF rules, i.e., if
evaluatePreconfiguredWaf() is not used, this field will have no effect.
final
- preview → bool?
-
If set to true, the specified action is not enforced.
final
- priority → int?
-
An integer indicating the priority of a rule in the list. The priority
must be a positive value between 0 and 2147483647.
Rules are evaluated from highest to lowest priority where 0 is the
highest priority and 2147483647 is the lowest priority.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - rateLimitOptions → SecurityPolicyRuleRateLimitOptions?
-
Must be specified if the action is "rate_based_ban" or "throttle" or
"fairshare". Cannot be specified for any other actions.
final
- redirectOptions → SecurityPolicyRuleRedirectOptions?
-
Parameters defining the redirect action. Cannot be specified for any
other actions.
This field is only supported in Global Security Policies of type
CLOUD_ARMOR.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String