requestHeadersToAdds property
The list of request headers to add or overwrite if they're already present.
Implementation
final List<SecurityPolicyRuleHttpHeaderActionHttpHeaderOption>
requestHeadersToAdds;
The list of request headers to add or overwrite if they're already present.
final List<SecurityPolicyRuleHttpHeaderActionHttpHeaderOption>
requestHeadersToAdds;