SecurityPolicyRuleHttpHeaderActionHttpHeaderOption class final
Constructors
- SecurityPolicyRuleHttpHeaderActionHttpHeaderOption({String? headerName, String? headerValue})
- SecurityPolicyRuleHttpHeaderActionHttpHeaderOption.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerName → String?
-
The name of the header to set.
final
- headerValue → String?
-
The value to set the named header to.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String