SecurityPolicyRuleMatcher class final
Represents a match condition that incoming traffic is evaluated against. Exactly one field must be specified.
Constructors
- SecurityPolicyRuleMatcher({SecurityPolicyRuleMatcherConfig? config, Expr? expr, SecurityPolicyRuleMatcherExprOptions? exprOptions, String? versionedExpr})
- SecurityPolicyRuleMatcher.fromJson(Object? j)
-
factory
Properties
- config → SecurityPolicyRuleMatcherConfig?
-
The configuration options available when specifying versioned_expr.
This field must be specified if versioned_expr is specified and cannot
be specified if versioned_expr is not specified.
final
- expr → Expr?
-
User defined CEVAL expression.
A CEVAL expression is used to specify match criteria such as origin.ip,
source.region_code and contents in the request header.
Expressions containing
evaluateThreatIntelligencerequire a Cloud Armor Enterprise subscription and are not supported in Edge Policies nor in Regional Policies. Expressions containingevaluatePreconfiguredExpr('sourceiplist-*')require a Cloud Armor Enterprise subscription and are only supported in Global Security Policies.final - exprOptions → SecurityPolicyRuleMatcherExprOptions?
-
The configuration options available when specifying a user defined
CEVAL expression (i.e., 'expr').
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- versionedExpr → String?
-
Preconfigured versioned expression.
If this field is specified, config must also be specified.
Available preconfigured expressions along with their requirements are:
SRC_IPS_V1 - must specify the corresponding src_ip_range field in
config.
Check the VersionedExpr enum for the list of possible values.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String