exprOptions property
The configuration options available when specifying a user defined CEVAL expression (i.e., 'expr').
Implementation
final SecurityPolicyRuleMatcherExprOptions? exprOptions;
The configuration options available when specifying a user defined CEVAL expression (i.e., 'expr').
final SecurityPolicyRuleMatcherExprOptions? exprOptions;