SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions class final

Constructors

SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions({List<String> actionTokenSiteKeys = const [], List<String> sessionTokenSiteKeys = const []})
SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions.fromJson(Object? j)
factory

Properties

actionTokenSiteKeys List<String>
A list of site keys to be used during the validation of reCAPTCHA action-tokens. The provided site keys need to be created from reCAPTCHA API under the same project where the security policy is created.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionTokenSiteKeys List<String>
A list of site keys to be used during the validation of reCAPTCHA session-tokens. The provided site keys need to be created from reCAPTCHA API under the same project where the security policy is created.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String