sessionTokenSiteKeys property
A list of site keys to be used during the validation of reCAPTCHA session-tokens. The provided site keys need to be created from reCAPTCHA API under the same project where the security policy is created.
Implementation
final List<String> sessionTokenSiteKeys;