SecurityPolicyRuleMatcher_VersionedExpr class final

Preconfigured versioned expression. If this field is specified, config must also be specified. Available preconfigured expressions along with their requirements are: SRC_IPS_V1 - must specify the corresponding src_ip_range field in config.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const SecurityPolicyRuleMatcher_VersionedExpr
The default value for SecurityPolicyRuleMatcher_VersionedExpr.
srcIpsV1 → const SecurityPolicyRuleMatcher_VersionedExpr
Matches the source IP address of a request to the IP ranges supplied in config.
undefinedVersionedExpr → const SecurityPolicyRuleMatcher_VersionedExpr
A value indicating that the enum field is not set.