userDefinedFields property
User-defined fields. Each element names a defined field and lists the matching values for that field.
Implementation
final List<SecurityPolicyRuleNetworkMatcherUserDefinedFieldMatch>
userDefinedFields;
User-defined fields. Each element names a defined field and lists the matching values for that field.
final List<SecurityPolicyRuleNetworkMatcherUserDefinedFieldMatch>
userDefinedFields;