requestQueryParamsToExclude property

A list of request query parameter names whose value will be excluded from inspection during preconfigured WAF evaluation. Note that the parameter can be in the query string or in the POST body.

Implementation

final List<SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
requestQueryParamsToExclude;