requestUrisToExclude property
A list of request URIs from the request line to be excluded from inspection during preconfigured WAF evaluation. When specifying this field, the query or fragment part should be excluded.
Implementation
final List<SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
requestUrisToExclude;