SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams class
final
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
op
→ String?
-
The match operator for the field.
Check the Op enum for the list of possible values.
final
-
qualifiedName
→ String
-
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or google.rpc.ErrorInfo.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
val
→ String?
-
The value of the field.
final