SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams_Op class final

The match operator for the field.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams_Op
The default value for SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams_Op.
contains → const SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams_Op
The operator matches if the field value contains the specified value.
endsWith → const SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams_Op
The operator matches if the field value ends with the specified value.
equals → const SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams_Op
The operator matches if the field value equals the specified value.
equalsAny → const SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams_Op
The operator matches if the field value is any value.
startsWith → const SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams_Op
The operator matches if the field value starts with the specified value.
undefinedOp → const SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams_Op
A value indicating that the enum field is not set.