endsWith constant
The operator matches if the field value ends with the specified value.
Implementation
static const endsWith =
SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams_Op(
'ENDS_WITH',
);
The operator matches if the field value ends with the specified value.
static const endsWith =
SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams_Op(
'ENDS_WITH',
);