SecurityPolicyRuleRateLimitOptions class final

Constructors

SecurityPolicyRuleRateLimitOptions({int? banDurationSec, SecurityPolicyRuleRateLimitOptionsThreshold? banThreshold, String? conformAction, String? enforceOnKey, List<SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig> enforceOnKeyConfigs = const [], String? enforceOnKeyName, String? exceedAction, SecurityPolicyRuleRedirectOptions? exceedRedirectOptions, SecurityPolicyRuleRateLimitOptionsThreshold? rateLimitThreshold})
SecurityPolicyRuleRateLimitOptions.fromJson(Object? j)
factory

Properties

banDurationSec int?
Can only be specified if the action for the rule is "rate_based_ban". If specified, determines the time (in seconds) the traffic will continue to be banned by the rate limit after the rate falls below the threshold.
final
banThreshold SecurityPolicyRuleRateLimitOptionsThreshold?
Can only be specified if the action for the rule is "rate_based_ban". If specified, the key will be banned for the configured 'ban_duration_sec' when the number of requests that exceed the 'rate_limit_threshold' also exceed this 'ban_threshold'.
final
conformAction String?
Action to take for requests that are under the configured rate limit threshold. Valid option is "allow" only.
final
enforceOnKey String?
Determines the key to enforce the rate_limit_threshold on. Possible values are:
final
enforceOnKeyConfigs List<SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig>
If specified, any combination of values of enforce_on_key_type/enforce_on_key_name is treated as the key on which ratelimit threshold/action is enforced. You can specify up to 3 enforce_on_key_configs. If enforce_on_key_configs is specified, enforce_on_key must not be specified.
final
enforceOnKeyName String?
Rate limit key name applicable only for the following key types: HTTP_HEADER -- Name of the HTTP header whose value is taken as the key value. HTTP_COOKIE -- Name of the HTTP cookie whose value is taken as the key value.
final
exceedAction String?
Action to take for requests that are above the configured rate limit threshold, to either deny with a specified HTTP response code, or redirect to a different endpoint. Valid options are deny(STATUS), where valid values for STATUS are 403, 404, 429, and 502, and redirect, where the redirect parameters come from exceedRedirectOptions below. The redirect action is only supported in Global Security Policies of type CLOUD_ARMOR.
final
exceedRedirectOptions SecurityPolicyRuleRedirectOptions?
Parameters defining the redirect action that is used as the exceed action. Cannot be specified if the exceed action is not redirect. This field is only supported in Global Security Policies of type CLOUD_ARMOR.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
rateLimitThreshold SecurityPolicyRuleRateLimitOptionsThreshold?
Threshold at which to begin ratelimiting.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String