banThreshold property

Can only be specified if the action for the rule is "rate_based_ban". If specified, the key will be banned for the configured 'ban_duration_sec' when the number of requests that exceed the 'rate_limit_threshold' also exceed this 'ban_threshold'.

Implementation

final SecurityPolicyRuleRateLimitOptionsThreshold? banThreshold;