conformAction property
Action to take for requests that are under the configured rate limit threshold. Valid option is "allow" only.
Implementation
final String? conformAction;
Action to take for requests that are under the configured rate limit threshold. Valid option is "allow" only.
final String? conformAction;