enforceOnKeyName property

String? enforceOnKeyName
final

Rate limit key name applicable only for the following key types: HTTP_HEADER -- Name of the HTTP header whose value is taken as the key value. HTTP_COOKIE -- Name of the HTTP cookie whose value is taken as the key value.

Implementation

final String? enforceOnKeyName;