SecurityPolicyRuleRateLimitOptions_EnforceOnKey class final
Determines the key to enforce the rate_limit_threshold on. Possible values are:
- ALL: A single rate limit threshold is applied to all the requests matching this rule. This is the default value if "enforceOnKey" is not configured.
- IP: The source IP address of the request is the key. Each IP has this limit enforced separately.
- HTTP_HEADER: The value of the HTTP header whose name is configured under "enforceOnKeyName". The key value is truncated to the first 128 bytes of the header value. If no such header is present in the request, the key type defaults toALL.
- XFF_IP: The first IP address (i.e. the originating client IP address) specified in the list of IPs under X-Forwarded-For HTTP header. If no such header is present or the value is not a valid IP, the key defaults to the source IP address of the request i.e. key type IP.
- HTTP_COOKIE: The value of the HTTP cookie whose name is configured under "enforceOnKeyName". The key value is truncated to the first 128 bytes of the cookie value. If no such cookie is present in the request, the key type defaults toALL.
- HTTP_PATH: The URL path of the HTTP request. The key value is truncated to the first 128 bytes.
- SNI: Server name indication in the TLS session of the HTTPS request. The key value is truncated to the first 128 bytes. The key type defaults to ALL on a HTTP session.
- REGION_CODE: The country/region from which the request originates.
- TLS_JA3_FINGERPRINT: JA3 TLS/SSL fingerprint if the client connects using HTTPS, HTTP/2 or HTTP/3. If not available, the key type defaults to ALL.
- USER_IP: The IP address of the originating client, which is resolved based on "userIpRequestHeaders" configured with the security policy. If there is no "userIpRequestHeaders" configuration or an IP address cannot be resolved from it, the key type defaults toIP.
- ASN: The autonomous system number of the originating client. If not available, the key type defaults toALL.
- TLS_JA4_FINGERPRINT: JA4 TLS/SSL fingerprint if the client connects using HTTPS, HTTP/2 or HTTP/3. If not available, the key type defaults to ALL.
For "fairshare" action, this value is limited to ALL i.e. a single rate limit threshold is enforced for all the requests matching the rule.
Constructors
- SecurityPolicyRuleRateLimitOptions_EnforceOnKey(String value)
-
const
- SecurityPolicyRuleRateLimitOptions_EnforceOnKey.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const SecurityPolicyRuleRateLimitOptions_EnforceOnKey
- The default value for SecurityPolicyRuleRateLimitOptions_EnforceOnKey.
- all → const SecurityPolicyRuleRateLimitOptions_EnforceOnKey
- asn → const SecurityPolicyRuleRateLimitOptions_EnforceOnKey
- httpCookie → const SecurityPolicyRuleRateLimitOptions_EnforceOnKey
- httpHeader → const SecurityPolicyRuleRateLimitOptions_EnforceOnKey
- httpPath → const SecurityPolicyRuleRateLimitOptions_EnforceOnKey
- ip → const SecurityPolicyRuleRateLimitOptions_EnforceOnKey
- regionCode → const SecurityPolicyRuleRateLimitOptions_EnforceOnKey
- sni → const SecurityPolicyRuleRateLimitOptions_EnforceOnKey
- tlsJa3Fingerprint → const SecurityPolicyRuleRateLimitOptions_EnforceOnKey
- tlsJa4Fingerprint → const SecurityPolicyRuleRateLimitOptions_EnforceOnKey
- undefinedEnforceOnKey → const SecurityPolicyRuleRateLimitOptions_EnforceOnKey
- A value indicating that the enum field is not set.
- userIp → const SecurityPolicyRuleRateLimitOptions_EnforceOnKey
- xffIp → const SecurityPolicyRuleRateLimitOptions_EnforceOnKey