SecurityPolicyUserDefinedField class final

Constructors

SecurityPolicyUserDefinedField({String? base, String? mask, String? name, int? offset, int? size})
SecurityPolicyUserDefinedField.fromJson(Object? j)
factory

Properties

base String?
The base relative to which 'offset' is measured. Possible values are:
final
hashCode int
The hash code for this object.
no setterinherited
mask String?
If specified, apply this mask (bitwise AND) to the field to ignore bits before matching. Encoded as a hexadecimal number (starting with "0x"). The last byte of the field (in network byte order) corresponds to the least significant byte of the mask.
final
name String?
The name of this field. Must be unique within the policy.
final
offset int?
Offset of the first byte of the field (in network byte order) relative to 'base'.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int?
Size of the field in bytes. Valid values: 1-4.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String