SecurityPolicyUserDefinedField_Base class final
The base relative to which 'offset' is measured. Possible values are:
- IPV4: Points to the beginning of the IPv4 header.
- IPV6: Points to the beginning of the IPv6 header.
- TCP: Points to the beginning of the TCP header, skipping over any IPv4 options or IPv6 extension headers. Not present for non-first fragments.
- UDP: Points to the beginning of the UDP header, skipping over any IPv4 options or IPv6 extension headers. Not present for non-first fragments.
required
Constructors
- SecurityPolicyUserDefinedField_Base(String value)
-
const
- SecurityPolicyUserDefinedField_Base.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const SecurityPolicyUserDefinedField_Base
- The default value for SecurityPolicyUserDefinedField_Base.
- ipv4 → const SecurityPolicyUserDefinedField_Base
- ipv6 → const SecurityPolicyUserDefinedField_Base
- tcp → const SecurityPolicyUserDefinedField_Base
- udp → const SecurityPolicyUserDefinedField_Base
- undefinedBase → const SecurityPolicyUserDefinedField_Base
- A value indicating that the enum field is not set.