SerialPortOutput class final
An instance serial console output.
Constructors
- SerialPortOutput({String? contents, String? kind, int? next, String? selfLink, int? start})
- SerialPortOutput.fromJson(Object? j)
-
factory
Properties
- contents → String?
-
Output OnlyThe contents of the console output.final - hashCode → int
-
The hash code for this object.
no setterinherited
- kind → String?
-
Output only.
Output OnlyType of the resource. Alwayscompute#serialPortOutput for serial port output.final - next → int?
-
Output OnlyThe position of the next byte of content, regardless of whether the content exists, following the output returned in thecontentsproperty. Use this value in the next request as the start parameter.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfLink → String?
-
Output only.
Output OnlyServer-defined URL for this resource.final - start → int?
-
The starting byte position of the output that was returned.
This should match the start parameter sent with the request.
If the serial console output exceeds the size of the buffer (1 MB), older
output is overwritten by newer content. The output start value will
indicate the byte position of the output that was returned, which might be
different than the
startvalue that was specified in the request.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String