ServiceAccount class final

A service account.

Constructors

ServiceAccount({String? email, List<String> scopes = const []})
ServiceAccount.fromJson(Object? j)
factory

Properties

email String?
Email address of the service account.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes List<String>
The list of scopes to be made available for this service account.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String