ServiceAttachment class final

Represents a ServiceAttachment resource.

A service attachment represents a service that a producer has exposed. It encapsulates the load balancer which fronts the service runs and a list of NAT IP ranges that the producers uses to represent the consumers connecting to the service.

Constructors

ServiceAttachment({List<ServiceAttachmentConnectedEndpoint> connectedEndpoints = const [], String? connectionPreference, List<ServiceAttachmentConsumerProjectLimit> consumerAcceptLists = const [], List<String> consumerRejectLists = const [], String? creationTimestamp, String? description, List<String> domainNames = const [], bool? enableProxyProtocol, String? fingerprint, BigInt? id, String? kind, Map<String, String> metadata = const {}, String? name, int? natIpsPerEndpoint, List<String> natSubnets = const [], String? producerForwardingRule, int? propagatedConnectionLimit, Uint128? pscServiceAttachmentId, bool? reconcileConnections, String? region, String? selfLink, String? targetService})
ServiceAttachment.fromJson(Object? j)
factory

Properties

connectedEndpoints List<ServiceAttachmentConnectedEndpoint>
Output only. Output Only An array of connections for all the consumers connected to this service attachment.
final
connectionPreference String?
The connection preference of service attachment. The value can be set to ACCEPT_AUTOMATIC. An ACCEPT_AUTOMATIC service attachment is one that always accepts the connection from consumer forwarding rules. Check the ConnectionPreference enum for the list of possible values.
final
consumerAcceptLists List<ServiceAttachmentConsumerProjectLimit>
Specifies which consumer projects or networks are allowed to connect to the service attachment. Each project or network has a connection limit. A given service attachment can manage connections at either the project or network level. Therefore, both the accept and reject lists for a given service attachment must contain either only projects or only networks or only endpoints.
final
consumerRejectLists List<String>
Specifies a list of projects or networks that are not allowed to connect to this service attachment. The project can be specified using its project ID or project number and the network can be specified using its URL. A given service attachment can manage connections at either the project or network level. Therefore, both the reject and accept lists for a given service attachment must contain either only projects or only networks.
final
creationTimestamp String?
Output only. Output Only Creation timestamp inRFC3339 text format.
final
description String?
An optional description of this resource. Provide this property when you create the resource.
final
domainNames List<String>
If specified, the domain name will be used during the integration between the PSC connected endpoints and the Cloud DNS. For example, this is a valid domain name: "p.mycompany.com.". Current max number of domain names supported is 1.
final
enableProxyProtocol bool?
If true, enable the proxy protocol which is for supplying client TCP/IP address data in TCP connections that traverse proxies on their way to destination servers.
final
fingerprint String?
Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a ServiceAttachment. An up-to-date fingerprint must be provided in order to patch/update the ServiceAttachment; otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the ServiceAttachment.
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output only. Output Only The unique identifier for the resource type. The server generates this identifier.
final
kind String?
Output only. Output Only Type of the resource. Alwayscompute#serviceAttachment for service attachments.
final
metadata Map<String, String>
Metadata of the service attachment.
final
name String?
Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
natIpsPerEndpoint int?
The number of NAT IP addresses to be allocated per connected endpoint. If not specified, the default value is 1.
final
natSubnets List<String>
An array of URLs where each entry is the URL of a subnet provided by the service producer to use for NAT in this service attachment.
final
producerForwardingRule String?
The URL of a forwarding rule with loadBalancingScheme INTERNAL* that is serving the endpoint identified by this service attachment.
final
propagatedConnectionLimit int?
The number of consumer spokes that connected Private Service Connect endpoints can be propagated to through Network Connectivity Center. This limit lets the service producer limit how many propagated Private Service Connect connections can be established to this service attachment from a single consumer.
final
pscServiceAttachmentId Uint128?
Output only. Output Only An 128-bit global unique ID of the PSC service attachment.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
reconcileConnections bool?
This flag determines whether a consumer accept/reject list change can reconcile the statuses of existing ACCEPTED or REJECTED PSC endpoints.
final
region String?
Output only. Output Only URL of the region where the service attachment resides. This field applies only to the region resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output only. Output Only Server-defined URL for the resource.
final
targetService String?
The URL of a service serving the endpoint identified by this service attachment.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String