connectedEndpoints property
Output only. Output Only An array of connections for all the consumers connected to
this service attachment.
Implementation
final List<ServiceAttachmentConnectedEndpoint> connectedEndpoints;
Output only. Output Only An array of connections for all the consumers connected to
this service attachment.
final List<ServiceAttachmentConnectedEndpoint> connectedEndpoints;