enableProxyProtocol property
If true, enable the proxy protocol which is for supplying client TCP/IP address data in TCP connections that traverse proxies on their way to destination servers.
Implementation
final bool? enableProxyProtocol;
If true, enable the proxy protocol which is for supplying client TCP/IP address data in TCP connections that traverse proxies on their way to destination servers.
final bool? enableProxyProtocol;