toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (connectionPreference != null)
      'connectionPreference=$connectionPreference',
    if (creationTimestamp != null) 'creationTimestamp=$creationTimestamp',
    if (description != null) 'description=$description',
    if (enableProxyProtocol != null)
      'enableProxyProtocol=$enableProxyProtocol',
    if (fingerprint != null) 'fingerprint=$fingerprint',
    if (id != null) 'id=$id',
    if (kind != null) 'kind=$kind',
    if (name != null) 'name=$name',
    if (natIpsPerEndpoint != null) 'natIpsPerEndpoint=$natIpsPerEndpoint',
    if (producerForwardingRule != null)
      'producerForwardingRule=$producerForwardingRule',
    if (propagatedConnectionLimit != null)
      'propagatedConnectionLimit=$propagatedConnectionLimit',
    if (reconcileConnections != null)
      'reconcileConnections=$reconcileConnections',
    if (region != null) 'region=$region',
    if (selfLink != null) 'selfLink=$selfLink',
    if (targetService != null) 'targetService=$targetService',
  ].join(',');
  return 'ServiceAttachment(${$contents})';
}