ServiceAttachmentConnectedEndpoint class final

Output Only A connection connected to this service attachment.

Constructors

ServiceAttachmentConnectedEndpoint({String? consumerNetwork, String? endpoint, String? endpointWithId, List<String> natIps = const [], int? propagatedConnectionCount, BigInt? pscConnectionId, String? status})
ServiceAttachmentConnectedEndpoint.fromJson(Object? j)
factory

Properties

consumerNetwork String?
The url of the consumer network.
final
endpoint String?
The url of a connected endpoint.
final
endpointWithId String?
The url of a connected endpoint with resource id.
final
hashCode int
The hash code for this object.
no setterinherited
natIps List<String>
NAT IPs of the connected PSC endpoint and those of other endpoints propagated from it.
final
propagatedConnectionCount int?
The number of consumer Network Connectivity Center spokes that the connected Private Service Connect endpoint has propagated to.
final
pscConnectionId BigInt?
The PSC connection id of the connected endpoint.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
The status of a connected endpoint to this service attachment. Check the Status enum for the list of possible values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String