status property
The status of a connected endpoint to this service attachment. Check the Status enum for the list of possible values.
Implementation
final String? status;
The status of a connected endpoint to this service attachment. Check the Status enum for the list of possible values.
final String? status;