ServiceAttachmentConsumerProjectLimit class final

Constructors

ServiceAttachmentConsumerProjectLimit({int? connectionLimit, String? endpointUrl, String? networkUrl, String? projectIdOrNum})
ServiceAttachmentConsumerProjectLimit.fromJson(Object? j)
factory

Properties

connectionLimit int?
The value of the limit to set. For endpoint_url, the limit should be no more than 1.
final
endpointUrl String?
The URL for the PSC endpoint to accept
final
hashCode int
The hash code for this object.
no setterinherited
networkUrl String?
The network URL for the network to set the limit for.
final
projectIdOrNum String?
The project id or number for the project to set the limit for.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String