connectionLimit property
The value of the limit to set. For endpoint_url, the limit should be no more than 1.
Implementation
final int? connectionLimit;
The value of the limit to set. For endpoint_url, the limit should be no more than 1.
final int? connectionLimit;