insert method

Creates a ServiceAttachment in the specified project in the given scope using the parameters that are included in the request.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> insert(InsertServiceAttachmentRequest request) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/regions/${request.region}/serviceAttachments',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.post(
    url,
    body: request.serviceAttachmentResource,
  );
  return Operation.fromJson(response);
}