SetBackendServiceTargetSslProxyRequest class final

A request message for TargetSslProxies.SetBackendService. See the method description for details.

Constructors

SetBackendServiceTargetSslProxyRequest({required String project, String? requestId, required TargetSslProxiesSetBackendServiceRequest? targetSslProxiesSetBackendServiceRequestResource, required String targetSslProxy})
SetBackendServiceTargetSslProxyRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requestId String?
An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetSslProxiesSetBackendServiceRequestResource TargetSslProxiesSetBackendServiceRequest?
The body resource for this request
final
targetSslProxy String
Name of the TargetSslProxy resource whose BackendService resource is to be set.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String