SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo_State class final
Output Only Status of the action, which can be one of the following:
PROPAGATING, PROPAGATED, ABANDONED, FAILED, or DONE.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo_State
- The default value for SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo_State.
- abandoned → const SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo_State
- Operation not tracked in this location e.g. zone is marked as DOWN.
- done → const SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo_State
- Operation has completed successfully.
- failed → const SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo_State
- Operation is in an error state.
- propagated → const SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo_State
- Operation is confirmed to be in the location.
- propagating → const SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo_State
- Operation is not yet confirmed to have been created in the location.
- undefinedState → const SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo_State
- A value indicating that the enum field is not set.
- unspecified → const SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo_State