backendBucket property
Name of the BackendBucket resource to which the security policy should be set. The name should conform to RFC1035.
Implementation
final String backendBucket;
Name of the BackendBucket resource to which the security policy should be set. The name should conform to RFC1035.
final String backendBucket;