backendService property
Name of the BackendService resource to which the edge security policy should be set. The name should conform to RFC1035.
Implementation
final String backendService;
Name of the BackendService resource to which the edge security policy should be set. The name should conform to RFC1035.
final String backendService;