SetIamPolicyReservationBlockRequest class final

A request message for ReservationBlocks.SetIamPolicy. See the method description for details.

Constructors

SetIamPolicyReservationBlockRequest({required String parentResource, required String project, required String resource, required String zone, required ZoneSetNestedPolicyRequest? zoneSetNestedPolicyRequestResource})
SetIamPolicyReservationBlockRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
parentResource String
Name or id of parent resource of the resource for this request.
final
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
resource String
Name or id of the resource for this request.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zone String
The name of the zone for this request.
final
zoneSetNestedPolicyRequestResource ZoneSetNestedPolicyRequest?
The body resource for this request
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String