SetMachineTypeInstanceRequest class final

A request message for Instances.SetMachineType. See the method description for details.

Constructors

SetMachineTypeInstanceRequest({required String instance, required InstancesSetMachineTypeRequest? instancesSetMachineTypeRequestResource, required String project, String? requestId, required String zone})
SetMachineTypeInstanceRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
instance String
Name of the instance scoping this request.
final
instancesSetMachineTypeRequestResource InstancesSetMachineTypeRequest?
The body resource for this request
final
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requestId String?
An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zone String
The name of the zone for this request.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String