instance property
Name of the Instance resource to which the security policy should be set. The name should conform to RFC1035.
Implementation
final String instance;
Name of the Instance resource to which the security policy should be set. The name should conform to RFC1035.
final String instance;