targetInstance property
Name of the TargetInstance resource to which the security policy should be set. The name should conform to RFC1035.
Implementation
final String targetInstance;
Name of the TargetInstance resource to which the security policy should be set. The name should conform to RFC1035.
final String targetInstance;