targetPool property
Name of the TargetPool resource to which the security policy should be set. The name should conform to RFC1035.
Implementation
final String targetPool;
Name of the TargetPool resource to which the security policy should be set. The name should conform to RFC1035.
final String targetPool;