SetSslPolicyTargetHttpsProxyRequest class final

A request message for TargetHttpsProxies.SetSslPolicy. See the method description for details.

Constructors

SetSslPolicyTargetHttpsProxyRequest({required String project, String? requestId, required SslPolicyReference? sslPolicyReferenceResource, required String targetHttpsProxy})
SetSslPolicyTargetHttpsProxyRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requestId String?
An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sslPolicyReferenceResource SslPolicyReference?
The body resource for this request
final
targetHttpsProxy String
Name of the TargetHttpsProxy resource whose SSL policy is to be set. The name must be 1-63 characters long, and comply with RFC1035.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String