ShareSettings class final

The share setting for reservations and sole tenancy node groups.

Constructors

ShareSettings({Map<String, ShareSettingsProjectConfig> projectMap = const {}, String? shareType})
ShareSettings.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
projectMap Map<String, ShareSettingsProjectConfig>
A map of project id and project config. This is only valid when share_type's value is SPECIFIC_PROJECTS.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shareType String?
Type of sharing for this shared-reservation Check the ShareType enum for the list of possible values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String