ShieldedInstanceConfig class final

A set of Shielded Instance options.

Constructors

ShieldedInstanceConfig({bool? enableIntegrityMonitoring, bool? enableSecureBoot, bool? enableVtpm})
ShieldedInstanceConfig.fromJson(Object? j)
factory

Properties

enableIntegrityMonitoring bool?
Defines whether the instance has integrity monitoring enabled.Enabled by default.
final
enableSecureBoot bool?
Defines whether the instance has Secure Boot enabled.Disabled by default.
final
enableVtpm bool?
Defines whether the instance has the vTPM enabled.Enabled by default.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String