ShieldedInstanceIntegrityPolicy class final

The policy describes the baseline against which Instance boot integrity is measured.

Constructors

ShieldedInstanceIntegrityPolicy({bool? updateAutoLearnPolicy})
ShieldedInstanceIntegrityPolicy.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updateAutoLearnPolicy bool?
Updates the integrity policy baseline using the measurements from the VM instance's most recent boot.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String