updateAutoLearnPolicy property
Updates the integrity policy baseline using the measurements from the VM instance's most recent boot.
Implementation
final bool? updateAutoLearnPolicy;
Updates the integrity policy baseline using the measurements from the VM instance's most recent boot.
final bool? updateAutoLearnPolicy;