SignedUrlKey class final

Represents a customer-supplied Signing Key used by Cloud CDN Signed URLs

Constructors

SignedUrlKey({String? keyName, String? keyValue})
SignedUrlKey.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
keyName String?
Name of the key. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
keyValue String?
128-bit key value used for signing the URL. The key value must be a validRFC 4648 Section 5 base64url encoded string.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String