Snapshot class final

Represents a Persistent Disk Snapshot resource.

You can use snapshots to back up data on a regular interval. For more information, read Creating persistent disk snapshots.

Constructors

Snapshot({String? architecture, bool? autoCreated, String? chainName, int? creationSizeBytes, String? creationTimestamp, String? description, int? diskSizeGb, int? downloadBytes, bool? enableConfidentialCompute, bool? guestFlush, List<GuestOsFeature> guestOsFeatures = const [], BigInt? id, String? kind, String? labelFingerprint, Map<String, String> labels = const {}, List<int> licenseCodes = const [], List<String> licenses = const [], String? locationHint, String? name, SnapshotParams? params, String? region, bool? satisfiesPzi, bool? satisfiesPzs, String? selfLink, CustomerEncryptionKey? snapshotEncryptionKey, String? snapshotGroupId, String? snapshotGroupName, String? snapshotType, String? sourceDisk, CustomerEncryptionKey? sourceDiskEncryptionKey, String? sourceDiskForRecoveryCheckpoint, String? sourceDiskId, String? sourceInstantSnapshot, CustomerEncryptionKey? sourceInstantSnapshotEncryptionKey, String? sourceInstantSnapshotId, String? sourceSnapshotSchedulePolicy, String? sourceSnapshotSchedulePolicyId, String? status, int? storageBytes, String? storageBytesStatus, List<String> storageLocations = const []})
Snapshot.fromJson(Object? j)
factory

Properties

architecture String?
Output only. Output Only The architecture of the snapshot. Valid values are ARM64 or X86_64. Check the Architecture enum for the list of possible values.
final
autoCreated bool?
Output only. Output Only Set to true if snapshots are automatically created by applying resource policy on the target disk.
final
chainName String?
Creates the new snapshot in the snapshot chain labeled with the specified name. The chain name must be 1-63 characters long and comply with RFC1035. This is an uncommon option only for advanced service owners who needs to create separate snapshot chains, for example, for chargeback tracking. When you describe your snapshot resource, this field is visible only if it has a non-empty value.
final
creationSizeBytes int?
Output only. Output Only Size in bytes of the snapshot at creation time.
final
creationTimestamp String?
Output only. Output Only Creation timestamp inRFC3339 text format.
final
description String?
An optional description of this resource. Provide this property when you create the resource.
final
diskSizeGb int?
Output only. Output Only Size of the source disk, specified in GB.
final
downloadBytes int?
Output only. Output Only Number of bytes downloaded to restore a snapshot to a disk.
final
enableConfidentialCompute bool?
Output only. Whether this snapshot is created from a confidential compute mode disk. Output Only: This field is not set by user, but from source disk.
final
guestFlush bool?
Input Only Whether to attempt an application consistent snapshot by informing the OS to prepare for the snapshot process.
final
guestOsFeatures List<GuestOsFeature>
Output only. Output Only A list of features to enable on the guest operating system. Applicable only for bootable images. Read Enabling guest operating system features to see a list of available options.
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output only. Output Only The unique identifier for the resource. This identifier is defined by the server.
final
kind String?
Output only. Output Only Type of the resource. Always compute#snapshot for Snapshot resources.
final
labelFingerprint String?
A fingerprint for the labels being applied to this snapshot, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet.
final
labels Map<String, String>
Labels to apply to this snapshot. These can be later modified by the setLabels method. Label values may be empty.
final
licenseCodes List<int>
Output only. Output Only Integer license codes indicating which licenses are attached to this snapshot.
final
licenses List<String>
Output only. Output Only A list of public visible licenses that apply to this snapshot. This can be because the original image had licenses attached (such as a Windows image).
final
locationHint String?
An opaque location hint used to place the snapshot close to other resources. This field is for use by internal tools that use the public API.
final
name String?
Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
params SnapshotParams?
Input only. Input Only Additional params passed with the request, but not persisted as part of resource payload.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
region String?
Output only. Output Only URL of the region where the snapshot resides. Only applicable for regional snapshots.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzi bool?
Output only. Reserved for future use.
final
satisfiesPzs bool?
Output only. Output Only Reserved for future use.
final
Output only. Output Only Server-defined URL for the resource.
final
snapshotEncryptionKey CustomerEncryptionKey?
Encrypts the snapshot using acustomer-supplied encryption key.
final
snapshotGroupId String?
Output only. Output Only The unique ID of the snapshot group that this snapshot belongs to. The usage of snapshot group feature is restricted.
final
snapshotGroupName String?
Output only. Output only The snapshot group that this snapshot belongs to. The usage of snapshot group feature is restricted.
final
snapshotType String?
Indicates the type of the snapshot. Check the SnapshotType enum for the list of possible values.
final
sourceDisk String?
The source disk used to create this snapshot.
final
sourceDiskEncryptionKey CustomerEncryptionKey?
The customer-supplied encryption key of the source disk. Required if the source disk is protected by a customer-supplied encryption key.
final
sourceDiskForRecoveryCheckpoint String?
The source disk whose recovery checkpoint will be used to create this snapshot.
final
sourceDiskId String?
Output only. Output Only The ID value of the disk used to create this snapshot. This value may be used to determine whether the snapshot was taken from the current or a previous instance of a given disk name.
final
sourceInstantSnapshot String?
The source instant snapshot used to create this snapshot. You can provide this as a partial or full URL to the resource. For example, the following are valid values:
final
sourceInstantSnapshotEncryptionKey CustomerEncryptionKey?
Customer provided encryption key when creating Snapshot from Instant Snapshot.
final
sourceInstantSnapshotId String?
Output only. Output Only The unique ID of the instant snapshot used to create this snapshot. This value identifies the exact instant snapshot that was used to create this snapshot. For example, if you created the snapshot from an instant snapshot that was later deleted and recreated under the same name, the source instant snapshot ID would identify the exact instant snapshot that was used.
final
sourceSnapshotSchedulePolicy String?
Output only. Output Only URL of the resource policy which created this scheduled snapshot.
final
sourceSnapshotSchedulePolicyId String?
Output only. Output Only ID of the resource policy which created this scheduled snapshot.
final
status String?
Output only. Output Only The status of the snapshot. This can beCREATING, DELETING, FAILED,READY, or UPLOADING. Check the Status enum for the list of possible values.
final
storageBytes int?
Output only. Output Only A size of the storage used by the snapshot. As snapshots share storage, this number is expected to change with snapshot creation/deletion.
final
storageBytesStatus String?
Output only. Deprecated Instead, check the storageBytes field. After snapshot creation, the storageBytesStatus field is alwaysUP_TO_DATE. Output Only An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be unset, meaning the snapshot is being created, or UP_TO_DATE, meaning the size of the snapshot is up-to-date. Check the StorageBytesStatus enum for the list of possible values.
final
storageLocations List<String>
Cloud Storage bucket storage location of the snapshot (regional or multi-regional).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String