architecture property
Output only. Output Only The architecture of the snapshot. Valid values are
ARM64 or X86_64.
Check the Architecture enum for the list of possible values.
Implementation
final String? architecture;
Output only. Output Only The architecture of the snapshot. Valid values are
ARM64 or X86_64.
Check the Architecture enum for the list of possible values.
final String? architecture;