autoCreated property

bool? autoCreated
final

Output only. Output Only Set to true if snapshots are automatically created by applying resource policy on the target disk.

Implementation

final bool? autoCreated;