downloadBytes property
Output only. Output Only Number of bytes downloaded to restore a snapshot to a disk.
Implementation
final int? downloadBytes;
Output only. Output Only Number of bytes downloaded to restore a snapshot to a disk.
final int? downloadBytes;