licenses property

List<String> licenses
final

Output only. Output Only A list of public visible licenses that apply to this snapshot. This can be because the original image had licenses attached (such as a Windows image).

Implementation

final List<String> licenses;