locationHint property
An opaque location hint used to place the snapshot close to other resources. This field is for use by internal tools that use the public API.
Implementation
final String? locationHint;
An opaque location hint used to place the snapshot close to other resources. This field is for use by internal tools that use the public API.
final String? locationHint;