snapshotGroupName property
Output only. Output only The snapshot group that this snapshot belongs to. The usage
of snapshot group feature is restricted.
Implementation
final String? snapshotGroupName;
Output only. Output only The snapshot group that this snapshot belongs to. The usage
of snapshot group feature is restricted.
final String? snapshotGroupName;