sourceDiskForRecoveryCheckpoint property
The source disk whose recovery checkpoint will be used to create this snapshot.
Implementation
final String? sourceDiskForRecoveryCheckpoint;
The source disk whose recovery checkpoint will be used to create this snapshot.
final String? sourceDiskForRecoveryCheckpoint;