sourceInstantSnapshotEncryptionKey property
Customer provided encryption key when creating Snapshot from Instant Snapshot.
Implementation
final CustomerEncryptionKey? sourceInstantSnapshotEncryptionKey;
Customer provided encryption key when creating Snapshot from Instant Snapshot.
final CustomerEncryptionKey? sourceInstantSnapshotEncryptionKey;