sourceInstantSnapshotId property

String? sourceInstantSnapshotId
final

Output only. Output Only The unique ID of the instant snapshot used to create this snapshot. This value identifies the exact instant snapshot that was used to create this snapshot. For example, if you created the snapshot from an instant snapshot that was later deleted and recreated under the same name, the source instant snapshot ID would identify the exact instant snapshot that was used.

Implementation

final String? sourceInstantSnapshotId;