storageBytes property

int? storageBytes
final

Output only. Output Only A size of the storage used by the snapshot. As snapshots share storage, this number is expected to change with snapshot creation/deletion.

Implementation

final int? storageBytes;