toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (architecture != null) 'architecture=$architecture',
    if (autoCreated != null) 'autoCreated=$autoCreated',
    if (chainName != null) 'chainName=$chainName',
    if (creationSizeBytes != null) 'creationSizeBytes=$creationSizeBytes',
    if (creationTimestamp != null) 'creationTimestamp=$creationTimestamp',
    if (description != null) 'description=$description',
    if (diskSizeGb != null) 'diskSizeGb=$diskSizeGb',
    if (downloadBytes != null) 'downloadBytes=$downloadBytes',
    if (enableConfidentialCompute != null)
      'enableConfidentialCompute=$enableConfidentialCompute',
    if (guestFlush != null) 'guestFlush=$guestFlush',
    if (id != null) 'id=$id',
    if (kind != null) 'kind=$kind',
    if (labelFingerprint != null) 'labelFingerprint=$labelFingerprint',
    if (locationHint != null) 'locationHint=$locationHint',
    if (name != null) 'name=$name',
    if (region != null) 'region=$region',
    if (satisfiesPzi != null) 'satisfiesPzi=$satisfiesPzi',
    if (satisfiesPzs != null) 'satisfiesPzs=$satisfiesPzs',
    if (selfLink != null) 'selfLink=$selfLink',
    if (snapshotGroupId != null) 'snapshotGroupId=$snapshotGroupId',
    if (snapshotGroupName != null) 'snapshotGroupName=$snapshotGroupName',
    if (snapshotType != null) 'snapshotType=$snapshotType',
    if (sourceDisk != null) 'sourceDisk=$sourceDisk',
    if (sourceDiskForRecoveryCheckpoint != null)
      'sourceDiskForRecoveryCheckpoint=$sourceDiskForRecoveryCheckpoint',
    if (sourceDiskId != null) 'sourceDiskId=$sourceDiskId',
    if (sourceInstantSnapshot != null)
      'sourceInstantSnapshot=$sourceInstantSnapshot',
    if (sourceInstantSnapshotId != null)
      'sourceInstantSnapshotId=$sourceInstantSnapshotId',
    if (sourceSnapshotSchedulePolicy != null)
      'sourceSnapshotSchedulePolicy=$sourceSnapshotSchedulePolicy',
    if (sourceSnapshotSchedulePolicyId != null)
      'sourceSnapshotSchedulePolicyId=$sourceSnapshotSchedulePolicyId',
    if (status != null) 'status=$status',
    if (storageBytes != null) 'storageBytes=$storageBytes',
    if (storageBytesStatus != null) 'storageBytesStatus=$storageBytesStatus',
  ].join(',');
  return 'Snapshot(${$contents})';
}