SnapshotGroupParameters class final

Constructors

SnapshotGroupParameters({List<String> replicaZones = const [], String? sourceSnapshotGroup, String? type})
SnapshotGroupParameters.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
replicaZones List<String>
URLs of the zones where disks should be replicated to. Only applicable for regional resources.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceSnapshotGroup String?
The source snapshot group used to create disks. You can provide this as a partial or full URL to the resource. For example, the following are valid values:
final
type String?
URL of the disk type resource describing which disk type to use to create disks. Provide this when creating the disk. For example:projects/project/zones/zone/diskTypes/pd-ssd. See Persistent disk types.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String