SnapshotSettings class final

Properties

accessLocation SnapshotSettingsAccessLocation?
(Regional snapshots use only)Policy of which location is allowed to access snapshot.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storageLocation SnapshotSettingsStorageLocationSettings?
Policy of which storage location is going to be resolved, and additional data that particularizes how the policy is going to be carried out.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String