accessLocation property
(Regional snapshots use only)Policy of which location is allowed to access snapshot.
Implementation
final SnapshotSettingsAccessLocation? accessLocation;
(Regional snapshots use only)Policy of which location is allowed to access snapshot.
final SnapshotSettingsAccessLocation? accessLocation;