storageLocation property

Policy of which storage location is going to be resolved, and additional data that particularizes how the policy is going to be carried out.

Implementation

final SnapshotSettingsStorageLocationSettings? storageLocation;