locations property
List of regions that can restore a regional snapshot from the current region
Implementation
final Map<String, SnapshotSettingsAccessLocationAccessLocationPreference>
locations;
List of regions that can restore a regional snapshot from the current region
final Map<String, SnapshotSettingsAccessLocationAccessLocationPreference>
locations;