policy property
Policy of which location is allowed to access snapshot. Check the Policy enum for the list of possible values.
Implementation
final String? policy;
Policy of which location is allowed to access snapshot. Check the Policy enum for the list of possible values.
final String? policy;