SnapshotSettingsAccessLocation_Policy class final

Policy of which location is allowed to access snapshot.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const SnapshotSettingsAccessLocation_Policy
The default value for SnapshotSettingsAccessLocation_Policy.
allRegions → const SnapshotSettingsAccessLocation_Policy
Any regions will be able to access the source location.
policyUnspecified → const SnapshotSettingsAccessLocation_Policy
specificRegions → const SnapshotSettingsAccessLocation_Policy
Only allowlisted regions will be able to restore region scoped snapshots
undefinedPolicy → const SnapshotSettingsAccessLocation_Policy
A value indicating that the enum field is not set.