SnapshotSettingsService class final
The SnapshotSettings API.
- Implementers
Constructors
- SnapshotSettingsService({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
SnapshotSettingsServiceusingclientfor transport. - SnapshotSettingsService.fromApiKey([String? apiKey])
-
Creates a
SnapshotSettingsServicethat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
get(
GetSnapshotSettingRequest request) → Future< SnapshotSettings> - Get snapshot settings.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchSnapshotSettingRequest request) → Future< Operation> - Patch snapshot settings.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited