name property
Name of the location. It should be one of the Cloud Storage buckets. Only one location can be specified.
Implementation
final String? name;
Name of the location. It should be one of the Cloud Storage buckets. Only one location can be specified.
final String? name;