kmsKeyName property

String? kmsKeyName
final

Optional. The new KMS key to replace the current one on the snapshot. If empty, the snapshot will be re-encrypted using the primary version of the snapshot's current KMS key.

The KMS key can be provided in the following formats:

 - projects/project_id/locations/region/keyRings/key_ring/cryptoKeys/key

Implementation

final String? kmsKeyName;