Snapshot_Status class final

Output only. Output Only The status of the snapshot. This can beCREATING, DELETING, FAILED,READY, or UPLOADING.

Constructors

Snapshot_Status(String value)
const
Snapshot_Status.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const Snapshot_Status
The default value for Snapshot_Status.
creating → const Snapshot_Status
Snapshot creation is in progress.
deleting → const Snapshot_Status
Snapshot is currently being deleted.
failed → const Snapshot_Status
Snapshot creation failed.
ready → const Snapshot_Status
Snapshot has been created successfully.
undefinedStatus → const Snapshot_Status
A value indicating that the enum field is not set.
uploading → const Snapshot_Status
Snapshot is being uploaded.