insert method

Creates a snapshot in the specified project using the data included in the request. For regular snapshot creation, consider using this method instead of disks.createSnapshot, as this method supports more features, such as creating snapshots in a project different from the source disk project.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> insert(InsertSnapshotRequest request) async {
  final url = _endPoint.replace(
    path: '/compute/v1/projects/${request.project}/global/snapshots',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.post(url, body: request.snapshotResource);
  return Operation.fromJson(response);
}