updateKmsKey method

Future<Operation> updateKmsKey(
  1. UpdateKmsKeySnapshotRequest request
)

Rotates the customer-managed encryption key to the latest version for the specified snapshot.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> updateKmsKey(UpdateKmsKeySnapshotRequest request) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/global/snapshots/${request.snapshot}/updateKmsKey',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.post(
    url,
    body: request.snapshotUpdateKmsKeyRequestResource,
  );
  return Operation.fromJson(response);
}