SourceDiskEncryptionKey class
final
Properties
-
diskEncryptionKey
→ CustomerEncryptionKey?
-
Thecustomer-supplied
encryption key of the source disk. Required if the source disk is
protected by a customer-supplied encryption key.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
qualifiedName
→ String
-
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or google.rpc.ErrorInfo.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
sourceDisk
→ String?
-
URL of the disk attached to the source instance. This can be a full or
valid partial URL. For example, the following are valid values:
final