deletionProtection property
Whether the instance created from this machine image should be protected against deletion.
Implementation
final bool? deletionProtection;
Whether the instance created from this machine image should be protected against deletion.
final bool? deletionProtection;