description property
An optional text description for the instances that are created from this machine image.
Implementation
final String? description;
An optional text description for the instances that are created from this machine image.
final String? description;