disks property

List<SavedAttachedDisk> disks
final

An array of disks that are associated with the instances that are created from this machine image.

Implementation

final List<SavedAttachedDisk> disks;