guestAccelerators property
A list of guest accelerator cards' type and count to use for instances created from this machine image.
Implementation
final List<AcceleratorConfig> guestAccelerators;
A list of guest accelerator cards' type and count to use for instances created from this machine image.
final List<AcceleratorConfig> guestAccelerators;