networkInterfaces property
An array of network access configurations for this interface.
Implementation
final List<NetworkInterface> networkInterfaces;
An array of network access configurations for this interface.
final List<NetworkInterface> networkInterfaces;