scheduling property
Specifies the scheduling options for the instances that are created from this machine image.
Implementation
final Scheduling? scheduling;
Specifies the scheduling options for the instances that are created from this machine image.
final Scheduling? scheduling;