toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (canIpForward != null) 'canIpForward=$canIpForward',
    if (deletionProtection != null) 'deletionProtection=$deletionProtection',
    if (description != null) 'description=$description',
    if (keyRevocationActionType != null)
      'keyRevocationActionType=$keyRevocationActionType',
    if (machineType != null) 'machineType=$machineType',
    if (minCpuPlatform != null) 'minCpuPlatform=$minCpuPlatform',
    if (postKeyRevocationActionType != null)
      'postKeyRevocationActionType=$postKeyRevocationActionType',
  ].join(',');
  return 'SourceInstanceProperties(${$contents})';
}