SslCertificates class final

The SslCertificates API.

Implementers

Constructors

SslCertificates({required Client client, Uri? endPoint, String? gcclVersion})
Creates a SslCertificates using client for transport.
SslCertificates.fromApiKey([String? apiKey])
Creates a SslCertificates that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(AggregatedListSslCertificatesRequest request) Future<SslCertificateAggregatedList>
Retrieves the list of all SslCertificate resources, regional and global, available to the specified project.
close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteSslCertificateRequest request) Future<Operation>
Deletes the specified SslCertificate resource.
get(GetSslCertificateRequest request) Future<SslCertificate>
Returns the specified SslCertificate resource.
insert(InsertSslCertificateRequest request) Future<Operation>
Creates a SslCertificate resource in the specified project using the data included in the request.
list(ListSslCertificatesRequest request) Future<SslCertificateList>
Retrieves the list of SslCertificate resources available to the specified project.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited