get method

Lists all of the ordered rules present in a single specified policy.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<SslPolicy> get(GetSslPolicyRequest request) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/global/sslPolicies/${request.sslPolicy}',
  );
  final response = await _client.get(url);
  return SslPolicy.fromJson(response);
}