warnings property

List<Warnings> warnings
final

Output only. Output Only If potential misconfigurations are detected for this SSL policy, this field will be populated with warning messages.

Implementation

final List<Warnings> warnings;