SslPolicy_PostQuantumKeyExchange class final

One of DEFAULT, ENABLED, orDEFERRED. Controls whether the load balancer negotiates X25519MLKEM768 key exchange when clients advertise support for it. When set to DEFAULT, or if no SSL Policy is attached to the target proxy, the load balancer disallows X25519MLKEM768 key exchange before October 2026, and allows it afterward. When set to ENABLED, the load balancer allows X25519MLKEM768 key exchange. When set toDEFERRED, the load balancer disallows X25519MLKEM768 key exchange until October 2027, and allows it afterward.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const SslPolicy_PostQuantumKeyExchange
The default value for SslPolicy_PostQuantumKeyExchange.
default$ → const SslPolicy_PostQuantumKeyExchange
Default behavior: disabled until October 2026, enabled afterward.
deferred → const SslPolicy_PostQuantumKeyExchange
Disabled until October 2027, enabled afterward.
enabled → const SslPolicy_PostQuantumKeyExchange
Enabled now.
undefinedPostQuantumKeyExchange → const SslPolicy_PostQuantumKeyExchange
A value indicating that the enum field is not set.