disks property

Disks created on the instances that will be preserved on instance delete, update, etc. This map is keyed with the device names of the disks.

Implementation

final Map<String, StatefulPolicyPreservedStateDiskDevice> disks;