externalIPs property

External network IPs assigned to the instances that will be preserved on instance delete, update, etc. This map is keyed with the network interface name.

Implementation

final Map<String, StatefulPolicyPreservedStateNetworkIp> externalIPs;