StatefulPolicyPreservedStateDiskDevice_AutoDelete class final
These stateful disks will never be deleted during autohealing, update or VM instance recreate operations. This flag is used to configure if the disk should be deleted after it is no longer used by the group, e.g. when the given instance or the whole group is deleted. Note: disks attached inREAD_ONLY mode cannot be auto-deleted.
Constructors
- StatefulPolicyPreservedStateDiskDevice_AutoDelete(String value)
-
const
- StatefulPolicyPreservedStateDiskDevice_AutoDelete.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const StatefulPolicyPreservedStateDiskDevice_AutoDelete
- The default value for StatefulPolicyPreservedStateDiskDevice_AutoDelete.
- never → const StatefulPolicyPreservedStateDiskDevice_AutoDelete
- onPermanentInstanceDeletion → const StatefulPolicyPreservedStateDiskDevice_AutoDelete
- undefinedAutoDelete → const StatefulPolicyPreservedStateDiskDevice_AutoDelete
- A value indicating that the enum field is not set.