zone property
The name of the zone for this request. This must be the zone of the primary or secondary disks in the consistency group.
Implementation
final String zone;
The name of the zone for this request. This must be the zone of the primary or secondary disks in the consistency group.
final String zone;