region property
The name of the region for this request. This must be the region of the primary or secondary disks in the consistency group.
Implementation
final String region;
The name of the region for this request. This must be the region of the primary or secondary disks in the consistency group.
final String region;