discardLocalSsd property

bool? discardLocalSsd
final

This property is required if the instance has any attached Local SSD disks. If false, Local SSD data will be preserved when the instance is suspended. If true, the contents of any attached Local SSD disks will be discarded.

Implementation

final bool? discardLocalSsd;