noGracefulShutdown property
When set, graceful shutdown is skipped for instance stopping even if it's configured for the instances.
Implementation
final bool? noGracefulShutdown;
When set, graceful shutdown is skipped for instance stopping even if it's configured for the instances.
final bool? noGracefulShutdown;