StoragePool class final

Represents a zonal storage pool resource.

Constructors

StoragePool({String? capacityProvisioningType, String? creationTimestamp, String? description, StoragePoolExapoolProvisionedCapacityGb? exapoolProvisionedCapacityGb, BigInt? id, String? kind, String? labelFingerprint, Map<String, String> labels = const {}, String? name, StoragePoolParams? params, String? performanceProvisioningType, int? poolProvisionedCapacityGb, int? poolProvisionedIops, int? poolProvisionedThroughput, StoragePoolResourceStatus? resourceStatus, String? selfLink, String? selfLinkWithId, StoragePoolShareSettings? shareSettings, String? state, StoragePoolResourceStatus? status, String? storagePoolType, String? zone})
StoragePool.fromJson(Object? j)
factory

Properties

capacityProvisioningType String?
Provisioning type of the byte capacity of the pool. Check the CapacityProvisioningType enum for the list of possible values.
final
creationTimestamp String?
Output only. Output Only Creation timestamp inRFC3339 text format.
final
description String?
An optional description of this resource. Provide this property when you create the resource.
final
exapoolProvisionedCapacityGb StoragePoolExapoolProvisionedCapacityGb?
Provisioned capacities for each SKU for this Exapool in GiB
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output only. Output Only The unique identifier for the resource. This identifier is defined by the server.
final
kind String?
Output only. Output Only Type of the resource. Always compute#storagePool for storage pools.
final
labelFingerprint String?
A fingerprint for the labels being applied to this storage pool, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet.
final
labels Map<String, String>
Labels to apply to this storage pool. These can be later modified by the setLabels method.
final
name String?
Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
params StoragePoolParams?
Input only. Additional params passed with the request, but not persisted as part of resource payload.
final
performanceProvisioningType String?
Provisioning type of the performance-related parameters of the pool, such as throughput and IOPS. Check the PerformanceProvisioningType enum for the list of possible values.
final
poolProvisionedCapacityGb int?
Size of the storage pool in GiB. For more information about the size limits, see https://cloud.google.com/compute/docs/disks/storage-pools.
final
poolProvisionedIops int?
Provisioned IOPS of the storage pool. Only relevant if the storage pool type is hyperdisk-balanced.
final
poolProvisionedThroughput int?
Provisioned throughput of the storage pool in MiB/s. Only relevant if the storage pool type is hyperdisk-balanced or hyperdisk-throughput.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
resourceStatus StoragePoolResourceStatus?
Output only. Output Only Status information for the storage pool resource.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output only. Output Only Server-defined fully-qualified URL for this resource.
final
selfLinkWithId String?
Output only. Output Only Server-defined URL for this resource's resource id.
final
shareSettings StoragePoolShareSettings?
Share settings for the storage pool.
final
state String?
Output only. Output Only The status of storage pool creation.
final
status StoragePoolResourceStatus?
Output only. Output Only Status information for the storage pool resource.
final
storagePoolType String?
Type of the storage pool.
final
zone String?
Output only. Output Only URL of the zone where the storage pool resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String