params property
Input only. Additional params passed with the request, but not persisted as part of resource payload.
Implementation
final StoragePoolParams? params;
Input only. Additional params passed with the request, but not persisted as part of resource payload.
final StoragePoolParams? params;