poolProvisionedIops property
Provisioned IOPS of the storage pool. Only relevant if the storage pool type is hyperdisk-balanced.
Implementation
final int? poolProvisionedIops;
Provisioned IOPS of the storage pool. Only relevant if the storage pool type is hyperdisk-balanced.
final int? poolProvisionedIops;