poolProvisionedThroughput property
Provisioned throughput of the storage pool in MiB/s. Only relevant if the storage pool type is hyperdisk-balanced or hyperdisk-throughput.
Implementation
final int? poolProvisionedThroughput;
Provisioned throughput of the storage pool in MiB/s. Only relevant if the storage pool type is hyperdisk-balanced or hyperdisk-throughput.
final int? poolProvisionedThroughput;