status property
Output only. Output Only The disk status.
Check the Status enum for the list of possible values.
Implementation
final String? status;
Output only. Output Only The disk status.
Check the Status enum for the list of possible values.
final String? status;