StoragePoolDisk_Status class final

Output only. Output Only The disk status.

Constructors

StoragePoolDisk_Status(String value)
const
StoragePoolDisk_Status.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const StoragePoolDisk_Status
The default value for StoragePoolDisk_Status.
creating → const StoragePoolDisk_Status
Disk is provisioning
deleting → const StoragePoolDisk_Status
Disk is deleting.
failed → const StoragePoolDisk_Status
Disk creation failed.
ready → const StoragePoolDisk_Status
Disk is ready for use.
restoring → const StoragePoolDisk_Status
Source data is being copied into the disk.
unavailable → const StoragePoolDisk_Status
Disk is currently unavailable and cannot be accessed, attached or detached.
undefinedStatus → const StoragePoolDisk_Status
A value indicating that the enum field is not set.