StoragePoolExapoolProvisionedCapacityGb class final

Exapool provisioned capacities for each SKU type

Constructors

StoragePoolExapoolProvisionedCapacityGb({int? capacityOptimized, int? readOptimized, int? writeOptimized})
StoragePoolExapoolProvisionedCapacityGb.fromJson(Object? j)
factory

Properties

capacityOptimized int?
Size, in GiB, of provisioned capacity-optimized capacity for this Exapool
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
readOptimized int?
Size, in GiB, of provisioned read-optimized capacity for this Exapool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
writeOptimized int?
Size, in GiB, of provisioned write-optimized capacity for this Exapool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String