StoragePoolResourceStatus class final

Output Only Contains output only fields.

Constructors

StoragePoolResourceStatus({int? diskCount, int? exapoolMaxReadIops, int? exapoolMaxReadThroughput, int? exapoolMaxWriteIops, int? exapoolMaxWriteThroughput, String? lastResizeTimestamp, int? maxTotalProvisionedDiskCapacityGb, int? poolUsedCapacityBytes, int? poolUsedIops, int? poolUsedThroughput, int? poolUserWrittenBytes, int? totalProvisionedDiskCapacityGb, int? totalProvisionedDiskIops, int? totalProvisionedDiskThroughput})
StoragePoolResourceStatus.fromJson(Object? j)
factory

Properties

diskCount int?
Output Only Number of disks used.
final
exapoolMaxReadIops int?
Output only. Output Only Maximum allowed read IOPS for this Exapool.
final
exapoolMaxReadThroughput int?
Output only. Output Only Maximum allowed read throughput in MiB/s for this Exapool.
final
exapoolMaxWriteIops int?
Output only. Output Only Maximum allowed write IOPS for this Exapool.
final
exapoolMaxWriteThroughput int?
Output only. Output Only Maximum allowed write throughput in MiB/s for this Exapool.
final
hashCode int
The hash code for this object.
no setterinherited
lastResizeTimestamp String?
Output only. Output Only Timestamp of the last successful resize inRFC3339 text format.
final
maxTotalProvisionedDiskCapacityGb int?
Output Only Maximum allowed aggregate disk size in GiB.
final
poolUsedCapacityBytes int?
Output Only Space used by data stored in disks within the storage pool (in bytes). This will reflect the total number of bytes written to the disks in the pool, in contrast to the capacity of those disks.
final
poolUsedIops int?
Output Only Sum of all the disks' provisioned IOPS, minus some amount that is allowed per disk that is not counted towards pool's IOPS capacity. For more information, see https://cloud.google.com/compute/docs/disks/storage-pools.
final
poolUsedThroughput int?
Output Only Sum of all the disks' provisioned throughput in MiB/s.
final
poolUserWrittenBytes int?
Output Only Amount of data written into the pool, before it is compacted.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalProvisionedDiskCapacityGb int?
Output Only Sum of all the disks' provisioned capacity (in GiB) in this storage pool. A disk's provisioned capacity is the same as its total capacity.
final
totalProvisionedDiskIops int?
Output Only Sum of all the disks' provisioned IOPS.
final
totalProvisionedDiskThroughput int?
Output Only Sum of all the disks' provisioned throughput in MiB/s, minus some amount that is allowed per disk that is not counted towards pool's throughput capacity.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String