poolUsedCapacityBytes property

int? poolUsedCapacityBytes
final

Output Only Space used by data stored in disks within the storage pool (in bytes). This will reflect the total number of bytes written to the disks in the pool, in contrast to the capacity of those disks.

Implementation

final int? poolUsedCapacityBytes;