poolUserWrittenBytes property
Output Only Amount of data written into the pool, before it is
compacted.
Implementation
final int? poolUserWrittenBytes;
Output Only Amount of data written into the pool, before it is
compacted.
final int? poolUserWrittenBytes;