toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (diskCount != null) 'diskCount=$diskCount',
    if (exapoolMaxReadIops != null) 'exapoolMaxReadIops=$exapoolMaxReadIops',
    if (exapoolMaxReadThroughput != null)
      'exapoolMaxReadThroughput=$exapoolMaxReadThroughput',
    if (exapoolMaxWriteIops != null)
      'exapoolMaxWriteIops=$exapoolMaxWriteIops',
    if (exapoolMaxWriteThroughput != null)
      'exapoolMaxWriteThroughput=$exapoolMaxWriteThroughput',
    if (lastResizeTimestamp != null)
      'lastResizeTimestamp=$lastResizeTimestamp',
    if (maxTotalProvisionedDiskCapacityGb != null)
      'maxTotalProvisionedDiskCapacityGb=$maxTotalProvisionedDiskCapacityGb',
    if (poolUsedCapacityBytes != null)
      'poolUsedCapacityBytes=$poolUsedCapacityBytes',
    if (poolUsedIops != null) 'poolUsedIops=$poolUsedIops',
    if (poolUsedThroughput != null) 'poolUsedThroughput=$poolUsedThroughput',
    if (poolUserWrittenBytes != null)
      'poolUserWrittenBytes=$poolUserWrittenBytes',
    if (totalProvisionedDiskCapacityGb != null)
      'totalProvisionedDiskCapacityGb=$totalProvisionedDiskCapacityGb',
    if (totalProvisionedDiskIops != null)
      'totalProvisionedDiskIops=$totalProvisionedDiskIops',
    if (totalProvisionedDiskThroughput != null)
      'totalProvisionedDiskThroughput=$totalProvisionedDiskThroughput',
  ].join(',');
  return 'StoragePoolResourceStatus(${$contents})';
}