projectId property
The project ID, should be same as the key of this project config in the parent map.
Implementation
final String? projectId;
The project ID, should be same as the key of this project config in the parent map.
final String? projectId;