StoragePool_State class final

Output only. Output Only The status of storage pool creation.

 - CREATING: Storage pool is provisioning.
 storagePool.
 - FAILED: Storage pool creation failed.
 - READY: Storage pool is ready for use.
 - DELETING: Storage pool is deleting.

Constructors

StoragePool_State(String value)
const
StoragePool_State.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const StoragePool_State
The default value for StoragePool_State.
creating → const StoragePool_State
StoragePool is provisioning
deleting → const StoragePool_State
StoragePool is deleting.
failed → const StoragePool_State
StoragePool creation failed.
ready → const StoragePool_State
StoragePool is ready for use.
undefinedState → const StoragePool_State
A value indicating that the enum field is not set.