get method

Returns a specified storage pool. Gets a list of available storage pools by making a list() request.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<StoragePool> get(GetStoragePoolRequest request) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/zones/${request.zone}/storagePools/${request.storagePool}',
  );
  final response = await _client.get(url);
  return StoragePool.fromJson(response);
}