setIamPolicy method

Future<Policy> setIamPolicy(
  1. SetIamPolicyStoragePoolRequest request
)

Sets the access control policy on the specified resource. Replaces any existing policy.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Policy> setIamPolicy(SetIamPolicyStoragePoolRequest request) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/zones/${request.zone}/storagePools/${request.resource}/setIamPolicy',
  );
  final response = await _client.post(
    url,
    body: request.zoneSetPolicyRequestResource,
  );
  return Policy.fromJson(response);
}