update method

Updates the specified storagePool with the data included in the request. The update is performed only on selected fields included as part of update-mask. Only the following fields can be modified: pool_provisioned_capacity_gb, pool_provisioned_iops and pool_provisioned_throughput.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> update(UpdateStoragePoolRequest request) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/zones/${request.zone}/storagePools/${request.storagePool}',
    queryParameters: {
      'requestId': ?request.requestId,
      'updateMask': ?request.updateMask,
    },
  );
  final response = await _client.patch(
    url,
    body: request.storagePoolResource,
  );
  return Operation.fromJson(response);
}