StoragePoolsScopedList class
final
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
qualifiedName
→ String
-
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or google.rpc.ErrorInfo.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
storagePools
→ List<StoragePool>
-
Output Only A list of storage pool contained in this scope.
final
-
warning
→ Warning?
-
Output Only Informational warning which replaces the list of storage pool
when the list is empty.
final