gatewayAddress property
Output only. Output Only The gateway address for default routes to reach destination
addresses outside this subnetwork.
Implementation
final String? gatewayAddress;
Output only. Output Only The gateway address for default routes to reach destination
addresses outside this subnetwork.
final String? gatewayAddress;