logConfig property
This field denotes the VPC flow logging options for this subnetwork. If logging is enabled, logs are exported to Cloud Logging.
Implementation
final SubnetworkLogConfig? logConfig;
This field denotes the VPC flow logging options for this subnetwork. If logging is enabled, logs are exported to Cloud Logging.
final SubnetworkLogConfig? logConfig;