params property
Input only. Input Only Additional params passed with the request, but not persisted
as part of resource payload.
Implementation
final SubnetworkParams? params;
Input only. Input Only Additional params passed with the request, but not persisted
as part of resource payload.
final SubnetworkParams? params;