region property
URL of the region where the Subnetwork resides. This field can be set only at resource creation time.
Implementation
final String? region;
URL of the region where the Subnetwork resides. This field can be set only at resource creation time.
final String? region;