toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (allowSubnetCidrRoutesOverlap != null)
      'allowSubnetCidrRoutesOverlap=$allowSubnetCidrRoutesOverlap',
    if (creationTimestamp != null) 'creationTimestamp=$creationTimestamp',
    if (description != null) 'description=$description',
    if (enableFlowLogs != null) 'enableFlowLogs=$enableFlowLogs',
    if (externalIpv6Prefix != null) 'externalIpv6Prefix=$externalIpv6Prefix',
    if (fingerprint != null) 'fingerprint=$fingerprint',
    if (gatewayAddress != null) 'gatewayAddress=$gatewayAddress',
    if (id != null) 'id=$id',
    if (internalIpv6Prefix != null) 'internalIpv6Prefix=$internalIpv6Prefix',
    if (ipCidrRange != null) 'ipCidrRange=$ipCidrRange',
    if (ipCollection != null) 'ipCollection=$ipCollection',
    if (ipv6AccessType != null) 'ipv6AccessType=$ipv6AccessType',
    if (ipv6CidrRange != null) 'ipv6CidrRange=$ipv6CidrRange',
    if (ipv6GceEndpoint != null) 'ipv6GceEndpoint=$ipv6GceEndpoint',
    if (kind != null) 'kind=$kind',
    if (name != null) 'name=$name',
    if (network != null) 'network=$network',
    if (privateIpGoogleAccess != null)
      'privateIpGoogleAccess=$privateIpGoogleAccess',
    if (privateIpv6GoogleAccess != null)
      'privateIpv6GoogleAccess=$privateIpv6GoogleAccess',
    if (purpose != null) 'purpose=$purpose',
    if (region != null) 'region=$region',
    if (reservedInternalRange != null)
      'reservedInternalRange=$reservedInternalRange',
    if (resolveSubnetMask != null) 'resolveSubnetMask=$resolveSubnetMask',
    if (role != null) 'role=$role',
    if (selfLink != null) 'selfLink=$selfLink',
    if (stackType != null) 'stackType=$stackType',
    if (state != null) 'state=$state',
  ].join(',');
  return 'Subnetwork(${$contents})';
}