flowSampling property
Can only be specified if VPC flow logging for this subnetwork is enabled.
The value of the field must be in 0, 1. Set the sampling rate of VPC
flow logs within the subnetwork where 1.0 means all collected logs are
reported and 0.0 means no logs are reported. Default is 0.5 unless
otherwise specified by the org policy, which means half of all collected
logs are reported.
Implementation
final double? flowSampling;