SubnetworkLogConfig_AggregationInterval class final
Can only be specified if VPC flow logging for this subnetwork is enabled. Toggles the aggregation interval for collecting flow logs. Increasing the interval time will reduce the amount of generated flow logs for long lasting connections. Default is an interval of 5 seconds per connection.
Constructors
- SubnetworkLogConfig_AggregationInterval(String value)
-
const
- SubnetworkLogConfig_AggregationInterval.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const SubnetworkLogConfig_AggregationInterval
- The default value for SubnetworkLogConfig_AggregationInterval.
- interval1Min → const SubnetworkLogConfig_AggregationInterval
- interval5Min → const SubnetworkLogConfig_AggregationInterval
- interval5Sec → const SubnetworkLogConfig_AggregationInterval
- interval10Min → const SubnetworkLogConfig_AggregationInterval
- interval15Min → const SubnetworkLogConfig_AggregationInterval
- interval30Sec → const SubnetworkLogConfig_AggregationInterval
- undefinedAggregationInterval → const SubnetworkLogConfig_AggregationInterval
- A value indicating that the enum field is not set.