SubnetworkSecondaryRange_IpVersion class final

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const SubnetworkSecondaryRange_IpVersion
The default value for SubnetworkSecondaryRange_IpVersion.
ipv4 → const SubnetworkSecondaryRange_IpVersion
ipv6 → const SubnetworkSecondaryRange_IpVersion
ipVersionUnspecified → const SubnetworkSecondaryRange_IpVersion
Treated as IPV4 for backward-compatibility.
undefinedIpVersion → const SubnetworkSecondaryRange_IpVersion
A value indicating that the enum field is not set.