SubnetworkUtilizationDetails class final

The current IP utilization of all subnetwork ranges. Contains the total number of allocated and free IPs in each range.

Properties

externalIpv6InstanceUtilization SubnetworkUtilizationDetailsIpv6Utilization?
Utilizations of external IPV6 IP range.
final
externalIpv6LbUtilization SubnetworkUtilizationDetailsIpv6Utilization?
Utilizations of external IPV6 IP range for NetLB.
final
hashCode int
The hash code for this object.
no setterinherited
internalIpv6Utilization SubnetworkUtilizationDetailsIpv6Utilization?
Utilizations of internal IPV6 IP range.
final
ipv4Utilizations List<SubnetworkUtilizationDetailsIpv4Utilization>
Utilizations of all IPV4 IP ranges. For primary ranges, the range name will be empty.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String