SubnetworkUtilizationDetailsIpv4Utilization class final

The IPV4 utilization of a single IP range.

Constructors

SubnetworkUtilizationDetailsIpv4Utilization({String? rangeName, int? totalAllocatedIp, int? totalFreeIp})
SubnetworkUtilizationDetailsIpv4Utilization.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
rangeName String?
Will be set for secondary range. Empty for primary IPv4 range.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalAllocatedIp int?
final
totalFreeIp int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String