Subnetwork_ResolveSubnetMask class final

Configures subnet mask resolution for this subnetwork.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const Subnetwork_ResolveSubnetMask
The default value for Subnetwork_ResolveSubnetMask.
arpAllRanges → const Subnetwork_ResolveSubnetMask
All ranges assigned to the VM NIC will respond to ARP.
arpBroadcastPrimaryRange → const Subnetwork_ResolveSubnetMask
VMs will receive an ARP response from a VM instance owning the target IP address within the subnetwork's primary CIDR range, if such a VM instance exists and is running.
arpBroadcastPrimaryRangeWithLearning → const Subnetwork_ResolveSubnetMask
Combines ARP_BROADCAST_PRIMARY_RANGE with MAC learning. Enables cache mapping between IP addresses and custom MAC addresses of instances and use of it to set the correct destination MAC address. If this option is chosen, the subnetwork must have /24 or a smaller CIDR range.
arpPrimaryRange → const Subnetwork_ResolveSubnetMask
Only the primary range of the VM NIC will respond to ARP.
undefinedResolveSubnetMask → const Subnetwork_ResolveSubnetMask
A value indicating that the enum field is not set.