undefinedRole constant
Subnetwork_Role
const undefinedRole
A value indicating that the enum field is not set.
Implementation
static const undefinedRole = Subnetwork_Role('UNDEFINED_ROLE');
A value indicating that the enum field is not set.
static const undefinedRole = Subnetwork_Role('UNDEFINED_ROLE');