listUsable method

Retrieves an aggregated list of all usable subnetworks in the project.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<UsableSubnetworksAggregatedList> listUsable(
  ListUsableSubnetworksRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/aggregated/subnetworks/listUsable',
    queryParameters: {
      'filter': ?request.filter,
      if (request.maxResults case final $1?) 'maxResults': '${$1}',
      'orderBy': ?request.orderBy,
      'pageToken': ?request.pageToken,
      if (request.returnPartialSuccess case final $1?)
        'returnPartialSuccess': '${$1}',
      'serviceProject': ?request.serviceProject,
    },
  );
  final response = await _client.get(url);
  return UsableSubnetworksAggregatedList.fromJson(response);
}