setPrivateIpGoogleAccess method

Future<Operation> setPrivateIpGoogleAccess(
  1. SetPrivateIpGoogleAccessSubnetworkRequest request
)

Set whether VMs in this subnet can access Google services without assigning external IP addresses through Private Google Access.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> setPrivateIpGoogleAccess(
  SetPrivateIpGoogleAccessSubnetworkRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/regions/${request.region}/subnetworks/${request.subnetwork}/setPrivateIpGoogleAccess',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.post(
    url,
    body: request.subnetworksSetPrivateIpGoogleAccessRequestResource,
  );
  return Operation.fromJson(response);
}