SubnetworksScopedList class final

Constructors

SubnetworksScopedList({List<Subnetwork> subnetworks = const [], Warning? warning})
SubnetworksScopedList.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subnetworks List<Subnetwork>
A list of subnetworks contained in this scope.
final
warning Warning?
An informational warning that appears when the list of addresses is empty.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String