SuspendInstanceRequest class final

A request message for Instances.Suspend. See the method description for details.

Constructors

SuspendInstanceRequest({bool? discardLocalSsd, required String instance, required String project, String? requestId, required String zone})
SuspendInstanceRequest.fromJson(Object? j)
factory

Properties

discardLocalSsd bool?
This property is required if the instance has any attached Local SSD disks. If false, Local SSD data will be preserved when the instance is suspended. If true, the contents of any attached Local SSD disks will be discarded.
final
hashCode int
The hash code for this object.
no setterinherited
instance String
Name of the instance resource to suspend.
final
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requestId String?
An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zone String
The name of the zone for this request.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String