TargetGrpcProxies class final
The TargetGrpcProxies API.
- Implementers
Constructors
- TargetGrpcProxies({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
TargetGrpcProxiesusingclientfor transport. - TargetGrpcProxies.fromApiKey([String? apiKey])
-
Creates a
TargetGrpcProxiesthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteTargetGrpcProxyRequest request) → Future< Operation> - Deletes the specified TargetGrpcProxy in the given scope
-
get(
GetTargetGrpcProxyRequest request) → Future< TargetGrpcProxy> - Returns the specified TargetGrpcProxy resource in the given scope.
-
insert(
InsertTargetGrpcProxyRequest request) → Future< Operation> - Creates a TargetGrpcProxy in the specified project in the given scope using the parameters that are included in the request.
-
list(
ListTargetGrpcProxiesRequest request) → Future< TargetGrpcProxyList> - Lists the TargetGrpcProxies for a project in the given scope.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchTargetGrpcProxyRequest request) → Future< Operation> - Patches the specified TargetGrpcProxy resource with the data included in the request. This method supports PATCH semantics and usesJSON merge patch format and processing rules.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited