patch method

Patches the specified TargetHttpProxy resource with the data included in the request. This method supports PATCH semantics and usesJSON merge patch format and processing rules.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> patch(PatchTargetHttpProxyRequest request) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/global/targetHttpProxies/${request.targetHttpProxy}',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.patch(
    url,
    body: request.targetHttpProxyResource,
  );
  return Operation.fromJson(response);
}