TargetHttpsProxy_QuicOverride class final

Specifies the QUIC override policy for this TargetHttpsProxy resource. This setting determines whether the load balancer attempts to negotiate QUIC with clients. You can specify NONE, ENABLE, orDISABLE.

  • When quic-override is set to NONE, Google manages whether QUIC is used.
  • When quic-override is set to ENABLE, the load balancer uses QUIC when possible.
  • When quic-override is set to DISABLE, the load balancer doesn't use QUIC.
  • If the quic-override flag is not specified,NONE is implied.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const TargetHttpsProxy_QuicOverride
The default value for TargetHttpsProxy_QuicOverride.
disable → const TargetHttpsProxy_QuicOverride
The load balancer will not attempt to negotiate QUIC with clients.
enable → const TargetHttpsProxy_QuicOverride
The load balancer will attempt to negotiate QUIC with clients.
none → const TargetHttpsProxy_QuicOverride
No overrides to the default QUIC policy. This option is implicit if no QUIC override has been specified in the request.
undefinedQuicOverride → const TargetHttpsProxy_QuicOverride
A value indicating that the enum field is not set.