permissive constant

This enables TLS 1.3 0-RTT, and only allows Early Data to be included on requests with safe HTTP methods (GET, HEAD, OPTIONS, TRACE). This mode does not enforce any other limitations for requests with Early Data. The application owner should validate that Early Data is acceptable for a given request path.

Implementation

static const permissive = TargetHttpsProxy_TlsEarlyData('PERMISSIVE');