unrestricted constant

TargetHttpsProxy_TlsEarlyData const unrestricted

This enables TLS 1.3 Early Data for requests with any HTTP method including non-idempotent methods list POST. This mode does not enforce any other limitations. This may be valuable for gRPC use cases. However, we do not recommend this method unless you have evaluated your security stance and mitigated the risk of replay attacks using other mechanisms.

Implementation

static const unrestricted = TargetHttpsProxy_TlsEarlyData('UNRESTRICTED');