TargetInstance_NatPolicy class final

Must have a value of NO_NAT. Protocol forwarding delivers packets while preserving the destination IP address of the forwarding rule referencing the target instance.

Constructors

TargetInstance_NatPolicy(String value)
const
TargetInstance_NatPolicy.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const TargetInstance_NatPolicy
The default value for TargetInstance_NatPolicy.
noNat → const TargetInstance_NatPolicy
No NAT performed.
undefinedNatPolicy → const TargetInstance_NatPolicy
A value indicating that the enum field is not set.