TargetInstances class final

The TargetInstances API.

Implementers

Constructors

TargetInstances({required Client client, Uri? endPoint, String? gcclVersion})
Creates a TargetInstances using client for transport.
TargetInstances.fromApiKey([String? apiKey])
Creates a TargetInstances that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(AggregatedListTargetInstancesRequest request) Future<TargetInstanceAggregatedList>
Retrieves an aggregated list of target instances.
close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteTargetInstanceRequest request) Future<Operation>
Deletes the specified TargetInstance resource.
get(GetTargetInstanceRequest request) Future<TargetInstance>
Returns the specified TargetInstance resource.
insert(InsertTargetInstanceRequest request) Future<Operation>
Creates a TargetInstance resource in the specified project and zone using the data included in the request.
list(ListTargetInstancesRequest request) Future<TargetInstanceList>
Retrieves a list of TargetInstance resources available to the specified project and zone.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setSecurityPolicy(SetSecurityPolicyTargetInstanceRequest request) Future<Operation>
Sets the Google Cloud Armor security policy for the specified target instance. For more information, seeGoogle Cloud Armor Overview
testIamPermissions(TestIamPermissionsTargetInstanceRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited