TargetPool class final

Represents a Target Pool resource.

Target pools are used with external passthrough Network Load Balancers. A target pool references member instances, an associated legacy HttpHealthCheck resource, and, optionally, a backup target pool. For more information, readUsing target pools.

Constructors

TargetPool({String? backupPool, String? creationTimestamp, String? description, double? failoverRatio, List<String> healthChecks = const [], BigInt? id, List<String> instances = const [], String? kind, String? name, String? region, String? securityPolicy, String? selfLink, String? sessionAffinity})
TargetPool.fromJson(Object? j)
factory

Properties

backupPool String?
The server-defined URL for the resource. This field is applicable only when the containing target pool is serving a forwarding rule as the primary pool, and its failoverRatio field is properly set to a value between 0, 1.backupPool and failoverRatio together define the fallback behavior of the primary target pool: if the ratio of the healthy instances in the primary pool is at or belowfailoverRatio, traffic arriving at the load-balanced IP will be directed to the backup pool.
final
creationTimestamp String?
Output only. Output Only Creation timestamp inRFC3339 text format.
final
description String?
An optional description of this resource. Provide this property when you create the resource.
final
failoverRatio double?
This field is applicable only when the containing target pool is serving a forwarding rule as the primary pool (i.e., not as a backup pool to some other target pool). The value of the field must be in 0, 1.
final
hashCode int
The hash code for this object.
no setterinherited
healthChecks List<String>
The URL of the HttpHealthCheck resource. A member instance in this pool is considered healthy if and only if the health checks pass. Only legacy HttpHealthChecks are supported. Only one health check may be specified.
final
id BigInt?
Output Only The unique identifier for the resource. This identifier is defined by the server.
final
instances List<String>
A list of resource URLs to the virtual machine instances serving this pool. They must live in zones contained in the same region as this pool.
final
kind String?
Output only. Output Only Type of the resource. Always compute#targetPool for target pools.
final
name String?
Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
region String?
Output only. Output Only URL of the region where the target pool resides.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
securityPolicy String?
Output Only The resource URL for the security policy associated with this target pool.
final
Output Only Server-defined URL for the resource.
final
sessionAffinity String?
Session affinity option, must be one of the following values: NONE: Connections from the same client IP may go to any instance in the pool. CLIENT_IP: Connections from the same client IP will go to the same instance in the pool while that instance remains healthy. CLIENT_IP_PROTO: Connections from the same client IP with the same IP protocol will go to the same instance in the pool while that instance remains healthy. Check the SessionAffinity enum for the list of possible values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String