healthChecks property

List<String> healthChecks
final

The URL of the HttpHealthCheck resource. A member instance in this pool is considered healthy if and only if the health checks pass. Only legacy HttpHealthChecks are supported. Only one health check may be specified.

Implementation

final List<String> healthChecks;