TargetPoolInstanceHealth class final
Constructors
-
TargetPoolInstanceHealth({List<
HealthStatus> healthStatus = const [], String? kind}) - TargetPoolInstanceHealth.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
healthStatus
→ List<
HealthStatus> -
final
- kind → String?
-
Output only.
Output OnlyType of resource. Alwayscompute#targetPoolInstanceHealth when checking the health of an instance.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String