httpCookie constant
TargetPool_SessionAffinity
const httpCookie
The hash is based on a user provided cookie.
Implementation
static const httpCookie = TargetPool_SessionAffinity('HTTP_COOKIE');
The hash is based on a user provided cookie.
static const httpCookie = TargetPool_SessionAffinity('HTTP_COOKIE');