strongCookieAffinity constant

TargetPool_SessionAffinity const strongCookieAffinity

Strong cookie-based affinity. Connections bearing the same cookie will be served by the same backend VM while that VM remains healthy, as long as the cookie has not expired.

Implementation

static const strongCookieAffinity = TargetPool_SessionAffinity(
  'STRONG_COOKIE_AFFINITY',
);