setSecurityPolicy method

Future<Operation> setSecurityPolicy(
  1. SetSecurityPolicyTargetPoolRequest request
)

Sets the Google Cloud Armor security policy for the specified target pool. For more information, seeGoogle Cloud Armor Overview

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> setSecurityPolicy(
  SetSecurityPolicyTargetPoolRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/regions/${request.region}/targetPools/${request.targetPool}/setSecurityPolicy',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.post(
    url,
    body: request.securityPolicyReferenceResource,
  );
  return Operation.fromJson(response);
}