TargetPoolsAddInstanceRequest class
final
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
instances
→ List<InstanceReference>
-
A full or partial URL to an instance to add to this target pool. This can
be a full or partial URL. For example, the following are valid URLs:
final
-
qualifiedName
→ String
-
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or google.rpc.ErrorInfo.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited