menu
google_cloud_compute_v1 package
documentation
compute.dart
TargetSslProxiesSetSslCertificatesRequest class
TargetSslProxiesSetSslCertificatesRequest class
dark_mode
light_mode
TargetSslProxiesSetSslCertificatesRequest
class
final
Constructors
TargetSslProxiesSetSslCertificatesRequest
({
List
<
String
>
sslCertificates
=
const []
})
TargetSslProxiesSetSslCertificatesRequest.fromJson
(
Object
?
j
)
factory
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
qualifiedName
→
String
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or
google.rpc.ErrorInfo
.
final
inherited
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
sslCertificates
→
List
<
String
>
New set of URLs to SslCertificate resources to associate with this TargetSslProxy. At least one SSL certificate must be specified. Currently, you may specify up to 15 SSL certificates.
final
Methods
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson
(
)
→
Object
toString
(
)
→
String
A string representation of this object.
override
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
Constants
fullyQualifiedName
→ const
String
google_cloud_compute_v1 package
documentation
compute
TargetSslProxiesSetSslCertificatesRequest class
compute library