TargetSslProxy_ProxyHeader class final

Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const TargetSslProxy_ProxyHeader
The default value for TargetSslProxy_ProxyHeader.
none → const TargetSslProxy_ProxyHeader
proxyV1 → const TargetSslProxy_ProxyHeader
undefinedProxyHeader → const TargetSslProxy_ProxyHeader
A value indicating that the enum field is not set.