TargetTcpProxies class final

The TargetTcpProxies API.

Implementers

Constructors

TargetTcpProxies({required Client client, Uri? endPoint, String? gcclVersion})
Creates a TargetTcpProxies using client for transport.
TargetTcpProxies.fromApiKey([String? apiKey])
Creates a TargetTcpProxies that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(AggregatedListTargetTcpProxiesRequest request) Future<TargetTcpProxyAggregatedList>
Retrieves the list of all TargetTcpProxy resources, regional and global, available to the specified project.
close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteTargetTcpProxyRequest request) Future<Operation>
Deletes the specified TargetTcpProxy resource.
get(GetTargetTcpProxyRequest request) Future<TargetTcpProxy>
Returns the specified TargetTcpProxy resource.
insert(InsertTargetTcpProxyRequest request) Future<Operation>
Creates a TargetTcpProxy resource in the specified project using the data included in the request.
list(ListTargetTcpProxiesRequest request) Future<TargetTcpProxyList>
Retrieves the list of TargetTcpProxy resources available to the specified project.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBackendService(SetBackendServiceTargetTcpProxyRequest request) Future<Operation>
Changes the BackendService for TargetTcpProxy.
setProxyHeader(SetProxyHeaderTargetTcpProxyRequest request) Future<Operation>
Changes the ProxyHeaderType for TargetTcpProxy.
testIamPermissions(TestIamPermissionsTargetTcpProxyRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited