proxyHeader property
The new type of proxy header to append before sending data to the backend. NONE or PROXY_V1 are allowed. Check the ProxyHeader enum for the list of possible values.
Implementation
final String? proxyHeader;
The new type of proxy header to append before sending data to the backend. NONE or PROXY_V1 are allowed. Check the ProxyHeader enum for the list of possible values.
final String? proxyHeader;