loadBalancingScheme property
Specifies the type of load balancing scheme used by this target proxy. Check the LoadBalancingScheme enum for the list of possible values.
Implementation
final String? loadBalancingScheme;
Specifies the type of load balancing scheme used by this target proxy. Check the LoadBalancingScheme enum for the list of possible values.
final String? loadBalancingScheme;