TargetTcpProxyAggregatedList class final

Constructors

TargetTcpProxyAggregatedList({String? id, Map<String, TargetTcpProxiesScopedList> items = const {}, String? kind, String? nextPageToken, String? selfLink, List<String> unreachables = const [], Warning? warning})
TargetTcpProxyAggregatedList.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String?
Output Only Unique identifier for the resource; defined by the server.
final
items Map<String, TargetTcpProxiesScopedList>
A list of TargetTcpProxiesScopedList resources.
final
kind String?
Output only. Output Only Type of resource. Alwayscompute#targetTcpProxyAggregatedList for lists of Target TCP Proxies.
final
nextPageToken String?
Output Only This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output only. Output Only Server-defined URL for this resource.
final
unreachables List<String>
Output only. Output Only Unreachable resources.
final
warning Warning?
Output Only Informational warning message.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String