TargetTcpProxy_LoadBalancingScheme class final
Specifies the type of load balancing scheme used by this target proxy.
Constructors
- TargetTcpProxy_LoadBalancingScheme(String value)
-
const
- TargetTcpProxy_LoadBalancingScheme.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const TargetTcpProxy_LoadBalancingScheme
- The default value for TargetTcpProxy_LoadBalancingScheme.
- external → const TargetTcpProxy_LoadBalancingScheme
- externalManaged → const TargetTcpProxy_LoadBalancingScheme
- internalManaged → const TargetTcpProxy_LoadBalancingScheme
- loadBalancingSchemeUnspecified → const TargetTcpProxy_LoadBalancingScheme
- undefinedLoadBalancingScheme → const TargetTcpProxy_LoadBalancingScheme
- A value indicating that the enum field is not set.