TargetVpnGateway class final

Represents a Target VPN Gateway resource.

The target VPN gateway resource represents a Classic Cloud VPN gateway. For more information, read thethe Cloud VPN Overview.

Constructors

TargetVpnGateway({String? creationTimestamp, String? description, List<String> forwardingRules = const [], BigInt? id, String? kind, String? labelFingerprint, Map<String, String> labels = const {}, String? name, String? network, TargetVpnGatewayParams? params, String? region, String? selfLink, String? status, List<String> tunnels = const []})
TargetVpnGateway.fromJson(Object? j)
factory

Properties

creationTimestamp String?
Output only. Output Only Creation timestamp inRFC3339 text format.
final
description String?
An optional description of this resource. Provide this property when you create the resource.
final
forwardingRules List<String>
Output Only A list of URLs to the ForwardingRule resources. ForwardingRules are created usingcompute.forwardingRules.insert and associated with a VPN gateway.
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output Only The unique identifier for the resource. This identifier is defined by the server.
final
kind String?
Output only. Output Only Type of resource. Alwayscompute#targetVpnGateway for target VPN gateways.
final
labelFingerprint String?
A fingerprint for the labels being applied to this TargetVpnGateway, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet.
final
labels Map<String, String>
Labels for this resource. These can only be added or modified by thesetLabels method. Each label key/value pair must comply withRFC1035. Label values may be empty.
final
name String?
Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
network String?
URL of the network to which this VPN gateway is attached. Provided by the client when the VPN gateway is created.
final
params TargetVpnGatewayParams?
Input only. Input Only Additional params passed with the request, but not persisted as part of resource payload.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
region String?
Output Only URL of the region where the target VPN gateway resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output Only Server-defined URL for the resource.
final
status String?
Output Only The status of the VPN gateway, which can be one of the following: CREATING, READY, FAILED, or DELETING. Check the Status enum for the list of possible values.
final
tunnels List<String>
Output Only A list of URLs to VpnTunnel resources. VpnTunnels are created using the compute.vpntunnels.insert method and associated with a VPN gateway.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String