region property

String? region
final

Output Only URL of the region where the target VPN gateway resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.

Implementation

final String? region;