TargetVpnGateway_Status class final

Output Only The status of the VPN gateway, which can be one of the following: CREATING, READY, FAILED, or DELETING.

Constructors

TargetVpnGateway_Status(String value)
const
TargetVpnGateway_Status.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const TargetVpnGateway_Status
The default value for TargetVpnGateway_Status.
creating → const TargetVpnGateway_Status
deleting → const TargetVpnGateway_Status
failed → const TargetVpnGateway_Status
ready → const TargetVpnGateway_Status
undefinedStatus → const TargetVpnGateway_Status
A value indicating that the enum field is not set.