expectedOutputUrl property
The expected output URL evaluated by a load balancer containing the scheme, host, path and query parameters.
Implementation
final String? expectedOutputUrl;
The expected output URL evaluated by a load balancer containing the scheme, host, path and query parameters.
final String? expectedOutputUrl;