latestWindowStartTime property
The latest time for the planned maintenance window to start. This timestamp value is in RFC3339 text format.
Implementation
final String? latestWindowStartTime;
The latest time for the planned maintenance window to start. This timestamp value is in RFC3339 text format.
final String? latestWindowStartTime;