windowEndTime property
The time by which the maintenance disruption will be completed. This timestamp value is in RFC3339 text format.
Implementation
final String? windowEndTime;
The time by which the maintenance disruption will be completed. This timestamp value is in RFC3339 text format.
final String? windowEndTime;