UpcomingMaintenance_MaintenanceReasons class final

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const UpcomingMaintenance_MaintenanceReasons
The default value for UpcomingMaintenance_MaintenanceReasons.
failureDisk → const UpcomingMaintenance_MaintenanceReasons
Maintenance due to disk errors.
failureGpu → const UpcomingMaintenance_MaintenanceReasons
Maintenance due to GPU errors.
failureGpuMultipleFaultyHostsCustomerReported → const UpcomingMaintenance_MaintenanceReasons
Maintenance due to customer reported multiple faulty hosts via R&R Subblock API.
failureGpuNvlinkSwitchCustomerReported → const UpcomingMaintenance_MaintenanceReasons
Maintenance due to customer reported NVLink switch failure via R&R Subblock API.
failureGpuTemperature → const UpcomingMaintenance_MaintenanceReasons
Maintenance due to high GPU temperature.
failureGpuXid → const UpcomingMaintenance_MaintenanceReasons
Maintenance due to GPU xid failure.
failureInfra → const UpcomingMaintenance_MaintenanceReasons
Maintenance due to infrastructure errors.
failureInterface → const UpcomingMaintenance_MaintenanceReasons
Maintenance due to interface errors.
failureMemory → const UpcomingMaintenance_MaintenanceReasons
Maintenance due to memory errors.
failureNetwork → const UpcomingMaintenance_MaintenanceReasons
Maintenance due to network errors.
Maintenance due to NVLink failure.
failureRedundantHardwareFault → const UpcomingMaintenance_MaintenanceReasons
Maintenance due to redundant hardware fault.
failureTpu → const UpcomingMaintenance_MaintenanceReasons
Maintenance due to TPU errors.
infrastructureRelocation → const UpcomingMaintenance_MaintenanceReasons
Maintenance due to infrastructure relocation.
maintenanceReasonUnknown → const UpcomingMaintenance_MaintenanceReasons
Unknown maintenance reason. Do not use this value.
plannedNetworkUpdate → const UpcomingMaintenance_MaintenanceReasons
Maintenance due to planned network update.
plannedUpdate → const UpcomingMaintenance_MaintenanceReasons
Maintenance due to planned update to the instance.
undefinedMaintenanceReasons → const UpcomingMaintenance_MaintenanceReasons
A value indicating that the enum field is not set.