UpcomingMaintenance_MaintenanceStatus class final

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const UpcomingMaintenance_MaintenanceStatus
The default value for UpcomingMaintenance_MaintenanceStatus.
ongoing → const UpcomingMaintenance_MaintenanceStatus
There is ongoing maintenance on this VM.
pending → const UpcomingMaintenance_MaintenanceStatus
There is pending maintenance.
undefinedMaintenanceStatus → const UpcomingMaintenance_MaintenanceStatus
A value indicating that the enum field is not set.
unknown → const UpcomingMaintenance_MaintenanceStatus
Unknown maintenance status. Do not use this value.