UpdateDiskRequest class final
A request message for Disks.Update. See the method description for details.
Constructors
- UpdateDiskRequest({required String disk, required Disk? diskResource, String? paths, required String project, String? requestId, String? updateMask, required String zone})
- UpdateDiskRequest.fromJson(Object? j)
-
factory
Properties
- disk → String
-
The disk name for this request.
final
- diskResource → Disk?
-
The body resource for this request
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- paths → String?
-
final
- project → String
-
Project ID for this request.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - requestId → String?
-
An optional request ID to identify requests. Specify a unique request ID so
that if you must retry your request, the server will know to ignore the
request if it has already been completed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updateMask → String?
-
update_mask indicates fields to be updated as part of this request.
final
- zone → String
-
The name of the zone for this request.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String