UpdateInstanceRequest class final

A request message for Instances.Update. See the method description for details.

Constructors

UpdateInstanceRequest({bool? discardLocalSsd, required String instance, required Instance? instanceResource, String? minimalAction, String? mostDisruptiveAllowedAction, required String project, String? requestId, required String zone})
UpdateInstanceRequest.fromJson(Object? j)
factory

Properties

discardLocalSsd bool?
Whether to discard local SSDs from the instance during restart default value is false.
final
hashCode int
The hash code for this object.
no setterinherited
instance String
Name of the instance resource to update.
final
instanceResource Instance?
The body resource for this request
final
minimalAction String?
Specifies the action to take when updating an instance even if the updated properties do not require it. If not specified, then Compute Engine acts based on the minimum action that the updated properties require. Check the MinimalAction enum for the list of possible values.
final
mostDisruptiveAllowedAction String?
Specifies the most disruptive action that can be taken on the instance as part of the update. Compute Engine returns an error if the instance properties require a more disruptive action as part of the instance update. Valid options from lowest to highest are NO_EFFECT, REFRESH, and RESTART. Check the MostDisruptiveAllowedAction enum for the list of possible values.
final
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requestId String?
An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zone String
The name of the zone for this request.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String