discardLocalSsd property
Whether to discard local SSDs from the instance during restart default value is false.
Implementation
final bool? discardLocalSsd;
Whether to discard local SSDs from the instance during restart default value is false.
final bool? discardLocalSsd;