mostDisruptiveAllowedAction property

String? mostDisruptiveAllowedAction
final

Specifies the most disruptive action that can be taken on the instance as part of the update. Compute Engine returns an error if the instance properties require a more disruptive action as part of the instance update. Valid options from lowest to highest are NO_EFFECT, REFRESH, and RESTART. Check the MostDisruptiveAllowedAction enum for the list of possible values.

Implementation

final String? mostDisruptiveAllowedAction;