UpdateInstanceRequest_MinimalAction class final
Specifies the action to take when updating an instance even if the updated properties do not require it. If not specified, then Compute Engine acts based on the minimum action that the updated properties require. Additional supported values which may be not listed in the enum directly due to technical reasons: INVALID NO_EFFECT REFRESH RESTART
Constructors
- UpdateInstanceRequest_MinimalAction(String value)
-
const
- UpdateInstanceRequest_MinimalAction.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const UpdateInstanceRequest_MinimalAction
- The default value for UpdateInstanceRequest_MinimalAction.
- undefinedMinimalAction → const UpdateInstanceRequest_MinimalAction
- A value indicating that the enum field is not set.