UpdateInstanceRequest_MostDisruptiveAllowedAction class final
Specifies the most disruptive action that can be taken on the instance as part of the update. Compute Engine returns an error if the instance properties require a more disruptive action as part of the instance update. Valid options from lowest to highest are NO_EFFECT, REFRESH, and RESTART. Additional supported values which may be not listed in the enum directly due to technical reasons: INVALID NO_EFFECT REFRESH RESTART
Constructors
- UpdateInstanceRequest_MostDisruptiveAllowedAction(String value)
-
const
- UpdateInstanceRequest_MostDisruptiveAllowedAction.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const UpdateInstanceRequest_MostDisruptiveAllowedAction
- The default value for UpdateInstanceRequest_MostDisruptiveAllowedAction.
- undefinedMostDisruptiveAllowedAction → const UpdateInstanceRequest_MostDisruptiveAllowedAction
- A value indicating that the enum field is not set.