headers property
HTTP headers for this request. If headers contains a host header, then host must also match the header value.
Implementation
final List<UrlMapTestHeader> headers;
HTTP headers for this request. If headers contains a host header, then host must also match the header value.
final List<UrlMapTestHeader> headers;