host property
Host portion of the URL. If headers contains a host header, then host must also match the header value.
Implementation
final String? host;
Host portion of the URL. If headers contains a host header, then host must also match the header value.
final String? host;