UrlMapValidationResult class final

Message representing the validation result for a UrlMap.

Constructors

UrlMapValidationResult({List<String> loadErrors = const [], bool? loadSucceeded, List<TestFailure> testFailures = const [], bool? testPassed})
UrlMapValidationResult.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
loadErrors List<String>
final
loadSucceeded bool?
Whether the given UrlMap can be successfully loaded. If false, 'loadErrors' indicates the reasons.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
testFailures List<TestFailure>
final
testPassed bool?
If successfully loaded, this field indicates whether the test passed. If false, 'testFailures's indicate the reason of failure.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String