testPassed property
If successfully loaded, this field indicates whether the test passed. If false, 'testFailures's indicate the reason of failure.
Implementation
final bool? testPassed;
If successfully loaded, this field indicates whether the test passed. If false, 'testFailures's indicate the reason of failure.
final bool? testPassed;