UrlMaps class final
The UrlMaps API.
- Implementers
Constructors
- UrlMaps({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
UrlMapsusingclientfor transport. - UrlMaps.fromApiKey([String? apiKey])
-
Creates a
UrlMapsthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
aggregatedList(
AggregatedListUrlMapsRequest request) → Future< UrlMapsAggregatedList> - Retrieves the list of all UrlMap resources, regional and global, available to the specified project.
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteUrlMapRequest request) → Future< Operation> - Deletes the specified UrlMap resource.
-
get(
GetUrlMapRequest request) → Future< UrlMap> - Returns the specified UrlMap resource.
-
insert(
InsertUrlMapRequest request) → Future< Operation> - Creates a UrlMap resource in the specified project using the data included in the request.
-
invalidateCache(
InvalidateCacheUrlMapRequest request) → Future< Operation> - Initiates a cache invalidation operation, invalidating the specified path, scoped to the specified UrlMap.
-
list(
ListUrlMapsRequest request) → Future< UrlMapList> - Retrieves the list of UrlMap resources available to the specified project.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchUrlMapRequest request) → Future< Operation> - Patches the specified UrlMap resource with the data included in the request. This method supportsPATCH semantics and uses theJSON merge patch format and processing rules.
-
testIamPermissions(
TestIamPermissionsUrlMapRequest request) → Future< TestPermissionsResponse> - Returns permissions that a caller has on the specified resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
UpdateUrlMapRequest request) → Future< Operation> - Updates the specified UrlMap resource with the data included in the request.
-
validate(
ValidateUrlMapRequest request) → Future< UrlMapsValidateResponse> - Runs static validation for the UrlMap. In particular, the tests of the provided UrlMap will be run. Calling this method does NOT create the UrlMap.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited