invalidateCache method

Future<Operation> invalidateCache(
  1. InvalidateCacheUrlMapRequest request
)

Initiates a cache invalidation operation, invalidating the specified path, scoped to the specified UrlMap.

For more information, see Invalidating cached content.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> invalidateCache(
  InvalidateCacheUrlMapRequest request,
) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/global/urlMaps/${request.urlMap}/invalidateCache',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.post(
    url,
    body: request.cacheInvalidationRuleResource,
  );
  return Operation.fromJson(response);
}