update method

Future<Operation> update(
  1. UpdateUrlMapRequest request
)

Updates the specified UrlMap resource with the data included in the request.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> update(UpdateUrlMapRequest request) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/global/urlMaps/${request.urlMap}',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.put(url, body: request.urlMapResource);
  return Operation.fromJson(response);
}