UrlMapsValidateRequest class final

Constructors

UrlMapsValidateRequest({List<String> loadBalancingSchemes = const [], UrlMap? resource})
UrlMapsValidateRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
loadBalancingSchemes List<String>
Specifies the load balancer type(s) this validation request is for. UseEXTERNAL_MANAGED for global external Application Load Balancers and regional external Application Load Balancers. Use EXTERNAL for classic Application Load Balancers.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
resource UrlMap?
Content of the UrlMap to be validated.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String