UrlMapsValidateRequest_LoadBalancingSchemes class final

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const UrlMapsValidateRequest_LoadBalancingSchemes
The default value for UrlMapsValidateRequest_LoadBalancingSchemes.
external → const UrlMapsValidateRequest_LoadBalancingSchemes
Signifies that this will be used for classic Application Load Balancers.
externalManaged → const UrlMapsValidateRequest_LoadBalancingSchemes
Signifies that this will be used for Envoy-based global external Application Load Balancers.
loadBalancingSchemeUnspecified → const UrlMapsValidateRequest_LoadBalancingSchemes
If unspecified, the validation will try to infer the scheme from the backend service resources this Url map references. If the inference is not possible, EXTERNAL will be used as the default type.
undefinedLoadBalancingSchemes → const UrlMapsValidateRequest_LoadBalancingSchemes
A value indicating that the enum field is not set.