UrlRewrite class final
The spec for modifying the path before sending the request to the matched backend service.
Constructors
- UrlRewrite({String? hostRewrite, String? pathPrefixRewrite, String? pathTemplateRewrite})
- UrlRewrite.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hostRewrite → String?
-
Before forwarding the request to the selected service, the request's
host header is replaced with contents of hostRewrite.
final
- pathPrefixRewrite → String?
-
Before forwarding the request to the selected backend service, the
matching portion of the request's path is replaced bypathPrefixRewrite.
final
- pathTemplateRewrite → String?
-
If specified, the pattern rewrites the URL path (based on the :path
header) using the HTTP template syntax.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String