hostRewrite property

String? hostRewrite
final

Before forwarding the request to the selected service, the request's host header is replaced with contents of hostRewrite.

The value must be from 1 to 255 characters.

Implementation

final String? hostRewrite;