toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (externalIpv6Prefix != null) 'externalIpv6Prefix=$externalIpv6Prefix',
    if (internalIpv6Prefix != null) 'internalIpv6Prefix=$internalIpv6Prefix',
    if (ipCidrRange != null) 'ipCidrRange=$ipCidrRange',
    if (ipv6AccessType != null) 'ipv6AccessType=$ipv6AccessType',
    if (network != null) 'network=$network',
    if (purpose != null) 'purpose=$purpose',
    if (role != null) 'role=$role',
    if (stackType != null) 'stackType=$stackType',
    if (subnetwork != null) 'subnetwork=$subnetwork',
  ].join(',');
  return 'UsableSubnetwork(${$contents})';
}