UsableSubnetworkSecondaryRange class final
Secondary IP range of a usable subnetwork.
Constructors
- UsableSubnetworkSecondaryRange({String? ipCidrRange, String? rangeName})
- UsableSubnetworkSecondaryRange.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ipCidrRange → String?
-
The range of IP addresses belonging to this subnetwork secondary range.
Can be Ipv4 or Ipv6 range.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - rangeName → String?
-
The name associated with this subnetwork secondary range, used when adding
an alias IP range to a VM instance.
The name must be 1-63 characters long, and comply withRFC1035.
The name must be unique within the subnetwork.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String