UsableSubnetwork_Purpose class final

Constructors

UsableSubnetwork_Purpose(String value)
const
UsableSubnetwork_Purpose.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const UsableSubnetwork_Purpose
The default value for UsableSubnetwork_Purpose.
globalManagedProxy → const UsableSubnetwork_Purpose
Subnet reserved for Global Envoy-based Load Balancing.
internalHttpsLoadBalancer → const UsableSubnetwork_Purpose
Subnet reserved for Internal HTTP(S) Load Balancing. This is a legacy purpose, please use REGIONAL_MANAGED_PROXY instead.
peerMigration → const UsableSubnetwork_Purpose
Subnetwork will be used for Migration from one peered VPC to another. (a transient state of subnetwork while migrating resources from one project to another).
private → const UsableSubnetwork_Purpose
Regular user created or automatically created subnet.
privateNat → const UsableSubnetwork_Purpose
Subnetwork used as source range for Private NAT Gateways.
privateRfc1918 → const UsableSubnetwork_Purpose
Regular user created or automatically created subnet.
privateServiceConnect → const UsableSubnetwork_Purpose
Subnetworks created for Private Service Connect in the producer network.
regionalManagedProxy → const UsableSubnetwork_Purpose
Subnetwork used for Regional Envoy-based Load Balancing.
undefinedPurpose → const UsableSubnetwork_Purpose
A value indicating that the enum field is not set.