UsableSubnetwork_Role class final
The role of subnetwork. Currently, this field is only used when purpose is set to GLOBAL_MANAGED_PROXY orREGIONAL_MANAGED_PROXY. The value can be set toACTIVE or BACKUP. An ACTIVE subnetwork is one that is currently being used for Envoy-based load balancers in a region. A BACKUP subnetwork is one that is ready to be promoted to ACTIVE or is currently draining. This field can be updated with a patch request.
Constructors
- UsableSubnetwork_Role(String value)
-
const
- UsableSubnetwork_Role.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const UsableSubnetwork_Role
- The default value for UsableSubnetwork_Role.
- active → const UsableSubnetwork_Role
- The ACTIVE subnet that is currently used.
- backup → const UsableSubnetwork_Role
- The BACKUP subnet that could be promoted to ACTIVE.
- undefinedRole → const UsableSubnetwork_Role
- A value indicating that the enum field is not set.