UsableSubnetworksAggregatedList class final

Constructors

UsableSubnetworksAggregatedList({String? id, List<UsableSubnetwork> items = const [], String? kind, String? nextPageToken, List<SubnetworksScopedWarning> scopedWarnings = const [], String? selfLink, List<String> unreachables = const [], Warning? warning})
UsableSubnetworksAggregatedList.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String?
Output Only The unique identifier for the resource. This identifier is defined by the server.
final
items List<UsableSubnetwork>
Output A list of usable subnetwork URLs.
final
kind String?
Output only. Output Only Type of resource. Alwayscompute#usableSubnetworksAggregatedList for aggregated lists of usable subnetworks.
final
nextPageToken String?
Output Only This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. In special cases listUsable may return 0 subnetworks andnextPageToken which still should be used to get the next page of results.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopedWarnings List<SubnetworksScopedWarning>
Output only. Output Only Informational warning messages for failures encountered from scopes.
final
Output only. Output Only Server-defined URL for this resource.
final
unreachables List<String>
Output only. Output Only Unreachable resources.
final
warning Warning?
Output Only Informational warning message.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String