ValidateRegionUrlMapRequest class final

A request message for RegionUrlMaps.Validate. See the method description for details.

Constructors

ValidateRegionUrlMapRequest({required String project, required String region, required RegionUrlMapsValidateRequest? regionUrlMapsValidateRequestResource, required String urlMap})
ValidateRegionUrlMapRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
region String
Name of the region scoping this request.
final
regionUrlMapsValidateRequestResource RegionUrlMapsValidateRequest?
The body resource for this request
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
urlMap String
Name of the UrlMap resource to be validated as.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String