ValidateUrlMapRequest class final

A request message for UrlMaps.Validate. See the method description for details.

Constructors

ValidateUrlMapRequest({required String project, required String urlMap, required UrlMapsValidateRequest? urlMapsValidateRequestResource})
ValidateUrlMapRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
urlMap String
Name of the UrlMap resource to be validated as.
final
urlMapsValidateRequestResource UrlMapsValidateRequest?
The body resource for this request
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String