VmEndpointNatMappings class final
Contain information of Nat mapping for a VM endpoint (i.e., NIC).
Constructors
-
VmEndpointNatMappings({String? instanceName, List<
VmEndpointNatMappingsInterfaceNatMappings> interfaceNatMappings = const []}) - VmEndpointNatMappings.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- instanceName → String?
-
Output only. Name of the VM instance which the endpoint belongs to
final
-
interfaceNatMappings
→ List<
VmEndpointNatMappingsInterfaceNatMappings> -
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String