VmEndpointNatMappingsList class final
Contains a list of VmEndpointNatMappings.
Constructors
-
VmEndpointNatMappingsList({String? id, String? kind, String? nextPageToken, List<
VmEndpointNatMappings> result = const [], String? selfLink, Warning? warning}) - VmEndpointNatMappingsList.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
Output OnlyThe unique identifier for the resource. This identifier is defined by the server.final - kind → String?
-
Output only.
Output OnlyType of resource. Alwayscompute#vmEndpointNatMappingsList for lists of Nat mappings of VM endpoints.final - nextPageToken → String?
-
Output OnlyThis token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited -
result
→ List<
VmEndpointNatMappings> -
Output OnlyA list of Nat mapping information of VM endpoints.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfLink → String?
-
Output only.
Output OnlyServer-defined URL for this resource.final - warning → Warning?
-
Output OnlyInformational warning message.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String