state property
Optional. Output only. Output Only Current state of the policy: ACTIVE or DELETING.
Check the State enum for the list of possible values.
Implementation
final String? state;
Optional. Output only. Output Only Current state of the policy: ACTIVE or DELETING.
Check the State enum for the list of possible values.
final String? state;