VmExtensionPolicyExtensionPolicy class final

Configuration for a specific VM extension.

Constructors

VmExtensionPolicyExtensionPolicy({String? pinnedVersion, String? stringConfig})
VmExtensionPolicyExtensionPolicy.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
pinnedVersion String?
Optional. The specific version of the extension to install. If not set, the latest version is used.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringConfig String?
Optional. String-based configuration data for the extension.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String