Tag keys/values directly bound to this resource.
Tag keys and values have the same definition as resource
manager tags. The field is allowed for INSERT
only. The keys/values to set on the resource should be specified in
either ID { : } or Namespaced format
{ : }.
For example the following are valid inputs: