state property

String? state
final

Indicates the high availability requirement state for the VPN connection. Valid values are CONNECTION_REDUNDANCY_MET,CONNECTION_REDUNDANCY_NOT_MET. Check the State enum for the list of possible values.

Implementation

final String? state;