VpnGatewayStatusTunnel class final

Contains some information about a VPN tunnel.

Constructors

VpnGatewayStatusTunnel({int? localGatewayInterface, int? peerGatewayInterface, String? tunnelUrl})
VpnGatewayStatusTunnel.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
localGatewayInterface int?
Output only. The VPN gateway interface this VPN tunnel is associated with.
final
peerGatewayInterface int?
Output only. The peer gateway interface this VPN tunnel is connected to, the peer gateway could either be an external VPN gateway or a Google Cloud VPN gateway.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tunnelUrl String?
Output only. URL reference to the VPN tunnel.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String