VpnGateways class final

The VpnGateways API.

Implementers

Constructors

VpnGateways({required Client client, Uri? endPoint, String? gcclVersion})
Creates a VpnGateways using client for transport.
VpnGateways.fromApiKey([String? apiKey])
Creates a VpnGateways that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(AggregatedListVpnGatewaysRequest request) Future<VpnGatewayAggregatedList>
Retrieves an aggregated list of VPN gateways.
close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteVpnGatewayRequest request) Future<Operation>
Deletes the specified VPN gateway.
get(GetVpnGatewayRequest request) Future<VpnGateway>
Returns the specified VPN gateway.
getStatus(GetStatusVpnGatewayRequest request) Future<VpnGatewaysGetStatusResponse>
Returns the status for the specified VPN gateway.
insert(InsertVpnGatewayRequest request) Future<Operation>
Creates a VPN gateway in the specified project and region using the data included in the request.
list(ListVpnGatewaysRequest request) Future<VpnGatewayList>
Retrieves a list of VPN gateways available to the specified project and region.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setLabels(SetLabelsVpnGatewayRequest request) Future<Operation>
Sets the labels on a VpnGateway. To learn more about labels, read theLabeling Resources documentation.
testIamPermissions(TestIamPermissionsVpnGatewayRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited