cipherSuite property
User specified list of ciphers to use for the phase 1 and phase 2 of the IKE protocol.
Implementation
final VpnTunnelCipherSuite? cipherSuite;
User specified list of ciphers to use for the phase 1 and phase 2 of the IKE protocol.
final VpnTunnelCipherSuite? cipherSuite;