sharedSecret property
Shared secret used to set the secure session between the Cloud VPN gateway and the peer VPN gateway.
Implementation
final String? sharedSecret;
Shared secret used to set the secure session between the Cloud VPN gateway and the peer VPN gateway.
final String? sharedSecret;