toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final $contents = [
    if (creationTimestamp != null) 'creationTimestamp=$creationTimestamp',
    if (description != null) 'description=$description',
    if (detailedStatus != null) 'detailedStatus=$detailedStatus',
    if (id != null) 'id=$id',
    if (ikeVersion != null) 'ikeVersion=$ikeVersion',
    if (kind != null) 'kind=$kind',
    if (labelFingerprint != null) 'labelFingerprint=$labelFingerprint',
    if (name != null) 'name=$name',
    if (peerExternalGateway != null)
      'peerExternalGateway=$peerExternalGateway',
    if (peerExternalGatewayInterface != null)
      'peerExternalGatewayInterface=$peerExternalGatewayInterface',
    if (peerGcpGateway != null) 'peerGcpGateway=$peerGcpGateway',
    if (peerIp != null) 'peerIp=$peerIp',
    if (region != null) 'region=$region',
    if (router != null) 'router=$router',
    if (selfLink != null) 'selfLink=$selfLink',
    if (sharedSecret != null) 'sharedSecret=$sharedSecret',
    if (sharedSecretHash != null) 'sharedSecretHash=$sharedSecretHash',
    if (status != null) 'status=$status',
    if (targetVpnGateway != null) 'targetVpnGateway=$targetVpnGateway',
    if (vpnGateway != null) 'vpnGateway=$vpnGateway',
    if (vpnGatewayInterface != null)
      'vpnGatewayInterface=$vpnGatewayInterface',
  ].join(',');
  return 'VpnTunnel(${$contents})';
}