VpnTunnelPhase2Algorithms class final
Constructors
-
VpnTunnelPhase2Algorithms({List<
String> encryption = const [], List<String> integrity = const [], List<String> pfs = const []}) - VpnTunnelPhase2Algorithms.fromJson(Object? j)
-
factory
Properties
-
encryption
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
integrity
→ List<
String> -
final
-
pfs
→ List<
String> -
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String