failed constant
VpnTunnel_Status
const failed
Tunnel creation has failed and the tunnel is not ready to be used.
Implementation
static const failed = VpnTunnel_Status('FAILED');
Tunnel creation has failed and the tunnel is not ready to be used.
static const failed = VpnTunnel_Status('FAILED');