aliases property

List<String> aliases
final

A list of alternate IDs. The format should be:

  • E.g. XSS-stable Generic suffix like "stable" is particularly useful if a policy likes to avail newer set of expressions without having to change the policy. A given alias name can't be used for more than one entity set.

Implementation

final List<String> aliases;