Warning class final
Informational warning message.
Constructors
Properties
- code → String?
-
Output OnlyA warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response. Check the Code enum for the list of possible values.final -
data
→ List<
Data> -
Output OnlyMetadata about this warning in key: value format. For example:final - hashCode → int
-
The hash code for this object.
no setterinherited
- message → String?
-
Output OnlyA human-readable description of the warning code.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String