noResultsOnPage constant
Warning_Code
const noResultsOnPage
No results are present on a particular list page.
Implementation
static const noResultsOnPage = Warning_Code('NO_RESULTS_ON_PAGE');
No results are present on a particular list page.
static const noResultsOnPage = Warning_Code('NO_RESULTS_ON_PAGE');