singleInstancePropertyTemplate constant
Warnings_Code
const singleInstancePropertyTemplate
Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.
Implementation
static const singleInstancePropertyTemplate = Warnings_Code(
'SINGLE_INSTANCE_PROPERTY_TEMPLATE',
);