undefinedCode constant
Warnings_Code
const undefinedCode
A value indicating that the enum field is not set.
Implementation
static const undefinedCode = Warnings_Code('UNDEFINED_CODE');
A value indicating that the enum field is not set.
static const undefinedCode = Warnings_Code('UNDEFINED_CODE');