adminEnabled property

bool? adminEnabled
final

Output only. Output Only Indicates whether the wire is enabled. When false, the wire is disabled. When true and when the wire group of the wire is also enabled, the wire is enabled. Defaults to true.

Implementation

final bool? adminEnabled;