WireGroup class final

A resource that represents a group of redundant wires.

Constructors

WireGroup({bool? adminEnabled, String? creationTimestamp, String? description, Map<String, WireGroupEndpoint> endpoints = const {}, BigInt? id, String? kind, String? name, bool? reconciling, String? selfLink, WireGroupTopology? topology, WireProperties? wireProperties, List<Wire> wires = const []})
WireGroup.fromJson(Object? j)
factory

Properties

adminEnabled bool?
Indicates whether the wires in the wire group are enabled. When false, the wires in the wire group are disabled. When true and when there is simultaneously no wire-specific override of adminEnabled to false, a given wire is enabled. Defaults to true.
final
creationTimestamp String?
Output only. Output Only Creation timestamp inRFC3339 text format.
final
description String?
An optional description of the wire group.
final
endpoints Map<String, WireGroupEndpoint>
A map that contains the logical endpoints of the wire group. Specify key-value pairs for the map as follows:
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output only. Output Only The unique identifier for the resource type. The server generates this identifier.
final
kind String?
Output only. Output Only Type of the resource. Alwayscompute#wireGroups for wire groups.
final
name String?
Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
reconciling bool?
Output only. Output Only Indicates whether there are wire changes yet to be processed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output only. Output Only Server-defined URL for the resource.
final
topology WireGroupTopology?
Output only. Topology details for the wire group configuration.
final
wireProperties WireProperties?
Properties for all wires in the wire group.
final
wires List<Wire>
Output only. The single/redundant wire(s) managed by the wire group.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String