id property
Output only. Output Only The unique identifier for the resource type. The server
generates this identifier.
Implementation
final BigInt? id;
Output only. Output Only The unique identifier for the resource type. The server
generates this identifier.
final BigInt? id;