WireGroupEndpoint class final

A logical endpoint for the wire group. An endpoint represents a metro that contains redundant Interconnect connections. A wire group is created between two endpoints.

Constructors

WireGroupEndpoint({Map<String, WireGroupEndpointInterconnect> interconnects = const {}})
WireGroupEndpoint.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
interconnects Map<String, WireGroupEndpointInterconnect>
A map that contains the redundant Interconnect connections. Specify key-value pairs for the map as follows:
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String