interconnect property

String? interconnect
final

Required. An Interconnect connection. You can specify the connection as a partial or full URL. If the connection is in a different project from the cross-site network, use a format that specifies the project. See the following examples of partial and full URLs:

  global/interconnects/NAME


   projects/PROJECT_ID/global/interconnects/NAME

-
  https://compute.googleapis.com/compute/projects/PROJECT_ID/global/interconnects/NAME

Implementation

final String? interconnect;