endpoints property
Output only. Topology details for all endpoints in the wire group.
Implementation
final List<WireGroupTopologyEndpoint> endpoints;
Output only. Topology details for all endpoints in the wire group.
final List<WireGroupTopologyEndpoint> endpoints;