get method

Gets the specified wire group resource in the given scope.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<WireGroup> get(GetWireGroupRequest request) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/global/crossSiteNetworks/${request.crossSiteNetwork}/wireGroups/${request.wireGroup}',
  );
  final response = await _client.get(url);
  return WireGroup.fromJson(response);
}