patch method

Updates the specified wire group resource with the data included in the request. This method supportsPATCH semantics and usesJSON merge patch format and processing rules.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> patch(PatchWireGroupRequest request) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/global/crossSiteNetworks/${request.crossSiteNetwork}/wireGroups/${request.wireGroup}',
    queryParameters: {
      'requestId': ?request.requestId,
      'updateMask': ?request.updateMask,
      if (request.validateOnly case final $1?) 'validateOnly': '${$1}',
    },
  );
  final response = await _client.patch(url, body: request.wireGroupResource);
  return Operation.fromJson(response);
}