sharedWithWireGroup constant
WireProperties_BandwidthAllocation
const sharedWithWireGroup
This is the default behavior. Configures one unmetered bandwidth allocation for the wire group. The unmetered bandwidth is divided equally across each wire in the group, but dynamic throttling reallocates unused unmetered bandwidth from unused or underused wires to other wires in the group.
Implementation
static const sharedWithWireGroup = WireProperties_BandwidthAllocation(
'SHARED_WITH_WIRE_GROUP',
);