WireProperties_FaultResponse class final

Response when a fault is detected in a pseudowire:

  • NONE: default.
  • DISABLE_PORT: set the port line protocol down when inline probes detect a fault. This setting is only permitted on port mode pseudowires.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const WireProperties_FaultResponse
The default value for WireProperties_FaultResponse.
disablePort → const WireProperties_FaultResponse
Set the port line protocol down when inline probes detect a fault. This setting is only permitted on port mode pseudowires.
none → const WireProperties_FaultResponse
Default.
undefinedFaultResponse → const WireProperties_FaultResponse
A value indicating that the enum field is not set.