disablePort constant

WireProperties_FaultResponse const disablePort

Set the port line protocol down when inline probes detect a fault. This setting is only permitted on port mode pseudowires.

Implementation

static const disablePort = WireProperties_FaultResponse('DISABLE_PORT');