WithdrawPublicDelegatedPrefixeRequest class final

A request message for PublicDelegatedPrefixes.Withdraw. See the method description for details.

Constructors

WithdrawPublicDelegatedPrefixeRequest({required String project, required String publicDelegatedPrefix, required String region, String? requestId})
WithdrawPublicDelegatedPrefixeRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
project String
Project ID for this request.
final
publicDelegatedPrefix String
The name of the public delegated prefix. It should comply with RFC1035.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
region String
The name of theregion where the public delegated prefix is located. It should comply with RFC1035.
final
requestId String?
An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String