Zone class final

Represents a Zone resource.

A zone is a deployment area. These deployment areas are subsets of a region. For example the zone us-east1-b is located in theus-east1 region. For more information, readRegions and Zones.

Constructors

Zone({List<String> availableCpuPlatforms = const [], String? creationTimestamp, DeprecationStatus? deprecated, String? description, BigInt? id, String? kind, String? name, String? region, ZoneResourceStatus? resourceStatus, String? selfLink, String? status, bool? supportsPzs})
Zone.fromJson(Object? j)
factory

Properties

availableCpuPlatforms List<String>
Output Only Available cpu/platform selections for the zone.
final
creationTimestamp String?
Output Only Creation timestamp inRFC3339 text format.
final
deprecated DeprecationStatus?
Output Only The deprecation status associated with this zone.
final
description String?
Output Only Textual description of the resource.
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output Only The unique identifier for the resource. This identifier is defined by the server.
final
kind String?
Output only. Output Only Type of the resource. Always compute#zone for zones.
final
name String?
Output Only Name of the resource.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
region String?
Output Only Full URL reference to the region which hosts the zone.
final
resourceStatus ZoneResourceStatus?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output Only Server-defined URL for the resource.
final
status String?
Output Only Status of the zone, either UP orDOWN. Check the Status enum for the list of possible values.
final
supportsPzs bool?
Output only. Output Only Reserved for future use.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String