ZoneOperations class final

The ZoneOperations API.

Implementers

Constructors

ZoneOperations({required Client client, Uri? endPoint, String? gcclVersion})
Creates a ZoneOperations using client for transport.
ZoneOperations.fromApiKey([String? apiKey])
Creates a ZoneOperations that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteZoneOperationRequest request) Future<DeleteZoneOperationResponse>
Deletes the specified zone-specific Operations resource.
get(GetZoneOperationRequest request) Future<Operation>
Retrieves the specified zone-specific Operations resource.
list(ListZoneOperationsRequest request) Future<OperationList>
Retrieves a list of Operation resources contained within the specified zone.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
wait(WaitZoneOperationRequest request) Future<Operation>
Waits for the specified Operation resource to return as DONE or for the request to approach the 2 minute deadline, and retrieves the specified Operation resource. This method waits for no more than the 2 minutes and then returns the current state of the operation, which might be DONE or still in progress.

Operators

operator ==(Object other) bool
The equality operator.
inherited