ZoneSetLabelsRequest class final

Constructors

ZoneSetLabelsRequest({String? labelFingerprint, Map<String, String> labels = const {}})
ZoneSetLabelsRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
labelFingerprint String?
The fingerprint of the previous set of labels for this resource, used to detect conflicts. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels. Make a get() request to the resource to get the latest fingerprint.
final
labels Map<String, String>
The labels to set for this resource.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String