ZoneVmExtensionPolicies class final

The ZoneVmExtensionPolicies API.

Implementers

Constructors

ZoneVmExtensionPolicies({required Client client, Uri? endPoint, String? gcclVersion})
Creates a ZoneVmExtensionPolicies using client for transport.
ZoneVmExtensionPolicies.fromApiKey([String? apiKey])
Creates a ZoneVmExtensionPolicies that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteZoneVmExtensionPolicyRequest request) Future<Operation>
Deletes a specified zone VM extension policy within a project.
get(GetZoneVmExtensionPolicyRequest request) Future<VmExtensionPolicy>
Retrieves details of a specific zone VM extension policy within a project.
insert(InsertZoneVmExtensionPolicyRequest request) Future<Operation>
Creates a new zone-level VM extension policy within a project.
list(ListZoneVmExtensionPoliciesRequest request) Future<VmExtensionPolicyList>
Lists all VM extension policies within a specific zone for a project.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(UpdateZoneVmExtensionPolicyRequest request) Future<Operation>
Modifies an existing zone VM extension policy within a project.

Operators

operator ==(Object other) bool
The equality operator.
inherited