undefinedStatus constant
Zone_Status
const undefinedStatus
A value indicating that the enum field is not set.
Implementation
static const undefinedStatus = Zone_Status('UNDEFINED_STATUS');
A value indicating that the enum field is not set.
static const undefinedStatus = Zone_Status('UNDEFINED_STATUS');