Zones class final
The Zones API.
- Implementers
Constructors
- Zones({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
Zonesusingclientfor transport. - Zones.fromApiKey([String? apiKey])
-
Creates a
Zonesthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
get(
GetZoneRequest request) → Future< Zone> - Returns the specified Zone resource.
-
list(
ListZonesRequest request) → Future< ZoneList> - Retrieves the list of Zone resources available to the specified project.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited