FakeAddresses class base

Testing fake for Addresses.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(AggregatedListAddressesRequest request) Future<AddressAggregatedList>
Retrieves an aggregated list of addresses.
override
close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteAddressRequest request) Future<Operation>
Deletes the specified address resource.
override
get(GetAddressRequest request) Future<Address>
Returns the specified address resource.
override
insert(InsertAddressRequest request) Future<Operation>
Creates an address resource in the specified project by using the data included in the request.
override
list(ListAddressesRequest request) Future<AddressList>
Retrieves a list of addresses contained within the specified region.
override
move(MoveAddressRequest request) Future<Operation>
Moves the specified address resource.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setLabels(SetLabelsAddressRequest request) Future<Operation>
Sets the labels on an Address. To learn more about labels, read theLabeling Resources documentation.
override
testIamPermissions(TestIamPermissionsAddressRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited