FakeAdvice class base

Testing fake for Advice.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

calendarMode(CalendarModeAdviceRpcRequest request) Future<CalendarModeAdviceResponse>
Advise how, where and when to create the requested amount of instances with specified accelerators, within the specified time and location limits. The method recommends creating future reservations for the requested resources.
override
capacity(CapacityAdviceRpcRequest request) Future<CapacityAdviceResponse>
Advice on making real-time decisions (such as choosing zone or machine types) during deployment to maximize your chances of obtaining capacity.
override
capacityHistory(CapacityHistoryAdviceRequest request) Future<CapacityHistoryResponse>
Gets the capacity history.
override
close() → void
Closes the client and cleans up any resources associated with it.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited