calendarMode method
Advise how, where and when to create the requested amount of instances with specified accelerators, within the specified time and location limits. The method recommends creating future reservations for the requested resources.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<CalendarModeAdviceResponse> calendarMode(
CalendarModeAdviceRpcRequest request,
) async {
if (isClosed) throw StateError('Service is closed');
if (_calendarMode case final calendarMode?) {
return calendarMode(request);
}
throw UnsupportedError('calendarMode');
}