FakeAutoscalers class base
Testing fake for Autoscalers.
- Implemented types
Constructors
-
FakeAutoscalers({Future<
AutoscalerAggregatedList> aggregatedList(AggregatedListAutoscalersRequest request)?, Future<Operation> delete(DeleteAutoscalerRequest request)?, Future<Autoscaler> get(GetAutoscalerRequest request)?, Future<Operation> insert(InsertAutoscalerRequest request)?, Future<AutoscalerList> list(ListAutoscalersRequest request)?, Future<Operation> patch(PatchAutoscalerRequest request)?, Future<TestPermissionsResponse> testIamPermissions(TestIamPermissionsAutoscalerRequest request)?, Future<Operation> update(UpdateAutoscalerRequest request)?})
Properties
Methods
-
aggregatedList(
AggregatedListAutoscalersRequest request) → Future< AutoscalerAggregatedList> -
Retrieves an aggregated list of autoscalers.
override
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
delete(
DeleteAutoscalerRequest request) → Future< Operation> -
Deletes the specified autoscaler.
override
-
get(
GetAutoscalerRequest request) → Future< Autoscaler> -
Returns the specified autoscaler resource.
override
-
insert(
InsertAutoscalerRequest request) → Future< Operation> -
Creates an autoscaler in the specified project using the data
included in the request.
override
-
list(
ListAutoscalersRequest request) → Future< AutoscalerList> -
Retrieves a list of autoscalers contained within
the specified zone.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchAutoscalerRequest request) → Future< Operation> -
Updates an autoscaler in the specified project using the data
included in the request. This method supportsPATCH
semantics and uses theJSON merge
patch format and processing rules.
override
-
testIamPermissions(
TestIamPermissionsAutoscalerRequest request) → Future< TestPermissionsResponse> -
Returns permissions that a caller has on the specified resource.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
UpdateAutoscalerRequest request) → Future< Operation> -
Updates an autoscaler in the specified project using the data
included in the request.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited