addSignedUrlKey method

  1. @override
Future<Operation> addSignedUrlKey(
  1. AddSignedUrlKeyBackendBucketRequest request
)
override

Adds a key for validating requests with signed URLs for this backend bucket.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> addSignedUrlKey(
  AddSignedUrlKeyBackendBucketRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_addSignedUrlKey case final addSignedUrlKey?) {
    return addSignedUrlKey(request);
  }
  throw UnsupportedError('addSignedUrlKey');
}