listUsable method

Retrieves a list of all usable backend buckets in the specified project.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<BackendBucketListUsable> listUsable(
  ListUsableBackendBucketsRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_listUsable case final listUsable?) {
    return listUsable(request);
  }
  throw UnsupportedError('listUsable');
}