getEffectiveSecurityPolicies method

Returns effective security policies applied to this backend service.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<GetEffectiveSecurityPoliciesBackendServiceResponse>
getEffectiveSecurityPolicies(
  GetEffectiveSecurityPoliciesBackendServiceRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_getEffectiveSecurityPolicies
      case final getEffectiveSecurityPolicies?) {
    return getEffectiveSecurityPolicies(request);
  }
  throw UnsupportedError('getEffectiveSecurityPolicies');
}