getHealth method

Gets the most recent health check results for this BackendService.

Example request body:

{ "group": "/zones/us-east1-b/instanceGroups/lb-backend-example" }

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<BackendServiceGroupHealth> getHealth(
  GetHealthBackendServiceRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_getHealth case final getHealth?) {
    return getHealth(request);
  }
  throw UnsupportedError('getHealth');
}