patch method

  1. @override
Future<Operation> patch(
  1. PatchBackendServiceRequest request
)
override

Patches the specified BackendService resource with the data included in the request. For more information, see Backend services overview. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> patch(PatchBackendServiceRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_patch case final patch?) {
    return patch(request);
  }
  throw UnsupportedError('patch');
}