addResourcePolicies method
Adds existing resource policies to a disk. You can only add one policy which will be applied to this disk for scheduling snapshot creation.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<Operation> addResourcePolicies(
AddResourcePoliciesDiskRequest request,
) async {
if (isClosed) throw StateError('Service is closed');
if (_addResourcePolicies case final addResourcePolicies?) {
return addResourcePolicies(request);
}
throw UnsupportedError('addResourcePolicies');
}