aggregatedList method

  1. @override
Future<DiskAggregatedList> aggregatedList(
  1. AggregatedListDisksRequest request
)
override

Retrieves an aggregated list of persistent disks.

To prevent failure, it is recommended that you set the returnPartialSuccess parameter to true.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<DiskAggregatedList> aggregatedList(
  AggregatedListDisksRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_aggregatedList case final aggregatedList?) {
    return aggregatedList(request);
  }
  throw UnsupportedError('aggregatedList');
}