resize method

  1. @override
Future<Operation> resize(
  1. ResizeDiskRequest request
)
override

Resizes the specified persistent disk. You can only increase the size of the disk.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> resize(ResizeDiskRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_resize case final resize?) {
    return resize(request);
  }
  throw UnsupportedError('resize');
}