update method
Updates the specified disk with the data included in the request. The update is performed only on selected fields included as part of update-mask.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<Operation> update(UpdateDiskRequest request) async {
if (isClosed) throw StateError('Service is closed');
if (_update case final update?) {
return update(request);
}
throw UnsupportedError('update');
}