FakeExternalVpnGateways class base

Testing fake for ExternalVpnGateways.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteExternalVpnGatewayRequest request) Future<Operation>
Deletes the specified externalVpnGateway.
override
get(GetExternalVpnGatewayRequest request) Future<ExternalVpnGateway>
Returns the specified externalVpnGateway. Get a list of available externalVpnGateways by making a list() request.
override
insert(InsertExternalVpnGatewayRequest request) Future<Operation>
Creates a ExternalVpnGateway in the specified project using the data included in the request.
override
list(ListExternalVpnGatewaysRequest request) Future<ExternalVpnGatewayList>
Retrieves the list of ExternalVpnGateway available to the specified project.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setLabels(SetLabelsExternalVpnGatewayRequest request) Future<Operation>
Sets the labels on an ExternalVpnGateway. To learn more about labels, read the Labeling Resources documentation.
override
testIamPermissions(TestIamPermissionsExternalVpnGatewayRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited