FakeFirewallPolicies class base

Testing fake for FirewallPolicies.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addAssociation(AddAssociationFirewallPolicyRequest request) Future<Operation>
Inserts an association for the specified firewall policy.
override
addRule(AddRuleFirewallPolicyRequest request) Future<Operation>
Inserts a rule into a firewall policy.
override
cloneRules(CloneRulesFirewallPolicyRequest request) Future<Operation>
Copies rules to the specified firewall policy.
override
close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteFirewallPolicyRequest request) Future<Operation>
Deletes the specified policy.
override
get(GetFirewallPolicyRequest request) Future<FirewallPolicy>
Returns the specified firewall policy.
override
getAssociation(GetAssociationFirewallPolicyRequest request) Future<FirewallPolicyAssociation>
Gets an association with the specified name.
override
getIamPolicy(GetIamPolicyFirewallPolicyRequest request) Future<Policy>
Gets the access control policy for a resource. May be empty if no such policy or resource exists.
override
getRule(GetRuleFirewallPolicyRequest request) Future<FirewallPolicyRule>
Gets a rule of the specified priority.
override
insert(InsertFirewallPolicyRequest request) Future<Operation>
Creates a new policy in the specified project using the data included in the request.
override
list(ListFirewallPoliciesRequest request) Future<FirewallPolicyList>
Lists all the policies that have been configured for the specified folder or organization.
override
listAssociations(ListAssociationsFirewallPolicyRequest request) Future<FirewallPoliciesListAssociationsResponse>
Lists associations of a specified target, i.e., organization or folder.
override
move(MoveFirewallPolicyRequest request) Future<Operation>
Moves the specified firewall policy.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(PatchFirewallPolicyRequest request) Future<Operation>
Patches the specified policy with the data included in the request.
override
patchRule(PatchRuleFirewallPolicyRequest request) Future<Operation>
Patches a rule of the specified priority.
override
removeAssociation(RemoveAssociationFirewallPolicyRequest request) Future<Operation>
Removes an association for the specified firewall policy.
override
removeRule(RemoveRuleFirewallPolicyRequest request) Future<Operation>
Deletes a rule of the specified priority.
override
setIamPolicy(SetIamPolicyFirewallPolicyRequest request) Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy.
override
testIamPermissions(TestIamPermissionsFirewallPolicyRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited