update method
Updates the specified firewall rule with the data included in the request. Note that all fields will be updated if using PUT, even fields that are not specified. To update individual fields, please use PATCH instead.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<Operation> update(UpdateFirewallRequest request) async {
if (isClosed) throw StateError('Service is closed');
if (_update case final update?) {
return update(request);
}
throw UnsupportedError('update');
}