patch method

  1. @override
Future<Operation> patch(
  1. PatchForwardingRuleRequest request
)
override

Updates the specified forwarding rule with the data included in the request. This method supportsPATCH semantics and uses theJSON merge patch format and processing rules. Currently, you can only patch the network_tier field.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> patch(PatchForwardingRuleRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_patch case final patch?) {
    return patch(request);
  }
  throw UnsupportedError('patch');
}