FakeFutureReservations class base

Testing fake for FutureReservations.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(AggregatedListFutureReservationsRequest request) Future<FutureReservationsAggregatedListResponse>
Retrieves an aggregated list of future reservations.
override
cancel(CancelFutureReservationRequest request) Future<Operation>
Cancel the specified future reservation.
override
close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteFutureReservationRequest request) Future<Operation>
Deletes the specified future reservation.
override
get(GetFutureReservationRequest request) Future<FutureReservation>
Retrieves information about the specified future reservation.
override
insert(InsertFutureReservationRequest request) Future<Operation>
Creates a new Future Reservation.
override
list(ListFutureReservationsRequest request) Future<FutureReservationsListResponse>
A list of all the future reservations that have been configured for the specified project in specified zone.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(UpdateFutureReservationRequest request) Future<Operation>
Updates the specified future reservation.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited