list method

A list of all the future reservations that have been configured for the specified project in specified zone.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<FutureReservationsListResponse> list(
  ListFutureReservationsRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_list case final list?) {
    return list(request);
  }
  throw UnsupportedError('list');
}