FakeGlobalAddresses class base
Testing fake for GlobalAddresses.
- Implemented types
Constructors
-
FakeGlobalAddresses({Future<
Operation> delete(DeleteGlobalAddressRequest request)?, Future<Address> get(GetGlobalAddressRequest request)?, Future<Operation> insert(InsertGlobalAddressRequest request)?, Future<AddressList> list(ListGlobalAddressesRequest request)?, Future<Operation> move(MoveGlobalAddressRequest request)?, Future<Operation> setLabels(SetLabelsGlobalAddressRequest request)?, Future<TestPermissionsResponse> testIamPermissions(TestIamPermissionsGlobalAddressRequest request)?})
Properties
Methods
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
delete(
DeleteGlobalAddressRequest request) → Future< Operation> -
Deletes the specified address resource.
override
-
get(
GetGlobalAddressRequest request) → Future< Address> -
Returns the specified address resource.
override
-
insert(
InsertGlobalAddressRequest request) → Future< Operation> -
Creates an address resource in the specified project by using the data
included in the request.
override
-
list(
ListGlobalAddressesRequest request) → Future< AddressList> -
Retrieves a list of global addresses.
override
-
move(
MoveGlobalAddressRequest request) → Future< Operation> -
Moves the specified address resource from one project to another project.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setLabels(
SetLabelsGlobalAddressRequest request) → Future< Operation> -
Sets the labels on a GlobalAddress. To learn more about labels, read theLabeling
Resources documentation.
override
-
testIamPermissions(
TestIamPermissionsGlobalAddressRequest request) → Future< TestPermissionsResponse> -
Returns permissions that a caller has on the specified resource.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited