attachNetworkEndpoints method

Attach a network endpoint to the specified network endpoint group.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> attachNetworkEndpoints(
  AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_attachNetworkEndpoints case final attachNetworkEndpoints?) {
    return attachNetworkEndpoints(request);
  }
  throw UnsupportedError('attachNetworkEndpoints');
}