delete method

Deletes the specified network endpoint group.Note that the NEG cannot be deleted if there are backend services referencing it.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> delete(
  DeleteGlobalNetworkEndpointGroupRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_delete case final delete?) {
    return delete(request);
  }
  throw UnsupportedError('delete');
}