listNetworkEndpoints method

Lists the network endpoints in the specified network endpoint group.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<NetworkEndpointGroupsListNetworkEndpoints> listNetworkEndpoints(
  ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_listNetworkEndpoints case final listNetworkEndpoints?) {
    return listNetworkEndpoints(request);
  }
  throw UnsupportedError('listNetworkEndpoints');
}