FakeGlobalOperations class base
Testing fake for GlobalOperations.
- Implemented types
Constructors
-
FakeGlobalOperations({Future<
OperationAggregatedList> aggregatedList(AggregatedListGlobalOperationsRequest request)?, Future<DeleteGlobalOperationResponse> delete(DeleteGlobalOperationRequest request)?, Future<Operation> get(GetGlobalOperationRequest request)?, Future<OperationList> list(ListGlobalOperationsRequest request)?, Future<Operation> wait(WaitGlobalOperationRequest request)?})
Properties
Methods
-
aggregatedList(
AggregatedListGlobalOperationsRequest request) → Future< OperationAggregatedList> -
Retrieves an aggregated list of all operations.
override
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
delete(
DeleteGlobalOperationRequest request) → Future< DeleteGlobalOperationResponse> -
Deletes the specified Operations resource.
override
-
get(
GetGlobalOperationRequest request) → Future< Operation> -
Retrieves the specified Operations resource.
override
-
list(
ListGlobalOperationsRequest request) → Future< OperationList> -
Retrieves a list of Operation resources contained within the specified
project.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
wait(
WaitGlobalOperationRequest request) → Future< Operation> -
Waits for the specified Operation resource to return as
DONEor for the request to approach the 2 minute deadline, and retrieves the specified Operation resource. This method differs from theGETmethod in that it waits for no more than the default deadline (2 minutes) and then returns the current state of the operation, which might beDONEor still in progress.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited