FakeGlobalOrganizationOperations class base

Testing fake for GlobalOrganizationOperations.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteGlobalOrganizationOperationRequest request) Future<DeleteGlobalOrganizationOperationResponse>
Deletes the specified Operations resource.
override
get(GetGlobalOrganizationOperationRequest request) Future<Operation>
Retrieves the specified Operations resource. Gets a list of operations by making a list() request.
override
list(ListGlobalOrganizationOperationsRequest request) Future<OperationList>
Retrieves a list of Operation resources contained within the specified organization.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited