FakeGlobalPublicDelegatedPrefixes class base

Testing fake for GlobalPublicDelegatedPrefixes.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteGlobalPublicDelegatedPrefixeRequest request) Future<Operation>
Deletes the specified global PublicDelegatedPrefix.
override
get(GetGlobalPublicDelegatedPrefixeRequest request) Future<PublicDelegatedPrefix>
Returns the specified global PublicDelegatedPrefix resource.
override
insert(InsertGlobalPublicDelegatedPrefixeRequest request) Future<Operation>
Creates a global PublicDelegatedPrefix in the specified project using the parameters that are included in the request.
override
list(ListGlobalPublicDelegatedPrefixesRequest request) Future<PublicDelegatedPrefixList>
Lists the global PublicDelegatedPrefixes for a project.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(PatchGlobalPublicDelegatedPrefixeRequest request) Future<Operation>
Patches the specified global PublicDelegatedPrefix resource with the data included in the request. This method supportsPATCH semantics and usesJSON merge patch format and processing rules.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited