FakeGlobalVmExtensionPolicies class base

Testing fake for GlobalVmExtensionPolicies.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(AggregatedListGlobalVmExtensionPoliciesRequest request) Future<VmExtensionPolicyAggregatedListResponse>
Retrieves the list of all VM Extension Policy resources available to the specified project.
override
close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteGlobalVmExtensionPolicyRequest request) Future<Operation>
Purge scoped resources (zonal policies) from a global VM extension policy, and then delete the global VM extension policy. Purge of the scoped resources is a pre-condition of the global VM extension policy deletion. The deletion of the global VM extension policy happens after the purge rollout is done, so it's not a part of the LRO. It's an automatic process that triggers in the backend.
override
get(GetGlobalVmExtensionPolicyRequest request) Future<GlobalVmExtensionPolicy>
Gets details of a global VM extension policy.
override
insert(InsertGlobalVmExtensionPolicyRequest request) Future<Operation>
Creates a new project level GlobalVmExtensionPolicy.
override
list(ListGlobalVmExtensionPoliciesRequest request) Future<GlobalVmExtensionPolicyList>
Lists global VM extension policies.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(UpdateGlobalVmExtensionPolicyRequest request) Future<Operation>
Updates a global VM extension policy.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited