FakeHealthChecks class base
Testing fake for HealthChecks.
- Implemented types
Constructors
-
FakeHealthChecks({Future<
HealthChecksAggregatedList> aggregatedList(AggregatedListHealthChecksRequest request)?, Future<Operation> delete(DeleteHealthCheckRequest request)?, Future<HealthCheck> get(GetHealthCheckRequest request)?, Future<Operation> insert(InsertHealthCheckRequest request)?, Future<HealthCheckList> list(ListHealthChecksRequest request)?, Future<Operation> patch(PatchHealthCheckRequest request)?, Future<TestPermissionsResponse> testIamPermissions(TestIamPermissionsHealthCheckRequest request)?, Future<Operation> update(UpdateHealthCheckRequest request)?})
Properties
Methods
-
aggregatedList(
AggregatedListHealthChecksRequest request) → Future< HealthChecksAggregatedList> -
Retrieves the list of all HealthCheck resources, regional and global,
available to the specified project.
override
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
delete(
DeleteHealthCheckRequest request) → Future< Operation> -
Deletes the specified HealthCheck resource.
override
-
get(
GetHealthCheckRequest request) → Future< HealthCheck> -
Returns the specified HealthCheck resource.
override
-
insert(
InsertHealthCheckRequest request) → Future< Operation> -
Creates a HealthCheck resource in the specified project using the data
included in the request.
override
-
list(
ListHealthChecksRequest request) → Future< HealthCheckList> -
Retrieves the list of HealthCheck resources available to the specified
project.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchHealthCheckRequest request) → Future< Operation> -
Updates a HealthCheck resource in the specified project using the data
included in the request. This method supportsPATCH
semantics and uses theJSON merge
patch format and processing rules.
override
-
testIamPermissions(
TestIamPermissionsHealthCheckRequest request) → Future< TestPermissionsResponse> -
Returns permissions that a caller has on the specified resource.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
UpdateHealthCheckRequest request) → Future< Operation> -
Updates a HealthCheck resource in the specified project using the data
included in the request.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited