FakeHosts class base
Testing fake for Hosts.
- Implemented types
Constructors
-
FakeHosts({Future<
Host> get(GetHostRequest request)?, Future<Operation> getVersion(GetVersionHostRequest request)?, Future<HostsListResponse> list(ListHostsRequest request)?})
Properties
Methods
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
get(
GetHostRequest request) → Future< Host> -
Retrieves information about the specified host.
override
-
getVersion(
GetVersionHostRequest request) → Future< Operation> -
Allows customers to get SBOM versions of a host.
override
-
list(
ListHostsRequest request) → Future< HostsListResponse> -
Retrieves a list of hosts.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited