FakeImageFamilyViews class base
Testing fake for ImageFamilyViews.
- Implemented types
Constructors
-
FakeImageFamilyViews({Future<
ImageFamilyView> get(GetImageFamilyViewRequest request)?})
Properties
Methods
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
get(
GetImageFamilyViewRequest request) → Future< ImageFamilyView> -
Returns the latest image that is part of an image family, is not
deprecated and is rolled out in the specified zone.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited