get method
Returns the latest image that is part of an image family, is not deprecated and is rolled out in the specified zone.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<ImageFamilyView> get(GetImageFamilyViewRequest request) async {
if (isClosed) throw StateError('Service is closed');
if (_get case final get?) {
return get(request);
}
throw UnsupportedError('get');
}