getFromFamily method

  1. @override
Future<Image> getFromFamily(
  1. GetFromFamilyImageRequest request
)
override

Returns the latest image that is part of an image family and is not deprecated. For more information on image families, seePublic image families documentation.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Image> getFromFamily(GetFromFamilyImageRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_getFromFamily case final getFromFamily?) {
    return getFromFamily(request);
  }
  throw UnsupportedError('getFromFamily');
}