list method
Retrieves the list of custom images available to the specified project. Custom images are images you create that belong to your project. This method does not get any images that belong to other projects, including publicly-available images, like Debian 8. If you want to get a list of publicly-available images, use this method to make a request to the respective image project, such as debian-cloud or windows-cloud.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<ImageList> list(ListImagesRequest request) async {
if (isClosed) throw StateError('Service is closed');
if (_list case final list?) {
return list(request);
}
throw UnsupportedError('list');
}