cancel method

Cancels the specified resize request and removes it from the queue. Cancelled resize request does no longer wait for the resources to be provisioned. Cancel is only possible for requests that are accepted in the queue.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> cancel(
  CancelInstanceGroupManagerResizeRequestRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_cancel case final cancel?) {
    return cancel(request);
  }
  throw UnsupportedError('cancel');
}