applyUpdatesToInstances method
Applies changes to selected instances on the managed instance group. This method can be used to apply new overrides and/or new versions.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<Operation> applyUpdatesToInstances(
ApplyUpdatesToInstancesInstanceGroupManagerRequest request,
) async {
if (isClosed) throw StateError('Service is closed');
if (_applyUpdatesToInstances case final applyUpdatesToInstances?) {
return applyUpdatesToInstances(request);
}
throw UnsupportedError('applyUpdatesToInstances');
}