delete method
Deletes the specified managed instance group and all of the instances in that group. Note that the instance group must not belong to a backend service. Read Deleting an instance group for more information.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<Operation> delete(DeleteInstanceGroupManagerRequest request) async {
if (isClosed) throw StateError('Service is closed');
if (_delete case final delete?) {
return delete(request);
}
throw UnsupportedError('delete');
}