get method

Returns the specified zonal instance group. Get a list of available zonal instance groups by making a list() request.

For managed instance groups, use theinstanceGroupManagers or regionInstanceGroupManagers methods instead.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<InstanceGroup> get(GetInstanceGroupRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_get case final get?) {
    return get(request);
  }
  throw UnsupportedError('get');
}