insert method
Creates an instance group in the specified project using the parameters that are included in the request.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<Operation> insert(InsertInstanceGroupRequest request) async {
if (isClosed) throw StateError('Service is closed');
if (_insert case final insert?) {
return insert(request);
}
throw UnsupportedError('insert');
}