removeInstances method

  1. @override
Future<Operation> removeInstances(
  1. RemoveInstancesInstanceGroupRequest request
)
override

Removes one or more instances from the specified instance group, but does not delete those instances.

If the group is part of a backend service that has enabled connection draining, it can take up to 60 seconds after the connection draining duration before the VM instance is removed or deleted.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> removeInstances(
  RemoveInstancesInstanceGroupRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_removeInstances case final removeInstances?) {
    return removeInstances(request);
  }
  throw UnsupportedError('removeInstances');
}