FakeInstanceSettingsService class base
Testing fake for InstanceSettingsService.
- Implemented types
Constructors
-
FakeInstanceSettingsService({Future<
InstanceSettings> get(GetInstanceSettingRequest request)?, Future<Operation> patch(PatchInstanceSettingRequest request)?})
Properties
Methods
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
get(
GetInstanceSettingRequest request) → Future< InstanceSettings> -
Get Instance settings.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchInstanceSettingRequest request) → Future< Operation> -
Patch Instance settings
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited