FakeInstanceTemplates class base

Testing fake for InstanceTemplates.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(AggregatedListInstanceTemplatesRequest request) Future<InstanceTemplateAggregatedList>
Retrieves the list of all InstanceTemplates resources, regional and global, available to the specified project.
override
close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteInstanceTemplateRequest request) Future<Operation>
Deletes the specified instance template. Deleting an instance template is permanent and cannot be undone. It is not possible to delete templates that are already in use by a managed instance group.
override
get(GetInstanceTemplateRequest request) Future<InstanceTemplate>
Returns the specified instance template.
override
getIamPolicy(GetIamPolicyInstanceTemplateRequest request) Future<Policy>
Gets the access control policy for a resource. May be empty if no such policy or resource exists.
override
insert(InsertInstanceTemplateRequest request) Future<Operation>
Creates an instance template in the specified project using the data that is included in the request. If you are creating a new template to update an existing instance group, your new instance template must use the same network or, if applicable, the same subnetwork as the original template.
override
list(ListInstanceTemplatesRequest request) Future<InstanceTemplateList>
Retrieves a list of instance templates that are contained within the specified project.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setIamPolicy(SetIamPolicyInstanceTemplateRequest request) Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy.
override
testIamPermissions(TestIamPermissionsInstanceTemplateRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited