delete method
Deletes the specified instance template. Deleting an instance template is permanent and cannot be undone. It is not possible to delete templates that are already in use by a managed instance group.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<Operation> delete(DeleteInstanceTemplateRequest request) async {
if (isClosed) throw StateError('Service is closed');
if (_delete case final delete?) {
return delete(request);
}
throw UnsupportedError('delete');
}