list method

Retrieves a list of instance templates that are contained within the specified project.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<InstanceTemplateList> list(
  ListInstanceTemplatesRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_list case final list?) {
    return list(request);
  }
  throw UnsupportedError('list');
}