deleteNetworkInterface method

  1. @override
Future<Operation> deleteNetworkInterface(
  1. DeleteNetworkInterfaceInstanceRequest request
)
override

Deletes one dynamic network interface from an active instance. InstancesDeleteNetworkInterfaceRequest indicates:

  • instance from which to delete, using project+zone+resource_id fields;
  • dynamic network interface to be deleted, using network_interface_name field;

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> deleteNetworkInterface(
  DeleteNetworkInterfaceInstanceRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_deleteNetworkInterface case final deleteNetworkInterface?) {
    return deleteNetworkInterface(request);
  }
  throw UnsupportedError('deleteNetworkInterface');
}