getEffectiveFirewalls method

Returns effective firewalls applied to an interface of the instance.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<InstancesGetEffectiveFirewallsResponse> getEffectiveFirewalls(
  GetEffectiveFirewallsInstanceRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_getEffectiveFirewalls case final getEffectiveFirewalls?) {
    return getEffectiveFirewalls(request);
  }
  throw UnsupportedError('getEffectiveFirewalls');
}