getSerialPortOutput method

  1. @override
Future<SerialPortOutput> getSerialPortOutput(
  1. GetSerialPortOutputInstanceRequest request
)
override

Returns the last 1 MB of serial port output from the specified instance.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<SerialPortOutput> getSerialPortOutput(
  GetSerialPortOutputInstanceRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_getSerialPortOutput case final getSerialPortOutput?) {
    return getSerialPortOutput(request);
  }
  throw UnsupportedError('getSerialPortOutput');
}