list method

  1. @override
Future<InstanceList> list(
  1. ListInstancesRequest request
)
override

Retrieves the list of instances contained within the specified zone.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<InstanceList> list(ListInstancesRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_list case final list?) {
    return list(request);
  }
  throw UnsupportedError('list');
}