listReferrers method

Retrieves a list of resources that refer to the VM instance specified in the request. For example, if the VM instance is part of a managed or unmanaged instance group, the referrers list includes the instance group. For more information, readViewing referrers to VM instances.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<InstanceListReferrers> listReferrers(
  ListReferrersInstancesRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_listReferrers case final listReferrers?) {
    return listReferrers(request);
  }
  throw UnsupportedError('listReferrers');
}