setDiskAutoDelete method

  1. @override
Future<Operation> setDiskAutoDelete(
  1. SetDiskAutoDeleteInstanceRequest request
)
override

Sets the auto-delete flag for a disk attached to an instance.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> setDiskAutoDelete(
  SetDiskAutoDeleteInstanceRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_setDiskAutoDelete case final setDiskAutoDelete?) {
    return setDiskAutoDelete(request);
  }
  throw UnsupportedError('setDiskAutoDelete');
}