setMetadata method

  1. @override
Future<Operation> setMetadata(
  1. SetMetadataInstanceRequest request
)
override

Sets metadata for the specified instance to the data included in the request.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> setMetadata(SetMetadataInstanceRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_setMetadata case final setMetadata?) {
    return setMetadata(request);
  }
  throw UnsupportedError('setMetadata');
}