setMinCpuPlatform method

  1. @override
Future<Operation> setMinCpuPlatform(
  1. SetMinCpuPlatformInstanceRequest request
)
override

Changes the minimum CPU platform that this instance should use. This method can only be called on a stopped instance. For more information, readSpecifying a Minimum CPU Platform.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> setMinCpuPlatform(
  SetMinCpuPlatformInstanceRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_setMinCpuPlatform case final setMinCpuPlatform?) {
    return setMinCpuPlatform(request);
  }
  throw UnsupportedError('setMinCpuPlatform');
}