simulateMaintenanceEvent method

  1. @override
Future<Operation> simulateMaintenanceEvent(
  1. SimulateMaintenanceEventInstanceRequest request
)
override

Simulates a host maintenance event on a VM. For more information, see Simulate a host maintenance event.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> simulateMaintenanceEvent(
  SimulateMaintenanceEventInstanceRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_simulateMaintenanceEvent case final simulateMaintenanceEvent?) {
    return simulateMaintenanceEvent(request);
  }
  throw UnsupportedError('simulateMaintenanceEvent');
}