update method

  1. @override
Future<Operation> update(
  1. UpdateInstanceRequest request
)
override

Updates an instance only if the necessary resources are available. This method can update only a specific set of instance properties. See Updating a running instance for a list of updatable instance properties.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> update(UpdateInstanceRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_update case final update?) {
    return update(request);
  }
  throw UnsupportedError('update');
}