updateDisplayDevice method

  1. @override
Future<Operation> updateDisplayDevice(
  1. UpdateDisplayDeviceInstanceRequest request
)
override

Updates the Display config for a VM instance. You can only use this method on a stopped VM instance. This method supportsPATCH semantics and uses theJSON merge patch format and processing rules.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> updateDisplayDevice(
  UpdateDisplayDeviceInstanceRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_updateDisplayDevice case final updateDisplayDevice?) {
    return updateDisplayDevice(request);
  }
  throw UnsupportedError('updateDisplayDevice');
}