FakeInstantSnapshotGroups class base

Testing fake for InstantSnapshotGroups.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteInstantSnapshotGroupRequest request) Future<Operation>
deletes a Zonal InstantSnapshotGroup resource
override
get(GetInstantSnapshotGroupRequest request) Future<InstantSnapshotGroup>
returns the specified InstantSnapshotGroup resource in the specified zone.
override
getIamPolicy(GetIamPolicyInstantSnapshotGroupRequest request) Future<Policy>
Gets the access control policy for a resource. May be empty if no such policy or resource exists.
override
insert(InsertInstantSnapshotGroupRequest request) Future<Operation>
inserts a Zonal InstantSnapshotGroup resource
override
list(ListInstantSnapshotGroupsRequest request) Future<ListInstantSnapshotGroups>
retrieves the list of InstantSnapshotGroup resources contained within the specified zone.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setIamPolicy(SetIamPolicyInstantSnapshotGroupRequest request) Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy.
override
testIamPermissions(TestIamPermissionsInstantSnapshotGroupRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited