FakeInterconnectAttachments class base
Testing fake for InterconnectAttachments.
- Implemented types
Constructors
-
FakeInterconnectAttachments({Future<
InterconnectAttachmentAggregatedList> aggregatedList(AggregatedListInterconnectAttachmentsRequest request)?, Future<Operation> delete(DeleteInterconnectAttachmentRequest request)?, Future<InterconnectAttachment> get(GetInterconnectAttachmentRequest request)?, Future<Operation> insert(InsertInterconnectAttachmentRequest request)?, Future<InterconnectAttachmentList> list(ListInterconnectAttachmentsRequest request)?, Future<Operation> patch(PatchInterconnectAttachmentRequest request)?, Future<Operation> setLabels(SetLabelsInterconnectAttachmentRequest request)?})
Properties
Methods
-
aggregatedList(
AggregatedListInterconnectAttachmentsRequest request) → Future< InterconnectAttachmentAggregatedList> -
Retrieves an aggregated list of interconnect attachments.
override
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
delete(
DeleteInterconnectAttachmentRequest request) → Future< Operation> -
Deletes the specified interconnect attachment.
override
-
get(
GetInterconnectAttachmentRequest request) → Future< InterconnectAttachment> -
Returns the specified interconnect attachment.
override
-
insert(
InsertInterconnectAttachmentRequest request) → Future< Operation> -
Creates an InterconnectAttachment in the specified project using the data
included in the request.
override
-
list(
ListInterconnectAttachmentsRequest request) → Future< InterconnectAttachmentList> -
Retrieves the list of interconnect attachments contained within
the specified region.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchInterconnectAttachmentRequest request) → Future< Operation> -
Updates the specified interconnect attachment with the data included in the
request. This method supportsPATCH
semantics and uses theJSON merge
patch format and processing rules.
override
-
setLabels(
SetLabelsInterconnectAttachmentRequest request) → Future< Operation> -
Sets the labels on an InterconnectAttachment. To learn more about labels,
read the Labeling
Resources documentation.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited