setLabels method

Sets the labels on an InterconnectAttachment. To learn more about labels, read the Labeling Resources documentation.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> setLabels(
  SetLabelsInterconnectAttachmentRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_setLabels case final setLabels?) {
    return setLabels(request);
  }
  throw UnsupportedError('setLabels');
}