createMembers method

  1. @override
Future<Operation> createMembers(
  1. CreateMembersInterconnectGroupRequest request
)
override

Create Interconnects with redundancy by creating them in a specified interconnect group.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> createMembers(
  CreateMembersInterconnectGroupRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_createMembers case final createMembers?) {
    return createMembers(request);
  }
  throw UnsupportedError('createMembers');
}