FakeInterconnectLocations class base
Testing fake for InterconnectLocations.
- Implemented types
Constructors
-
FakeInterconnectLocations({Future<
InterconnectLocation> get(GetInterconnectLocationRequest request)?, Future<InterconnectLocationList> list(ListInterconnectLocationsRequest request)?})
Properties
Methods
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
get(
GetInterconnectLocationRequest request) → Future< InterconnectLocation> -
Returns the details for the specified interconnect location. Gets a list of
available interconnect locations by making a list() request.
override
-
list(
ListInterconnectLocationsRequest request) → Future< InterconnectLocationList> -
Retrieves the list of interconnect locations available to the specified
project.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited