get method
Returns the details for the specified interconnect remote location. Gets a list of available interconnect remote locations by making alist() request.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<InterconnectRemoteLocation> get(
GetInterconnectRemoteLocationRequest request,
) async {
if (isClosed) throw StateError('Service is closed');
if (_get case final get?) {
return get(request);
}
throw UnsupportedError('get');
}