FakeLicenseCodes class base
Testing fake for LicenseCodes.
- Implemented types
Constructors
-
FakeLicenseCodes({Future<
LicenseCode> get(GetLicenseCodeRequest request)?, Future<Policy> getIamPolicy(GetIamPolicyLicenseCodeRequest request)?, Future<Policy> setIamPolicy(SetIamPolicyLicenseCodeRequest request)?, Future<TestPermissionsResponse> testIamPermissions(TestIamPermissionsLicenseCodeRequest request)?})
Properties
Methods
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
get(
GetLicenseCodeRequest request) → Future< LicenseCode> -
Return a specified license code. License codes are mirrored across
all projects that have permissions to read the License Code.
Caution This resource is intended
for use only by third-party partners who are creatingCloud Marketplace
images.
override
-
getIamPolicy(
GetIamPolicyLicenseCodeRequest request) → Future< Policy> -
Gets the access control policy for a resource. May be empty if no such
policy or resource exists.
Caution This resource is intended
for use only by third-party partners who are creatingCloud Marketplace
images.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setIamPolicy(
SetIamPolicyLicenseCodeRequest request) → Future< Policy> -
Sets the access control policy on the specified resource.
Replaces any existing policy.
Caution This resource is intended
for use only by third-party partners who are creatingCloud Marketplace
images.
override
-
testIamPermissions(
TestIamPermissionsLicenseCodeRequest request) → Future< TestPermissionsResponse> -
Returns permissions that a caller has on the specified resource.
Caution This resource is intended
for use only by third-party partners who are creatingCloud Marketplace
images.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited