setIamPolicy method
Sets the access control policy on the specified resource. Replaces any existing policy. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<Policy> setIamPolicy(SetIamPolicyLicenseCodeRequest request) async {
if (isClosed) throw StateError('Service is closed');
if (_setIamPolicy case final setIamPolicy?) {
return setIamPolicy(request);
}
throw UnsupportedError('setIamPolicy');
}