delete method

  1. @override
Future<Operation> delete(
  1. DeleteLicenseRequest request
)
override

Deletes the specified license. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> delete(DeleteLicenseRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_delete case final delete?) {
    return delete(request);
  }
  throw UnsupportedError('delete');
}