get method

  1. @override
Future<License> get(
  1. GetLicenseRequest request
)
override

Returns the specified License resource. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<License> get(GetLicenseRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_get case final get?) {
    return get(request);
  }
  throw UnsupportedError('get');
}