insert method

  1. @override
Future<Operation> insert(
  1. InsertMachineImageRequest request
)
override

Creates a machine image in the specified project using the data that is included in the request. If you are creating a new machine image to update an existing instance, your new machine image should use the same network or, if applicable, the same subnetwork as the original instance.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> insert(InsertMachineImageRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_insert case final insert?) {
    return insert(request);
  }
  throw UnsupportedError('insert');
}