FakeMachineTypes class base

Testing fake for MachineTypes.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(AggregatedListMachineTypesRequest request) Future<MachineTypeAggregatedList>
Retrieves an aggregated list of machine types.
override
close() → void
Closes the client and cleans up any resources associated with it.
override
get(GetMachineTypeRequest request) Future<MachineType>
Returns the specified machine type.
override
list(ListMachineTypesRequest request) Future<MachineTypeList>
Retrieves a list of machine types available to the specified project.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited