FakeNetworkEdgeSecurityServices class base

Testing fake for NetworkEdgeSecurityServices.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(AggregatedListNetworkEdgeSecurityServicesRequest request) Future<NetworkEdgeSecurityServiceAggregatedList>
Retrieves the list of all NetworkEdgeSecurityService resources available to the specified project.
override
close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteNetworkEdgeSecurityServiceRequest request) Future<Operation>
Deletes the specified service.
override
get(GetNetworkEdgeSecurityServiceRequest request) Future<NetworkEdgeSecurityService>
Gets a specified NetworkEdgeSecurityService.
override
insert(InsertNetworkEdgeSecurityServiceRequest request) Future<Operation>
Creates a new service in the specified project using the data included in the request.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(PatchNetworkEdgeSecurityServiceRequest request) Future<Operation>
Patches the specified policy with the data included in the request.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited