patch method

Patches the specified policy with the data included in the request.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> patch(
  PatchNetworkEdgeSecurityServiceRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_patch case final patch?) {
    return patch(request);
  }
  throw UnsupportedError('patch');
}