FakeNetworkEndpointGroups class base

Testing fake for NetworkEndpointGroups.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(AggregatedListNetworkEndpointGroupsRequest request) Future<NetworkEndpointGroupAggregatedList>
Retrieves the list of network endpoint groups and sorts them by zone.
override
attachNetworkEndpoints(AttachNetworkEndpointsNetworkEndpointGroupRequest request) Future<Operation>
Attach a list of network endpoints to the specified network endpoint group.
override
close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteNetworkEndpointGroupRequest request) Future<Operation>
Deletes the specified network endpoint group. The network endpoints in the NEG and the VM instances they belong to are not terminated when the NEG is deleted. Note that the NEG cannot be deleted if there are backend services referencing it.
override
detachNetworkEndpoints(DetachNetworkEndpointsNetworkEndpointGroupRequest request) Future<Operation>
Detach a list of network endpoints from the specified network endpoint group.
override
get(GetNetworkEndpointGroupRequest request) Future<NetworkEndpointGroup>
Returns the specified network endpoint group.
override
insert(InsertNetworkEndpointGroupRequest request) Future<Operation>
Creates a network endpoint group in the specified project using the parameters that are included in the request.
override
list(ListNetworkEndpointGroupsRequest request) Future<NetworkEndpointGroupList>
Retrieves the list of network endpoint groups that are located in the specified project and zone.
override
listNetworkEndpoints(ListNetworkEndpointsNetworkEndpointGroupsRequest request) Future<NetworkEndpointGroupsListNetworkEndpoints>
Lists the network endpoints in the specified network endpoint group.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
testIamPermissions(TestIamPermissionsNetworkEndpointGroupRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited