getPacketMirroringRule method

Gets a packet mirroring rule of the specified priority.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<FirewallPolicyRule> getPacketMirroringRule(
  GetPacketMirroringRuleNetworkFirewallPolicyRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_getPacketMirroringRule case final getPacketMirroringRule?) {
    return getPacketMirroringRule(request);
  }
  throw UnsupportedError('getPacketMirroringRule');
}