patchPacketMirroringRule method

  1. @override
Future<Operation> patchPacketMirroringRule(
  1. PatchPacketMirroringRuleNetworkFirewallPolicyRequest request
)
override

Patches a packet mirroring rule of the specified priority.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> patchPacketMirroringRule(
  PatchPacketMirroringRuleNetworkFirewallPolicyRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_patchPacketMirroringRule case final patchPacketMirroringRule?) {
    return patchPacketMirroringRule(request);
  }
  throw UnsupportedError('patchPacketMirroringRule');
}