FakeNetworkProfiles class base

Testing fake for NetworkProfiles.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
override
get(GetNetworkProfileRequest request) Future<NetworkProfile>
Returns the specified network profile.
override
list(ListNetworkProfilesRequest request) Future<NetworkProfilesListResponse>
Retrieves a list of network profiles available to the specified project.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited