FakeNetworks class base

Testing fake for Networks.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addPeering(AddPeeringNetworkRequest request) Future<Operation>
Adds a peering to the specified network.
override
cancelRequestRemovePeering(CancelRequestRemovePeeringNetworkRequest request) Future<Operation>
Cancel requests to remove a peering from the specified network. Applicable only for PeeringConnection with update_strategy=CONSENSUS. Cancels a request to remove a peering from the specified network.
override
close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteNetworkRequest request) Future<Operation>
Deletes the specified network.
override
get(GetNetworkRequest request) Future<Network>
Returns the specified network.
override
getEffectiveFirewalls(GetEffectiveFirewallsNetworkRequest request) Future<NetworksGetEffectiveFirewallsResponse>
Returns the effective firewalls on a given network.
override
insert(InsertNetworkRequest request) Future<Operation>
Creates a network in the specified project using the data included in the request.
override
list(ListNetworksRequest request) Future<NetworkList>
Retrieves the list of networks available to the specified project.
override
listPeeringRoutes(ListPeeringRoutesNetworksRequest request) Future<ExchangedPeeringRoutesList>
Lists the peering routes exchanged over peering connection.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(PatchNetworkRequest request) Future<Operation>
Patches the specified network with the data included in the request. Only routingConfig can be modified.
override
removePeering(RemovePeeringNetworkRequest request) Future<Operation>
Removes a peering from the specified network.
override
requestRemovePeering(RequestRemovePeeringNetworkRequest request) Future<Operation>
Requests to remove a peering from the specified network. Applicable only for PeeringConnection with update_strategy=CONSENSUS.
override
switchToCustomMode(SwitchToCustomModeNetworkRequest request) Future<Operation>
Switches the network mode from auto subnet mode to custom subnet mode.
override
toString() String
A string representation of this object.
inherited
updatePeering(UpdatePeeringNetworkRequest request) Future<Operation>
Updates the specified network peering with the data included in the request. You can only modify the NetworkPeering.export_custom_routes field and the NetworkPeering.import_custom_routes field.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited