cancelRequestRemovePeering method

  1. @override
Future<Operation> cancelRequestRemovePeering(
  1. CancelRequestRemovePeeringNetworkRequest request
)
override

Cancel requests to remove a peering from the specified network. Applicable only for PeeringConnection with update_strategy=CONSENSUS. Cancels a request to remove a peering from the specified network.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> cancelRequestRemovePeering(
  CancelRequestRemovePeeringNetworkRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_cancelRequestRemovePeering case final cancelRequestRemovePeering?) {
    return cancelRequestRemovePeering(request);
  }
  throw UnsupportedError('cancelRequestRemovePeering');
}