list method

  1. @override
Future<NetworkList> list(
  1. ListNetworksRequest request
)
override

Retrieves the list of networks available to the specified project.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<NetworkList> list(ListNetworksRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_list case final list?) {
    return list(request);
  }
  throw UnsupportedError('list');
}