requestRemovePeering method

  1. @override
Future<Operation> requestRemovePeering(
  1. RequestRemovePeeringNetworkRequest request
)
override

Requests to remove a peering from the specified network. Applicable only for PeeringConnection with update_strategy=CONSENSUS.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> requestRemovePeering(
  RequestRemovePeeringNetworkRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_requestRemovePeering case final requestRemovePeering?) {
    return requestRemovePeering(request);
  }
  throw UnsupportedError('requestRemovePeering');
}