switchToCustomMode method

  1. @override
Future<Operation> switchToCustomMode(
  1. SwitchToCustomModeNetworkRequest request
)
override

Switches the network mode from auto subnet mode to custom subnet mode.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> switchToCustomMode(
  SwitchToCustomModeNetworkRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_switchToCustomMode case final switchToCustomMode?) {
    return switchToCustomMode(request);
  }
  throw UnsupportedError('switchToCustomMode');
}