updatePeering method

  1. @override
Future<Operation> updatePeering(
  1. UpdatePeeringNetworkRequest request
)
override

Updates the specified network peering with the data included in the request. You can only modify the NetworkPeering.export_custom_routes field and the NetworkPeering.import_custom_routes field.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> updatePeering(UpdatePeeringNetworkRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_updatePeering case final updatePeering?) {
    return updatePeering(request);
  }
  throw UnsupportedError('updatePeering');
}