FakeNodeGroups class base

Testing fake for NodeGroups.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addNodes(AddNodesNodeGroupRequest request) Future<Operation>
Adds specified number of nodes to the node group.
override
aggregatedList(AggregatedListNodeGroupsRequest request) Future<NodeGroupAggregatedList>
Retrieves an aggregated list of node groups. Note: use nodeGroups.listNodes for more details about each group.
override
close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteNodeGroupRequest request) Future<Operation>
Deletes the specified NodeGroup resource.
override
deleteNodes(DeleteNodesNodeGroupRequest request) Future<Operation>
Deletes specified nodes from the node group.
override
get(GetNodeGroupRequest request) Future<NodeGroup>
Returns the specified NodeGroup. Get a list of available NodeGroups by making a list() request. Note: the "nodes" field should not be used. Use nodeGroups.listNodes instead.
override
getIamPolicy(GetIamPolicyNodeGroupRequest request) Future<Policy>
Gets the access control policy for a resource. May be empty if no such policy or resource exists.
override
insert(InsertNodeGroupRequest request) Future<Operation>
Creates a NodeGroup resource in the specified project using the data included in the request.
override
list(ListNodeGroupsRequest request) Future<NodeGroupList>
Retrieves a list of node groups available to the specified project. Note: use nodeGroups.listNodes for more details about each group.
override
listNodes(ListNodesNodeGroupsRequest request) Future<NodeGroupsListNodes>
Lists nodes in the node group.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(PatchNodeGroupRequest request) Future<Operation>
Updates the specified node group.
override
performMaintenance(PerformMaintenanceNodeGroupRequest request) Future<Operation>
Perform maintenance on a subset of nodes in the node group.
override
setIamPolicy(SetIamPolicyNodeGroupRequest request) Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy.
override
setNodeTemplate(SetNodeTemplateNodeGroupRequest request) Future<Operation>
Updates the node template of the node group.
override
simulateMaintenanceEvent(SimulateMaintenanceEventNodeGroupRequest request) Future<Operation>
Simulates maintenance event on specified nodes from the node group.
override
testIamPermissions(TestIamPermissionsNodeGroupRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited