addNodes method

  1. @override
Future<Operation> addNodes(
  1. AddNodesNodeGroupRequest request
)
override

Adds specified number of nodes to the node group.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> addNodes(AddNodesNodeGroupRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_addNodes case final addNodes?) {
    return addNodes(request);
  }
  throw UnsupportedError('addNodes');
}