list method

  1. @override
Future<NodeGroupList> list(
  1. ListNodeGroupsRequest request
)
override

Retrieves a list of node groups available to the specified project. Note: use nodeGroups.listNodes for more details about each group.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<NodeGroupList> list(ListNodeGroupsRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_list case final list?) {
    return list(request);
  }
  throw UnsupportedError('list');
}