FakeNodeTypes class base

Testing fake for NodeTypes.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(AggregatedListNodeTypesRequest request) Future<NodeTypeAggregatedList>
Retrieves an aggregated list of node types.
override
close() → void
Closes the client and cleans up any resources associated with it.
override
get(GetNodeTypeRequest request) Future<NodeType>
Returns the specified node type.
override
list(ListNodeTypesRequest request) Future<NodeTypeList>
Retrieves a list of node types available to the specified project.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited