list method

List all the policies that have been configured for the specified organization.

Use this API to read Cloud Armor policies. Previously, alpha and beta versions of this API were used to read firewall policies. This usage is now disabled for most organizations. Use firewallPolicies.list instead.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<SecurityPolicyList> list(
  ListOrganizationSecurityPoliciesRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_list case final list?) {
    return list(request);
  }
  throw UnsupportedError('list');
}