FakePacketMirrorings class base
Testing fake for PacketMirrorings.
- Implemented types
Constructors
-
FakePacketMirrorings({Future<
PacketMirroringAggregatedList> aggregatedList(AggregatedListPacketMirroringsRequest request)?, Future<Operation> delete(DeletePacketMirroringRequest request)?, Future<PacketMirroring> get(GetPacketMirroringRequest request)?, Future<Operation> insert(InsertPacketMirroringRequest request)?, Future<PacketMirroringList> list(ListPacketMirroringsRequest request)?, Future<Operation> patch(PatchPacketMirroringRequest request)?, Future<TestPermissionsResponse> testIamPermissions(TestIamPermissionsPacketMirroringRequest request)?})
Properties
Methods
-
aggregatedList(
AggregatedListPacketMirroringsRequest request) → Future< PacketMirroringAggregatedList> -
Retrieves an aggregated list of packetMirrorings.
override
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
delete(
DeletePacketMirroringRequest request) → Future< Operation> -
Deletes the specified PacketMirroring resource.
override
-
get(
GetPacketMirroringRequest request) → Future< PacketMirroring> -
Returns the specified PacketMirroring resource.
override
-
insert(
InsertPacketMirroringRequest request) → Future< Operation> -
Creates a PacketMirroring resource in the specified project and region
using the data included in the request.
override
-
list(
ListPacketMirroringsRequest request) → Future< PacketMirroringList> -
Retrieves a list of PacketMirroring resources available to the specified
project and region.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchPacketMirroringRequest request) → Future< Operation> -
Patches the specified PacketMirroring resource with the data included in
the request. This method supportsPATCH
semantics and usesJSON merge
patch format and processing rules.
override
-
testIamPermissions(
TestIamPermissionsPacketMirroringRequest request) → Future< TestPermissionsResponse> -
Returns permissions that a caller has on the specified resource.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited