patch method

Patches the specified PacketMirroring resource with the data included in the request. This method supportsPATCH semantics and usesJSON merge patch format and processing rules.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> patch(PatchPacketMirroringRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_patch case final patch?) {
    return patch(request);
  }
  throw UnsupportedError('patch');
}