FakePreviewFeatures class base

Testing fake for PreviewFeatures.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
override
get(GetPreviewFeatureRequest request) Future<PreviewFeature>
Returns the details of the given PreviewFeature.
override
list(ListPreviewFeaturesRequest request) Future<PreviewFeatureList>
Returns the details of the given PreviewFeature.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(UpdatePreviewFeatureRequest request) Future<Operation>
Patches the given PreviewFeature. This method is used to enable or disable a PreviewFeature.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited