update method

  1. @override
Future<Operation> update(
  1. UpdatePreviewFeatureRequest request
)
override

Patches the given PreviewFeature. This method is used to enable or disable a PreviewFeature.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> update(UpdatePreviewFeatureRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_update case final update?) {
    return update(request);
  }
  throw UnsupportedError('update');
}