get method

  1. @override
Future<Project> get(
  1. GetProjectRequest request
)
override

Returns the specified Project resource.

To decrease latency for this method, you can optionally omit any unneeded information from the response by using a field mask. This practice is especially recommended for unused quota information (the quotas field). To exclude one or more fields, set your request's fields query parameter to only include the fields you need. For example, to only include the id and selfLink fields, add the query parameter ?fields=id,selfLink to your request.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Project> get(GetProjectRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_get case final get?) {
    return get(request);
  }
  throw UnsupportedError('get');
}