listXpnHosts method

  1. @override
Future<XpnHostList> listXpnHosts(
  1. ListXpnHostsProjectsRequest request
)
override

Lists all shared VPC host projects visible to the user in an organization.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<XpnHostList> listXpnHosts(ListXpnHostsProjectsRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_listXpnHosts case final listXpnHosts?) {
    return listXpnHosts(request);
  }
  throw UnsupportedError('listXpnHosts');
}