moveInstance method
Moves an instance and its attached persistent disks from one zone to another. Note: Moving VMs or disks by using this method might cause unexpected behavior. For more information, see the known issue. Deprecated This method is deprecated. See moving instance across zones instead.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<Operation> moveInstance(MoveInstanceProjectRequest request) async {
if (isClosed) throw StateError('Service is closed');
if (_moveInstance case final moveInstance?) {
return moveInstance(request);
}
throw UnsupportedError('moveInstance');
}