setCloudArmorTier method
Sets the Cloud Armor tier of the project. To set ENTERPRISE or above the billing account of the project must be subscribed to Cloud Armor Enterprise. See Subscribing to Cloud Armor Enterprise for more information.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<Operation> setCloudArmorTier(
SetCloudArmorTierProjectRequest request,
) async {
if (isClosed) throw StateError('Service is closed');
if (_setCloudArmorTier case final setCloudArmorTier?) {
return setCloudArmorTier(request);
}
throw UnsupportedError('setCloudArmorTier');
}