setDefaultNetworkTier method

  1. @override
Future<Operation> setDefaultNetworkTier(
  1. SetDefaultNetworkTierProjectRequest request
)
override

Sets the default network tier of the project. The default network tier is used when an address/forwardingRule/instance is created without specifying the network tier field.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> setDefaultNetworkTier(
  SetDefaultNetworkTierProjectRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_setDefaultNetworkTier case final setDefaultNetworkTier?) {
    return setDefaultNetworkTier(request);
  }
  throw UnsupportedError('setDefaultNetworkTier');
}