setUsageExportBucket method
Enables the usage export feature and sets theusage export bucket where reports are stored. If you provide an empty request body using this method, the usage export feature will be disabled.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<Operation> setUsageExportBucket(
SetUsageExportBucketProjectRequest request,
) async {
if (isClosed) throw StateError('Service is closed');
if (_setUsageExportBucket case final setUsageExportBucket?) {
return setUsageExportBucket(request);
}
throw UnsupportedError('setUsageExportBucket');
}