FakePublicAdvertisedPrefixes class base

Testing fake for PublicAdvertisedPrefixes.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

announce(AnnouncePublicAdvertisedPrefixeRequest request) Future<Operation>
Announces the specified PublicAdvertisedPrefix
override
close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeletePublicAdvertisedPrefixeRequest request) Future<Operation>
Deletes the specified PublicAdvertisedPrefix
override
get(GetPublicAdvertisedPrefixeRequest request) Future<PublicAdvertisedPrefix>
Returns the specified PublicAdvertisedPrefix resource.
override
insert(InsertPublicAdvertisedPrefixeRequest request) Future<Operation>
Creates a PublicAdvertisedPrefix in the specified project using the parameters that are included in the request.
override
list(ListPublicAdvertisedPrefixesRequest request) Future<PublicAdvertisedPrefixList>
Lists the PublicAdvertisedPrefixes for a project.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(PatchPublicAdvertisedPrefixeRequest request) Future<Operation>
Patches the specified Router resource with the data included in the request. This method supportsPATCH semantics and usesJSON merge patch format and processing rules.
override
toString() String
A string representation of this object.
inherited
withdraw(WithdrawPublicAdvertisedPrefixeRequest request) Future<Operation>
Withdraws the specified PublicAdvertisedPrefix
override

Operators

operator ==(Object other) bool
The equality operator.
inherited