FakeRegionAutoscalers class base

Testing fake for RegionAutoscalers.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteRegionAutoscalerRequest request) Future<Operation>
Deletes the specified autoscaler.
override
get(GetRegionAutoscalerRequest request) Future<Autoscaler>
Returns the specified autoscaler.
override
insert(InsertRegionAutoscalerRequest request) Future<Operation>
Creates an autoscaler in the specified project using the data included in the request.
override
list(ListRegionAutoscalersRequest request) Future<RegionAutoscalerList>
Retrieves a list of autoscalers contained within the specified region.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(PatchRegionAutoscalerRequest request) Future<Operation>
Updates an autoscaler in the specified project using the data included in the request. This method supportsPATCH semantics and uses theJSON merge patch format and processing rules.
override
testIamPermissions(TestIamPermissionsRegionAutoscalerRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
override
toString() String
A string representation of this object.
inherited
update(UpdateRegionAutoscalerRequest request) Future<Operation>
Updates an autoscaler in the specified project using the data included in the request.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited