FakeRegionBackendBuckets class base

Testing fake for RegionBackendBuckets.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteRegionBackendBucketRequest request) Future<Operation>
Deletes the specified regional BackendBucket resource.
override
get(GetRegionBackendBucketRequest request) Future<BackendBucket>
Returns the specified regional BackendBucket resource.
override
getIamPolicy(GetIamPolicyRegionBackendBucketRequest request) Future<Policy>
Gets the access control policy for a resource. May be empty if no such policy or resource exists.
override
insert(InsertRegionBackendBucketRequest request) Future<Operation>
Creates a RegionBackendBucket in the specified project in the given scope using the parameters that are included in the request.
override
list(ListRegionBackendBucketsRequest request) Future<BackendBucketList>
Retrieves the list of BackendBucket resources available to the specified project in the given region.
override
listUsable(ListUsableRegionBackendBucketsRequest request) Future<BackendBucketListUsable>
Retrieves a list of all usable backend buckets in the specified project in the given region.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(PatchRegionBackendBucketRequest request) Future<Operation>
Updates the specified BackendBucket resource with the data included in the request. This method supportsPATCH semantics and uses theJSON merge patch format and processing rules.
override
setIamPolicy(SetIamPolicyRegionBackendBucketRequest request) Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy.
override
testIamPermissions(TestIamPermissionsRegionBackendBucketRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited