getHealth method

Gets the most recent health check results for this regional BackendService.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<BackendServiceGroupHealth> getHealth(
  GetHealthRegionBackendServiceRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_getHealth case final getHealth?) {
    return getHealth(request);
  }
  throw UnsupportedError('getHealth');
}