insert method

Creates a regional BackendService resource in the specified project using the data included in the request. For more information, see Backend services overview.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> insert(InsertRegionBackendServiceRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_insert case final insert?) {
    return insert(request);
  }
  throw UnsupportedError('insert');
}