listUsable method
Retrieves a list of all usable backend services for Application Load Balancers and Proxy Network Load Balancers in the specified project in the given region. Backend services for external and internal passthrough Network Load Balancers are not included in the response.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<BackendServiceListUsable> listUsable(
ListUsableRegionBackendServicesRequest request,
) async {
if (isClosed) throw StateError('Service is closed');
if (_listUsable case final listUsable?) {
return listUsable(request);
}
throw UnsupportedError('listUsable');
}