FakeRegionCommitments class base
Testing fake for RegionCommitments.
- Implemented types
Constructors
-
FakeRegionCommitments({Future<
CommitmentAggregatedList> aggregatedList(AggregatedListRegionCommitmentsRequest request)?, Future<Commitment> get(GetRegionCommitmentRequest request)?, Future<Operation> insert(InsertRegionCommitmentRequest request)?, Future<CommitmentList> list(ListRegionCommitmentsRequest request)?, Future<Operation> update(UpdateRegionCommitmentRequest request)?})
Properties
Methods
-
aggregatedList(
AggregatedListRegionCommitmentsRequest request) → Future< CommitmentAggregatedList> -
Retrieves an aggregated list of commitments by region.
override
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
get(
GetRegionCommitmentRequest request) → Future< Commitment> -
Returns the specified commitment resource.
override
-
insert(
InsertRegionCommitmentRequest request) → Future< Operation> -
Creates a commitment in the specified project using the data
included in the request.
override
-
list(
ListRegionCommitmentsRequest request) → Future< CommitmentList> -
Retrieves a list of commitments contained within
the specified region.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
UpdateRegionCommitmentRequest request) → Future< Operation> -
Updates the specified commitment with the data included in the request.
Update is performed only on selected fields included as part of
update-mask. Only the following fields can be updated: auto_renew and plan.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited