update method

Updates the specified commitment with the data included in the request. Update is performed only on selected fields included as part of update-mask. Only the following fields can be updated: auto_renew and plan.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> update(UpdateRegionCommitmentRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_update case final update?) {
    return update(request);
  }
  throw UnsupportedError('update');
}