aggregatedList method

Retrieves the list of all CompositeHealthCheck resources (all regional) available to the specified project.

To prevent failure, it is recommended that you set the returnPartialSuccess parameter to true.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<CompositeHealthCheckAggregatedList> aggregatedList(
  AggregatedListRegionCompositeHealthChecksRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_aggregatedList case final aggregatedList?) {
    return aggregatedList(request);
  }
  throw UnsupportedError('aggregatedList');
}