FakeRegionDiskTypes class base
Testing fake for RegionDiskTypes.
- Implemented types
Constructors
-
FakeRegionDiskTypes({Future<
DiskType> get(GetRegionDiskTypeRequest request)?, Future<RegionDiskTypeList> list(ListRegionDiskTypesRequest request)?})
Properties
Methods
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
get(
GetRegionDiskTypeRequest request) → Future< DiskType> -
Returns the specified regional disk type.
override
-
list(
ListRegionDiskTypesRequest request) → Future< RegionDiskTypeList> -
Retrieves a list of regional disk types available to the specified project.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited