stopAsyncReplication method

  1. @override
Future<Operation> stopAsyncReplication(
  1. StopAsyncReplicationRegionDiskRequest request
)
override

Stops asynchronous replication. Can be invoked either on the primary or on the secondary disk.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> stopAsyncReplication(
  StopAsyncReplicationRegionDiskRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_stopAsyncReplication case final stopAsyncReplication?) {
    return stopAsyncReplication(request);
  }
  throw UnsupportedError('stopAsyncReplication');
}