stopGroupAsyncReplication method

  1. @override
Future<Operation> stopGroupAsyncReplication(
  1. StopGroupAsyncReplicationRegionDiskRequest request
)
override

Stops asynchronous replication for a consistency group of disks. Can be invoked either in the primary or secondary scope.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> stopGroupAsyncReplication(
  StopGroupAsyncReplicationRegionDiskRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_stopGroupAsyncReplication case final stopGroupAsyncReplication?) {
    return stopGroupAsyncReplication(request);
  }
  throw UnsupportedError('stopGroupAsyncReplication');
}