FakeRegionHealthChecks class base

Testing fake for RegionHealthChecks.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteRegionHealthCheckRequest request) Future<Operation>
Deletes the specified HealthCheck resource.
override
get(GetRegionHealthCheckRequest request) Future<HealthCheck>
Returns the specified HealthCheck resource.
override
insert(InsertRegionHealthCheckRequest request) Future<Operation>
Creates a HealthCheck resource in the specified project using the data included in the request.
override
list(ListRegionHealthChecksRequest request) Future<HealthCheckList>
Retrieves the list of HealthCheck resources available to the specified project.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(PatchRegionHealthCheckRequest request) Future<Operation>
Updates a HealthCheck resource in the specified project using the data included in the request. This method supportsPATCH semantics and uses theJSON merge patch format and processing rules.
override
testIamPermissions(TestIamPermissionsRegionHealthCheckRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
override
toString() String
A string representation of this object.
inherited
update(UpdateRegionHealthCheckRequest request) Future<Operation>
Updates a HealthCheck resource in the specified project using the data included in the request.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited