update method

Updates a HealthCheck resource in the specified project using the data included in the request.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> update(UpdateRegionHealthCheckRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_update case final update?) {
    return update(request);
  }
  throw UnsupportedError('update');
}