cancel method

Cancels the specified resize request. Cancelled resize request no longer waits for the resources to be provisioned. Cancel is only possible for requests that are in accepted state.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> cancel(
  CancelRegionInstanceGroupManagerResizeRequestRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_cancel case final cancel?) {
    return cancel(request);
  }
  throw UnsupportedError('cancel');
}