applyUpdatesToInstances method

Apply updates to selected instances the managed instance group.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> applyUpdatesToInstances(
  ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_applyUpdatesToInstances case final applyUpdatesToInstances?) {
    return applyUpdatesToInstances(request);
  }
  throw UnsupportedError('applyUpdatesToInstances');
}