insert method
Creates a managed instance group using the information that you specify in the request. After the group is created, instances in the group are created using the specified instance template. This operation is marked as DONE when the group is created even if the instances in the group have not yet been created. You must separately verify the status of the individual instances with thelistmanagedinstances method.
A regional managed instance group can contain up to 2000 instances.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<Operation> insert(
InsertRegionInstanceGroupManagerRequest request,
) async {
if (isClosed) throw StateError('Service is closed');
if (_insert case final insert?) {
return insert(request);
}
throw UnsupportedError('insert');
}