patchPerInstanceConfigs method

Inserts or patches per-instance configurations for the managed instance group. perInstanceConfig.name serves as a key used to distinguish whether to perform insert or patch.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> patchPerInstanceConfigs(
  PatchPerInstanceConfigsRegionInstanceGroupManagerRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_patchPerInstanceConfigs case final patchPerInstanceConfigs?) {
    return patchPerInstanceConfigs(request);
  }
  throw UnsupportedError('patchPerInstanceConfigs');
}