setInstanceTemplate method

Sets the instance template to use when creating new instances or recreating instances in this group. Existing instances are not affected.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> setInstanceTemplate(
  SetInstanceTemplateRegionInstanceGroupManagerRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_setInstanceTemplate case final setInstanceTemplate?) {
    return setInstanceTemplate(request);
  }
  throw UnsupportedError('setInstanceTemplate');
}