listInstances method
Lists the instances in the specified instance group and displays information about the named ports. Depending on the specified options, this method can list all instances or only the instances that are running. The orderBy query parameter is not supported.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<RegionInstanceGroupsListInstances> listInstances(
ListInstancesRegionInstanceGroupsRequest request,
) async {
if (isClosed) throw StateError('Service is closed');
if (_listInstances case final listInstances?) {
return listInstances(request);
}
throw UnsupportedError('listInstances');
}