setNamedPorts method

Sets the named ports for the specified regional instance group.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> setNamedPorts(
  SetNamedPortsRegionInstanceGroupRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_setNamedPorts case final setNamedPorts?) {
    return setNamedPorts(request);
  }
  throw UnsupportedError('setNamedPorts');
}