FakeRegionInstanceTemplates class base

Testing fake for RegionInstanceTemplates.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteRegionInstanceTemplateRequest request) Future<Operation>
Deletes the specified instance template. Deleting an instance template is permanent and cannot be undone.
override
get(GetRegionInstanceTemplateRequest request) Future<InstanceTemplate>
Returns the specified instance template.
override
insert(InsertRegionInstanceTemplateRequest request) Future<Operation>
Creates an instance template in the specified project and region using the global instance template whose URL is included in the request.
override
list(ListRegionInstanceTemplatesRequest request) Future<InstanceTemplateList>
Retrieves a list of instance templates that are contained within the specified project and region.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited