FakeRegionInstantSnapshots class base
Testing fake for RegionInstantSnapshots.
- Implemented types
Constructors
-
FakeRegionInstantSnapshots({Future<
Operation> delete(DeleteRegionInstantSnapshotRequest request)?, Future<InstantSnapshot> get(GetRegionInstantSnapshotRequest request)?, Future<Policy> getIamPolicy(GetIamPolicyRegionInstantSnapshotRequest request)?, Future<Operation> insert(InsertRegionInstantSnapshotRequest request)?, Future<InstantSnapshotList> list(ListRegionInstantSnapshotsRequest request)?, Future<Policy> setIamPolicy(SetIamPolicyRegionInstantSnapshotRequest request)?, Future<Operation> setLabels(SetLabelsRegionInstantSnapshotRequest request)?, Future<TestPermissionsResponse> testIamPermissions(TestIamPermissionsRegionInstantSnapshotRequest request)?})
Properties
Methods
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
delete(
DeleteRegionInstantSnapshotRequest request) → Future< Operation> -
Deletes the specified InstantSnapshot resource. Keep in mind that deleting
a single instantSnapshot might not necessarily delete all the data on that
instantSnapshot. If any data on the instantSnapshot that is marked for
deletion is needed for subsequent instantSnapshots, the data will be moved
to the next corresponding instantSnapshot.
override
-
get(
GetRegionInstantSnapshotRequest request) → Future< InstantSnapshot> -
Returns the specified InstantSnapshot resource in the specified region.
override
-
getIamPolicy(
GetIamPolicyRegionInstantSnapshotRequest request) → Future< Policy> -
Gets the access control policy for a resource. May be empty if no such
policy or resource exists.
override
-
insert(
InsertRegionInstantSnapshotRequest request) → Future< Operation> -
Creates an instant snapshot in the specified region.
override
-
list(
ListRegionInstantSnapshotsRequest request) → Future< InstantSnapshotList> -
Retrieves the list of InstantSnapshot resources contained within
the specified region.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setIamPolicy(
SetIamPolicyRegionInstantSnapshotRequest request) → Future< Policy> -
Sets the access control policy on the specified resource.
Replaces any existing policy.
override
-
setLabels(
SetLabelsRegionInstantSnapshotRequest request) → Future< Operation> -
Sets the labels on a instantSnapshot in the given region. To learn more
about labels, read the Labeling
Resources documentation.
override
-
testIamPermissions(
TestIamPermissionsRegionInstantSnapshotRequest request) → Future< TestPermissionsResponse> -
Returns permissions that a caller has on the specified resource.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited