FakeRegionNetworkEndpointGroups class base
Testing fake for RegionNetworkEndpointGroups.
- Implemented types
Constructors
-
FakeRegionNetworkEndpointGroups({Future<
Operation> attachNetworkEndpoints(AttachNetworkEndpointsRegionNetworkEndpointGroupRequest request)?, Future<Operation> delete(DeleteRegionNetworkEndpointGroupRequest request)?, Future<Operation> detachNetworkEndpoints(DetachNetworkEndpointsRegionNetworkEndpointGroupRequest request)?, Future<NetworkEndpointGroup> get(GetRegionNetworkEndpointGroupRequest request)?, Future<Operation> insert(InsertRegionNetworkEndpointGroupRequest request)?, Future<NetworkEndpointGroupList> list(ListRegionNetworkEndpointGroupsRequest request)?, Future<NetworkEndpointGroupsListNetworkEndpoints> listNetworkEndpoints(ListNetworkEndpointsRegionNetworkEndpointGroupsRequest request)?})
Properties
Methods
-
attachNetworkEndpoints(
AttachNetworkEndpointsRegionNetworkEndpointGroupRequest request) → Future< Operation> -
Attach a list of network endpoints to the specified network endpoint group.
override
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
delete(
DeleteRegionNetworkEndpointGroupRequest request) → Future< Operation> -
Deletes the specified network endpoint group. Note that the NEG cannot be
deleted if it is configured as a backend of a backend service.
override
-
detachNetworkEndpoints(
DetachNetworkEndpointsRegionNetworkEndpointGroupRequest request) → Future< Operation> -
Detach the network endpoint from the specified network endpoint group.
override
-
get(
GetRegionNetworkEndpointGroupRequest request) → Future< NetworkEndpointGroup> -
Returns the specified network endpoint group.
override
-
insert(
InsertRegionNetworkEndpointGroupRequest request) → Future< Operation> -
Creates a network endpoint group in the specified project using the
parameters that are included in the request.
override
-
list(
ListRegionNetworkEndpointGroupsRequest request) → Future< NetworkEndpointGroupList> -
Retrieves the list of regional network endpoint groups available to the
specified project in the given region.
override
-
listNetworkEndpoints(
ListNetworkEndpointsRegionNetworkEndpointGroupsRequest request) → Future< NetworkEndpointGroupsListNetworkEndpoints> -
Lists the network endpoints in the specified network endpoint group.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited