detachNetworkEndpoints method

Detach the network endpoint from the specified network endpoint group.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> detachNetworkEndpoints(
  DetachNetworkEndpointsRegionNetworkEndpointGroupRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_detachNetworkEndpoints case final detachNetworkEndpoints?) {
    return detachNetworkEndpoints(request);
  }
  throw UnsupportedError('detachNetworkEndpoints');
}