list method
Retrieves the list of regional network endpoint groups available to the specified project in the given region.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<NetworkEndpointGroupList> list(
ListRegionNetworkEndpointGroupsRequest request,
) async {
if (isClosed) throw StateError('Service is closed');
if (_list case final list?) {
return list(request);
}
throw UnsupportedError('list');
}