FakeRegionOperations class base

Testing fake for RegionOperations.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteRegionOperationRequest request) Future<DeleteRegionOperationResponse>
Deletes the specified region-specific Operations resource.
override
get(GetRegionOperationRequest request) Future<Operation>
Retrieves the specified region-specific Operations resource.
override
list(ListRegionOperationsRequest request) Future<OperationList>
Retrieves a list of Operation resources contained within the specified region.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
wait(WaitRegionOperationRequest request) Future<Operation>
Waits for the specified Operation resource to return as DONE or for the request to approach the 2 minute deadline, and retrieves the specified Operation resource. This method differs from the GET method in that it waits for no more than the default deadline (2 minutes) and then returns the current state of the operation, which might be DONE or still in progress.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited