FakeRegionSecurityPolicies class base
Testing fake for RegionSecurityPolicies.
- Implemented types
Constructors
-
FakeRegionSecurityPolicies({Future<
Operation> addRule(AddRuleRegionSecurityPolicyRequest request)?, Future<Operation> delete(DeleteRegionSecurityPolicyRequest request)?, Future<SecurityPolicy> get(GetRegionSecurityPolicyRequest request)?, Future<SecurityPolicyRule> getRule(GetRuleRegionSecurityPolicyRequest request)?, Future<Operation> insert(InsertRegionSecurityPolicyRequest request)?, Future<SecurityPolicyList> list(ListRegionSecurityPoliciesRequest request)?, Future<Operation> patch(PatchRegionSecurityPolicyRequest request)?, Future<Operation> patchRule(PatchRuleRegionSecurityPolicyRequest request)?, Future<Operation> removeRule(RemoveRuleRegionSecurityPolicyRequest request)?, Future<Operation> setLabels(SetLabelsRegionSecurityPolicyRequest request)?})
Properties
Methods
-
addRule(
AddRuleRegionSecurityPolicyRequest request) → Future< Operation> -
Inserts a rule into a security policy.
override
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
delete(
DeleteRegionSecurityPolicyRequest request) → Future< Operation> -
Deletes the specified policy.
override
-
get(
GetRegionSecurityPolicyRequest request) → Future< SecurityPolicy> -
List all of the ordered rules present in a single specified policy.
override
-
getRule(
GetRuleRegionSecurityPolicyRequest request) → Future< SecurityPolicyRule> -
Gets a rule at the specified priority.
override
-
insert(
InsertRegionSecurityPolicyRequest request) → Future< Operation> -
Creates a new policy in the specified project using the data included in
the request.
override
-
list(
ListRegionSecurityPoliciesRequest request) → Future< SecurityPolicyList> -
List all the policies that have been configured for the specified project
and region.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchRegionSecurityPolicyRequest request) → Future< Operation> -
Patches the specified policy with the data included in the request. To
clear fields in the policy, leave the fields empty and specify them in the
updateMask. This cannot be used to be update the rules in the policy.
Please use the per rule methods like addRule, patchRule, and removeRule
instead.
override
-
patchRule(
PatchRuleRegionSecurityPolicyRequest request) → Future< Operation> -
Patches a rule at the specified priority. To clear fields in the rule,
leave the fields empty and specify them in the updateMask.
override
-
removeRule(
RemoveRuleRegionSecurityPolicyRequest request) → Future< Operation> -
Deletes a rule at the specified priority.
override
-
setLabels(
SetLabelsRegionSecurityPolicyRequest request) → Future< Operation> -
Sets the labels on a security policy. To learn more about labels,
read the Labeling Resources
documentation.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited