FakeRegionSnapshotSettings class base
Testing fake for RegionSnapshotSettings.
- Implemented types
Constructors
-
FakeRegionSnapshotSettings({Future<
SnapshotSettings> get(GetRegionSnapshotSettingRequest request)?, Future<Operation> patch(PatchRegionSnapshotSettingRequest request)?})
Properties
Methods
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
get(
GetRegionSnapshotSettingRequest request) → Future< SnapshotSettings> -
Get region snapshot settings.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchRegionSnapshotSettingRequest request) → Future< Operation> -
Patch region snapshot settings.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited