delete method
Deletes the specified Snapshot resource. Keep in mind that deleting a single snapshot might not necessarily delete all the data on that snapshot. If any data on the snapshot that is marked for deletion is needed for subsequent snapshots, the data will be moved to the next corresponding snapshot.
For more information, seeDeleting snapshots.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<Operation> delete(DeleteRegionSnapshotRequest request) async {
if (isClosed) throw StateError('Service is closed');
if (_delete case final delete?) {
return delete(request);
}
throw UnsupportedError('delete');
}