updateKmsKey method

  1. @override
Future<Operation> updateKmsKey(
  1. UpdateKmsKeyRegionSnapshotRequest request
)
override

Rotates the customer-managed encryption key to the latest version for the specified snapshot.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> updateKmsKey(
  UpdateKmsKeyRegionSnapshotRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_updateKmsKey case final updateKmsKey?) {
    return updateKmsKey(request);
  }
  throw UnsupportedError('updateKmsKey');
}