FakeRegionSslCertificates class base

Testing fake for RegionSslCertificates.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteRegionSslCertificateRequest request) Future<Operation>
Deletes the specified SslCertificate resource in the region.
override
get(GetRegionSslCertificateRequest request) Future<SslCertificate>
Returns the specified SslCertificate resource in the specified region. Get a list of available SSL certificates by making a list() request.
override
insert(InsertRegionSslCertificateRequest request) Future<Operation>
Creates a SslCertificate resource in the specified project and region using the data included in the request
override
list(ListRegionSslCertificatesRequest request) Future<SslCertificateList>
Retrieves the list of SslCertificate resources available to the specified project in the specified region.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited