FakeRegionTargetHttpProxies class base
Testing fake for RegionTargetHttpProxies.
- Implemented types
Constructors
-
FakeRegionTargetHttpProxies({Future<
Operation> delete(DeleteRegionTargetHttpProxyRequest request)?, Future<TargetHttpProxy> get(GetRegionTargetHttpProxyRequest request)?, Future<Operation> insert(InsertRegionTargetHttpProxyRequest request)?, Future<TargetHttpProxyList> list(ListRegionTargetHttpProxiesRequest request)?, Future<Operation> setUrlMap(SetUrlMapRegionTargetHttpProxyRequest request)?})
Properties
Methods
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
delete(
DeleteRegionTargetHttpProxyRequest request) → Future< Operation> -
Deletes the specified TargetHttpProxy resource.
override
-
get(
GetRegionTargetHttpProxyRequest request) → Future< TargetHttpProxy> -
Returns the specified TargetHttpProxy resource in the specified region.
override
-
insert(
InsertRegionTargetHttpProxyRequest request) → Future< Operation> -
Creates a TargetHttpProxy resource in the specified project and region
using the data included in the request.
override
-
list(
ListRegionTargetHttpProxiesRequest request) → Future< TargetHttpProxyList> -
Retrieves the list of TargetHttpProxy resources available
to the specified project in the specified region.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setUrlMap(
SetUrlMapRegionTargetHttpProxyRequest request) → Future< Operation> -
Changes the URL map for TargetHttpProxy.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited