FakeRegionTargetHttpsProxies class base

Testing fake for RegionTargetHttpsProxies.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteRegionTargetHttpsProxyRequest request) Future<Operation>
Deletes the specified TargetHttpsProxy resource.
override
get(GetRegionTargetHttpsProxyRequest request) Future<TargetHttpsProxy>
Returns the specified TargetHttpsProxy resource in the specified region.
override
insert(InsertRegionTargetHttpsProxyRequest request) Future<Operation>
Creates a TargetHttpsProxy resource in the specified project and region using the data included in the request.
override
list(ListRegionTargetHttpsProxiesRequest request) Future<TargetHttpsProxyList>
Retrieves the list of TargetHttpsProxy resources available to the specified project in the specified region.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(PatchRegionTargetHttpsProxyRequest request) Future<Operation>
Patches the specified regional TargetHttpsProxy resource with the data included in the request. This method supports PATCH semantics and usesJSON merge patch format and processing rules.
override
setSslCertificates(SetSslCertificatesRegionTargetHttpsProxyRequest request) Future<Operation>
Replaces SslCertificates for TargetHttpsProxy.
override
setUrlMap(SetUrlMapRegionTargetHttpsProxyRequest request) Future<Operation>
Changes the URL map for TargetHttpsProxy.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited