FakeRegionTargetTcpProxies class base

Testing fake for RegionTargetTcpProxies.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteRegionTargetTcpProxyRequest request) Future<Operation>
Deletes the specified TargetTcpProxy resource.
override
get(GetRegionTargetTcpProxyRequest request) Future<TargetTcpProxy>
Returns the specified TargetTcpProxy resource.
override
insert(InsertRegionTargetTcpProxyRequest request) Future<Operation>
Creates a TargetTcpProxy resource in the specified project and region using the data included in the request.
override
list(ListRegionTargetTcpProxiesRequest request) Future<TargetTcpProxyList>
Retrieves a list of TargetTcpProxy resources available to the specified project in a given region.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited