list method

  1. @override
Future<UrlMapList> list(
  1. ListRegionUrlMapsRequest request
)
override

Retrieves the list of UrlMap resources available to the specified project in the specified region.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<UrlMapList> list(ListRegionUrlMapsRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_list case final list?) {
    return list(request);
  }
  throw UnsupportedError('list');
}