list method

  1. @override
Future<ZoneList> list(
  1. ListRegionZonesRequest request
)
override

Retrieves the list of Zone resources under the specific region available to the specified project.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<ZoneList> list(ListRegionZonesRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_list case final list?) {
    return list(request);
  }
  throw UnsupportedError('list');
}