FakeRegions class base
Testing fake for Regions.
- Implemented types
Constructors
-
FakeRegions({Future<
Region> get(GetRegionRequest request)?, Future<RegionList> list(ListRegionsRequest request)?})
Properties
Methods
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
get(
GetRegionRequest request) → Future< Region> -
Returns the specified Region resource.
override
-
list(
ListRegionsRequest request) → Future< RegionList> -
Retrieves the list of region resources available to the specified project.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited