FakeReliabilityRisks class base
Testing fake for ReliabilityRisks.
- Implemented types
Constructors
-
FakeReliabilityRisks({Future<
ReliabilityRisk> get(GetReliabilityRiskRequest request)?, Future<ReliabilityRisksListResponse> list(ListReliabilityRisksRequest request)?})
Properties
Methods
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
get(
GetReliabilityRiskRequest request) → Future< ReliabilityRisk> -
Returns the specified ReliabilityRisk resource.
override
-
list(
ListReliabilityRisksRequest request) → Future< ReliabilityRisksListResponse> -
Retrieves the list of reliabilityRisks available in the specified project.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited