FakeReservationBlocks class base

Testing fake for ReservationBlocks.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
override
get(GetReservationBlockRequest request) Future<ReservationBlocksGetResponse>
Retrieves information about the specified reservation block.
override
getIamPolicy(GetIamPolicyReservationBlockRequest request) Future<Policy>
Gets the access control policy for a resource. May be empty if no such policy or resource exists.
override
list(ListReservationBlocksRequest request) Future<ReservationBlocksListResponse>
Retrieves a list of reservation blocks under a single reservation.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
performMaintenance(PerformMaintenanceReservationBlockRequest request) Future<Operation>
Allows customers to perform maintenance on a reservation block
override
setIamPolicy(SetIamPolicyReservationBlockRequest request) Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy.
override
testIamPermissions(TestIamPermissionsReservationBlockRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited