FakeReservationSlots class base

Testing fake for ReservationSlots.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
override
get(GetReservationSlotRequest request) Future<ReservationSlotsGetResponse>
Retrieves information about the specified reservation slot.
override
getHealth(GetHealthReservationSlotRequest request) Future<Operation>
Get health info on a reservation slot.
override
getVersion(GetVersionReservationSlotRequest request) Future<Operation>
Allows customers to get SBOM versions of a reservation slot.
override
list(ListReservationSlotsRequest request) Future<ReservationSlotsListResponse>
Retrieves a list of reservation slots under a single reservation.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(UpdateReservationSlotRequest request) Future<Operation>
Update a reservation slot in the specified sub-block.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited