FakeReservationSubBlocks class base

Testing fake for ReservationSubBlocks.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
override
get(GetReservationSubBlockRequest request) Future<ReservationSubBlocksGetResponse>
Retrieves information about the specified reservation subBlock.
override
getIamPolicy(GetIamPolicyReservationSubBlockRequest request) Future<Policy>
Gets the access control policy for a resource. May be empty if no such policy or resource exists.
override
getVersion(GetVersionReservationSubBlockRequest request) Future<Operation>
Allows customers to get SBOM versions of a reservation subBlock.
override
list(ListReservationSubBlocksRequest request) Future<ReservationSubBlocksListResponse>
Retrieves a list of reservation subBlocks under a single reservation.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
performMaintenance(PerformMaintenanceReservationSubBlockRequest request) Future<Operation>
Allows customers to perform maintenance on a reservation subBlock
override
reportFaulty(ReportFaultyReservationSubBlockRequest request) Future<Operation>
Allows customers to report a faulty subBlock.
override
setIamPolicy(SetIamPolicyReservationSubBlockRequest request) Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy.
override
testIamPermissions(TestIamPermissionsReservationSubBlockRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited