FakeResourcePolicies class base

Testing fake for ResourcePolicies.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(AggregatedListResourcePoliciesRequest request) Future<ResourcePolicyAggregatedList>
Retrieves an aggregated list of resource policies.
override
close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteResourcePolicyRequest request) Future<Operation>
Deletes the specified resource policy.
override
get(GetResourcePolicyRequest request) Future<ResourcePolicy>
Retrieves all information of the specified resource policy.
override
getIamPolicy(GetIamPolicyResourcePolicyRequest request) Future<Policy>
Gets the access control policy for a resource. May be empty if no such policy or resource exists.
override
insert(InsertResourcePolicyRequest request) Future<Operation>
Creates a new resource policy.
override
list(ListResourcePoliciesRequest request) Future<ResourcePolicyList>
A list all the resource policies that have been configured for the specified project in specified region.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(PatchResourcePolicyRequest request) Future<Operation>
Modify the specified resource policy.
override
setIamPolicy(SetIamPolicyResourcePolicyRequest request) Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy.
override
testIamPermissions(TestIamPermissionsResourcePolicyRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited