FakeRolloutPlans class base

Testing fake for RolloutPlans.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteRolloutPlanRequest request) Future<Operation>
Deletes a RolloutPlan.
override
get(GetRolloutPlanRequest request) Future<RolloutPlan>
Gets details of a single project-scoped RolloutPlan.
override
insert(InsertRolloutPlanRequest request) Future<Operation>
Creates a new RolloutPlan in a given project and location.
override
list(ListRolloutPlansRequest request) Future<RolloutPlansListResponse>
Lists RolloutPlans in a given project and location.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited