advance method

  1. @override
Future<Operation> advance(
  1. AdvanceRolloutRequest request
)
override

Advances a Rollout to the next wave, or completes it if no waves remain.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> advance(AdvanceRolloutRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_advance case final advance?) {
    return advance(request);
  }
  throw UnsupportedError('advance');
}