listBgpRoutes method

  1. @override
Future<RoutersListBgpRoutes> listBgpRoutes(
  1. ListBgpRoutesRoutersRequest request
)
override

Retrieves a list of router bgp routes available to the specified project.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<RoutersListBgpRoutes> listBgpRoutes(
  ListBgpRoutesRoutersRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_listBgpRoutes case final listBgpRoutes?) {
    return listBgpRoutes(request);
  }
  throw UnsupportedError('listBgpRoutes');
}