FakeRoutes class base

Testing fake for Routes.

Implemented types

Constructors

FakeRoutes({Future<Operation> delete(DeleteRouteRequest request)?, Future<Route> get(GetRouteRequest request)?, Future<Operation> insert(InsertRouteRequest request)?, Future<RouteList> list(ListRoutesRequest request)?, Future<TestPermissionsResponse> testIamPermissions(TestIamPermissionsRouteRequest request)?})

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteRouteRequest request) Future<Operation>
Deletes the specified Route resource.
override
get(GetRouteRequest request) Future<Route>
Returns the specified Route resource.
override
insert(InsertRouteRequest request) Future<Operation>
Creates a Route resource in the specified project using the data included in the request.
override
list(ListRoutesRequest request) Future<RouteList>
Retrieves the list of Route resources available to the specified project.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
testIamPermissions(TestIamPermissionsRouteRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited