get method

List all of the ordered rules present in a single specified policy.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<SecurityPolicy> get(GetSecurityPolicyRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_get case final get?) {
    return get(request);
  }
  throw UnsupportedError('get');
}