listPreconfiguredExpressionSets method

Gets the current list of preconfigured Web Application Firewall (WAF) expressions.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<SecurityPoliciesListPreconfiguredExpressionSetsResponse>
listPreconfiguredExpressionSets(
  ListPreconfiguredExpressionSetsSecurityPoliciesRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_listPreconfiguredExpressionSets
      case final listPreconfiguredExpressionSets?) {
    return listPreconfiguredExpressionSets(request);
  }
  throw UnsupportedError('listPreconfiguredExpressionSets');
}