patchRule method

  1. @override
Future<Operation> patchRule(
  1. PatchRuleSecurityPolicyRequest request
)
override

Patches a rule at the specified priority. To clear fields in the rule, leave the fields empty and specify them in the updateMask.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> patchRule(PatchRuleSecurityPolicyRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_patchRule case final patchRule?) {
    return patchRule(request);
  }
  throw UnsupportedError('patchRule');
}