FakeServiceAttachments class base
Testing fake for ServiceAttachments.
- Implemented types
Constructors
-
FakeServiceAttachments({Future<
ServiceAttachmentAggregatedList> aggregatedList(AggregatedListServiceAttachmentsRequest request)?, Future<Operation> delete(DeleteServiceAttachmentRequest request)?, Future<ServiceAttachment> get(GetServiceAttachmentRequest request)?, Future<Policy> getIamPolicy(GetIamPolicyServiceAttachmentRequest request)?, Future<Operation> insert(InsertServiceAttachmentRequest request)?, Future<ServiceAttachmentList> list(ListServiceAttachmentsRequest request)?, Future<Operation> patch(PatchServiceAttachmentRequest request)?, Future<Policy> setIamPolicy(SetIamPolicyServiceAttachmentRequest request)?, Future<TestPermissionsResponse> testIamPermissions(TestIamPermissionsServiceAttachmentRequest request)?})
Properties
Methods
-
aggregatedList(
AggregatedListServiceAttachmentsRequest request) → Future< ServiceAttachmentAggregatedList> -
Retrieves the list of all ServiceAttachment resources,
regional and global, available to the specified project.
override
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
delete(
DeleteServiceAttachmentRequest request) → Future< Operation> -
Deletes the specified ServiceAttachment in the given scope
override
-
get(
GetServiceAttachmentRequest request) → Future< ServiceAttachment> -
Returns the specified ServiceAttachment resource in the given scope.
override
-
getIamPolicy(
GetIamPolicyServiceAttachmentRequest request) → Future< Policy> -
Gets the access control policy for a resource. May be empty if no such
policy or resource exists.
override
-
insert(
InsertServiceAttachmentRequest request) → Future< Operation> -
Creates a ServiceAttachment in the specified project in the given scope
using the parameters that are included in the request.
override
-
list(
ListServiceAttachmentsRequest request) → Future< ServiceAttachmentList> -
Lists the ServiceAttachments for a project in the given scope.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchServiceAttachmentRequest request) → Future< Operation> -
Patches the specified ServiceAttachment resource with the data included in
the request. This method supports PATCH
semantics and usesJSON merge
patch format and processing rules.
override
-
setIamPolicy(
SetIamPolicyServiceAttachmentRequest request) → Future< Policy> -
Sets the access control policy on the specified resource.
Replaces any existing policy.
override
-
testIamPermissions(
TestIamPermissionsServiceAttachmentRequest request) → Future< TestPermissionsResponse> -
Returns permissions that a caller has on the specified resource.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited