FakeSnapshotSettingsService class base
Testing fake for SnapshotSettingsService.
- Implemented types
Constructors
-
FakeSnapshotSettingsService({Future<
SnapshotSettings> get(GetSnapshotSettingRequest request)?, Future<Operation> patch(PatchSnapshotSettingRequest request)?})
Properties
Methods
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
get(
GetSnapshotSettingRequest request) → Future< SnapshotSettings> -
Get snapshot settings.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchSnapshotSettingRequest request) → Future< Operation> -
Patch snapshot settings.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited