FakeSslCertificates class base

Testing fake for SslCertificates.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(AggregatedListSslCertificatesRequest request) Future<SslCertificateAggregatedList>
Retrieves the list of all SslCertificate resources, regional and global, available to the specified project.
override
close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteSslCertificateRequest request) Future<Operation>
Deletes the specified SslCertificate resource.
override
get(GetSslCertificateRequest request) Future<SslCertificate>
Returns the specified SslCertificate resource.
override
insert(InsertSslCertificateRequest request) Future<Operation>
Creates a SslCertificate resource in the specified project using the data included in the request.
override
list(ListSslCertificatesRequest request) Future<SslCertificateList>
Retrieves the list of SslCertificate resources available to the specified project.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited