FakeStoragePools class base
Testing fake for StoragePools.
- Implemented types
Constructors
-
FakeStoragePools({Future<
StoragePoolAggregatedList> aggregatedList(AggregatedListStoragePoolsRequest request)?, Future<Operation> delete(DeleteStoragePoolRequest request)?, Future<StoragePool> get(GetStoragePoolRequest request)?, Future<Policy> getIamPolicy(GetIamPolicyStoragePoolRequest request)?, Future<Operation> insert(InsertStoragePoolRequest request)?, Future<StoragePoolList> list(ListStoragePoolsRequest request)?, Future<StoragePoolListDisks> listDisks(ListDisksStoragePoolsRequest request)?, Future<Policy> setIamPolicy(SetIamPolicyStoragePoolRequest request)?, Future<TestPermissionsResponse> testIamPermissions(TestIamPermissionsStoragePoolRequest request)?, Future<Operation> update(UpdateStoragePoolRequest request)?})
Properties
Methods
-
aggregatedList(
AggregatedListStoragePoolsRequest request) → Future< StoragePoolAggregatedList> -
Retrieves an aggregated list of storage pools.
override
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
delete(
DeleteStoragePoolRequest request) → Future< Operation> -
Deletes the specified storage pool. Deleting a storagePool
removes its data permanently and is irreversible. However, deleting a
storagePool does not delete any snapshots previously
made from the storagePool. You must separately delete
snapshots.
override
-
get(
GetStoragePoolRequest request) → Future< StoragePool> -
Returns a specified storage pool. Gets a list of available
storage pools by making a list() request.
override
-
getIamPolicy(
GetIamPolicyStoragePoolRequest request) → Future< Policy> -
Gets the access control policy for a resource. May be empty if no such
policy or resource exists.
override
-
insert(
InsertStoragePoolRequest request) → Future< Operation> -
Creates a storage pool in the specified project using the data
in the request.
override
-
list(
ListStoragePoolsRequest request) → Future< StoragePoolList> -
Retrieves a list of storage pools contained within
the specified zone.
override
-
listDisks(
ListDisksStoragePoolsRequest request) → Future< StoragePoolListDisks> -
Lists the disks in a specified storage pool.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setIamPolicy(
SetIamPolicyStoragePoolRequest request) → Future< Policy> -
Sets the access control policy on the specified resource.
Replaces any existing policy.
override
-
testIamPermissions(
TestIamPermissionsStoragePoolRequest request) → Future< TestPermissionsResponse> -
Returns permissions that a caller has on the specified resource.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
UpdateStoragePoolRequest request) → Future< Operation> -
Updates the specified storagePool with the data included in the request.
The update is performed only on selected fields included as part
of update-mask. Only the following fields can be modified:
pool_provisioned_capacity_gb, pool_provisioned_iops and
pool_provisioned_throughput.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited