delete method

  1. @override
Future<Operation> delete(
  1. DeleteStoragePoolRequest request
)
override

Deletes the specified storage pool. Deleting a storagePool removes its data permanently and is irreversible. However, deleting a storagePool does not delete any snapshots previously made from the storagePool. You must separately delete snapshots.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> delete(DeleteStoragePoolRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_delete case final delete?) {
    return delete(request);
  }
  throw UnsupportedError('delete');
}