get method

  1. @override
Future<StoragePool> get(
  1. GetStoragePoolRequest request
)
override

Returns a specified storage pool. Gets a list of available storage pools by making a list() request.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<StoragePool> get(GetStoragePoolRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_get case final get?) {
    return get(request);
  }
  throw UnsupportedError('get');
}