update method

  1. @override
Future<Operation> update(
  1. UpdateStoragePoolRequest request
)
override

Updates the specified storagePool with the data included in the request. The update is performed only on selected fields included as part of update-mask. Only the following fields can be modified: pool_provisioned_capacity_gb, pool_provisioned_iops and pool_provisioned_throughput.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> update(UpdateStoragePoolRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_update case final update?) {
    return update(request);
  }
  throw UnsupportedError('update');
}