expandIpCidrRange method

  1. @override
Future<Operation> expandIpCidrRange(
  1. ExpandIpCidrRangeSubnetworkRequest request
)
override

Expands the IP CIDR range of the subnetwork to a specified value.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> expandIpCidrRange(
  ExpandIpCidrRangeSubnetworkRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_expandIpCidrRange case final expandIpCidrRange?) {
    return expandIpCidrRange(request);
  }
  throw UnsupportedError('expandIpCidrRange');
}