patch method
Patches the specified subnetwork with the data included in the request. Only certain fields can be updated with a patch request as indicated in the field descriptions. You must specify the current fingerprint of the subnetwork resource being patched.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<Operation> patch(PatchSubnetworkRequest request) async {
if (isClosed) throw StateError('Service is closed');
if (_patch case final patch?) {
return patch(request);
}
throw UnsupportedError('patch');
}