setPrivateIpGoogleAccess method

  1. @override
Future<Operation> setPrivateIpGoogleAccess(
  1. SetPrivateIpGoogleAccessSubnetworkRequest request
)
override

Set whether VMs in this subnet can access Google services without assigning external IP addresses through Private Google Access.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> setPrivateIpGoogleAccess(
  SetPrivateIpGoogleAccessSubnetworkRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_setPrivateIpGoogleAccess case final setPrivateIpGoogleAccess?) {
    return setPrivateIpGoogleAccess(request);
  }
  throw UnsupportedError('setPrivateIpGoogleAccess');
}