FakeTargetGrpcProxies class base

Testing fake for TargetGrpcProxies.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteTargetGrpcProxyRequest request) Future<Operation>
Deletes the specified TargetGrpcProxy in the given scope
override
get(GetTargetGrpcProxyRequest request) Future<TargetGrpcProxy>
Returns the specified TargetGrpcProxy resource in the given scope.
override
insert(InsertTargetGrpcProxyRequest request) Future<Operation>
Creates a TargetGrpcProxy in the specified project in the given scope using the parameters that are included in the request.
override
list(ListTargetGrpcProxiesRequest request) Future<TargetGrpcProxyList>
Lists the TargetGrpcProxies for a project in the given scope.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(PatchTargetGrpcProxyRequest request) Future<Operation>
Patches the specified TargetGrpcProxy resource with the data included in the request. This method supports PATCH semantics and usesJSON merge patch format and processing rules.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited