FakeTargetHttpProxies class base
Testing fake for TargetHttpProxies.
- Implemented types
Constructors
-
FakeTargetHttpProxies({Future<
TargetHttpProxyAggregatedList> aggregatedList(AggregatedListTargetHttpProxiesRequest request)?, Future<Operation> delete(DeleteTargetHttpProxyRequest request)?, Future<TargetHttpProxy> get(GetTargetHttpProxyRequest request)?, Future<Operation> insert(InsertTargetHttpProxyRequest request)?, Future<TargetHttpProxyList> list(ListTargetHttpProxiesRequest request)?, Future<Operation> patch(PatchTargetHttpProxyRequest request)?, Future<Operation> setUrlMap(SetUrlMapTargetHttpProxyRequest request)?})
Properties
Methods
-
aggregatedList(
AggregatedListTargetHttpProxiesRequest request) → Future< TargetHttpProxyAggregatedList> -
Retrieves the list of all TargetHttpProxy resources, regional and global,
available to the specified project.
override
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
delete(
DeleteTargetHttpProxyRequest request) → Future< Operation> -
Deletes the specified TargetHttpProxy resource.
override
-
get(
GetTargetHttpProxyRequest request) → Future< TargetHttpProxy> -
Returns the specified TargetHttpProxy resource.
override
-
insert(
InsertTargetHttpProxyRequest request) → Future< Operation> -
Creates a TargetHttpProxy resource in the specified
project using the data included in the request.
override
-
list(
ListTargetHttpProxiesRequest request) → Future< TargetHttpProxyList> -
Retrieves the list of TargetHttpProxy resources available
to the specified project.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchTargetHttpProxyRequest request) → Future< Operation> -
Patches the specified TargetHttpProxy resource with the data included in
the request. This method supports PATCH
semantics and usesJSON merge
patch format and processing rules.
override
-
setUrlMap(
SetUrlMapTargetHttpProxyRequest request) → Future< Operation> -
Changes the URL map for TargetHttpProxy.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited