FakeTargetHttpsProxies class base

Testing fake for TargetHttpsProxies.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(AggregatedListTargetHttpsProxiesRequest request) Future<TargetHttpsProxyAggregatedList>
Retrieves the list of all TargetHttpsProxy resources, regional and global, available to the specified project.
override
close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteTargetHttpsProxyRequest request) Future<Operation>
Deletes the specified TargetHttpsProxy resource.
override
get(GetTargetHttpsProxyRequest request) Future<TargetHttpsProxy>
Returns the specified TargetHttpsProxy resource.
override
insert(InsertTargetHttpsProxyRequest request) Future<Operation>
Creates a TargetHttpsProxy resource in the specified project using the data included in the request.
override
list(ListTargetHttpsProxiesRequest request) Future<TargetHttpsProxyList>
Retrieves the list of TargetHttpsProxy resources available to the specified project.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(PatchTargetHttpsProxyRequest request) Future<Operation>
Patches the specified TargetHttpsProxy resource with the data included in the request. This method supports PATCH semantics and usesJSON merge patch format and processing rules.
override
setCertificateMap(SetCertificateMapTargetHttpsProxyRequest request) Future<Operation>
Changes the Certificate Map for TargetHttpsProxy.
override
setQuicOverride(SetQuicOverrideTargetHttpsProxyRequest request) Future<Operation>
Sets the QUIC override policy for TargetHttpsProxy.
override
setSslCertificates(SetSslCertificatesTargetHttpsProxyRequest request) Future<Operation>
Replaces SslCertificates for TargetHttpsProxy.
override
setSslPolicy(SetSslPolicyTargetHttpsProxyRequest request) Future<Operation>
Sets the SSL policy for TargetHttpsProxy. The SSL policy specifies the server-side support for SSL features. This affects connections between clients and the HTTPS proxy load balancer. They do not affect the connection between the load balancer and the backends.
override
setUrlMap(SetUrlMapTargetHttpsProxyRequest request) Future<Operation>
Changes the URL map for TargetHttpsProxy.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited