setSslPolicy method

  1. @override
Future<Operation> setSslPolicy(
  1. SetSslPolicyTargetHttpsProxyRequest request
)
override

Sets the SSL policy for TargetHttpsProxy. The SSL policy specifies the server-side support for SSL features. This affects connections between clients and the HTTPS proxy load balancer. They do not affect the connection between the load balancer and the backends.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> setSslPolicy(
  SetSslPolicyTargetHttpsProxyRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_setSslPolicy case final setSslPolicy?) {
    return setSslPolicy(request);
  }
  throw UnsupportedError('setSslPolicy');
}