setSecurityPolicy method

  1. @override
Future<Operation> setSecurityPolicy(
  1. SetSecurityPolicyTargetPoolRequest request
)
override

Sets the Google Cloud Armor security policy for the specified target pool. For more information, seeGoogle Cloud Armor Overview

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> setSecurityPolicy(
  SetSecurityPolicyTargetPoolRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_setSecurityPolicy case final setSecurityPolicy?) {
    return setSecurityPolicy(request);
  }
  throw UnsupportedError('setSecurityPolicy');
}