FakeTargetSslProxies class base

Testing fake for TargetSslProxies.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteTargetSslProxyRequest request) Future<Operation>
Deletes the specified TargetSslProxy resource.
override
get(GetTargetSslProxyRequest request) Future<TargetSslProxy>
Returns the specified TargetSslProxy resource.
override
insert(InsertTargetSslProxyRequest request) Future<Operation>
Creates a TargetSslProxy resource in the specified project using the data included in the request.
override
list(ListTargetSslProxiesRequest request) Future<TargetSslProxyList>
Retrieves the list of TargetSslProxy resources available to the specified project.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBackendService(SetBackendServiceTargetSslProxyRequest request) Future<Operation>
Changes the BackendService for TargetSslProxy.
override
setCertificateMap(SetCertificateMapTargetSslProxyRequest request) Future<Operation>
Changes the Certificate Map for TargetSslProxy.
override
setProxyHeader(SetProxyHeaderTargetSslProxyRequest request) Future<Operation>
Changes the ProxyHeaderType for TargetSslProxy.
override
setSslCertificates(SetSslCertificatesTargetSslProxyRequest request) Future<Operation>
Changes SslCertificates for TargetSslProxy.
override
setSslPolicy(SetSslPolicyTargetSslProxyRequest request) Future<Operation>
Sets the SSL policy for TargetSslProxy. The SSL policy specifies the server-side support for SSL features. This affects connections between clients and the load balancer. They do not affect the connection between the load balancer and the backends.
override
testIamPermissions(TestIamPermissionsTargetSslProxyRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited