FakeTargetTcpProxies class base

Testing fake for TargetTcpProxies.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(AggregatedListTargetTcpProxiesRequest request) Future<TargetTcpProxyAggregatedList>
Retrieves the list of all TargetTcpProxy resources, regional and global, available to the specified project.
override
close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteTargetTcpProxyRequest request) Future<Operation>
Deletes the specified TargetTcpProxy resource.
override
get(GetTargetTcpProxyRequest request) Future<TargetTcpProxy>
Returns the specified TargetTcpProxy resource.
override
insert(InsertTargetTcpProxyRequest request) Future<Operation>
Creates a TargetTcpProxy resource in the specified project using the data included in the request.
override
list(ListTargetTcpProxiesRequest request) Future<TargetTcpProxyList>
Retrieves the list of TargetTcpProxy resources available to the specified project.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBackendService(SetBackendServiceTargetTcpProxyRequest request) Future<Operation>
Changes the BackendService for TargetTcpProxy.
override
setProxyHeader(SetProxyHeaderTargetTcpProxyRequest request) Future<Operation>
Changes the ProxyHeaderType for TargetTcpProxy.
override
testIamPermissions(TestIamPermissionsTargetTcpProxyRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited