FakeUrlMaps class base

Testing fake for UrlMaps.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(AggregatedListUrlMapsRequest request) Future<UrlMapsAggregatedList>
Retrieves the list of all UrlMap resources, regional and global, available to the specified project.
override
close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteUrlMapRequest request) Future<Operation>
Deletes the specified UrlMap resource.
override
get(GetUrlMapRequest request) Future<UrlMap>
Returns the specified UrlMap resource.
override
insert(InsertUrlMapRequest request) Future<Operation>
Creates a UrlMap resource in the specified project using the data included in the request.
override
invalidateCache(InvalidateCacheUrlMapRequest request) Future<Operation>
Initiates a cache invalidation operation, invalidating the specified path, scoped to the specified UrlMap.
override
list(ListUrlMapsRequest request) Future<UrlMapList>
Retrieves the list of UrlMap resources available to the specified project.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(PatchUrlMapRequest request) Future<Operation>
Patches the specified UrlMap resource with the data included in the request. This method supportsPATCH semantics and uses theJSON merge patch format and processing rules.
override
testIamPermissions(TestIamPermissionsUrlMapRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
override
toString() String
A string representation of this object.
inherited
update(UpdateUrlMapRequest request) Future<Operation>
Updates the specified UrlMap resource with the data included in the request.
override
validate(ValidateUrlMapRequest request) Future<UrlMapsValidateResponse>
Runs static validation for the UrlMap. In particular, the tests of the provided UrlMap will be run. Calling this method does NOT create the UrlMap.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited