invalidateCache method

  1. @override
Future<Operation> invalidateCache(
  1. InvalidateCacheUrlMapRequest request
)
override

Initiates a cache invalidation operation, invalidating the specified path, scoped to the specified UrlMap.

For more information, see Invalidating cached content.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> invalidateCache(
  InvalidateCacheUrlMapRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_invalidateCache case final invalidateCache?) {
    return invalidateCache(request);
  }
  throw UnsupportedError('invalidateCache');
}