update method

  1. @override
Future<Operation> update(
  1. UpdateUrlMapRequest request
)
override

Updates the specified UrlMap resource with the data included in the request.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> update(UpdateUrlMapRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_update case final update?) {
    return update(request);
  }
  throw UnsupportedError('update');
}