insert method

  1. @override
Future<Operation> insert(
  1. InsertVpnGatewayRequest request
)
override

Creates a VPN gateway in the specified project and region using the data included in the request.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> insert(InsertVpnGatewayRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_insert case final insert?) {
    return insert(request);
  }
  throw UnsupportedError('insert');
}