testIamPermissions method

Returns permissions that a caller has on the specified resource.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<TestPermissionsResponse> testIamPermissions(
  TestIamPermissionsVpnGatewayRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_testIamPermissions case final testIamPermissions?) {
    return testIamPermissions(request);
  }
  throw UnsupportedError('testIamPermissions');
}