FakeVpnTunnels class base

Testing fake for VpnTunnels.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(AggregatedListVpnTunnelsRequest request) Future<VpnTunnelAggregatedList>
Retrieves an aggregated list of VPN tunnels.
override
close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteVpnTunnelRequest request) Future<Operation>
Deletes the specified VpnTunnel resource.
override
get(GetVpnTunnelRequest request) Future<VpnTunnel>
Returns the specified VpnTunnel resource.
override
insert(InsertVpnTunnelRequest request) Future<Operation>
Creates a VpnTunnel resource in the specified project and region using the data included in the request.
override
list(ListVpnTunnelsRequest request) Future<VpnTunnelList>
Retrieves a list of VpnTunnel resources contained in the specified project and region.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setLabels(SetLabelsVpnTunnelRequest request) Future<Operation>
Sets the labels on a VpnTunnel. To learn more about labels, read theLabeling Resources documentation.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited