list method

  1. @override
Future<VpnTunnelList> list(
  1. ListVpnTunnelsRequest request
)
override

Retrieves a list of VpnTunnel resources contained in the specified project and region.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<VpnTunnelList> list(ListVpnTunnelsRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_list case final list?) {
    return list(request);
  }
  throw UnsupportedError('list');
}