FakeZoneVmExtensionPolicies class base

Testing fake for ZoneVmExtensionPolicies.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteZoneVmExtensionPolicyRequest request) Future<Operation>
Deletes a specified zone VM extension policy within a project.
override
get(GetZoneVmExtensionPolicyRequest request) Future<VmExtensionPolicy>
Retrieves details of a specific zone VM extension policy within a project.
override
insert(InsertZoneVmExtensionPolicyRequest request) Future<Operation>
Creates a new zone-level VM extension policy within a project.
override
list(ListZoneVmExtensionPoliciesRequest request) Future<VmExtensionPolicyList>
Lists all VM extension policies within a specific zone for a project.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(UpdateZoneVmExtensionPolicyRequest request) Future<Operation>
Modifies an existing zone VM extension policy within a project.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited