FakeZones class base
Testing fake for Zones.
- Implemented types
Constructors
-
FakeZones({Future<
Zone> get(GetZoneRequest request)?, Future<ZoneList> list(ListZonesRequest request)?})
Properties
Methods
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
get(
GetZoneRequest request) → Future< Zone> -
Returns the specified Zone resource.
override
-
list(
ListZonesRequest request) → Future< ZoneList> -
Retrieves the list of Zone resources available to the specified project.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited