AcceleratorConfig class final
A specification of the type and number of accelerator cards attached to the instance.
Constructors
- AcceleratorConfig({int? acceleratorCount, String? acceleratorType})
- AcceleratorConfig.fromJson(Object? j)
-
factory
Properties
- acceleratorCount → int?
-
The number of the guest accelerator cards exposed to this instance.
final
- acceleratorType → String?
-
Full or partial URL of the accelerator type resource to attach to this
instance. For example:projects/my-project/zones/us-central1-c/acceleratorTypes/nvidia-tesla-p100
If you are creating an instance template, specify only the
accelerator name.
See GPUs on Compute Engine
for a full list of accelerator types.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String