AccessConfig_NetworkTier class final
This signifies the networking tier used for configuring this access configuration and can only take the following values: PREMIUM,STANDARD.
If an AccessConfig is specified without a valid external IP address, an ephemeral IP will be created with this networkTier.
If an AccessConfig with a valid external IP address is specified, it must match that of the networkTier associated with the Address resource owning that IP.
Constructors
- AccessConfig_NetworkTier(String value)
-
const
- AccessConfig_NetworkTier.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const AccessConfig_NetworkTier
- The default value for AccessConfig_NetworkTier.
- fixedStandard → const AccessConfig_NetworkTier
- Public internet quality with fixed bandwidth.
- High quality, Google-grade network tier, support for all networking products.
- standard → const AccessConfig_NetworkTier
- Public internet quality, only limited support for other networking products.
- standardOverridesFixedStandard → const AccessConfig_NetworkTier
- (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier is expired or not configured.
- undefinedNetworkTier → const AccessConfig_NetworkTier
- A value indicating that the enum field is not set.