AddAssociationFirewallPolicyRequest class final

A request message for FirewallPolicies.AddAssociation. See the method description for details.

Constructors

AddAssociationFirewallPolicyRequest({required String firewallPolicy, required FirewallPolicyAssociation? firewallPolicyAssociationResource, bool? replaceExistingAssociation, String? requestId})
AddAssociationFirewallPolicyRequest.fromJson(Object? j)
factory

Properties

firewallPolicy String
Name of the firewall policy to update.
final
firewallPolicyAssociationResource FirewallPolicyAssociation?
The body resource for this request
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
replaceExistingAssociation bool?
Indicates whether or not to replace it if an association of the attachment already exists. This is false by default, in which case an error will be returned if an association already exists.
final
requestId String?
An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String