region property
Output only. Output Only The URL of the region where a regional address resides.
For regional addresses, you must specify the region as a path parameter in
the HTTP request URL. This field is not applicable to global
addresses.
Implementation
final String? region;