status property
Output only. Output Only The status of the address, which can be one ofRESERVING, RESERVED, or IN_USE.
An address that is RESERVING is currently in the process of
being reserved. A RESERVED address is currently reserved and
available to use. An IN_USE address is currently being used
by another resource and is not available.
Check the Status enum for the list of possible values.
Implementation
final String? status;