Addresses class final

The Addresses API.

Implementers

Constructors

Addresses({required Client client, Uri? endPoint, String? gcclVersion})
Creates a Addresses using client for transport.
Addresses.fromApiKey([String? apiKey])
Creates a Addresses that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(AggregatedListAddressesRequest request) Future<AddressAggregatedList>
Retrieves an aggregated list of addresses.
close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteAddressRequest request) Future<Operation>
Deletes the specified address resource.
get(GetAddressRequest request) Future<Address>
Returns the specified address resource.
insert(InsertAddressRequest request) Future<Operation>
Creates an address resource in the specified project by using the data included in the request.
list(ListAddressesRequest request) Future<AddressList>
Retrieves a list of addresses contained within the specified region.
move(MoveAddressRequest request) Future<Operation>
Moves the specified address resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setLabels(SetLabelsAddressRequest request) Future<Operation>
Sets the labels on an Address. To learn more about labels, read theLabeling Resources documentation.
testIamPermissions(TestIamPermissionsAddressRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited