Advice class final
The Advice API.
- Implementers
Constructors
- Advice({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
Adviceusingclientfor transport. - Advice.fromApiKey([String? apiKey])
-
Creates a
Advicethat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
calendarMode(
CalendarModeAdviceRpcRequest request) → Future< CalendarModeAdviceResponse> - Advise how, where and when to create the requested amount of instances with specified accelerators, within the specified time and location limits. The method recommends creating future reservations for the requested resources.
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited