AliasIpRange class final
An alias IP range attached to an instance's network interface.
Constructors
- AliasIpRange({String? ipCidrRange, String? subnetworkRangeName})
- AliasIpRange.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ipCidrRange → String?
-
The IP alias ranges to allocate for this interface. This IP CIDR range
must belong to the specified subnetwork and cannot contain IP addresses
reserved by system or used by other network interfaces. This range may be
a single IP address (such as 10.2.3.4), a netmask (such as/24) or a CIDR-formatted string (such as10.1.2.0/24).
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subnetworkRangeName → String?
-
The name of a subnetwork secondary IP range from which to allocate an IP
alias range. If not specified, the primary range of the subnetwork is used.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String