AllocationResourceStatus class final
Output Only Contains output only fields.
Constructors
- AllocationResourceStatus({AllocationResourceStatusHealthInfo? healthInfo, int? reservationBlockCount, GroupMaintenanceInfo? reservationMaintenance, AllocationResourceStatusSpecificSkuallocation? specificSkuAllocation})
- AllocationResourceStatus.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- healthInfo → AllocationResourceStatusHealthInfo?
-
Output onlyHealth information for the reservation.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - reservationBlockCount → int?
-
The number of reservation blocks associated with this reservation.
final
- reservationMaintenance → GroupMaintenanceInfo?
-
Maintenance information for this reservation
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- specificSkuAllocation → AllocationResourceStatusSpecificSkuallocation?
-
Allocation Properties of this reservation.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String