AllocationResourceStatusSpecificSkuallocation class final
Contains Properties set for the reservation.
Constructors
-
AllocationResourceStatusSpecificSkuallocation({String? sourceInstanceTemplateId, Map<
String, int> utilizations = const {}}) - AllocationResourceStatusSpecificSkuallocation.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceInstanceTemplateId → String?
-
ID of the instance template used to populate reservation properties.
final
-
utilizations
→ Map<
String, int> -
Per service utilization breakdown. The Key is the Google Cloud managed
service name.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String