menu
google_cloud_compute_v1 package
documentation
compute.dart
AllocationSpecificSkuallocationAllocatedInstancePropertiesReservedDisk class
AllocationSpecificSkuallocationAllocatedInstancePropertiesReservedDisk class
dark_mode
light_mode
AllocationSpecificSkuallocationAllocatedInstancePropertiesReservedDisk
class
final
Constructors
AllocationSpecificSkuallocationAllocatedInstancePropertiesReservedDisk
({
int
?
diskSizeGb
,
String
?
interface
})
AllocationSpecificSkuallocationAllocatedInstancePropertiesReservedDisk.fromJson
(
Object
?
j
)
factory
Properties
diskSizeGb
→
int
?
Specifies the size of the disk in base-2 GB.
final
hashCode
→
int
The hash code for this object.
no setter
inherited
interface
→
String
?
Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. The default isSCSI. For performance characteristics of SCSI over NVMe, seeLocal SSD performance. Check the Interface enum for the list of possible values.
final
qualifiedName
→
String
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or
google.rpc.ErrorInfo
.
final
inherited
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson
(
)
→
Object
toString
(
)
→
String
A string representation of this object.
override
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
Constants
fullyQualifiedName
→ const
String
google_cloud_compute_v1 package
documentation
compute
AllocationSpecificSkuallocationAllocatedInstancePropertiesReservedDisk class
compute library