index property
Output only. Output Only A zero-based index to this disk, where 0 is reserved for the
boot disk. If you have many disks attached to an instance, each
disk would have a unique index number.
Implementation
final int? index;
Output only. Output Only A zero-based index to this disk, where 0 is reserved for the
boot disk. If you have many disks attached to an instance, each
disk would have a unique index number.
final int? index;