AttachedDisk_Interface class final
Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. For most machine types, the default is SCSI. Local SSDs can use either NVME or SCSI. In certain configurations, persistent disks can use NVMe. For more information, seeAbout persistent disks.
Constructors
- AttachedDisk_Interface(String value)
-
const
- AttachedDisk_Interface.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const AttachedDisk_Interface
- The default value for AttachedDisk_Interface.
- nvme → const AttachedDisk_Interface
- scsi → const AttachedDisk_Interface
- undefinedInterface → const AttachedDisk_Interface
- A value indicating that the enum field is not set.