autoscalingPolicy property
The configuration parameters for the autoscaling algorithm. You can define one or more signals for an autoscaler: cpuUtilization,customMetricUtilizations, andloadBalancingUtilization.
If none of these are specified, the default will be to autoscale based oncpuUtilization to 0.6 or 60%.
Implementation
final AutoscalingPolicy? autoscalingPolicy;