Autoscaler_Status class final
Output Only The status of the autoscaler configuration. Current set of
possible values:
- PENDING: Autoscaler backend hasn't read new/updated configuration.
- DELETING: Configuration is being deleted.
- ACTIVE: Configuration is acknowledged to be effective. Some warnings might be present in the statusDetails field.
- ERROR: Configuration has errors. Actionable for users. Details are present in the statusDetails field.
New values might be added in the future.
Constructors
- Autoscaler_Status(String value)
-
const
- Autoscaler_Status.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const Autoscaler_Status
- The default value for Autoscaler_Status.
- active → const Autoscaler_Status
- Configuration is acknowledged to be effective
- deleting → const Autoscaler_Status
- Configuration is being deleted
- error → const Autoscaler_Status
- Configuration has errors. Actionable for users.
- pending → const Autoscaler_Status
- Autoscaler backend hasn't read new/updated configuration
- undefinedStatus → const Autoscaler_Status
- A value indicating that the enum field is not set.