Autoscalers class final
The Autoscalers API.
- Implementers
Constructors
- Autoscalers({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
Autoscalersusingclientfor transport. - Autoscalers.fromApiKey([String? apiKey])
-
Creates a
Autoscalersthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
aggregatedList(
AggregatedListAutoscalersRequest request) → Future< AutoscalerAggregatedList> - Retrieves an aggregated list of autoscalers.
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteAutoscalerRequest request) → Future< Operation> - Deletes the specified autoscaler.
-
get(
GetAutoscalerRequest request) → Future< Autoscaler> - Returns the specified autoscaler resource.
-
insert(
InsertAutoscalerRequest request) → Future< Operation> - Creates an autoscaler in the specified project using the data included in the request.
-
list(
ListAutoscalersRequest request) → Future< AutoscalerList> - Retrieves a list of autoscalers contained within the specified zone.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchAutoscalerRequest request) → Future< Operation> - Updates an autoscaler in the specified project using the data included in the request. This method supportsPATCH semantics and uses theJSON merge patch format and processing rules.
-
testIamPermissions(
TestIamPermissionsAutoscalerRequest request) → Future< TestPermissionsResponse> - Returns permissions that a caller has on the specified resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
UpdateAutoscalerRequest request) → Future< Operation> - Updates an autoscaler in the specified project using the data included in the request.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited