AutoscalingPolicyCustomMetricUtilization class final
Custom utilization metric policy.
Constructors
- AutoscalingPolicyCustomMetricUtilization({String? filter, String? metric, double? singleInstanceAssignment, double? utilizationTarget, String? utilizationTargetType})
- AutoscalingPolicyCustomMetricUtilization.fromJson(Object? j)
-
factory
Properties
- filter → String?
-
A filter string, compatible with a Stackdriver Monitoringfilter string forTimeSeries.list API call. This filter is
used to select a specific TimeSeries for the purpose of autoscaling and
to determine whether the metric is exporting per-instance or
per-group data.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- metric → String?
-
The identifier (type) of the Stackdriver Monitoring metric. The metric
cannot have negative values.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- singleInstanceAssignment → double?
-
If scaling is based on a per-group metric value that represents the
total amount of work to be done or resource usage, set this value to an
amount assigned for a single instance of the scaled group. Autoscaler
keeps the number of instances proportional to the value of this
metric. The metric itself does not change value due to group
resizing.
final
- utilizationTarget → double?
-
The target value of the metric that autoscaler maintains. This
must be a positive value. A utilization metric scales number of
virtual machines handling requests to increase or decrease
proportionally to the metric.
final
- utilizationTargetType → String?
-
Defines how target utilization value is expressed for a Stackdriver
Monitoring metric. Either GAUGE,DELTA_PER_SECOND, or DELTA_PER_MINUTE.
Check the UtilizationTargetType enum for the list of possible values.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String