AutoscalingPolicyLoadBalancingUtilization class final
Configuration parameters of autoscaling based on load balancing.
Constructors
- AutoscalingPolicyLoadBalancingUtilization({double? utilizationTarget})
- AutoscalingPolicyLoadBalancingUtilization.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- utilizationTarget → double?
-
Fraction of backend capacity utilization (set in HTTP(S) load balancing
configuration) that the autoscaler maintains. Must be a positive float
value. If not defined, the default is 0.8.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String