timeWindowSec property
How far back autoscaling looks when computing recommendations to include directives regarding slower scale in, as described above.
Implementation
final int? timeWindowSec;
How far back autoscaling looks when computing recommendations to include directives regarding slower scale in, as described above.
final int? timeWindowSec;