AutoscalingPolicy_Mode class final
Defines the operating mode for this policy. The following modes are available:
- OFF: Disables the autoscaler but maintains its configuration.
- ONLY_SCALE_OUT: Restricts the autoscaler to add VM instances only.
- ON: Enables all autoscaler activities according to its policy.
For more information, see "Turning off or restricting an autoscaler"
Constructors
- AutoscalingPolicy_Mode(String value)
-
const
- AutoscalingPolicy_Mode.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const AutoscalingPolicy_Mode
- The default value for AutoscalingPolicy_Mode.
- off → const AutoscalingPolicy_Mode
- Do not automatically scale the MIG in or out. The recommended_size field contains the size of MIG that would be set if the actuation mode was enabled.
- on → const AutoscalingPolicy_Mode
- Automatically scale the MIG in and out according to the policy.
- onlyScaleOut → const AutoscalingPolicy_Mode
- Automatically create VMs according to the policy, but do not scale the MIG in.
- onlyUp → const AutoscalingPolicy_Mode
- Automatically create VMs according to the policy, but do not scale the MIG in. It's recommended to use ONLY_SCALE_OUT instead of ONLY_UP.
- undefinedMode → const AutoscalingPolicy_Mode
- A value indicating that the enum field is not set.