Awsv4Signature class final
Messages
Contains the configurations necessary to generate a signature for access to private storage buckets that support Signature Version 4 for authentication. The service name for generating the authentication header will always default to 's3'.
Constructors
- Awsv4Signature({String? accessKey, String? accessKeyId, String? accessKeyVersion, String? originRegion})
- Awsv4Signature.fromJson(Object? j)
-
factory
Properties
- accessKey → String?
-
The access key used for s3 bucket authentication. Required for updating or
creating a backend that uses AWS v4 signature authentication, but will not
be returned as part of the configuration when queried with a REST API GET
request.
final
- accessKeyId → String?
-
The identifier of an access key used for s3 bucket authentication.
final
- accessKeyVersion → String?
-
The optional version identifier for the access key. You can use this to
keep track of different iterations of your access key.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- originRegion → String?
-
The name of the cloud region of your origin. This is a free-form field with
the name of the region your cloud uses to host your origin. For example,
"us-east-1" for AWS or "us-ashburn-1" for OCI.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String