failover property

bool? failover
final

This field designates whether this is a failover backend. More than one failover backend can be configured for a given BackendService.

Implementation

final bool? failover;