failover property
This field designates whether this is a failover backend. More than one failover backend can be configured for a given BackendService.
Implementation
final bool? failover;
This field designates whether this is a failover backend. More than one failover backend can be configured for a given BackendService.
final bool? failover;