BackendCustomMetric class final
Custom Metrics are used for CUSTOM_METRICS balancing_mode.
Constructors
- BackendCustomMetric({bool? dryRun, double? maxUtilization, String? name})
- BackendCustomMetric.fromJson(Object? j)
-
factory
Properties
- dryRun → bool?
-
If true, the metric data is collected and reported to Cloud
Monitoring, but is not used for load balancing.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxUtilization → double?
-
Optional parameter to define a target utilization for the Custom Metrics
balancing mode. The valid range is
0.0, 1.0.final - name → String?
-
Name of a custom utilization signal. The name must be 1-64 characters
long and match the regular expression
[a-z]([-_.a-z0-9]*[a-z0-9])?which means that the first character must be a lowercase letter, and all following characters must be a dash, period, underscore, lowercase letter, or digit, except the last character, which cannot be a dash, period, or underscore. For usage guidelines, see Custom Metrics balancing mode. This field can only be used for a global or regional backend service with the loadBalancingScheme set to EXTERNAL_MANAGED,INTERNAL_MANAGED INTERNAL_SELF_MANAGED.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String