failoverPolicy property
Requires at least one backend instance group to be defined as a backup (failover) backend. For load balancers that have configurable failover: Internal passthrough Network Load Balancers and external passthrough Network Load Balancers.
failoverPolicy cannot be specified with haPolicy.
Implementation
final BackendServiceFailoverPolicy? failoverPolicy;