serviceBindings property
URLs of networkservices.ServiceBinding resources.
Can only be set if load balancing scheme is INTERNAL_SELF_MANAGED. If set, lists of backends and health checks must be both empty.
Implementation
final List<String> serviceBindings;