BackendServiceCdnPolicy_CacheMode class final
Specifies the cache setting for all responses from this backend. The possible values are:USE_ORIGIN_HEADERS Requires the origin to set valid caching headers to cache content. Responses without these headers will not be cached at Google's edge, and will require a full trip to the origin on every request, potentially impacting performance and increasing load on the origin server.FORCE_CACHE_ALL Cache all content, ignoring any "private", "no-store" or "no-cache" directives in Cache-Control response headers. Warning: this may result in Cloud CDN caching private, per-user (user identifiable) content.CACHE_ALL_STATIC Automatically cache static content, including common image formats, media (video and audio), and web assets (JavaScript and CSS). Requests and responses that are marked as uncacheable, as well as dynamic content (including HTML), will not be cached.
If no value is provided for cdnPolicy.cacheMode, it defaults to CACHE_ALL_STATIC.
Constructors
- BackendServiceCdnPolicy_CacheMode(String value)
-
const
- BackendServiceCdnPolicy_CacheMode.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const BackendServiceCdnPolicy_CacheMode
- The default value for BackendServiceCdnPolicy_CacheMode.
- cacheAllStatic → const BackendServiceCdnPolicy_CacheMode
- Automatically cache static content, including common image formats, media (video and audio), and web assets (JavaScript and CSS). Requests and responses that are marked as uncacheable, as well as dynamic content (including HTML), will not be cached.
- forceCacheAll → const BackendServiceCdnPolicy_CacheMode
- Cache all content, ignoring any "private", "no-store" or "no-cache" directives in Cache-Control response headers. Warning: this may result in Cloud CDN caching private, per-user (user identifiable) content.
- invalidCacheMode → const BackendServiceCdnPolicy_CacheMode
- undefinedCacheMode → const BackendServiceCdnPolicy_CacheMode
- A value indicating that the enum field is not set.
- useOriginHeaders → const BackendServiceCdnPolicy_CacheMode
- Requires the origin to set valid caching headers to cache content. Responses without these headers will not be cached at Google's edge, and will require a full trip to the origin on every request, potentially impacting performance and increasing load on the origin server.