BackendServiceConnectionTrackingPolicy_TrackingMode class final
Specifies the key used for connection tracking. There are two options:
- PER_CONNECTION: This is the default mode. The Connection Tracking is performed as per the Connection Key (default Hash Method) for the specific protocol.
- PER_SESSION: The Connection Tracking is performed as per the configured Session Affinity. It matches the configured Session Affinity.
For more details, see Tracking Mode for Network Load Balancing and Tracking Mode for Internal TCP/UDP Load Balancing.
Constructors
- BackendServiceConnectionTrackingPolicy_TrackingMode(String value)
-
const
- BackendServiceConnectionTrackingPolicy_TrackingMode.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const BackendServiceConnectionTrackingPolicy_TrackingMode
- The default value for BackendServiceConnectionTrackingPolicy_TrackingMode.
- invalidTrackingMode → const BackendServiceConnectionTrackingPolicy_TrackingMode
- perConnection → const BackendServiceConnectionTrackingPolicy_TrackingMode
- perSession → const BackendServiceConnectionTrackingPolicy_TrackingMode
- undefinedTrackingMode → const BackendServiceConnectionTrackingPolicy_TrackingMode
- A value indicating that the enum field is not set.