BackendServiceHapolicyLeader class final
Constructors
- BackendServiceHapolicyLeader({String? backendGroup, BackendServiceHapolicyLeaderNetworkEndpoint? networkEndpoint})
- BackendServiceHapolicyLeader.fromJson(Object? j)
-
factory
Properties
- backendGroup → String?
-
A fully-qualified URL (starting with https://www.googleapis.com/)
of the zonal Network Endpoint Group (NEG) with
GCE_VM_IPendpoints that the leader is attached to.final - hashCode → int
-
The hash code for this object.
no setterinherited
- networkEndpoint → BackendServiceHapolicyLeaderNetworkEndpoint?
-
The network endpoint within the leader.backendGroup that is
designated as the leader.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String