weightedRoundRobin constant
BackendServiceLocalityLoadBalancingPolicyConfigPolicy_Name
const weightedRoundRobin
Per-endpoint weighted round-robin Load Balancing using weights computed from Backend reported Custom Metrics. If set, the Backend Service responses are expected to contain non-standard HTTP response header field Endpoint-Load-Metrics. The reported metrics to use for computing the weights are specified via the customMetrics fields.
Implementation
static const weightedRoundRobin =
BackendServiceLocalityLoadBalancingPolicyConfigPolicy_Name(
'WEIGHTED_ROUND_ROBIN',
);