BackendServiceLogConfig class final
The available logging options for the load balancer traffic served by this backend service.
Constructors
-
BackendServiceLogConfig({bool? enable, List<
BackendServiceLogConfigLoggingHttpHeader> loggingHttpRequestHeaders = const [], List<BackendServiceLogConfigLoggingHttpHeader> loggingHttpResponseHeaders = const [], List<String> optionalFields = const [], String? optionalMode, double? sampleRate}) - BackendServiceLogConfig.fromJson(Object? j)
-
factory
Properties
- enable → bool?
-
Denotes whether to enable logging for the load balancer
traffic served by this backend service. The default value is false.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
loggingHttpRequestHeaders
→ List<
BackendServiceLogConfigLoggingHttpHeader> -
The list of request headers that will be logged to Stackdriver.
final
-
loggingHttpResponseHeaders
→ List<
BackendServiceLogConfigLoggingHttpHeader> -
The list of response headers that will be logged to Stackdriver.
final
-
optionalFields
→ List<
String> -
This field can only be specified if logging is enabled for this backend
service and "logConfig.optionalMode" was set to CUSTOM. Contains a list
of optional fields you want to include in the logs. For example:
serverInstance, serverGkeDetails.cluster,
serverGkeDetails.pod.podNamespace
final
- optionalMode → String?
-
This field can only be specified if logging is enabled for this backend
service. Configures whether all, none or a subset of optional fields
should be added to the reported logs. One of
INCLUDE_ALL_OPTIONAL, EXCLUDE_ALL_OPTIONAL, CUSTOM. Default is EXCLUDE_ALL_OPTIONAL. Check the OptionalMode enum for the list of possible values.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleRate → double?
-
This field can only be specified if logging is enabled for this backend
service. The value of the field must be in
0, 1. This configures the sampling rate of requests to the load balancer where 1.0 means all logged requests are reported and 0.0 means no logged requests are reported. The default value is 1.0.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String