BackendServiceLogConfig_OptionalMode class final

This field can only be specified if logging is enabled for this backend service. Configures whether all, none or a subset of optional fields should be added to the reported logs. One of INCLUDE_ALL_OPTIONAL, EXCLUDE_ALL_OPTIONAL, CUSTOM. Default is EXCLUDE_ALL_OPTIONAL.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const BackendServiceLogConfig_OptionalMode
The default value for BackendServiceLogConfig_OptionalMode.
custom → const BackendServiceLogConfig_OptionalMode
A subset of optional fields.
excludeAllOptional → const BackendServiceLogConfig_OptionalMode
None optional fields.
includeAllOptional → const BackendServiceLogConfig_OptionalMode
All optional fields.
undefinedOptionalMode → const BackendServiceLogConfig_OptionalMode
A value indicating that the enum field is not set.