BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity_Spillover class final
This field indicates whether zonal affinity is enabled or not. The possible values are:
- ZONAL_AFFINITY_DISABLED: Default Value. Zonal Affinity is disabled. The load balancer distributes new connections to all healthy backend endpoints across all zones.
- ZONAL_AFFINITY_STAY_WITHIN_ZONE: Zonal Affinity is enabled. The load balancer distributes new connections to all healthy backend endpoints in the local zone only. If there are no healthy backend endpoints in the local zone, the load balancer distributes new connections to all backend endpoints in the local zone.
- ZONAL_AFFINITY_SPILL_CROSS_ZONE: Zonal Affinity is enabled. The load balancer distributes new connections to all healthy backend endpoints in the local zone only. If there aren't enough healthy backend endpoints in the local zone, the load balancer distributes new connections to all healthy backend endpoints across all zones.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity_Spillover
- The default value for BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity_Spillover.
- undefinedSpillover → const BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity_Spillover
- A value indicating that the enum field is not set.
- zonalAffinityDisabled → const BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity_Spillover
- zonalAffinitySpillCrossZone → const BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity_Spillover
- zonalAffinityStayWithinZone → const BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity_Spillover