BackendService_IpAddressSelectionPolicy class final
Specifies a preference for traffic sent from the proxy to the backend (or from the client to the backend for proxyless gRPC). The possible values are:
- IPV4_ONLY: Only send IPv4 traffic to the backends of the backend service (Instance Group, Managed Instance Group, Network Endpoint Group), regardless of traffic from the client to the proxy. Only IPv4 health checks are used to check the health of the backends. This is the default setting.
- PREFER_IPV6: Prioritize the connection to the endpoint's IPv6 address over its IPv4 address (provided there is a healthy IPv6 address).
- IPV6_ONLY: Only send IPv6 traffic to the backends of the backend service (Instance Group, Managed Instance Group, Network Endpoint Group), regardless of traffic from the client to the proxy. Only IPv6 health checks are used to check the health of the backends.
This field is applicable to either:
- Advanced global external Application Load Balancer (load balancing scheme EXTERNAL_MANAGED),
- Regional external Application Load Balancer,
- Internal proxy Network Load Balancer (load balancing scheme INTERNAL_MANAGED),
- Regional internal Application Load Balancer (load balancing scheme INTERNAL_MANAGED),
- Traffic Director with Envoy proxies and proxyless gRPC (load balancing scheme INTERNAL_SELF_MANAGED).
Constructors
- BackendService_IpAddressSelectionPolicy(String value)
-
const
- BackendService_IpAddressSelectionPolicy.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const BackendService_IpAddressSelectionPolicy
- The default value for BackendService_IpAddressSelectionPolicy.
- ipAddressSelectionPolicyUnspecified → const BackendService_IpAddressSelectionPolicy
- Unspecified IP address selection policy.
- ipv4Only → const BackendService_IpAddressSelectionPolicy
- Only send IPv4 traffic to the backends of the Backend Service (Instance Group, Managed Instance Group, Network Endpoint Group) regardless of traffic from the client to the proxy. Only IPv4 health-checks are used to check the health of the backends. This is the default setting.
- ipv6Only → const BackendService_IpAddressSelectionPolicy
- Only send IPv6 traffic to the backends of the Backend Service (Instance Group, Managed Instance Group, Network Endpoint Group) regardless of traffic from the client to the proxy. Only IPv6 health-checks are used to check the health of the backends.
- preferIpv6 → const BackendService_IpAddressSelectionPolicy
- Prioritize the connection to the endpoints IPv6 address over its IPv4 address (provided there is a healthy IPv6 address).
- undefinedIpAddressSelectionPolicy → const BackendService_IpAddressSelectionPolicy
- A value indicating that the enum field is not set.