ipv6Only constant
BackendService_IpAddressSelectionPolicy
const ipv6Only
Only send IPv6 traffic to the backends of the Backend Service (Instance Group, Managed Instance Group, Network Endpoint Group) regardless of traffic from the client to the proxy. Only IPv6 health-checks are used to check the health of the backends.
Implementation
static const ipv6Only = BackendService_IpAddressSelectionPolicy('IPV6_ONLY');