BackendService_LoadBalancingScheme class final
Specifies the load balancer type. A backend service created for one type of load balancer cannot be used with another. For more information, refer toChoosing a load balancer.
Constructors
- BackendService_LoadBalancingScheme(String value)
-
const
- BackendService_LoadBalancingScheme.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const BackendService_LoadBalancingScheme
- The default value for BackendService_LoadBalancingScheme.
- external → const BackendService_LoadBalancingScheme
- Signifies that this will be used for classic Application Load Balancers, global external proxy Network Load Balancers, or external passthrough Network Load Balancers.
- externalManaged → const BackendService_LoadBalancingScheme
- Signifies that this will be used for global external Application Load Balancers, regional external Application Load Balancers, or regional external proxy Network Load Balancers.
- internal → const BackendService_LoadBalancingScheme
- Signifies that this will be used for internal passthrough Network Load Balancers.
- internalManaged → const BackendService_LoadBalancingScheme
- Signifies that this will be used for internal Application Load Balancers.
- internalSelfManaged → const BackendService_LoadBalancingScheme
- Signifies that this will be used by Traffic Director.
- invalidLoadBalancingScheme → const BackendService_LoadBalancingScheme
- undefinedLoadBalancingScheme → const BackendService_LoadBalancingScheme
- A value indicating that the enum field is not set.