BackendService_SessionAffinity class final
Type of session affinity to use. The default is NONE.
Only NONE and HEADER_FIELD are supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true.
For more details, see: Session Affinity.
sessionAffinity cannot be specified with haPolicy.
Constructors
- BackendService_SessionAffinity(String value)
-
const
- BackendService_SessionAffinity.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const BackendService_SessionAffinity
- The default value for BackendService_SessionAffinity.
- clientIp → const BackendService_SessionAffinity
- 2-tuple hash on packet's source and destination IP addresses. Connections from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy.
- clientIpNoDestination → const BackendService_SessionAffinity
- 1-tuple hash only on packet's source IP address. Connections from the same source IP address will be served by the same backend VM while that VM remains healthy. This option can only be used for Internal TCP/UDP Load Balancing.
- clientIpPortProto → const BackendService_SessionAffinity
- 5-tuple hash on packet's source and destination IP addresses, IP protocol, and source and destination ports. Connections for the same IP protocol from the same source IP address and port to the same destination IP address and port will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing.
- clientIpProto → const BackendService_SessionAffinity
- 3-tuple hash on packet's source and destination IP addresses, and IP protocol. Connections for the same IP protocol from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing.
- generatedCookie → const BackendService_SessionAffinity
- Hash based on a cookie generated by the L7 loadbalancer. Only valid for HTTP(S) load balancing.
- headerField → const BackendService_SessionAffinity
- The hash is based on a user specified header field.
- httpCookie → const BackendService_SessionAffinity
- The hash is based on a user provided cookie.
- none → const BackendService_SessionAffinity
- No session affinity. Connections from the same client IP may go to any instance in the pool.
- strongCookieAffinity → const BackendService_SessionAffinity
- Strong cookie-based affinity. Connections bearing the same cookie will be served by the same backend VM while that VM remains healthy, as long as the cookie has not expired.
- undefinedSessionAffinity → const BackendService_SessionAffinity
- A value indicating that the enum field is not set.