Backend_Preference class final
This field indicates whether this backend should be fully utilized before sending traffic to backends with default preference. The possible values are:
- PREFERRED: Backends with this preference level will be filled up to their capacity limits first, based on RTT.
- DEFAULT: If preferred backends don't have enough capacity, backends in this layer would be used and traffic would be assigned based on the load balancing algorithm you use. This is the default
Constructors
- Backend_Preference(String value)
-
const
- Backend_Preference.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const Backend_Preference
- The default value for Backend_Preference.
- default$ → const Backend_Preference
- No preference.
- preferenceUnspecified → const Backend_Preference
- If preference is unspecified, we set it to the DEFAULT value
- preferred → const Backend_Preference
- Traffic will be sent to this backend first.
- undefinedPreference → const Backend_Preference
- A value indicating that the enum field is not set.