Backend_TrafficDuration class final
Constructors
- Backend_TrafficDuration(String value)
-
const
- Backend_TrafficDuration.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const Backend_TrafficDuration
- The default value for Backend_TrafficDuration.
- long → const Backend_TrafficDuration
- Most of the requests are expected to take more than multiple seconds to finish.
- short → const Backend_TrafficDuration
- Most requests are expected to finish with a sub-second latency.
- trafficDurationUnspecified → const Backend_TrafficDuration
- Traffic duration is unspecified.
- undefinedTrafficDuration → const Backend_TrafficDuration
- A value indicating that the enum field is not set.