BfdPacket_Diagnostic class final
The diagnostic code specifies the local system's reason for the last change in session state. This allows remote systems to determine the reason that the previous session failed, for example. These diagnostic codes are specified in section 4.1 ofRFC5880
Constructors
- BfdPacket_Diagnostic(String value)
-
const
- BfdPacket_Diagnostic.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const BfdPacket_Diagnostic
- The default value for BfdPacket_Diagnostic.
- administrativelyDown → const BfdPacket_Diagnostic
- concatenatedPathDown → const BfdPacket_Diagnostic
- controlDetectionTimeExpired → const BfdPacket_Diagnostic
- diagnosticUnspecified → const BfdPacket_Diagnostic
- echoFunctionFailed → const BfdPacket_Diagnostic
- forwardingPlaneReset → const BfdPacket_Diagnostic
- neighborSignaledSessionDown → const BfdPacket_Diagnostic
- noDiagnostic → const BfdPacket_Diagnostic
- pathDown → const BfdPacket_Diagnostic
- reverseConcatenatedPathDown → const BfdPacket_Diagnostic
- undefinedDiagnostic → const BfdPacket_Diagnostic
- A value indicating that the enum field is not set.