BfdStatus class final
Next free: 15
Constructors
-
BfdStatus({String? bfdSessionInitializationMode, int? configUpdateTimestampMicros, BfdStatusPacketCounts? controlPacketCounts, List<
PacketIntervals> controlPacketIntervals = const [], String? localDiagnostic, String? localState, int? negotiatedLocalControlTxIntervalMs, BfdPacket? rxPacket, BfdPacket? txPacket, int? uptimeMs}) - BfdStatus.fromJson(Object? j)
-
factory
Properties
- bfdSessionInitializationMode → String?
-
The BFD session initialization mode for this BGP peer.
If set to ACTIVE, the Cloud Router will initiate the BFD session for
this BGP peer. If set to PASSIVE, the Cloud Router will wait for the
peer router to initiate the BFD session for this BGP peer. If set to
DISABLED, BFD is disabled for this BGP peer.
Check the BfdSessionInitializationMode enum for the list of possible values.
final
- configUpdateTimestampMicros → int?
-
Unix timestamp of the most recent config update.
final
- controlPacketCounts → BfdStatusPacketCounts?
-
Control packet counts for the current BFD session.
final
-
controlPacketIntervals
→ List<
PacketIntervals> -
Inter-packet time interval statistics for control packets.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- localDiagnostic → String?
-
The diagnostic code specifies the local system's reason for the last change
in session state. This allows remote systems to determine the reason that
the previous session failed, for example. These diagnostic codes are
specified in section 4.1 ofRFC5880
Check the LocalDiagnostic enum for the list of possible values.
final
- localState → String?
-
The current BFD session state as seen by the transmitting system. These
states are specified in section 4.1 ofRFC5880
Check the LocalState enum for the list of possible values.
final
- negotiatedLocalControlTxIntervalMs → int?
-
Negotiated transmit interval for control packets.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- rxPacket → BfdPacket?
-
The most recent Rx control packet for this BFD session.
final
- txPacket → BfdPacket?
-
The most recent Tx control packet for this BFD session.
final
- uptimeMs → int?
-
Session uptime in milliseconds. Value will be 0 if session is not up.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String