BgpRoute class final

Constructors

BgpRoute({List<BgpRouteAsPath> asPaths = const [], List<String> communities = const [], BgpRouteNetworkLayerReachabilityInformation? destination, int? med, String? origin})
BgpRoute.fromJson(Object? j)
factory

Properties

asPaths List<BgpRouteAsPath>
Output only. Output only AS-PATH for the route
final
communities List<String>
Output only. Output only BGP communities in human-readable A:B format.
final
destination BgpRouteNetworkLayerReachabilityInformation?
Output only. Output only Destination IP range for the route, in human-readable CIDR format
final
hashCode int
The hash code for this object.
no setterinherited
med int?
Output only. Output only BGP multi-exit discriminator
final
origin String?
Output only. Output only BGP origin (EGP, IGP or INCOMPLETE) Check the Origin enum for the list of possible values.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String