BgpRouteAsPath class final

Constructors

BgpRouteAsPath({List<int> asns = const [], List<int> asns32 = const [], String? type})
BgpRouteAsPath.fromJson(Object? j)
factory

Properties

asns List<int>
Output only. Output only ASNs in the path segment. When type is SEQUENCE, these are ordered.
final
asns32 List<int>
Output only. Output only ASNs in the path segment. This field is for better support of 32 bit ASNs as the other asns field suffers from overflow when the ASN is larger. When type is SEQUENCE, these are ordered.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
Output only. Output only Type of AS-PATH segment (SEQUENCE or SET) Check the Type enum for the list of possible values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String