BulkInsertDiskResource class final
A transient resource used in compute.disks.bulkInsert and compute.regionDisks.bulkInsert. It is only used to process requests and is not persisted.
Constructors
- BulkInsertDiskResource({InstantSnapshotGroupParameters? instantSnapshotGroupParameters, SnapshotGroupParameters? snapshotGroupParameters, String? sourceConsistencyGroupPolicy})
- BulkInsertDiskResource.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- instantSnapshotGroupParameters → InstantSnapshotGroupParameters?
-
The parameters for the instant snapshot group.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- snapshotGroupParameters → SnapshotGroupParameters?
-
The parameters for the snapshot group. The usage of snapshot group feature
is restricted.
final
- sourceConsistencyGroupPolicy → String?
-
The URL of the DiskConsistencyGroupPolicy for the group of disks to clone.
This may be a full or partial URL, such as:
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String