BulkInsertInstanceResource class final
A transient resource used in compute.instances.bulkInsert and compute.regionInstances.bulkInsert . This resource is not persisted anywhere, it is used only for processing the requests.
Constructors
-
BulkInsertInstanceResource({int? count, InstanceFlexibilityPolicy? instanceFlexibilityPolicy, InstanceProperties? instanceProperties, LocationPolicy? locationPolicy, int? minCount, String? namePattern, Map<
String, BulkInsertInstanceResourcePerInstanceProperties> perInstanceProperties = const {}, String? sourceInstanceTemplate}) - BulkInsertInstanceResource.fromJson(Object? j)
-
factory
Properties
- count → int?
-
The maximum number of instances to create.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- instanceFlexibilityPolicy → InstanceFlexibilityPolicy?
-
A flexible specification of machine type of instances to create.
final
- instanceProperties → InstanceProperties?
-
The instance properties defining the VM instances to be created. Required
if sourceInstanceTemplate is not provided.
final
- locationPolicy → LocationPolicy?
-
Policy for choosing target zone. For more information, seeCreate VMs in
bulk.
final
- minCount → int?
-
The minimum number of instances to create. If no min_count is
specified then count is used as the default value. Ifmin_count instances cannot be created, then no instances will
be created and instances already created will be deleted.
final
- namePattern → String?
-
The string pattern used for the names of the VMs.
Either name_pattern or per_instance_properties
must be set. The pattern must contain one continuous sequence of
placeholder hash characters (#) with each character corresponding to one
digit of the generated instance name. Example: a name_pattern
of inst-#### generates instance names such asinst-0001 and inst-0002. If existing instances
in the same project and zone have names that match the name pattern
then the generated instance numbers start after the biggest
existing number. For example, if there exists an instance with nameinst-0050, then instance names generated using the patterninst-#### begin with inst-0051. The name pattern
placeholder #...# can contain up to 18 characters.
final
-
perInstanceProperties
→ Map<
String, BulkInsertInstanceResourcePerInstanceProperties> -
Per-instance properties to be set on individual instances.
Keys of this map specify requested instance names.
Can be empty if name_pattern is used.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceInstanceTemplate → String?
-
Specifies the instance template from which to create instances. You may
combine sourceInstanceTemplate withinstanceProperties to override specific values from an
existing instance template. Bulk API follows the semantics of JSON Merge
Patch described by RFC
7396.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String