BulkInsertOperationStatus class
final
Properties
createdVmCount
→ int ?
Output Only Count of VMs successfully created so far.
final
deletedVmCount
→ int ?
Output Only Count of VMs that got deleted during rollback.
final
failedToCreateVmCount
→ int ?
Output Only Count of VMs that started creating but encountered an
error.
final
hashCode
→ int
The hash code for this object.
no setter inherited
qualifiedName
→ String
The fully qualified name of this message, i.e., google.protobuf.Duration
or google.rpc.ErrorInfo.
final inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
status
→ String ?
Output Only Creation status of BulkInsert operation - information
if the flow is rolling forward or rolling back.
Check the Status enum for the list of possible values.
final
targetVmCount
→ int ?
Output Only Count of VMs originally planned to be created.
final
google_cloud_compute_v1 0.1.0