status property

String? status
final

Output Only Creation status of BulkInsert operation - information if the flow is rolling forward or rolling back. Check the Status enum for the list of possible values.

Implementation

final String? status;