CachePolicy_CacheMode class final

Specifies the cache setting for all responses from this route. If not specified, Cloud CDN uses CACHE_ALL_STATIC mode.

Constructors

CachePolicy_CacheMode(String value)
const
CachePolicy_CacheMode.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const CachePolicy_CacheMode
The default value for CachePolicy_CacheMode.
cacheAllStatic → const CachePolicy_CacheMode
Automatically cache static content, including common image formats, media (video and audio), and web assets (JavaScript and CSS). Requests and responses that are marked as uncacheable, as well as dynamic content (including HTML), will not be cached.
forceCacheAll → const CachePolicy_CacheMode
Cache all content, ignoring any "private", "no-store" or "no-cache" directives in Cache-Control response headers. Warning: this may result in Cloud CDN caching private, per-user (user identifiable) content.
undefinedCacheMode → const CachePolicy_CacheMode
A value indicating that the enum field is not set.
useOriginHeaders → const CachePolicy_CacheMode
Requires the origin to set valid caching headers to cache content. Responses without these headers will not be cached at the edge, and will require a full trip to the origin on every request, potentially impacting performance and increasing load on the origin server.