futureResourcesSpecs property
Specification of resources to create in the future. The key of the map is an arbitrary string specified by the caller. Value of the map is a specification of required resources and their constraints. Currently only one value is allowed in this map.
Implementation
final Map<String, FutureResourcesSpec> futureResourcesSpecs;