recommendations property
Recommendations where, how and when to create the requested resources in order to maximize their obtainability and minimize cost.
Implementation
final List<CalendarModeRecommendation> recommendations;
Recommendations where, how and when to create the requested resources in order to maximize their obtainability and minimize cost.
final List<CalendarModeRecommendation> recommendations;