CalendarModeRecommendation class final
A single recommendation to create requested resources. Contains detailed recommendations for every future resources specification specified in CalendarModeAdviceRequest.
Constructors
-
CalendarModeRecommendation({Map<
String, FutureResourcesRecommendation> recommendationsPerSpec = const {}}) - CalendarModeRecommendation.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited -
recommendationsPerSpec
→ Map<
String, FutureResourcesRecommendation> -
Recommendations for every future resource specification passed in
CalendarModeAdviceRequest. Keys of the map correspond to keys
specified in the request.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String