CancelRolloutRequest class final
A request message for Rollouts.Cancel. See the method description for details.
Constructors
- CancelRolloutRequest({required String project, String? requestId, bool? rollback, required String rollout})
- CancelRolloutRequest.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- project → String
-
Project ID for this request.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - requestId → String?
-
An optional request ID to identify requests. Specify a unique request ID so
that if you must retry your request, the server will know to ignore the
request if it has already been completed.
final
- rollback → bool?
-
Optional. If true, then the ongoing rollout must be rolled back. Else, just cancel
the rollout without taking any further actions. Note that products must
support at least one of these options, however, it does not need to support
both.
final
- rollout → String
-
Name of the Rollout resource to cancel.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String