CapacityAdviceRequestDistributionPolicy_TargetShape class final

Target distribution shape. You can specify the following values:ANY, ANY_SINGLE_ZONE, or BALANCED.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const CapacityAdviceRequestDistributionPolicy_TargetShape
The default value for CapacityAdviceRequestDistributionPolicy_TargetShape.
any → const CapacityAdviceRequestDistributionPolicy_TargetShape
Picks zones for creating VM instances to fulfill the requested number of VMs within present resource constraints.
anySingleZone → const CapacityAdviceRequestDistributionPolicy_TargetShape
Creates all VM instances within a single zone. The zone is selected based on the present resource constraints.
balanced → const CapacityAdviceRequestDistributionPolicy_TargetShape
Prioritizes acquisition of resources, scheduling VMs in zones where resources are available while distributing VMs as evenly as possible across selected zones to minimize the impact of zonal failure.
targetShapeUnspecified → const CapacityAdviceRequestDistributionPolicy_TargetShape
Default value, unused.
undefinedTargetShape → const CapacityAdviceRequestDistributionPolicy_TargetShape
A value indicating that the enum field is not set.