CapacityAdviceResponseRecommendationScores class final
Groups information about a shard of capacity.
Constructors
- CapacityAdviceResponseRecommendationScores({String? estimatedUptime, double? obtainability})
- CapacityAdviceResponseRecommendationScores.fromJson(Object? j)
-
factory
Properties
- estimatedUptime → String?
-
The estimated run time of the majority of Spot VMs in the request
before preemption. The estimate is best-effort only. It is based on
historical data and current conditions.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- obtainability → double?
-
The obtainability score indicates the likelihood of successfully
obtaining (provisioning) the requested number of VMs.
The score range is 0.0 through 1.0. Higher is better.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String