CapacityAdviceResponseRecommendationShard class final
Shards represent blocks of uniform capacity in recommendations. Each shard is for a single zone and a single machine shape. Each shard defines a size expressed as the number of VMs.
Constructors
- CapacityAdviceResponseRecommendationShard({int? instanceCount, String? machineType, String? provisioningModel, String? zone})
- CapacityAdviceResponseRecommendationShard.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- instanceCount → int?
-
The number of instances.
final
- machineType → String?
-
The machine type corresponds to the instance selection in the request.
final
- provisioningModel → String?
-
The provisioning model that you want to view recommendations for.
Check the ProvisioningModel enum for the list of possible values.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- zone → String?
-
Output only. The zone name for this shard.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String