CapacityHistoryRequestInstancePropertiesScheduling_ProvisioningModel class final
The provisioning model to get capacity history for. This field must be set to SPOT.
For more information, see Compute Engine instances provisioning models.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const CapacityHistoryRequestInstancePropertiesScheduling_ProvisioningModel
- The default value for CapacityHistoryRequestInstancePropertiesScheduling_ProvisioningModel.
- flexStart → const CapacityHistoryRequestInstancePropertiesScheduling_ProvisioningModel
- Instance is provisioned using the Flex Start provisioning model and has a limited runtime.
- reservationBound → const CapacityHistoryRequestInstancePropertiesScheduling_ProvisioningModel
- Bound to the lifecycle of the reservation in which it is provisioned.
- spot → const CapacityHistoryRequestInstancePropertiesScheduling_ProvisioningModel
- Heavily discounted, no guaranteed runtime.
- standard → const CapacityHistoryRequestInstancePropertiesScheduling_ProvisioningModel
- Standard provisioning with user controlled runtime, no discounts.
- undefinedProvisioningModel → const CapacityHistoryRequestInstancePropertiesScheduling_ProvisioningModel
- A value indicating that the enum field is not set.