CapacityHistoryResponsePreemptionRecord class final
A record of Spot VM preemption history.
Constructors
- CapacityHistoryResponsePreemptionRecord({Interval? interval, double? preemptionRate})
- CapacityHistoryResponsePreemptionRecord.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- interval → Interval?
-
The time interval for this preemption record.
final
- preemptionRate → double?
-
The preemption rate during the interval, representing the fraction of
Spot VMs that were preempted. Range: 0.0 to 1.0. Preemption rate is
calculated as (total preempted Spots) / (total Spots that stopped
running).
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String