CircuitBreakers class final
Settings controlling the volume of requests, connections and retries to this backend service.
Constructors
- CircuitBreakers({int? maxConnections, int? maxPendingRequests, int? maxRequests, int? maxRequestsPerConnection, int? maxRetries})
- CircuitBreakers.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxConnections → int?
-
The maximum number of connections to the backend service. If not specified,
there is no limit.
final
- maxPendingRequests → int?
-
The maximum number of pending requests allowed to the backend service. If
not specified, there is no limit.
final
- maxRequests → int?
-
The maximum number of parallel requests that allowed to the backend
service. If not specified, there is no limit.
final
- maxRequestsPerConnection → int?
-
Maximum requests for a single connection to the backend service.
This parameter is respected by both the HTTP/1.1 and HTTP/2
implementations. If not specified, there is no limit. Setting this
parameter to 1 will effectively disable keep alive.
final
- maxRetries → int?
-
The maximum number of parallel retries allowed to the backend cluster. If
not specified, the default is 1.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String