Commitment class final

Represents a regional resource-based commitment resource.

Creating this commitment resource means that you are purchasing a resource-based committed use contract, with an explicit start and end time. You can purchase resource-based commitments for both hardware and software resources. For more information, read Resource-based committed use discounts

Constructors

Commitment({bool? autoRenew, String? category, String? creationTimestamp, String? customEndTimestamp, String? description, String? endTimestamp, List<String> existingReservations = const [], BigInt? id, String? kind, LicenseResourceCommitment? licenseResource, List<String> mergeSourceCommitments = const [], String? name, CommitmentParams? params, String? plan, String? region, List<Reservation> reservations = const [], CommitmentResourceStatus? resourceStatus, List<ResourceCommitment> resources = const [], String? selfLink, String? splitSourceCommitment, String? startTimestamp, String? status, String? statusMessage, String? type})
Commitment.fromJson(Object? j)
factory

Properties

autoRenew bool?
Specifies whether to automatically renew the commitment at the end of its current term. The default value is false. If you set the field to true, each time your commitment reaches the end of its term, Compute Engine automatically renews it for another term. You can update this field anytime before the commitment expires. For example, if the commitment is set to expire at 12 AM UTC-8 on January 3, 2027, you can update this field until 11:59 PM UTC-8 on January 2, 2027.
final
category String?
The category of the commitment; specifies whether the commitment is for hardware or software resources. Category MACHINE specifies that you are committing to hardware machine resources such asVCPU or MEMORY, listed in resources. Category LICENSE specifies that you are committing to software licenses, listed in licenseResources. Note that if you specify MACHINE commitments, then you must also specify a type to indicate the machine series of the hardware resource that you are committing to. Check the Category enum for the list of possible values.
final
creationTimestamp String?
Output only. Output Only Creation timestamp inRFC3339 text format.
final
customEndTimestamp String?
Input Only Optional, specifies the requested commitment end time inRFC3339 text format. Use this option when the desired commitment's end date is later than the start date + term duration.
final
description String?
An optional description of the commitment. You can provide this property when you create the resource.
final
endTimestamp String?
Output only. Output Only Commitment end time inRFC3339 text format.
final
existingReservations List<String>
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output only. Output Only The unique identifier for the resource. This identifier is defined by the server.
final
kind String?
Output only. Output Only Type of the resource. Always compute#commitment for commitments.
final
licenseResource LicenseResourceCommitment?
The license specification required as part of a license commitment.
final
mergeSourceCommitments List<String>
The list of source commitments that you are merging to create the new merged commitment. For more information, see Merging commitments.
final
name String?
Name of the commitment. You must specify a name when you purchase the commitment. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
params CommitmentParams?
Input only. Additional params passed with the request, but not persisted as part of resource payload.
final
plan String?
The minimum time duration that you commit to purchasing resources. The plan that you choose determines the preset term length of the commitment (which is 1 year or 3 years) and affects the discount rate that you receive for your resources. Committing to a longer time duration typically gives you a higher discount rate. The supported values for this field are TWELVE_MONTH (1 year), andTHIRTY_SIX_MONTH (3 years). Check the Plan enum for the list of possible values.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
region String?
Output only. Output Only URL of the region where the commitment and committed resources are located.
final
reservations List<Reservation>
The list of new reservations that you want to create and attach to this commitment.
final
resources List<ResourceCommitment>
The list of all the hardware resources, with their types and amounts, that you want to commit to. Specify as a separate entry in the list for each individual resource type.
final
resourceStatus CommitmentResourceStatus?
Output only. Output Only Status information for Commitment resource.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output only. Output Only Server-defined URL for the resource.
final
splitSourceCommitment String?
The source commitment from which you are transferring resources to create the new split commitment. For more information, see Split commitments.
final
startTimestamp String?
Output only. Output Only Commitment start time inRFC3339 text format.
final
status String?
Output only. Output Only Status of the commitment with regards to eventual expiration (each commitment has an end date defined). Status can be one of the following values: NOT_YET_ACTIVE, ACTIVE, orEXPIRED. Check the Status enum for the list of possible values.
final
statusMessage String?
Output only. Output Only An optional, human-readable explanation of the status.
final
type String?
The type of commitment; specifies the machine series for which you want to commit to purchasing resources. The choice of machine series affects the discount rate and the eligible resource types.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String