status property

String? status
final

Output only. Output Only Status of the commitment with regards to eventual expiration (each commitment has an end date defined). Status can be one of the following values: NOT_YET_ACTIVE, ACTIVE, orEXPIRED. Check the Status enum for the list of possible values.

Implementation

final String? status;