CommitmentResourceStatus class final
Output Only Contains output only fields.
Constructors
- CommitmentResourceStatus({String? customTermEligibilityEndTimestamp})
- CommitmentResourceStatus.fromJson(Object? j)
-
factory
Properties
- customTermEligibilityEndTimestamp → String?
-
Output only.
Output OnlyIndicates the end time of customer's eligibility to send custom term requests in RFC3339 text format. Term extension requests that (not the end time in the request) after this time will be rejected.final - hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String