ConsistentHashLoadBalancerSettings class final
This message defines settings for a consistent hash style load balancer.
Constructors
- ConsistentHashLoadBalancerSettings({ConsistentHashLoadBalancerSettingsHttpCookie? httpCookie, String? httpHeaderName, int? minimumRingSize})
- ConsistentHashLoadBalancerSettings.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpCookie → ConsistentHashLoadBalancerSettingsHttpCookie?
-
Hash is based on HTTP Cookie. This field describes a HTTP cookie that will
be used as the hash key for the consistent hash load balancer. If the
cookie is not present, it will be generated. This field is applicable if
the sessionAffinity is set to HTTP_COOKIE.
final
- httpHeaderName → String?
-
The hash based on the value of the specified header field. This field is
applicable if the sessionAffinity is set toHEADER_FIELD.
final
- minimumRingSize → int?
-
The minimum number of virtual nodes to use for the hash ring. Defaults to
1024. Larger ring sizes result in more granular load distributions. If the
number of hosts in the load balancing pool is larger than the ring size,
each host will be assigned a single virtual node.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String