ConsistentHashLoadBalancerSettingsHttpCookie class final

The information about the HTTP Cookie on which the hash function is based for load balancing policies that use a consistent hash.

Properties

hashCode int
The hash code for this object.
no setterinherited
name String?
Name of the cookie.
final
path String?
Path to set for the cookie.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ttl Duration?
Lifetime of the cookie.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String