allowCredentials property
In response to a preflight request, setting this to true indicates that the actual request can include user credentials. This field translates to the Access-Control-Allow-Credentials header.
Default is false.
Implementation
final bool? allowCredentials;