CrossSiteNetworks class final
The CrossSiteNetworks API.
- Implementers
Constructors
- CrossSiteNetworks({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
CrossSiteNetworksusingclientfor transport. - CrossSiteNetworks.fromApiKey([String? apiKey])
-
Creates a
CrossSiteNetworksthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteCrossSiteNetworkRequest request) → Future< Operation> - Deletes the specified cross-site network in the given scope.
-
get(
GetCrossSiteNetworkRequest request) → Future< CrossSiteNetwork> - Returns the specified cross-site network in the given scope.
-
insert(
InsertCrossSiteNetworkRequest request) → Future< Operation> - Creates a cross-site network in the specified project in the given scope using the parameters that are included in the request.
-
list(
ListCrossSiteNetworksRequest request) → Future< CrossSiteNetworkList> - Lists the cross-site networks for a project in the given scope.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchCrossSiteNetworkRequest request) → Future< Operation> - Updates the specified cross-site network with the data included in the request. This method supportsPATCH semantics and uses theJSON merge patch format and processing rules.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited