CustomErrorResponsePolicyCustomErrorResponseRule class final
Specifies the mapping between the response code that will be returned along with the custom error content and the response code returned by the backend service.
Constructors
-
CustomErrorResponsePolicyCustomErrorResponseRule({List<
String> matchResponseCodes = const [], int? overrideResponseCode, String? path}) - CustomErrorResponsePolicyCustomErrorResponseRule.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
matchResponseCodes
→ List<
String> -
Valid values include:
final
- overrideResponseCode → int?
-
The HTTP status code returned with the response containing the custom
error content. If overrideResponseCode is not supplied, the
same response code returned by the original backend bucket or backend
service is returned to the client.
final
- path → String?
-
The full path to a file within backendBucket . For example:/errors/defaultError.html
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String