The service account being used for the encryption request for the given KMS
key. If absent, the Compute Engine default service account is used.
For example:
DEPRECATED CSEK is no longer supported. Use CMEK instead.
Specifies a 256-bit customer-supplied
encryption key, encoded in RFC
4648 base64 to either encrypt or decrypt this resource. You can
provide either the rawKey or thersaEncryptedKey.
For example:
DEPRECATED CSEK is no longer supported. Use CMEK instead.
Specifies an RFC 4648 base64 encoded, RSA-wrapped 2048-bit
customer-supplied encryption key to either encrypt or decrypt this
resource. You can provide either the rawKey or thersaEncryptedKey.
For example:
DEPRECATED CSEK is no longer supported. Use CMEK instead.
Output only TheRFC
4648 base64 encoded SHA-256 hash of the customer-supplied
encryption key that protects this resource.