DeprecationStatus class final
Deprecation status for a public resource.
Constructors
- DeprecationStatus({String? deleted, String? deprecated, String? obsolete, String? replacement, String? state})
- DeprecationStatus.fromJson(Object? j)
-
factory
Properties
- deleted → String?
-
An optional RFC3339 timestamp on or after which the state of this
resource is intended to change to DELETED. This is only
informational and the status will not change unless the client explicitly
changes it.
final
- deprecated → String?
-
An optional RFC3339 timestamp on or after which the state of this
resource is intended to change to DEPRECATED. This is only
informational and the status will not change unless the client explicitly
changes it.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- obsolete → String?
-
An optional RFC3339 timestamp on or after which the state of this
resource is intended to change to OBSOLETE. This is only
informational and the status will not change unless the client explicitly
changes it.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - replacement → String?
-
The URL of the suggested replacement for a deprecated resource.
The suggested replacement resource must be the same kind of resource as the
deprecated resource.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → String?
-
The deprecation state of this resource. This can be ACTIVE,DEPRECATED, OBSOLETE, or DELETED.
Operations which communicate the end of life date for an image, can useACTIVE. Operations which create a new resource using aDEPRECATED resource will return successfully, but with a
warning indicating the deprecated resource and recommending its
replacement. Operations which use OBSOLETE orDELETED resources will be rejected and result in an error.
Check the State enum for the list of possible values.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String