DeprecationStatus_State class final
The deprecation state of this resource. This can be ACTIVE,DEPRECATED, OBSOLETE, or DELETED. Operations which communicate the end of life date for an image, can useACTIVE. Operations which create a new resource using aDEPRECATED resource will return successfully, but with a warning indicating the deprecated resource and recommending its replacement. Operations which use OBSOLETE orDELETED resources will be rejected and result in an error.
Constructors
- DeprecationStatus_State(String value)
-
const
- DeprecationStatus_State.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const DeprecationStatus_State
- The default value for DeprecationStatus_State.
- active → const DeprecationStatus_State
- deleted → const DeprecationStatus_State
- deprecated → const DeprecationStatus_State
- obsolete → const DeprecationStatus_State
- undefinedState → const DeprecationStatus_State
- A value indicating that the enum field is not set.