Disk class final

Represents a Persistent Disk resource.

Google Compute Engine has two Disk resources:

Persistent disks are required for running your VM instances. Create both boot and non-boot (data) persistent disks. For more information, read Persistent Disks. For more storage options, read Storage options.

The disks resource represents a zonal persistent disk. For more information, readZonal persistent disks.

The regionDisks resource represents a regional persistent disk. For more information, read Regional resources.

Constructors

Disk({String? accessMode, String? architecture, DiskAsyncReplication? asyncPrimaryDisk, Map<String, DiskAsyncReplicationList> asyncSecondaryDisks = const {}, String? creationTimestamp, String? description, CustomerEncryptionKey? diskEncryptionKey, bool? enableConfidentialCompute, List<GuestOsFeature> guestOsFeatures = const [], BigInt? id, String? kind, String? labelFingerprint, Map<String, String> labels = const {}, String? lastAttachTimestamp, String? lastDetachTimestamp, List<int> licenseCodes = const [], List<String> licenses = const [], String? locationHint, String? name, String? options, DiskParams? params, int? physicalBlockSizeBytes, int? provisionedIops, int? provisionedThroughput, String? region, List<String> replicaZones = const [], List<String> resourcePolicies = const [], DiskResourceStatus? resourceStatus, bool? satisfiesPzi, bool? satisfiesPzs, String? selfLink, int? sizeGb, String? sourceConsistencyGroupPolicy, String? sourceConsistencyGroupPolicyId, String? sourceDisk, String? sourceDiskId, String? sourceImage, CustomerEncryptionKey? sourceImageEncryptionKey, String? sourceImageId, String? sourceInstantSnapshot, String? sourceInstantSnapshotId, String? sourceSnapshot, CustomerEncryptionKey? sourceSnapshotEncryptionKey, String? sourceSnapshotId, String? sourceStorageObject, String? status, String? storagePool, String? type, List<String> users = const [], String? zone})
Disk.fromJson(Object? j)
factory

Properties

accessMode String?
The access mode of the disk.
final
architecture String?
The architecture of the disk. Valid values are ARM64 or X86_64. Check the Architecture enum for the list of possible values.
final
asyncPrimaryDisk DiskAsyncReplication?
Disk asynchronously replicated into this disk.
final
asyncSecondaryDisks Map<String, DiskAsyncReplicationList>
Output only. Output Only A list of disks this disk is asynchronously replicated to.
final
creationTimestamp String?
Output only. Output Only Creation timestamp inRFC3339 text format.
final
description String?
An optional description of this resource. Provide this property when you create the resource.
final
diskEncryptionKey CustomerEncryptionKey?
Encrypts the disk using a customer-supplied encryption key or a customer-managed encryption key.
final
enableConfidentialCompute bool?
Whether this disk is using confidential compute mode.
final
guestOsFeatures List<GuestOsFeature>
A list of features to enable on the guest operating system. Applicable only for bootable images. Read Enabling guest operating system features to see a list of available options.
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output only. Output Only The unique identifier for the resource. This identifier is defined by the server.
final
kind String?
Output only. Output Only Type of the resource. Always compute#disk for disks.
final
labelFingerprint String?
A fingerprint for the labels being applied to this disk, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet.
final
labels Map<String, String>
Labels to apply to this disk. These can be later modified by the setLabels method.
final
lastAttachTimestamp String?
Output only. Output Only Last attach timestamp inRFC3339 text format.
final
lastDetachTimestamp String?
Output only. Output Only Last detach timestamp inRFC3339 text format.
final
licenseCodes List<int>
Integer license codes indicating which licenses are attached to this disk.
final
licenses List<String>
A list of publicly visible licenses. Reserved for Google's use.
final
locationHint String?
An opaque location hint used to place the disk close to other resources. This field is for use by internal tools that use the public API.
final
name String?
Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
options String?
Internal use only.
final
params DiskParams?
Input only. Input Only Additional params passed with the request, but not persisted as part of resource payload.
final
physicalBlockSizeBytes int?
Physical block size of the persistent disk, in bytes. If not present in a request, a default value is used. The currently supported size is 4096, other sizes may be added in the future. If an unsupported value is requested, the error message will list the supported values for the caller's project.
final
provisionedIops int?
Indicates how many IOPS to provision for the disk. This sets the number of I/O operations per second that the disk can handle. Values must be between 10,000 and 120,000. For more details, see theExtreme persistent disk documentation.
final
provisionedThroughput int?
Indicates how much throughput to provision for the disk. This sets the number of throughput mb per second that the disk can handle. Values must be greater than or equal to 1.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
region String?
Output only. Output Only URL of the region where the disk resides. Only applicable for regional resources. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
final
replicaZones List<String>
URLs of the zones where the disk should be replicated to. Only applicable for regional resources.
final
resourcePolicies List<String>
Resource policies applied to this disk for automatic snapshot creations.
final
resourceStatus DiskResourceStatus?
Output only. Output Only Status information for the disk resource.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzi bool?
Output only. Reserved for future use.
final
satisfiesPzs bool?
Output only. Output Only Reserved for future use.
final
Output only. Output Only Server-defined fully-qualified URL for this resource.
final
sizeGb int?
Size, in GB, of the persistent disk. You can specify this field when creating a persistent disk using thesourceImage, sourceSnapshot, orsourceDisk parameter, or specify it alone to create an empty persistent disk.
final
sourceConsistencyGroupPolicy String?
Output only. Output Only URL of the DiskConsistencyGroupPolicy for a secondary disk that was created using a consistency group.
final
sourceConsistencyGroupPolicyId String?
Output only. Output Only ID of the DiskConsistencyGroupPolicy for a secondary disk that was created using a consistency group.
final
sourceDisk String?
The source disk used to create this disk. You can provide this as a partial or full URL to the resource. For example, the following are valid values:
final
sourceDiskId String?
Output only. Output Only The unique ID of the disk used to create this disk. This value identifies the exact disk that was used to create this persistent disk. For example, if you created the persistent disk from a disk that was later deleted and recreated under the same name, the source disk ID would identify the exact version of the disk that was used.
final
sourceImage String?
The source image used to create this disk. If the source image is deleted, this field will not be set.
final
sourceImageEncryptionKey CustomerEncryptionKey?
Thecustomer-supplied encryption key of the source image. Required if the source image is protected by a customer-supplied encryption key.
final
sourceImageId String?
Output only. Output Only The ID value of the image used to create this disk. This value identifies the exact image that was used to create this persistent disk. For example, if you created the persistent disk from an image that was later deleted and recreated under the same name, the source image ID would identify the exact version of the image that was used.
final
sourceInstantSnapshot String?
The source instant snapshot used to create this disk. You can provide this as a partial or full URL to the resource. For example, the following are valid values:
final
sourceInstantSnapshotId String?
Output only. Output Only The unique ID of the instant snapshot used to create this disk. This value identifies the exact instant snapshot that was used to create this persistent disk. For example, if you created the persistent disk from an instant snapshot that was later deleted and recreated under the same name, the source instant snapshot ID would identify the exact version of the instant snapshot that was used.
final
sourceSnapshot String?
The source snapshot used to create this disk. You can provide this as a partial or full URL to the resource. For example, the following are valid values:
final
sourceSnapshotEncryptionKey CustomerEncryptionKey?
Thecustomer-supplied encryption key of the source snapshot. Required if the source snapshot is protected by a customer-supplied encryption key.
final
sourceSnapshotId String?
Output only. Output Only The unique ID of the snapshot used to create this disk. This value identifies the exact snapshot that was used to create this persistent disk. For example, if you created the persistent disk from a snapshot that was later deleted and recreated under the same name, the source snapshot ID would identify the exact version of the snapshot that was used.
final
sourceStorageObject String?
The full Google Cloud Storage URI where the disk image is stored. This file must be a gzip-compressed tarball whose name ends in .tar.gz or virtual machine disk whose name ends in vmdk. Valid URIs may start with gs:// or https://storage.googleapis.com/. This flag is not optimized for creating multiple disks from a source storage object. To create many disks from a source storage object, use gcloud compute images import instead.
final
status String?
Output only. Output Only The status of disk creation.
final
storagePool String?
The storage pool in which the new disk is created. You can provide this as a partial or full URL to the resource. For example, the following are valid values:
final
type String?
URL of the disk type resource describing which disk type to use to create the disk. Provide this when creating the disk. For example:projects/project/zones/zone/diskTypes/pd-ssd. See Persistent disk types.
final
users List<String>
Output only. Output Only Links to the users of the disk (attached instances) in form:projects/project/zones/zone/instances/instance
final
zone String?
Output only. Output Only URL of the zone where the disk resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String