guestOsFeatures property
A list of features to enable on the guest operating system. Applicable only for bootable images. Read Enabling guest operating system features to see a list of available options.
Implementation
final List<GuestOsFeature> guestOsFeatures;