The other disk asynchronously replicated to or from the current disk.
You can provide this as a partial or full URL to the resource.
For example, the following are valid values:
Output only. Output Only The unique ID of the other disk asynchronously replicated
to or from the current disk. This value identifies the exact disk that
was used to create this replication. For example, if you started
replicating the persistent disk from a disk that was later deleted and
recreated under the same name, the disk ID would identify the exact
version of the disk that was used.