DiskInstantiationConfig_InstantiateFrom class final
Specifies whether to include the disk and what image to use. Possible values are:
- source-image: to use the same image that was used to
create the source instance's corresponding disk. Applicable to the boot
disk and additional read-write disks.
- source-image-family: to use the same image family that
was used to create the source instance's corresponding disk. Applicable
to the boot disk and additional read-write disks.
- custom-image: to use a user-provided image url for disk
creation. Applicable to the boot disk and additional read-write
disks.
- attach-read-only: to attach a read-only
disk. Applicable to read-only disks.
- do-not-include: to exclude a disk from the template. Applicable to additional read-write disks, local SSDs, and read-only disks.
Constructors
- DiskInstantiationConfig_InstantiateFrom(String value)
-
const
- DiskInstantiationConfig_InstantiateFrom.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const DiskInstantiationConfig_InstantiateFrom
- The default value for DiskInstantiationConfig_InstantiateFrom.
- attachReadOnly → const DiskInstantiationConfig_InstantiateFrom
- Attach the existing disk in read-only mode. The request will fail if the disk was attached in read-write mode on the source instance. Applicable to: read-only disks.
- blank → const DiskInstantiationConfig_InstantiateFrom
- Create a blank disk. The disk will be created unformatted. Applicable to: additional read-write disks, local SSDs.
- customImage → const DiskInstantiationConfig_InstantiateFrom
- Use the custom image specified in the custom_image field. Applicable to: boot disk, additional read-write disks.
- default$ → const DiskInstantiationConfig_InstantiateFrom
- Use the default instantiation option for the corresponding type of disk. For boot disk and any other R/W disks, new custom images will be created from each disk. For read-only disks, they will be attached in read-only mode. Local SSD disks will be created as blank volumes.
- doNotInclude → const DiskInstantiationConfig_InstantiateFrom
- Do not include the disk in the instance template. Applicable to: additional read-write disks, local SSDs, read-only disks.
- sourceImage → const DiskInstantiationConfig_InstantiateFrom
- Use the same source image used for creation of the source instance's corresponding disk. The request will fail if the source VM's disk was created from a snapshot. Applicable to: boot disk, additional read-write disks.
- sourceImageFamily → const DiskInstantiationConfig_InstantiateFrom
- Use the same source image family used for creation of the source instance's corresponding disk. The request will fail if the source image of the source disk does not belong to any image family. Applicable to: boot disk, additional read-write disks.
- undefinedInstantiateFrom → const DiskInstantiationConfig_InstantiateFrom
- A value indicating that the enum field is not set.