DiskMoveRequest class final

Constructors

DiskMoveRequest({String? destinationZone, String? targetDisk})
DiskMoveRequest.fromJson(Object? j)
factory

Properties

destinationZone String?
The URL of the destination zone to move the disk. This can be a full or partial URL. For example, the following are all valid URLs to a zone:
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetDisk String?
The URL of the target disk to move. This can be a full or partial URL. For example, the following are all valid URLs to a disk:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String