DiskType class final
Represents a Disk Type resource.
Google Compute Engine has two Disk Type resources:
You can choose from a variety of disk types based on your needs. For more information, readStorage options.
The diskTypes resource represents disk types for a zonal persistent disk. For more information, readZonal persistent disks.
The regionDiskTypes resource represents disk types for a regional persistent disk. For more information, read Regional persistent disks.
Constructors
Properties
- creationTimestamp → String?
-
Output OnlyCreation timestamp inRFC3339 text format.final - defaultDiskSizeGb → int?
-
Output OnlyServer-defined default disk size in GB.final - deprecated → DeprecationStatus?
-
Output OnlyThe deprecation status associated with this disk type.final - description → String?
-
Output OnlyAn optional description of this resource.final - hashCode → int
-
The hash code for this object.
no setterinherited
- id → BigInt?
-
Output OnlyThe unique identifier for the resource. This identifier is defined by the server.final - kind → String?
-
Output only.
Output OnlyType of the resource. Always compute#diskType for disk types.final - name → String?
-
Output OnlyName of the resource.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - region → String?
-
Output OnlyURL of the region where the disk type resides. Only applicable for regional resources. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfLink → String?
-
Output OnlyServer-defined URL for the resource.final - validDiskSize → String?
-
Output OnlyAn optional textual description of the valid disk size, such as "10GB-10TB".final - zone → String?
-
Output OnlyURL of the zone where the disk type resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String