DiskTypes class final
The DiskTypes API.
- Implementers
Constructors
- DiskTypes({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
DiskTypesusingclientfor transport. - DiskTypes.fromApiKey([String? apiKey])
-
Creates a
DiskTypesthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
aggregatedList(
AggregatedListDiskTypesRequest request) → Future< DiskTypeAggregatedList> - Retrieves an aggregated list of disk types.
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
get(
GetDiskTypeRequest request) → Future< DiskType> - Returns the specified disk type.
-
list(
ListDiskTypesRequest request) → Future< DiskTypeList> - Retrieves a list of disk types available to the specified project.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited