The distribution shape to which the group converges either proactively or
on resize events (depending on the value set inupdatePolicy.instanceRedistributionType).
Check the TargetShape enum for the list of possible values.
Zones where the regional managed instance group will create and manage
its instances.
By default, a regional MIG doesn't automatically select an AI zone to create
instances, even if an AI zone is available in the specified region. To
create instances in an AI zone in the selected region, you must explicitly
specify it in the distribution policy together with the other preferred
zones.