Errors class final
Represents a single error encountered during the processing of an operation.
Constructors
-
Errors({String? code, List<
ErrorDetails> errorDetails = const [], String? location, String? message}) - Errors.fromJson(Object? j)
-
factory
Properties
- code → String?
-
Output OnlyThe error type identifier for this error.final -
errorDetails
→ List<
ErrorDetails> -
Output OnlyAn optional list of messages that contain the error details. There is a set of defined message types to use for providing details.The syntax depends on the error code. For example, QuotaExceededInfo will have details when the error code is QUOTA_EXCEEDED.final - hashCode → int
-
The hash code for this object.
no setterinherited
- location → String?
-
Output OnlyIndicates the field in the request that caused the error. This property is optional.final - message → String?
-
Output OnlyAn optional, human-readable error message.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String