errorDetails property
Output Only An optional list of messages that contain the error
details. There is a set of defined message types to use for providing
details.The syntax depends on the error code. For example,
QuotaExceededInfo will have details when the error code is
QUOTA_EXCEEDED.
Implementation
final List<ErrorDetails> errorDetails;