ExchangedPeeringRoute class final

Constructors

ExchangedPeeringRoute({String? destRange, bool? imported, String? nextHopRegion, int? priority, String? type})
ExchangedPeeringRoute.fromJson(Object? j)
factory

Properties

destRange String?
The destination range of the route.
final
hashCode int
The hash code for this object.
no setterinherited
imported bool?
True if the peering route has been imported from a peer. The actual import happens if the field networkPeering.importCustomRoutes is true for this network, and networkPeering.exportCustomRoutes is true for the peer network, and the import does not result in a route conflict.
final
nextHopRegion String?
The region of peering route next hop, only applies to dynamic routes.
final
priority int?
The priority of the peering route.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
The type of the peering route. Check the Type enum for the list of possible values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String