ExternalVpnGatewayInterface class final
The interface for the external VPN gateway.
Constructors
- ExternalVpnGatewayInterface({int? id, String? ipAddress, String? ipv6Address})
- ExternalVpnGatewayInterface.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int?
-
The numeric ID of this interface.
The allowed input values for this id for different redundancy types of
external VPN gateway:
final
- ipAddress → String?
-
IP address of the interface in the external VPN gateway. Only IPv4 is
supported. This IP address can be either from your on-premise gateway or
another Cloud provider's VPN gateway, it cannot be an IP address from
Google Compute Engine.
final
- ipv6Address → String?
-
IPv6 address of the interface in the external VPN gateway. This IPv6
address can be either from your on-premise gateway or another Cloud
provider's VPN gateway, it cannot be an IP address from Google Compute
Engine. Must specify an IPv6 address (not IPV4-mapped) using any format
described in RFC 4291 (e.g. 2001:db8:0:0:2d9:51:0:0). The output format
is RFC 5952 format (e.g. 2001:db8::2d9:51:0:0).
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String