FirewallLogConfig_Metadata class final
This field can only be specified for a particular firewall rule if logging is enabled for that rule. This field denotes whether to include or exclude metadata for firewall logs.
Constructors
- FirewallLogConfig_Metadata(String value)
-
const
- FirewallLogConfig_Metadata.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const FirewallLogConfig_Metadata
- The default value for FirewallLogConfig_Metadata.
- excludeAllMetadata → const FirewallLogConfig_Metadata
- includeAllMetadata → const FirewallLogConfig_Metadata
- undefinedMetadata → const FirewallLogConfig_Metadata
- A value indicating that the enum field is not set.