menu
google_cloud_compute_v1 package
documentation
compute.dart
FirewallPolicyRuleSecureTag class
FirewallPolicyRuleSecureTag class
dark_mode
light_mode
FirewallPolicyRuleSecureTag
class
final
Constructors
FirewallPolicyRuleSecureTag
({
String
?
name
,
String
?
state
})
FirewallPolicyRuleSecureTag.fromJson
(
Object
?
j
)
factory
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
name
→
String
?
Name of the secure tag, created with TagManager's TagValue API.
final
qualifiedName
→
String
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or
google.rpc.ErrorInfo
.
final
inherited
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
state
→
String
?
Output only.
Output Only
State of the secure tag, either
EFFECTIVE
or
INEFFECTIVE
. A secure tag is
INEFFECTIVE
when it is deleted or its network is deleted. Check the State enum for the list of possible values.
final
Methods
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson
(
)
→
Object
toString
(
)
→
String
A string representation of this object.
override
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
Constants
fullyQualifiedName
→ const
String
google_cloud_compute_v1 package
documentation
compute
FirewallPolicyRuleSecureTag class
compute library