Firewall_Direction class final
Direction of traffic to which this firewall applies, either INGRESS or
EGRESS. The default is INGRESS. For EGRESS traffic, you cannot
specify the sourceTags fields.
Constructors
- Firewall_Direction(String value)
-
const
- Firewall_Direction.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const Firewall_Direction
- The default value for Firewall_Direction.
- egress → const Firewall_Direction
- Indicates that firewall should apply to outgoing traffic.
- ingress → const Firewall_Direction
- Indicates that firewall should apply to incoming traffic.
- undefinedDirection → const Firewall_Direction
- A value indicating that the enum field is not set.