update method
Updates the specified firewall rule with the data included in the request. Note that all fields will be updated if using PUT, even fields that are not specified. To update individual fields, please use PATCH instead.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
Future<Operation> update(UpdateFirewallRequest request) async {
final url = _endPoint.replace(
path:
'/compute/v1/projects/${request.project}/global/firewalls/${request.firewall}',
queryParameters: {'requestId': ?request.requestId},
);
final response = await _client.put(url, body: request.firewallResource);
return Operation.fromJson(response);
}