ForwardingRuleServiceDirectoryRegistration class final

Describes the auto-registration of the forwarding rule to Service Directory. The region and project of the Service Directory resource generated from this registration will be the same as this forwarding rule.

Constructors

ForwardingRuleServiceDirectoryRegistration({String? namespace, String? service, String? serviceDirectoryRegion})
ForwardingRuleServiceDirectoryRegistration.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
namespace String?
Service Directory namespace to register the forwarding rule under.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
service String?
Service Directory service to register the forwarding rule under.
final
serviceDirectoryRegion String?
Optional Service Directory region to register this global forwarding rule under. Default to "us-central1". Only used for PSC for Google APIs. All PSC for Google APIs forwarding rules on the same network should use the same Service Directory region.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String