ForwardingRule_IpVersion class final
The IP Version that will be used by this forwarding rule. Valid options are IPV4 or IPV6.
Constructors
- ForwardingRule_IpVersion(String value)
-
const
- ForwardingRule_IpVersion.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const ForwardingRule_IpVersion
- The default value for ForwardingRule_IpVersion.
- ipv4 → const ForwardingRule_IpVersion
- ipv6 → const ForwardingRule_IpVersion
- undefinedIpVersion → const ForwardingRule_IpVersion
- A value indicating that the enum field is not set.
- unspecifiedVersion → const ForwardingRule_IpVersion