ForwardingRules class final
The ForwardingRules API.
- Implementers
Constructors
- ForwardingRules({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
ForwardingRulesusingclientfor transport. - ForwardingRules.fromApiKey([String? apiKey])
-
Creates a
ForwardingRulesthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
aggregatedList(
AggregatedListForwardingRulesRequest request) → Future< ForwardingRuleAggregatedList> - Retrieves an aggregated list of forwarding rules.
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteForwardingRuleRequest request) → Future< Operation> - Deletes the specified ForwardingRule resource.
-
get(
GetForwardingRuleRequest request) → Future< ForwardingRule> - Returns the specified ForwardingRule resource.
-
insert(
InsertForwardingRuleRequest request) → Future< Operation> - Creates a ForwardingRule resource in the specified project and region using the data included in the request.
-
list(
ListForwardingRulesRequest request) → Future< ForwardingRuleList> - Retrieves a list of ForwardingRule resources available to the specified project and region.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchForwardingRuleRequest request) → Future< Operation> - Updates the specified forwarding rule with the data included in the request. This method supportsPATCH semantics and uses theJSON merge patch format and processing rules. Currently, you can only patch the network_tier field.
-
setLabels(
SetLabelsForwardingRuleRequest request) → Future< Operation> - Sets the labels on the specified resource. To learn more about labels, read the Labeling Resources documentation.
-
setTarget(
SetTargetForwardingRuleRequest request) → Future< Operation> - Changes target URL for forwarding rule. The new target should be of the same type as the old target.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited