ForwardingRulesScopedList class
final
Properties
-
forwardingRules
→ List<ForwardingRule>
-
A list of forwarding rules contained in this scope.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
qualifiedName
→ String
-
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or google.rpc.ErrorInfo.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
warning
→ Warning?
-
Informational warning which replaces the list of forwarding rules when
the list is empty.
final