resourceMetadata property
Output only. Contains standard resource metadata for an FutureReservation resource. It is populated for each instance of the FutureReservation resource, and includes the api_version the instance was retrieved through, and its canonical resource_type name.
Implementation
final ResourceMetadata? resourceMetadata;