FutureReservationCommitmentInfo_CommitmentPlan class final
Indicates if a Commitment needs to be created as part of FR delivery. If this field is not present, then no commitment needs to be created.
Constructors
- FutureReservationCommitmentInfo_CommitmentPlan(String value)
-
const
- FutureReservationCommitmentInfo_CommitmentPlan.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const FutureReservationCommitmentInfo_CommitmentPlan
- The default value for FutureReservationCommitmentInfo_CommitmentPlan.
- invalid → const FutureReservationCommitmentInfo_CommitmentPlan
- thirtySixMonth → const FutureReservationCommitmentInfo_CommitmentPlan
- twelveMonth → const FutureReservationCommitmentInfo_CommitmentPlan
- undefinedCommitmentPlan → const FutureReservationCommitmentInfo_CommitmentPlan
- A value indicating that the enum field is not set.