FutureReservationStatus class final
Output only Represents status related to the future reservation.
Constructors
-
FutureReservationStatus({String? amendmentStatus, List<
String> autoCreatedReservations = const [], StoragePoolExapoolProvisionedCapacityGb? exapoolProvisionedCapacityGb, FutureReservationStatusExistingMatchingUsageInfo? existingMatchingUsageInfo, int? fulfilledCount, FutureReservationStatusLastKnownGoodState? lastKnownGoodState, String? lockTime, String? procurementStatus, FutureReservationStatusSpecificSkuproperties? specificSkuProperties, FutureReservationStoragePoolProvisionedCapacity? storagePoolProvisionedCapacity}) - FutureReservationStatus.fromJson(Object? j)
-
factory
Properties
- amendmentStatus → String?
-
Output only.
Output OnlyThe current status of the requested amendment. Check the AmendmentStatus enum for the list of possible values.final -
autoCreatedReservations
→ List<
String> -
Output only. Fully qualified urls of the automatically created reservations at
start_time.
final
- exapoolProvisionedCapacityGb → StoragePoolExapoolProvisionedCapacityGb?
-
Output only. Exapool provisioned capacities for each SKU type.
final
- existingMatchingUsageInfo → FutureReservationStatusExistingMatchingUsageInfo?
-
Output only.
Output OnlyRepresents the existing matching usage for the future reservation.final - fulfilledCount → int?
-
Output only. This count indicates the fulfilled capacity so far. This is set during
"PROVISIONING" state. This count also includes capacity delivered as part
of existing matching reservations.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastKnownGoodState → FutureReservationStatusLastKnownGoodState?
-
Output only.
Output OnlyThis field represents the future reservation before an amendment was requested. If the amendment is declined, the Future Reservation will be reverted to the last known good state. The last known good state is not set when updating a future reservation whose Procurement Status is DRAFTING.final - lockTime → String?
-
Output only. Time when Future Reservation would become LOCKED, after which no
modifications to Future Reservation will be allowed. Applicable only
after the Future Reservation is in the APPROVED state. The lock_time is
an RFC3339 string. The procurement_status will transition to PROCURING
state at this time.
final
- procurementStatus → String?
-
Output only. Current state of this Future Reservation
Check the ProcurementStatus enum for the list of possible values.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- specificSkuProperties → FutureReservationStatusSpecificSkuproperties?
-
final
- storagePoolProvisionedCapacity → FutureReservationStoragePoolProvisionedCapacity?
-
Output only. Storage pool provisioned capacities for each SKU type.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String