FutureReservationStatusLastKnownGoodStateFutureReservationSpecs class final

The properties of the last known good state for the Future Reservation.

Properties

hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shareSettings ShareSettings?
Output only. Output Only The previous share settings of the Future Reservation.
final
specificSkuProperties FutureReservationSpecificSkuproperties?
Output only. Output Only The previous instance related properties of the Future Reservation.
final
timeWindow FutureReservationTimeWindow?
Output only. Output Only The previous time window of the Future Reservation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String