FutureReservation_ReservationMode class final

The reservation mode which determines reservation-termination behavior and expected pricing.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const FutureReservation_ReservationMode
The default value for FutureReservation_ReservationMode.
calendar → const FutureReservation_ReservationMode
The delivered reservations will delivered at specified start time and terminated at specified end time along with terminating the VMs running on it.
default$ → const FutureReservation_ReservationMode
The delivered reservations do not terminate VMs at the end of reservations. This is default mode.
reservationModeUnspecified → const FutureReservation_ReservationMode
undefinedReservationMode → const FutureReservation_ReservationMode
A value indicating that the enum field is not set.