FutureReservations class final
The FutureReservations API.
- Implementers
Constructors
- FutureReservations({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
FutureReservationsusingclientfor transport. - FutureReservations.fromApiKey([String? apiKey])
-
Creates a
FutureReservationsthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
aggregatedList(
AggregatedListFutureReservationsRequest request) → Future< FutureReservationsAggregatedListResponse> - Retrieves an aggregated list of future reservations.
-
cancel(
CancelFutureReservationRequest request) → Future< Operation> - Cancel the specified future reservation.
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteFutureReservationRequest request) → Future< Operation> - Deletes the specified future reservation.
-
get(
GetFutureReservationRequest request) → Future< FutureReservation> - Retrieves information about the specified future reservation.
-
insert(
InsertFutureReservationRequest request) → Future< Operation> - Creates a new Future Reservation.
-
list(
ListFutureReservationsRequest request) → Future< FutureReservationsListResponse> - A list of all the future reservations that have been configured for the specified project in specified zone.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
UpdateFutureReservationRequest request) → Future< Operation> - Updates the specified future reservation.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited