FutureResourcesRecommendation class final
Recommendation for single resources specification, to be created in the future.
Constructors
-
FutureResourcesRecommendation({String? endTime, String? location, Map<
String, FutureResourcesRecommendationOtherLocation> otherLocations = const {}, String? recommendationId, String? recommendationType, String? startTime}) - FutureResourcesRecommendation.fromJson(Object? j)
-
factory
Properties
- endTime → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- location → String?
-
The advised location for resource usage. When a zone, in format
'zones/'.
If not set, it means that no location is recommended - see
other_locations for details.
final
-
otherLocations
→ Map<
String, FutureResourcesRecommendationOtherLocation> -
List of locations in the request scope that were not
recommended. Keys of the map are zones, in format 'zones/'.
The values are status information indicating the recommendation status.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - recommendationId → String?
-
Unique id of the recommendation, a UUID string generated by the API.
final
- recommendationType → String?
-
Type of recommendation. Currently only FUTURE_RESERVATION is supported.
Check the RecommendationType enum for the list of possible values.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startTime → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String