FutureResourcesRecommendationOtherLocation class final
Information about recommendation status for locations that were allowed but not used by the response.
Constructors
- FutureResourcesRecommendationOtherLocation({String? details, String? status})
- FutureResourcesRecommendationOtherLocation.fromJson(Object? j)
-
factory
Properties
- details → String?
-
Details (human readable) describing the situation.
For example, if status is CONDITION_NOT_MET, then
details contain information about the parameters of the time window
that did not meet the required conditions.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String?
-
Status of recommendation in this location.
Check the Status enum for the list of possible values.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String