FutureResourcesRecommendationOtherLocation_Status class final
Status of recommendation in this location.
Constructors
- FutureResourcesRecommendationOtherLocation_Status(String value)
-
const
- FutureResourcesRecommendationOtherLocation_Status.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const FutureResourcesRecommendationOtherLocation_Status
- The default value for FutureResourcesRecommendationOtherLocation_Status.
- conditionsNotMet → const FutureResourcesRecommendationOtherLocation_Status
- The requested resources are offered in this location but the requested time window is does not meet the required conditions.
- noCapacity → const FutureResourcesRecommendationOtherLocation_Status
- The requested resources are offered in this location and the requested time window is accepted but there is no capacity within the requested time window.
- notSupported → const FutureResourcesRecommendationOtherLocation_Status
- The requested resources are not offered in this location. Retrying the request will not change this status.
- otherLocationStatusUndefined → const FutureResourcesRecommendationOtherLocation_Status
- Default value, unused.
- recommended → const FutureResourcesRecommendationOtherLocation_Status
- The requested resources are offered in this location and it is possible to request them. However, another location was better and was recommended.
- undefinedStatus → const FutureResourcesRecommendationOtherLocation_Status
- A value indicating that the enum field is not set.