FutureResourcesSpecAggregateResources class
final
Properties
acceleratorCount
→ int ?
Size of the request, in accelerator (chip) count.
final
hashCode
→ int
The hash code for this object.
no setter inherited
qualifiedName
→ String
The fully qualified name of this message, i.e., google.protobuf.Duration
or google.rpc.ErrorInfo.
final inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
vmFamily
→ String ?
The VM family that all instances scheduled against this reservation
must belong to. Use for TPU reservations.
Check the VmFamily enum for the list of possible values.
final
workloadType
→ String ?
Workload type. Use for TPU reservations.
Check the WorkloadType enum for the list of possible values.
final
google_cloud_compute_v1 0.1.1