FutureResourcesSpecLocationPolicy class final
Specification of locations to create resources in.
Constructors
-
FutureResourcesSpecLocationPolicy({Map<
String, FutureResourcesSpecLocationPolicyLocation> locations = const {}}) - FutureResourcesSpecLocationPolicy.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
locations
→ Map<
String, FutureResourcesSpecLocationPolicyLocation> -
Preferences for specified locations.
Keys of the map are locations - zones, in format of 'zones/'.
Values are preferences for the zones.
If a zone is not specified in this map, it is ALLOWed.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String