The machine type to use for instances that will use the reservation.
This field only accepts machine type names. e.g. n2-standard-4
and does not accept machine type full or partial url. e.g.
projects/my-l7ilb-project/zones/us-central1-a/machineTypes/n2-standard-4.
Use for GPU reservations.