GetHealthOperationMetadataHealthInfo_RepairCategory class final
Output only. The repair category.
Constructors
- GetHealthOperationMetadataHealthInfo_RepairCategory(String value)
-
const
- GetHealthOperationMetadataHealthInfo_RepairCategory.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const GetHealthOperationMetadataHealthInfo_RepairCategory
- The default value for GetHealthOperationMetadataHealthInfo_RepairCategory.
- repairCategoryCriticalFailure → const GetHealthOperationMetadataHealthInfo_RepairCategory
- The repair is because of critical failures, that are scoped outside emergent maintenance
- repairCategoryEmergentMaintenance → const GetHealthOperationMetadataHealthInfo_RepairCategory
- The repair is because of an emergent maintenance
- repairCategoryPlannedMaintenance → const GetHealthOperationMetadataHealthInfo_RepairCategory
- The repair is because of a planned maintenance
- repairCategoryUnspecified → const GetHealthOperationMetadataHealthInfo_RepairCategory
- Unspecified repair category.
- repairCategoryUserReportedFault → const GetHealthOperationMetadataHealthInfo_RepairCategory
- The repair is because of a user reported fault
- undefinedRepairCategory → const GetHealthOperationMetadataHealthInfo_RepairCategory
- A value indicating that the enum field is not set.