GetHealthOperationMetadataHealthInfo_UnhealthyReason class final
Output only. The reason for unhealthy status.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const GetHealthOperationMetadataHealthInfo_UnhealthyReason
- The default value for GetHealthOperationMetadataHealthInfo_UnhealthyReason.
- undefinedUnhealthyReason → const GetHealthOperationMetadataHealthInfo_UnhealthyReason
- A value indicating that the enum field is not set.
- unhealthyReasonPendingUserApproval → const GetHealthOperationMetadataHealthInfo_UnhealthyReason
- The slot is unhealthy because there is a pending repair, waiting for customer approval
- unhealthyReasonRepairing → const GetHealthOperationMetadataHealthInfo_UnhealthyReason
- The slot is unhealthy because repair is in progress
- unhealthyReasonUnschedulable → const GetHealthOperationMetadataHealthInfo_UnhealthyReason
- The slot is unhealthy because a vm cannot be scheduled on it, and no repairs are running on the slot
- unhealthyReasonUnspecified → const GetHealthOperationMetadataHealthInfo_UnhealthyReason
- Unspecified unhealthy reason.