GlobalAddresses class final
The GlobalAddresses API.
- Implementers
Constructors
- GlobalAddresses({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
GlobalAddressesusingclientfor transport. - GlobalAddresses.fromApiKey([String? apiKey])
-
Creates a
GlobalAddressesthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteGlobalAddressRequest request) → Future< Operation> - Deletes the specified address resource.
-
get(
GetGlobalAddressRequest request) → Future< Address> - Returns the specified address resource.
-
insert(
InsertGlobalAddressRequest request) → Future< Operation> - Creates an address resource in the specified project by using the data included in the request.
-
list(
ListGlobalAddressesRequest request) → Future< AddressList> - Retrieves a list of global addresses.
-
move(
MoveGlobalAddressRequest request) → Future< Operation> - Moves the specified address resource from one project to another project.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setLabels(
SetLabelsGlobalAddressRequest request) → Future< Operation> - Sets the labels on a GlobalAddress. To learn more about labels, read theLabeling Resources documentation.
-
testIamPermissions(
TestIamPermissionsGlobalAddressRequest request) → Future< TestPermissionsResponse> - Returns permissions that a caller has on the specified resource.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited