GlobalAddressesMoveRequest class
final
Properties
-
description
→ String?
-
An optional destination address description if intended to be different
from the source.
final
-
destinationAddress
→ String?
-
The URL of the destination address to move to. This can be a full or
partial URL. For example, the following are all valid URLs to a address:
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
qualifiedName
→ String
-
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or google.rpc.ErrorInfo.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited