GlobalNetworkEndpointGroups class final
The GlobalNetworkEndpointGroups API.
- Implementers
Constructors
- GlobalNetworkEndpointGroups({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
GlobalNetworkEndpointGroupsusingclientfor transport. - GlobalNetworkEndpointGroups.fromApiKey([String? apiKey])
-
Creates a
GlobalNetworkEndpointGroupsthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
attachNetworkEndpoints(
AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest request) → Future< Operation> - Attach a network endpoint to the specified network endpoint group.
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteGlobalNetworkEndpointGroupRequest request) → Future< Operation> - Deletes the specified network endpoint group.Note that the NEG cannot be deleted if there are backend services referencing it.
-
detachNetworkEndpoints(
DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest request) → Future< Operation> - Detach the network endpoint from the specified network endpoint group.
-
get(
GetGlobalNetworkEndpointGroupRequest request) → Future< NetworkEndpointGroup> - Returns the specified network endpoint group.
-
insert(
InsertGlobalNetworkEndpointGroupRequest request) → Future< Operation> - Creates a network endpoint group in the specified project using the parameters that are included in the request.
-
list(
ListGlobalNetworkEndpointGroupsRequest request) → Future< NetworkEndpointGroupList> - Retrieves the list of network endpoint groups that are located in the specified project.
-
listNetworkEndpoints(
ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest request) → Future< NetworkEndpointGroupsListNetworkEndpoints> - Lists the network endpoints in the specified network endpoint group.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited