GlobalOrganizationOperations class final
The GlobalOrganizationOperations API.
- Implementers
Constructors
- GlobalOrganizationOperations({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
GlobalOrganizationOperationsusingclientfor transport. - GlobalOrganizationOperations.fromApiKey([String? apiKey])
-
Creates a
GlobalOrganizationOperationsthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteGlobalOrganizationOperationRequest request) → Future< DeleteGlobalOrganizationOperationResponse> - Deletes the specified Operations resource.
-
get(
GetGlobalOrganizationOperationRequest request) → Future< Operation> -
Retrieves the specified Operations resource. Gets a list of operations
by making a
list()request. -
list(
ListGlobalOrganizationOperationsRequest request) → Future< OperationList> - Retrieves a list of Operation resources contained within the specified organization.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited