delete method
Purge scoped resources (zonal policies) from a global VM extension policy, and then delete the global VM extension policy. Purge of the scoped resources is a pre-condition of the global VM extension policy deletion. The deletion of the global VM extension policy happens after the purge rollout is done, so it's not a part of the LRO. It's an automatic process that triggers in the backend.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
Future<Operation> delete(DeleteGlobalVmExtensionPolicyRequest request) async {
final url = _endPoint.replace(
path:
'/compute/v1/projects/${request.project}/global/vmExtensionPolicies/${request.globalVmExtensionPolicy}/delete',
queryParameters: {'requestId': ?request.requestId},
);
final response = await _client.post(
url,
body: request.globalVmExtensionPolicyRolloutOperationRolloutInputResource,
);
return Operation.fromJson(response);
}