GlobalVmExtensionPolicy class final
Message describing GlobalVmExtensionPolicy object.
Constructors
-
GlobalVmExtensionPolicy({String? creationTimestamp, String? description, Map<
String, GlobalVmExtensionPolicyExtensionPolicy> extensionPolicies = const {}, BigInt? id, List<GlobalVmExtensionPolicyInstanceSelector> instanceSelectors = const [], String? kind, String? name, int? priority, GlobalVmExtensionPolicyRolloutOperation? rolloutOperation, String? scopedResourceStatus, String? selfLink, String? selfLinkWithId, String? updateTimestamp}) - GlobalVmExtensionPolicy.fromJson(Object? j)
-
factory
Properties
- creationTimestamp → String?
-
Output only.
Output OnlyCreation timestamp inRFC3339 text format.final - description → String?
-
An optional description of this resource. Provide this property when you
create the resource.
final
-
extensionPolicies
→ Map<
String, GlobalVmExtensionPolicyExtensionPolicy> -
Required. Map from extension (eg: "cloudops") to its policy configuration.
The key is the name of the extension.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → BigInt?
-
Output only.
Output OnlyThe unique identifier for the resource. This identifier is defined by the server.final -
instanceSelectors
→ List<
GlobalVmExtensionPolicyInstanceSelector> -
Optional. Selector to target VMs for a policy.
There is a logical "AND" between instance_selectors.
final
- kind → String?
-
Output only.
Output OnlyType of the resource. Alwayscompute#globalVmExtensionPolicy for globalVmExtensionPolicies.final - name → String?
-
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression
[a-z]([-a-z0-9]*[a-z0-9])?which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.final - priority → int?
-
Optional. Used to resolve conflicts when multiple policies are active for the same
extension. Defaults to 0.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - rolloutOperation → GlobalVmExtensionPolicyRolloutOperation?
-
Required. The rollout strategy and status.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scopedResourceStatus → String?
-
Output only.
Output OnlyThe scoped resource status. It's only for tracking the purging status of the policy. Check the ScopedResourceStatus enum for the list of possible values.final - selfLink → String?
-
Output only.
Output OnlyServer-defined fully-qualified URL for this resource.final - selfLinkWithId → String?
-
Output only.
Output OnlyServer-defined URL for this resource's resource id.final - updateTimestamp → String?
-
Output only.
Output OnlyUpdate timestamp inRFC3339 text format.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String