GlobalVmExtensionPolicyExtensionPolicy class final
Policy for a single extension.
Constructors
- GlobalVmExtensionPolicyExtensionPolicy({String? pinnedVersion, String? stringConfig})
- GlobalVmExtensionPolicyExtensionPolicy.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- pinnedVersion → String?
-
Optional. The version pinning for the extension.
If empty, the extension will be installed with the latest version
released by the extension producer.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringConfig → String?
-
Optional. String configuration. Any string payload that the extension
understands.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String