Optional. Specifies the behavior of the rollout if a conflict is detected in a
project during a rollout. This only applies to insert and update
methods.
Optional. Specifies the predefined rollout plan for the policy. Valid values
are SLOW_ROLLOUT and FAST_ROLLOUT. The recommended value is
SLOW_ROLLOUT for progressive rollout. For more information, see Rollout
plans for global policies.
Check the PredefinedRolloutPlan enum for the list of possible values.
Optional. The UUID that identifies a policy rollout retry attempt for update and
delete operations. Set this field only when retrying a rollout for an
existing extension policy.