GlobalVmExtensionPolicyRolloutOperationRolloutStatus class final
Constructors
-
GlobalVmExtensionPolicyRolloutOperationRolloutStatus({List<
GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata> currentRollouts = const [], GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata? previousRollout}) - GlobalVmExtensionPolicyRolloutOperationRolloutStatus.fromJson(Object? j)
-
factory
Properties
-
currentRollouts
→ List<
GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata> -
Output only.
Output OnlyThe current rollouts for the latest version of the resource. There should be only one current rollout, but for scalability, we make it repeated.final - hashCode → int
-
The hash code for this object.
no setterinherited
- previousRollout → GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata?
-
Output only.
Output OnlyThe last completed rollout resource. This field will not be populated until the first rollout is completed.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String