GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata class final
Constructors
-
GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata({Map<
String, GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadataLocationRolloutStatus> locationRolloutStatus = const {}, String? rollout, String? rolloutPlan, String? state}) - GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
locationRolloutStatus
→ Map<
String, GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadataLocationRolloutStatus> -
Output only.
Output OnlyThe rollout status for each location. The list of the locations is the same as the list of locations in the rollout plan.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - rollout → String?
-
Output only.
Output OnlyThe name of the rollout. Ex. projects//locations/global/rollouts/.final - rolloutPlan → String?
-
Output only.
Output OnlyThe name of the rollout plan. Ex. projects//locations/global/rolloutPlans/.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → String?
-
Output only.
Output OnlyThe overall state of the rollout. Check the State enum for the list of possible values.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String