GuestAttributes class final
A guest attributes entry.
Constructors
- GuestAttributes({String? kind, String? queryPath, GuestAttributesValue? queryValue, String? selfLink, String? variableKey, String? variableValue})
- GuestAttributes.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → String?
-
Output only.
Output OnlyType of the resource. Alwayscompute#guestAttributes for guest attributes entry.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - queryPath → String?
-
The path to be queried. This can be the default namespace ('') or a
nested namespace ('/') or a specified key
('/').
final
- queryValue → GuestAttributesValue?
-
Output only.
Output OnlyThe value of the requested queried path.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfLink → String?
-
Output only.
Output OnlyServer-defined URL for this resource.final - variableKey → String?
-
The key to search for.
final
- variableValue → String?
-
Output only.
Output OnlyThe value found for the requested key.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String