HealthCheckService class final
Represents a Health-Check as a Service resource.
Constructors
-
HealthCheckService({String? creationTimestamp, String? description, String? fingerprint, List<
String> healthChecks = const [], String? healthStatusAggregationPolicy, BigInt? id, String? kind, String? name, List<String> networkEndpointGroups = const [], List<String> notificationEndpoints = const [], String? region, String? selfLink}) - HealthCheckService.fromJson(Object? j)
-
factory
Properties
- creationTimestamp → String?
-
Output only.
Output OnlyCreation timestamp inRFC3339 text format.final - description → String?
-
An optional description of this resource. Provide this property when you
create the resource.
final
- fingerprint → String?
-
Fingerprint of this resource. A hash of the contents stored in this object.
This field is used in optimistic locking. This field will be ignored when
inserting a HealthCheckService. An up-to-date fingerprint must
be provided in order to patch/update the HealthCheckService; Otherwise, the
request will fail with error 412 conditionNotMet. To see the
latest fingerprint, make a get() request to retrieve the
HealthCheckService.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
healthChecks
→ List<
String> -
A list of URLs to the HealthCheck resources. Must have
at least one HealthCheck, and not more than 10 for regionalHealthCheckService, and not more than 1 for globalHealthCheckService.HealthCheck resources must haveportSpecification=USE_SERVING_PORT orportSpecification=USE_FIXED_PORT. For
regional HealthCheckService, theHealthCheck must be regional and in the same
region. For global HealthCheckService,HealthCheck must be global. Mix of regional and globalHealthChecks is not supported. Multiple regionalHealthChecks must belong to the same region. RegionalHealthChecks must belong to the same region as zones ofNetworkEndpointGroups. For globalHealthCheckService using globalINTERNET_IP_PORT NetworkEndpointGroups, the
global HealthChecks must specify sourceRegions,
and HealthChecks that specify sourceRegions can
only be used with global INTERNET_IP_PORTNetworkEndpointGroups.
final
- healthStatusAggregationPolicy → String?
-
Optional. Policy for how the results from multiple health checks
for the same endpoint are aggregated. Defaults to NO_AGGREGATION
if unspecified.
final
- id → BigInt?
-
Output only.
Output OnlyThe unique identifier for the resource. This identifier is defined by the server.final - kind → String?
-
Output only.
Output onlyType of the resource. Alwayscompute#healthCheckServicefor health check services.final - name → String?
-
Name of the resource. The name must be 1-63 characters long, and comply
with RFC1035. Specifically, the name must be 1-63 characters
long and match the regular expression
[a-z]([-a-z0-9]*[a-z0-9])?which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.final -
networkEndpointGroups
→ List<
String> -
A list of URLs to the NetworkEndpointGroup
resources. Must not have more than 100. For regionalHealthCheckService, NEGs must be in
zones in the region of the HealthCheckService. For globalHealthCheckServices, the NetworkEndpointGroups
must be global INTERNET_IP_PORT.
final
-
notificationEndpoints
→ List<
String> -
A list of URLs to the NotificationEndpoint
resources. Must not have more than 10. A list of endpoints for
receiving notifications of change in health status. For regionalHealthCheckService,NotificationEndpoint must be regional and in the
same region. For global HealthCheckService,NotificationEndpoint must be global.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - region → String?
-
Output only.
Output OnlyURL of the region where the health check service resides. This field is not applicable to global health check services. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfLink → String?
-
Output only.
Output OnlyServer-defined URL for the resource.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String