HealthCheckService_HealthStatusAggregationPolicy class final
Optional. Policy for how the results from multiple health checks for the same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified.
- NO_AGGREGATION. An EndpointHealth message is returned for each pair in the health check service.
- AND. If any health check of an endpoint reportsUNHEALTHY, then UNHEALTHY is theHealthState of the endpoint. If all health checks reportHEALTHY, the HealthState of the endpoint isHEALTHY.
. This is only allowed with regional HealthCheckService.
Constructors
- HealthCheckService_HealthStatusAggregationPolicy(String value)
-
const
- HealthCheckService_HealthStatusAggregationPolicy.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const HealthCheckService_HealthStatusAggregationPolicy
- The default value for HealthCheckService_HealthStatusAggregationPolicy.
- and → const HealthCheckService_HealthStatusAggregationPolicy
- If any backend's health check reports UNHEALTHY, then UNHEALTHY is the HealthState of the entire health check service. If all backend's are healthy, the HealthState of the health check service isHEALTHY.
- noAggregation → const HealthCheckService_HealthStatusAggregationPolicy
- An EndpointHealth message is returned for each backend in the health check service.
- undefinedHealthStatusAggregationPolicy → const HealthCheckService_HealthStatusAggregationPolicy
- A value indicating that the enum field is not set.