HealthSource class final
Represents a health source.
A health source resource specifies the source resources and the health aggregation policy applied to the source resources to determine the aggregated health status.
Constructors
-
HealthSource({String? creationTimestamp, String? description, String? fingerprint, String? healthAggregationPolicy, BigInt? id, String? kind, String? name, String? region, String? selfLink, String? selfLinkWithId, String? sourceType, List<
String> sources = const []}) - HealthSource.fromJson(Object? j)
-
factory
Properties
- creationTimestamp → String?
-
Output only.
Output OnlyCreation timestamp inRFC3339 text format.final - description → String?
-
An optional description of this resource. Provide this property when you
create the resource.
final
- fingerprint → String?
-
Fingerprint of this resource. A hash of the contents stored in this object.
This field is used in optimistic locking. This field will be ignored when
inserting a HealthSource. An up-to-date fingerprint
must be provided in order to patch the HealthSource; Otherwise, the request
will fail with error 412 conditionNotMet. To see the latest
fingerprint, make a get() request to retrieve the
HealthSource.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- healthAggregationPolicy → String?
-
URL to the HealthAggregationPolicy resource. Must be set. Must
be regional and in the same region as the HealthSource. Can be
mutated.
final
- id → BigInt?
-
Output only.
Output OnlyA unique identifier for this resource type. The server generates this identifier.final - kind → String?
-
Output only.
Output OnlyType of the resource. Alwayscompute#healthSource for health sources.final - name → String?
-
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression
[a-z]([-a-z0-9]*[a-z0-9])?which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - region → String?
-
Output only.
Output OnlyURL of the region where the health source resides. This field applies only to the regional resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfLink → String?
-
Output only.
Output OnlyServer-defined URL for the resource.final - selfLinkWithId → String?
-
Output only.
Output OnlyServer-defined URL with id for the resource.final -
sources
→ List<
String> -
URLs to the source resources. Must be size 1. Must be aBackendService if
the sourceType is BACKEND_SERVICE. TheBackendService must have load balancing schemeINTERNAL or INTERNAL_MANAGED and must be regional
and in the same region as the HealthSource (cross-region
deployment for INTERNAL_MANAGED is not supported). TheBackendService may use only IGs, MIGs, or NEGs of typeGCE_VM_IP or GCE_VM_IP_PORT. TheBackendService may not use haPolicy. Can be
mutated.
final
- sourceType → String?
-
Specifies the type of the HealthSource. The only allowed value
is BACKEND_SERVICE. Must be specified when theHealthSource is created, and cannot be mutated.
Check the SourceType enum for the list of possible values.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String