HealthSourcesGetHealthResponseSourceInfoBackendInfo class
final
Properties
-
endpointCount
→ int?
-
Total number of endpoints when determining the health of the
regionHealthSource.
final
-
group
→ String?
-
Fully qualified URL of an instance group or network endpoint group
behind the source backend service.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
healthyEndpointCount
→ int?
-
Number of endpoints considered healthy when determining health of the
regionHealthSource.
final
-
qualifiedName
→ String
-
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or google.rpc.ErrorInfo.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited