Constructors
HealthStatus ({Map <String , String > annotations = const {} , String ? forwardingRule , String ? forwardingRuleIp , String ? healthState , String ? instance , String ? ipAddress , String ? ipv6Address , String ? ipv6HealthState , int ? port , String ? weight , String ? weightError })
HealthStatus.fromJson (Object ? j )
factory
Properties
annotations
→ Map <String , String >
Metadata defined as annotations for network endpoint.
final
forwardingRule
→ String ?
URL of the forwarding rule associated with the health status of the
instance.
final
forwardingRuleIp
→ String ?
A forwarding rule IP address assigned to this instance.
final
hashCode
→ int
The hash code for this object.
no setter inherited
healthState
→ String ?
Health state of the IPv4 address of the instance.
Check the HealthState enum for the list of possible values.
final
instance
→ String ?
URL of the instance resource.
final
ipAddress
→ String ?
For target pool based Network Load Balancing, it indicates the forwarding
rule's IP address assigned to this instance. For other types of load
balancing, the field indicates VM internal ip.
final
ipv6Address
→ String ?
final
ipv6HealthState
→ String ?
Health state of the IPv6 address of the instance.
Check the Ipv6HealthState enum for the list of possible values.
final
port
→ int ?
The named port of the instance group, not necessarily the port that is
health-checked.
final
qualifiedName
→ String
The fully qualified name of this message, i.e., google.protobuf.Duration
or google.rpc.ErrorInfo.
final inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
weight
→ String ?
final
weightError
→ String ?
Check the WeightError enum for the list of possible values.
final
google_cloud_compute_v1 0.1.1