HealthStatusForNetworkEndpoint class
final
Properties
backendService
→ BackendServiceReference ?
URL of the backend service associated with the health state of the network
endpoint.
final
forwardingRule
→ ForwardingRuleReference ?
URL of the forwarding rule associated with the health state of the network
endpoint.
final
hashCode
→ int
The hash code for this object.
no setter inherited
healthCheck
→ HealthCheckReference ?
URL of the health check associated with the health state of the network
endpoint.
final
healthCheckService
→ HealthCheckServiceReference ?
URL of the health check service associated with the health state of the
network endpoint.
final
healthState
→ String ?
Health state of the network endpoint determined based on the health checks
configured.
Check the HealthState enum for the list of possible values.
final
ipv6HealthState
→ String ?
Health state of the ipv6 network endpoint determined based on the health
checks configured.
Check the Ipv6HealthState enum for the list of possible values.
final
qualifiedName
→ String
The fully qualified name of this message, i.e., google.protobuf.Duration
or google.rpc.ErrorInfo.
final inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
google_cloud_compute_v1 0.1.0