HostRule class final
UrlMaps A host-matching rule for a URL. If matched, will use the namedPathMatcher to select the BackendService.
Constructors
Properties
- description → String?
-
An optional description of this resource. Provide this property when you
create the resource.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hosts
→ List<
String> -
The list of host patterns to match. They must be valid hostnames with
optional port numbers in the format host:port.* matches any string of (
a-z0-9-.*). In that case, * must be the first character, and if followed by anything, the immediate following character must be either - or ..final - pathMatcher → String?
-
The name of the PathMatcher to use to match the path portion
of the URL if the hostRule matches the URL's host portion.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String