hosts property
The list of host patterns to match. They must be valid hostnames with
optional port numbers in the format host:port.* matches any string of (a-z0-9-.*). In
that case, * must be the first character, and if followed by
anything, the immediate following character must be either -
or ..
- based matching is not supported when the URL map is bound to a target gRPC proxy that has the validateForProxyless field set to true.
Implementation
final List<String> hosts;