useServingPort constant
Http2HealthCheck_PortSpecification
const useServingPort
For network endpoint group backends, the health check uses the port number specified on each endpoint in the network endpoint group. For instance group backends, the health check uses the port number specified for the backend service's named port defined in the instance group's named ports.
Implementation
static const useServingPort = Http2HealthCheck_PortSpecification(
'USE_SERVING_PORT',
);