HttpFaultDelay class final
Specifies the delay introduced by the load balancer before forwarding the request to the backend service as part of fault injection.
Constructors
- HttpFaultDelay({Duration? fixedDelay, double? percentage})
- HttpFaultDelay.fromJson(Object? j)
-
factory
Properties
- fixedDelay → Duration?
-
Specifies the value of the fixed delay interval.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- percentage → double?
-
The percentage of traffic for connections, operations, or requests for
which a delay is introduced as part of fault injection.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String