HttpFaultInjection class final
The specification for fault injection introduced into traffic to test the resiliency of clients to backend service failure. As part of fault injection, when clients send requests to a backend service, delays can be introduced by the load balancer on a percentage of requests before sending those request to the backend service. Similarly requests from clients can be aborted by the load balancer for a percentage of requests.
Constructors
- HttpFaultInjection({HttpFaultAbort? abort, HttpFaultDelay? delay})
- HttpFaultInjection.fromJson(Object? j)
-
factory
Properties
- abort → HttpFaultAbort?
-
The specification for how client requests are aborted as part of fault
injection.
final
- delay → HttpFaultDelay?
-
The specification for how client requests are delayed as part of fault
injection, before being sent to a backend service.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String