HttpHeaderMatch class final
matchRule criteria for request header matches.
Constructors
- HttpHeaderMatch({String? exactMatch, String? headerName, bool? invertMatch, String? prefixMatch, bool? presentMatch, Int64RangeMatch? rangeMatch, String? regexMatch, String? suffixMatch})
- HttpHeaderMatch.fromJson(Object? j)
-
factory
Properties
- exactMatch → String?
-
The value should exactly match contents of exactMatch.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerName → String?
-
The name of the HTTP header to match.
final
- invertMatch → bool?
-
If set to false, the headerMatch is considered a
match if the preceding match criteria are met. If set to true,
the headerMatch is considered a match if the preceding
match criteria are NOT met.
final
- prefixMatch → String?
-
The value of the header must start with the contents ofprefixMatch.
final
- presentMatch → bool?
-
A header with the contents of headerName must exist. The
match takes place whether or not the request's header has a value.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - rangeMatch → Int64RangeMatch?
-
The header value must be an integer and its value must be in the range
specified in rangeMatch. If the header does not contain an
integer, number or is empty, the match fails.
final
- regexMatch → String?
-
The value of the header must match the regular expression specified inregexMatch.
For more information about regular expression syntax, see Syntax.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suffixMatch → String?
-
The value of the header must end with the contents ofsuffixMatch.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String