HttpQueryParameterMatch class final

HttpRouteRuleMatch criteria for a request's query parameter.

Constructors

HttpQueryParameterMatch({String? exactMatch, String? name, bool? presentMatch, String? regexMatch})
HttpQueryParameterMatch.fromJson(Object? j)
factory

Properties

exactMatch String?
The queryParameterMatch matches if the value of the parameter exactly matches the contents of exactMatch.
final
hashCode int
The hash code for this object.
no setterinherited
name String?
The name of the query parameter to match. The query parameter must exist in the request, in the absence of which the request match fails.
final
presentMatch bool?
Specifies that the queryParameterMatch matches if the request contains the query parameter, irrespective of whether the parameter has a value or not.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
regexMatch String?
The queryParameterMatch matches if the value of the parameter matches the regular expression specified byregexMatch. For more information about regular expression syntax, see Syntax.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String