name property
The name of the query parameter to match. The query parameter must exist in the request, in the absence of which the request match fails.
Implementation
final String? name;
The name of the query parameter to match. The query parameter must exist in the request, in the absence of which the request match fails.
final String? name;