HttpRouteRule class final
The HttpRouteRule setting specifies how to match an HTTP request and the corresponding routing action that load balancing proxies perform.
Constructors
-
HttpRouteRule({CustomErrorResponsePolicy? customErrorResponsePolicy, String? description, HttpHeaderAction? headerAction, List<
HttpRouteRuleMatch> matchRules = const [], int? priority, HttpRouteAction? routeAction, String? service, HttpRedirectAction? urlRedirect}) - HttpRouteRule.fromJson(Object? j)
-
factory
Properties
- customErrorResponsePolicy → CustomErrorResponsePolicy?
-
customErrorResponsePolicy specifies how the Load
Balancer returns error responses when BackendServiceorBackendBucket responds with an error.
final
- description → String?
-
The short description conveying the intent of this routeRule.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerAction → HttpHeaderAction?
-
Specifies changes to request and response headers that need to take effect
for the selected backendService.
final
-
matchRules
→ List<
HttpRouteRuleMatch> -
The list of criteria for matching attributes of a request to thisrouteRule. This list has OR semantics: the request matches
this routeRule when any of thematchRules are satisfied. However predicates within
a given matchRule have AND semantics. All predicates
within a matchRule must match for the request to
match the rule.
final
- priority → int?
-
For routeRules within a given pathMatcher,
priority determines the order in which a load balancer interpretsrouteRules. RouteRules are evaluated in order
of priority, from the lowest to highest number. The priority of a
rule decreases as its number increases (1, 2, 3, N+1). The first rule
that matches the request is applied.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - routeAction → HttpRouteAction?
-
In response to a matching matchRule, the load balancer
performs advanced routing actions, such as URL rewrites and header
transformations, before forwarding the request to the selected backend.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- service → String?
-
The full or partial URL of the backend service resource to which traffic
is directed if this rule is matched. If routeAction is
also specified, advanced routing actions, such as URL rewrites,
take effect before sending the request to the backend.
final
- urlRedirect → HttpRedirectAction?
-
When this rule is matched, the request is redirected to a URL
specified by urlRedirect.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String