HttpRouteRuleMatch class final
HttpRouteRuleMatch specifies a set of criteria for matching requests to an HttpRouteRule. All specified criteria must be satisfied for a match to occur.
Constructors
-
HttpRouteRuleMatch({String? fullPathMatch, List<
HttpHeaderMatch> headerMatches = const [], bool? ignoreCase, List<MetadataFilter> metadataFilters = const [], String? pathTemplateMatch, String? prefixMatch, List<HttpQueryParameterMatch> queryParameterMatches = const [], String? regexMatch}) - HttpRouteRuleMatch.fromJson(Object? j)
-
factory
Properties
- fullPathMatch → String?
-
For satisfying the matchRule condition, the path of the
request must exactly match the value specified infullPathMatch after removing any query parameters and anchor
that may be part of the original URL.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headerMatches
→ List<
HttpHeaderMatch> -
Specifies a list of header match criteria, all of which must match
corresponding headers in the request.
final
- ignoreCase → bool?
-
Specifies that prefixMatch and fullPathMatch
matches are case sensitive.
final
-
metadataFilters
→ List<
MetadataFilter> -
Opaque filter criteria used by the load balancer to restrict routing
configuration to a limited set of xDS
compliant clients. In their xDS requests to the load balancer, xDS clients
present node
metadata. When there is a match, the relevant routing configuration
is made available to those proxies.
final
- pathTemplateMatch → String?
-
If specified, this field defines a path template pattern that must match
the :path header after the query string is removed.
final
- prefixMatch → String?
-
For satisfying the matchRule condition, the request's
path must begin with the specified prefixMatch.prefixMatch must begin with a /.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited -
queryParameterMatches
→ List<
HttpQueryParameterMatch> -
Specifies a list of query parameter match criteria, all of which must
match corresponding query parameters in the request.
final
- regexMatch → String?
-
For satisfying the matchRule condition, the path of the
request must satisfy the regular expression specified inregexMatch after removing any query parameters and anchor
supplied with the original URL. For
more information about regular expression syntax, see Syntax.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String