headerMatches property
Specifies a list of header match criteria, all of which must match corresponding headers in the request.
Implementation
final List<HttpHeaderMatch> headerMatches;
Specifies a list of header match criteria, all of which must match corresponding headers in the request.
final List<HttpHeaderMatch> headerMatches;