sourceImageId property
Output only. Output Only
The ID value of the image used to create this image. This value may be used
to determine whether the image was taken from the current or a previous
instance of a given image name.
Implementation
final String? sourceImageId;