sourceSnapshotId property
Output only. Output Only
The ID value of the snapshot used to create this image. This value may be
used to determine whether the snapshot was taken from the current or a
previous instance of a given snapshot name.
Implementation
final String? sourceSnapshotId;