disks property
Disks to be attached to the instances created from in this selection. They override the disks specified in the instance properties.
Implementation
final List<AttachedDisk> disks;
Disks to be attached to the instances created from in this selection. They override the disks specified in the instance properties.
final List<AttachedDisk> disks;