InstanceGroup class final
Represents an Instance Group resource.
Instance Groups can be used to configure a target forload balancing.
Instance groups can either be managed or unmanaged.
To create managed instance groups, use the instanceGroupManager orregionInstanceGroupManager resource instead.
Use zonal unmanaged instance groups if you need to applyload balancing to groups of heterogeneous instances or if you need to manage the instances yourself. You cannot create regional unmanaged instance groups.
For more information, readInstance groups.
Constructors
-
InstanceGroup({String? creationTimestamp, String? description, String? fingerprint, BigInt? id, String? kind, String? name, List<
NamedPort> namedPorts = const [], String? network, String? region, String? selfLink, int? size, String? subnetwork, String? zone}) - InstanceGroup.fromJson(Object? j)
-
factory
Properties
- creationTimestamp → String?
-
Output only.
Output OnlyThe creation timestamp for this instance group inRFC3339 text format.final - description → String?
-
An optional description of this resource. Provide this property when you
create the resource.
final
- fingerprint → String?
-
Output only.
Output OnlyThe fingerprint of the named ports. The system uses this fingerprint to detect conflicts when multiple users change the named ports concurrently.final - hashCode → int
-
The hash code for this object.
no setterinherited
- id → BigInt?
-
Output only.
Output OnlyA unique identifier for this instance group, generated by the server.final - kind → String?
-
Output only.
Output OnlyThe resource type, which is alwayscompute#instanceGroup for instance groups.final - name → String?
-
The name of the instance group. The name must be 1-63 characters
long, and comply withRFC1035.
final
-
namedPorts
→ List<
NamedPort> -
Optional. Assigns a name to a port number. For example:{name: "http", port: 80}
final
- network → String?
-
Output OnlyThe URL of the network to which all instances in the instance group belong. If your instance has multiple network interfaces, then the network and subnetwork fields only refer to the network and subnet used by your primary interface (nic0).final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - region → String?
-
Output only.
Output OnlyThe URL of theregion where the instance group is located (for regional resources).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfLink → String?
-
Output only.
Output OnlyThe URL for this instance group. The server generates this URL.final - size → int?
-
Output only.
Output OnlyThe total number of instances in the instance group.final - subnetwork → String?
-
Output only.
Output OnlyThe URL of the subnetwork to which all instances in the instance group belong. If your instance has multiple network interfaces, then the network and subnetwork fields only refer to the network and subnet used by your primary interface (nic0).final - zone → String?
-
Output only.
Output OnlyThe URL of thezone where the instance group is located (for zonal resources).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String