InstanceGroupManager class final
Represents a Managed Instance Group resource.
An instance group is a collection of VM instances that you can manage as a single entity. For more information, readInstance groups.
For zonal Managed Instance Group, use the instanceGroupManagers resource.
For regional Managed Instance Group, use theregionInstanceGroupManagers resource.
Constructors
-
InstanceGroupManager({InstanceGroupManagerAllInstancesConfig? allInstancesConfig, List<
InstanceGroupManagerAutoHealingPolicy> autoHealingPolicies = const [], String? baseInstanceName, String? creationTimestamp, InstanceGroupManagerActionsSummary? currentActions, String? description, DistributionPolicy? distributionPolicy, String? fingerprint, BigInt? id, InstanceGroupManagerInstanceFlexibilityPolicy? instanceFlexibilityPolicy, String? instanceGroup, InstanceGroupManagerInstanceLifecyclePolicy? instanceLifecyclePolicy, String? instanceTemplate, String? kind, String? listManagedInstancesResults, String? name, List<NamedPort> namedPorts = const [], String? region, InstanceGroupManagerResourcePolicies? resourcePolicies, bool? satisfiesPzi, bool? satisfiesPzs, String? selfLink, InstanceGroupManagerStandbyPolicy? standbyPolicy, StatefulPolicy? statefulPolicy, InstanceGroupManagerStatus? status, List<String> targetPools = const [], int? targetSize, InstanceGroupManagerTargetSizePolicy? targetSizePolicy, int? targetStoppedSize, int? targetSuspendedSize, InstanceGroupManagerUpdatePolicy? updatePolicy, List<InstanceGroupManagerVersion> versions = const [], String? zone}) - InstanceGroupManager.fromJson(Object? j)
-
factory
Properties
- allInstancesConfig → InstanceGroupManagerAllInstancesConfig?
-
Specifies configuration that overrides the instance template configuration
for the group.
final
-
autoHealingPolicies
→ List<
InstanceGroupManagerAutoHealingPolicy> -
The autohealing policy for this managed instance group. You can specify
only one value.
final
- baseInstanceName → String?
-
The base instance name is a prefix that you want to attach to the names of
all VMs in a MIG. The maximum character length is 58 and the name must
comply with RFC1035 format.
final
- creationTimestamp → String?
-
Output only. The creation timestamp for this managed instance group inRFC3339
text format.
final
- currentActions → InstanceGroupManagerActionsSummary?
-
Output only. The list of instance actions and the number of instances
in this managed instance group that are scheduled for each of those
actions.
final
- description → String?
-
An optional description of this resource.
final
- distributionPolicy → DistributionPolicy?
-
Policy specifying the intended distribution of managed instances across
zones in a regional managed instance group.
final
- fingerprint → String?
-
Fingerprint of this resource. This field may be used in optimistic locking.
It will be ignored when inserting an InstanceGroupManager. An up-to-date
fingerprint must be provided in order to update the InstanceGroupManager,
otherwise the request will fail with error412 conditionNotMet.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → BigInt?
-
Output only. A unique identifier for this resource type. The server
generates this identifier.
final
- instanceFlexibilityPolicy → InstanceGroupManagerInstanceFlexibilityPolicy?
-
Instance flexibility allowing MIG to create VMs from multiple
types of machines.
Instance flexibility configuration on MIG overrides instance
template configuration.
final
- instanceGroup → String?
-
Output only. The URL of the Instance Group resource.
final
- instanceLifecyclePolicy → InstanceGroupManagerInstanceLifecyclePolicy?
-
The repair policy for this managed instance group.
final
- instanceTemplate → String?
-
The URL of the instance template that is specified for this managed
instance group. The group uses this template to create all new instances
in the managed instance group. The templates for existing instances in the
group do not change unless you run recreateInstances, runapplyUpdatesToInstances, or set the group'supdatePolicy.type to PROACTIVE.
final
- kind → String?
-
Output only. The resource type, which is alwayscompute#instanceGroupManager for managed instance groups.
final
- listManagedInstancesResults → String?
-
Pagination behavior of the listManagedInstances API method for
this managed instance group.
Check the ListManagedInstancesResults enum for the list of possible values.
final
- name → String?
-
The name of the managed instance group. The name must be 1-63 characters
long, and comply withRFC1035.
final
-
namedPorts
→ List<
NamedPort> -
Output OnlyNamed ports configured on the Instance Groups complementary to this Instance Group Manager.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - region → String?
-
Output only.
Output OnlyThe URL of theregion where the managed instance group resides (for regional resources).final - resourcePolicies → InstanceGroupManagerResourcePolicies?
-
Resource policies for this managed instance group.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- satisfiesPzi → bool?
-
Output only. Reserved for future use.
final
- satisfiesPzs → bool?
-
Output only. Reserved for future use.
final
- selfLink → String?
-
Output only. The URL for this managed instance group. The server defines
this URL.
final
- standbyPolicy → InstanceGroupManagerStandbyPolicy?
-
Standby policy for stopped and suspended instances.
final
- statefulPolicy → StatefulPolicy?
-
Stateful configuration for this Instanced Group Manager
final
- status → InstanceGroupManagerStatus?
-
Output only. The status of this managed instance group.
final
-
targetPools
→ List<
String> -
The URLs for all TargetPool resources to which instances in theinstanceGroup field are added. The target pools automatically
apply to all of the instances in the managed instance group.
final
- targetSize → int?
-
The target number of running instances for this managed instance group.
You can reduce this number by using the instanceGroupManager
deleteInstances or abandonInstances methods. Resizing the group also
changes this number.
final
- targetSizePolicy → InstanceGroupManagerTargetSizePolicy?
-
The policy that specifies how the MIG creates its VMs to achieve the target
size.
final
- targetStoppedSize → int?
-
The target number of stopped instances for this managed instance group.
This number changes when you:
final
- targetSuspendedSize → int?
-
The target number of suspended instances for this managed instance group.
This number changes when you:
final
- updatePolicy → InstanceGroupManagerUpdatePolicy?
-
The update policy for this managed instance group.
final
-
versions
→ List<
InstanceGroupManagerVersion> -
Specifies the instance templates used by this managed instance group to
create instances.
final
- zone → String?
-
Output only. The URL of azone
where the managed instance group is located (for zonal resources).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String