Output only. The total number of instances in the managed instance group
that are scheduled to be abandoned. Abandoning an instance removes it
from the managed instance group without deleting it.
Output only. The number of instances in the managed instance group that
are scheduled to be created or are currently being created. If the group
fails to create any of these instances, it tries again until it creates
the instance successfully.
Output only. The number of instances that the managed instance group
will attempt to create. The group attempts to create each instance
only once. If the group fails to create any of these instances, it
decreases the group's targetSize value accordingly.
Output only. The number of instances in the managed instance group that
are scheduled to be recreated or are currently being being recreated.
Recreating an instance deletes the existing root persistent disk
and creates a new disk from the image that is defined in the
instance template.
Output only. The number of instances in the managed instance group that
are being reconfigured with properties that do not require a restart
or a recreate action. For example, setting or removing target
pools for the instance.
Output only. The number of instances in the managed instance group that
are being verified. See the managedInstances[].currentAction
property in the listManagedInstances method documentation.