abandoning property

int? abandoning
final

Output only. The total number of instances in the managed instance group that are scheduled to be abandoned. Abandoning an instance removes it from the managed instance group without deleting it.

Implementation

final int? abandoning;