deleting property

int? deleting
final

Output only. The number of instances in the managed instance group that are scheduled to be deleted or are currently being deleted.

Implementation

final int? deleting;