restarting property

int? restarting
final

Output only. The number of instances in the managed instance group that are scheduled to be restarted or are currently being restarted.

Implementation

final int? restarting;