starting property
Output only. The number of instances in the managed instance group that are scheduled to be started or are currently being started.
Implementation
final int? starting;
Output only. The number of instances in the managed instance group that are scheduled to be started or are currently being started.
final int? starting;