stopping property
Output only. The number of instances in the managed instance group that are scheduled to be stopped or are currently being stopped.
Implementation
final int? stopping;
Output only. The number of instances in the managed instance group that are scheduled to be stopped or are currently being stopped.
final int? stopping;