suspending property
Output only. The number of instances in the managed instance group that are scheduled to be suspended or are currently being suspended.
Implementation
final int? suspending;
Output only. The number of instances in the managed instance group that are scheduled to be suspended or are currently being suspended.
final int? suspending;