InstanceGroupManagerInstanceLifecyclePolicy_ForceUpdateOnRepair class final

A bit indicating whether to forcefully apply the group's latest configuration when repairing a VM. Valid options are:

 -  NO (default): If configuration updates are available, they are not
 forcefully applied during repair. Instead, configuration updates are
 applied according to the group's update policy.

 -  YES: If configuration updates are available, they are applied
 during repair.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited