InstanceGroupManagerResizeRequests class final
The InstanceGroupManagerResizeRequests API.
- Implementers
Constructors
- InstanceGroupManagerResizeRequests({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
InstanceGroupManagerResizeRequestsusingclientfor transport. - InstanceGroupManagerResizeRequests.fromApiKey([String? apiKey])
-
Creates a
InstanceGroupManagerResizeRequeststhat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancel(
CancelInstanceGroupManagerResizeRequestRequest request) → Future< Operation> - Cancels the specified resize request and removes it from the queue. Cancelled resize request does no longer wait for the resources to be provisioned. Cancel is only possible for requests that are accepted in the queue.
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteInstanceGroupManagerResizeRequestRequest request) → Future< Operation> - Deletes the specified, inactive resize request. Requests that are still active cannot be deleted. Deleting request does not delete instances that were provisioned previously.
-
get(
GetInstanceGroupManagerResizeRequestRequest request) → Future< InstanceGroupManagerResizeRequest> - Returns all of the details about the specified resize request.
-
insert(
InsertInstanceGroupManagerResizeRequestRequest request) → Future< Operation> - Creates a new resize request that starts provisioning VMs immediately or queues VM creation.
-
list(
ListInstanceGroupManagerResizeRequestsRequest request) → Future< InstanceGroupManagerResizeRequestsListResponse> - Retrieves a list of resize requests that are contained in the managed instance group.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited