Specifies the number of seconds that the MIG should wait to suspend or
stop a VM after that VM was created. The initial delay gives the
initialization script the time to prepare your VM for a quick scale out.
The value of initial delay must be between 0 and 3600 seconds. The
default value is 0.
Defines how a MIG resumes or starts VMs from a standby pool when the
group scales out. The default mode is MANUAL.
Check the Mode enum for the list of possible values.