mode property
Defines how a MIG resumes or starts VMs from a standby pool when the
group scales out. The default mode is MANUAL.
Check the Mode enum for the list of possible values.
Implementation
final String? mode;
Defines how a MIG resumes or starts VMs from a standby pool when the
group scales out. The default mode is MANUAL.
Check the Mode enum for the list of possible values.
final String? mode;