InstanceGroupManagerStatus class final
Constructors
-
InstanceGroupManagerStatus({InstanceGroupManagerStatusAllInstancesConfig? allInstancesConfig, List<
InstanceGroupManagerStatusAcceleratorTopology> appliedAcceleratorTopologies = const [], String? autoscaler, InstanceGroupManagerStatusBulkInstanceOperation? bulkInstanceOperation, InstanceGroupManagerStatusInstanceStatusSummary? currentInstanceStatuses, bool? isStable, InstanceGroupManagerStatusStateful? stateful, InstanceGroupManagerStatusVersionTarget? versionTarget}) - InstanceGroupManagerStatus.fromJson(Object? j)
-
factory
Properties
- allInstancesConfig → InstanceGroupManagerStatusAllInstancesConfig?
-
Output only. Status of all-instances configuration on the group.
final
-
appliedAcceleratorTopologies
→ List<
InstanceGroupManagerStatusAcceleratorTopology> -
Output only. The accelerator topology applied to this MIG.
Currently only one accelerator topology is supported.
final
- autoscaler → String?
-
Output only. The URL of theAutoscaler
that targets this instance group manager.
final
- bulkInstanceOperation → InstanceGroupManagerStatusBulkInstanceOperation?
-
Output only. The status of bulk instance operation.
final
- currentInstanceStatuses → InstanceGroupManagerStatusInstanceStatusSummary?
-
Output only. The list of instance statuses and the number of instances
in this managed instance group that have the status. Currently only shown
for TPU MIGs
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isStable → bool?
-
Output only. A bit indicating whether the managed instance group is in a
stable state. A stable state means that: none of the instances in the
managed instance group is currently undergoing any type of change (for
example, creation, restart, or deletion); no future changes are scheduled
for instances in the managed instance group; and the managed instance
group itself is not being modified.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stateful → InstanceGroupManagerStatusStateful?
-
Output only. Stateful status of the given Instance Group Manager.
final
- versionTarget → InstanceGroupManagerStatusVersionTarget?
-
Output only. A status of consistency of Instances' versions with their
target version specified by version field on Instance Group
Manager.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String