InstanceGroupManagerStatusAcceleratorTopology_State class final
Output only. The state of the accelerator topology.
Constructors
- InstanceGroupManagerStatusAcceleratorTopology_State(String value)
-
const
- InstanceGroupManagerStatusAcceleratorTopology_State.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const InstanceGroupManagerStatusAcceleratorTopology_State
- The default value for InstanceGroupManagerStatusAcceleratorTopology_State.
- activating → const InstanceGroupManagerStatusAcceleratorTopology_State
- The accelerator topology is being activated.
- active → const InstanceGroupManagerStatusAcceleratorTopology_State
- The accelerator topology is active.
- deactivating → const InstanceGroupManagerStatusAcceleratorTopology_State
- The accelerator topology is being deactivated.
- failed → const InstanceGroupManagerStatusAcceleratorTopology_State
- The accelerator topology failed.
- incomplete → const InstanceGroupManagerStatusAcceleratorTopology_State
- The configuration is incomplete and the accelerator topology cannot be activated due to insufficient number of running VMs.
- reactivating → const InstanceGroupManagerStatusAcceleratorTopology_State
- The accelerator topology is being reactivated.
- undefinedState → const InstanceGroupManagerStatusAcceleratorTopology_State
- A value indicating that the enum field is not set.