InstanceGroupManagerStatusBulkInstanceOperation class final
Bulk instance operation is the creation of VMs in a MIG when the targetSizePolicy.mode is set to BULK.
Constructors
- InstanceGroupManagerStatusBulkInstanceOperation({bool? inProgress, InstanceGroupManagerStatusBulkInstanceOperationLastProgressCheck? lastProgressCheck})
- InstanceGroupManagerStatusBulkInstanceOperation.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- inProgress → bool?
-
Output only. Informs whether bulk instance operation is in progress.
final
- lastProgressCheck → InstanceGroupManagerStatusBulkInstanceOperationLastProgressCheck?
-
Output only. Information from the last progress check of bulk instance
operation.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String