InstanceGroupManagerStatusInstanceStatusSummary class final

The list of instance statuses and the number of instances in this managed instance group that have the status. For more information about how to interpret each status check the instance lifecycle documentation. Currently only shown for TPU MIGs.

Constructors

InstanceGroupManagerStatusInstanceStatusSummary({int? deprovisioning, int? nonExistent, int? pending, int? pendingStop, int? provisioning, int? repairing, int? running, int? staging, int? stopped, int? stopping, int? suspended, int? suspending, int? terminated})
InstanceGroupManagerStatusInstanceStatusSummary.fromJson(Object? j)
factory

Properties

deprovisioning int?
Output only. The number of instances in the managed instance group that have DEPROVISIONING status.
final
hashCode int
The hash code for this object.
no setterinherited
nonExistent int?
Output only. The number of instances that have not been created yet or have been deleted. Includes only instances that would be shown in the listManagedInstances method and not all instances that have been deleted in the lifetime of the MIG. Does not include FlexStart instances that are waiting for the resources availability, they are considered as 'pending'.
final
pending int?
Output only. The number of instances in the managed instance group that have PENDING status, that is FlexStart instances that are waiting for resources. Instances that do not exist because of the other reasons are counted as 'non_existent'.
final
pendingStop int?
Output only. The number of instances in the managed instance group that have PENDING_STOP status.
final
provisioning int?
Output only. The number of instances in the managed instance group that have PROVISIONING status.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
repairing int?
Output only. The number of instances in the managed instance group that have REPAIRING status.
final
running int?
Output only. The number of instances in the managed instance group that have RUNNING status.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
staging int?
Output only. The number of instances in the managed instance group that have STAGING status.
final
stopped int?
Output only. The number of instances in the managed instance group that have STOPPED status.
final
stopping int?
Output only. The number of instances in the managed instance group that have STOPPING status.
final
suspended int?
Output only. The number of instances in the managed instance group that have SUSPENDED status.
final
suspending int?
Output only. The number of instances in the managed instance group that have SUSPENDING status.
final
terminated int?
Output only. The number of instances in the managed instance group that have TERMINATED status.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String