menu
google_cloud_compute_v1 package
documentation
compute.dart
InstanceGroupManagerStatusStatefulPerInstanceConfigs class
InstanceGroupManagerStatusStatefulPerInstanceConfigs class
dark_mode
light_mode
InstanceGroupManagerStatusStatefulPerInstanceConfigs
class
final
Constructors
InstanceGroupManagerStatusStatefulPerInstanceConfigs
({
bool
?
allEffective
})
InstanceGroupManagerStatusStatefulPerInstanceConfigs.fromJson
(
Object
?
j
)
factory
Properties
allEffective
→
bool
?
Output only. A bit indicating if all of the group's per-instance configurations (listed in the output of a listPerInstanceConfigs API call) have status EFFECTIVE or there are no per-instance-configs.
final
hashCode
→
int
The hash code for this object.
no setter
inherited
qualifiedName
→
String
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or
google.rpc.ErrorInfo
.
final
inherited
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson
(
)
→
Object
toString
(
)
→
String
A string representation of this object.
override
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
Constants
fullyQualifiedName
→ const
String
google_cloud_compute_v1 package
documentation
compute
InstanceGroupManagerStatusStatefulPerInstanceConfigs class
compute library