menu
google_cloud_compute_v1 package
documentation
compute.dart
InstanceGroupManagerStatusVersionTarget class
InstanceGroupManagerStatusVersionTarget class
dark_mode
light_mode
InstanceGroupManagerStatusVersionTarget
class
final
Constructors
InstanceGroupManagerStatusVersionTarget
({
bool
?
isReached
})
InstanceGroupManagerStatusVersionTarget.fromJson
(
Object
?
j
)
factory
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
isReached
→
bool
?
Output only. A bit indicating whether version target has been reached in this managed instance group, i.e. all instances are in their target version. Instances' target version are specified byversion field on Instance Group Manager.
final
qualifiedName
→
String
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or
google.rpc.ErrorInfo
.
final
inherited
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson
(
)
→
Object
toString
(
)
→
String
A string representation of this object.
override
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
Constants
fullyQualifiedName
→ const
String
google_cloud_compute_v1 package
documentation
compute
InstanceGroupManagerStatusVersionTarget class
compute library