mode property

String? mode
final

The mode of target size policy based on which the MIG creates its VMs individually or all at once. Check the Mode enum for the list of possible values.

Implementation

final String? mode;