InstanceGroupManagerUpdatePolicy_MostDisruptiveAllowedAction class final
Most disruptive action that is allowed to be taken on an instance. You can specify either NONE to forbid any actions,REFRESH to avoid restarting the VM and to limit disruption as much as possible. RESTART to allow actions that can be applied without instance replacing or REPLACE to allow all possible actions. If the Updater determines that the minimal update action needed is more disruptive than most disruptive allowed action you specify it will not perform the update at all. Additional supported values which may be not listed in the enum directly due to technical reasons: NONE REFRESH REPLACE RESTART
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const InstanceGroupManagerUpdatePolicy_MostDisruptiveAllowedAction
- The default value for InstanceGroupManagerUpdatePolicy_MostDisruptiveAllowedAction.
- undefinedMostDisruptiveAllowedAction → const InstanceGroupManagerUpdatePolicy_MostDisruptiveAllowedAction
- A value indicating that the enum field is not set.