InstanceGroupManagerUpdatePolicy_ReplacementMethod class final
What action should be used to replace instances. See minimal_action.REPLACE
Constructors
- InstanceGroupManagerUpdatePolicy_ReplacementMethod(String value)
-
const
- InstanceGroupManagerUpdatePolicy_ReplacementMethod.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const InstanceGroupManagerUpdatePolicy_ReplacementMethod
- The default value for InstanceGroupManagerUpdatePolicy_ReplacementMethod.
- recreate → const InstanceGroupManagerUpdatePolicy_ReplacementMethod
- Instances will be recreated (with the same name)
- substitute → const InstanceGroupManagerUpdatePolicy_ReplacementMethod
- Default option: instances will be deleted and created (with a new name)
- undefinedReplacementMethod → const InstanceGroupManagerUpdatePolicy_ReplacementMethod
- A value indicating that the enum field is not set.