InstanceGroupManagerVersion class final

Constructors

InstanceGroupManagerVersion({String? instanceTemplate, String? name, FixedOrPercent? targetSize})
InstanceGroupManagerVersion.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
instanceTemplate String?
The URL of the instance template that is specified for this managed instance group. The group uses this template to create new instances in the managed instance group until the targetSize for this version is reached. The templates for existing instances in the group do not change unless you run recreateInstances, runapplyUpdatesToInstances, or set the group'supdatePolicy.type to PROACTIVE; in those cases, existing instances are updated until the targetSize for this version is reached.
final
name String?
Name of the version. Unique among all versions in the scope of this managed instance group.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetSize FixedOrPercent?
Specifies the intended number of instances to be created from theinstanceTemplate. The final number of instances created from the template will be equal to:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String