delete method

Deletes the specified managed instance group and all of the instances in that group. Note that the instance group must not belong to a backend service. Read Deleting an instance group for more information.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> delete(DeleteInstanceGroupManagerRequest request) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/zones/${request.zone}/instanceGroupManagers/${request.instanceGroupManager}',
    queryParameters: {
      if (request.noGracefulShutdown case final $1?)
        'noGracefulShutdown': '${$1}',
      'requestId': ?request.requestId,
    },
  );
  final response = await _client.delete(url);
  return Operation.fromJson(response);
}