InstanceGroups class final
The InstanceGroups API.
- Implementers
Constructors
- InstanceGroups({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
InstanceGroupsusingclientfor transport. - InstanceGroups.fromApiKey([String? apiKey])
-
Creates a
InstanceGroupsthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addInstances(
AddInstancesInstanceGroupRequest request) → Future< Operation> - Adds a list of instances to the specified instance group. All of the instances in the instance group must be in the same network/subnetwork. Read Adding instances for more information.
-
aggregatedList(
AggregatedListInstanceGroupsRequest request) → Future< InstanceGroupAggregatedList> - Retrieves the list of instance groups and sorts them by zone.
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteInstanceGroupRequest request) → Future< Operation> - Deletes the specified instance group. The instances in the group are not deleted. Note that instance group must not belong to a backend service. Read Deleting an instance group for more information.
-
get(
GetInstanceGroupRequest request) → Future< InstanceGroup> - Returns the specified zonal instance group. Get a list of available zonal instance groups by making a list() request.
-
insert(
InsertInstanceGroupRequest request) → Future< Operation> - Creates an instance group in the specified project using the parameters that are included in the request.
-
list(
ListInstanceGroupsRequest request) → Future< InstanceGroupList> - Retrieves the list of zonal instance group resources contained within the specified zone.
-
listInstances(
ListInstancesInstanceGroupsRequest request) → Future< InstanceGroupsListInstances> -
Lists the instances in the specified instance group.
The orderBy query parameter is not supported.
The filter query parameter is supported, but only for
expressions that use
eq(equal) orne(not equal) operators. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeInstances(
RemoveInstancesInstanceGroupRequest request) → Future< Operation> - Removes one or more instances from the specified instance group, but does not delete those instances.
-
setNamedPorts(
SetNamedPortsInstanceGroupRequest request) → Future< Operation> - Sets the named ports for the specified instance group.
-
testIamPermissions(
TestIamPermissionsInstanceGroupRequest request) → Future< TestPermissionsResponse> - Returns permissions that a caller has on the specified resource.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited