InstanceGroupsListInstancesRequest_InstanceState class final
A filter for the state of the instances in the instance group. Valid options are ALL or RUNNING. If you do not specify this parameter the list includes all instances regardless of their state.
Constructors
- InstanceGroupsListInstancesRequest_InstanceState(String value)
-
const
- InstanceGroupsListInstancesRequest_InstanceState.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const InstanceGroupsListInstancesRequest_InstanceState
- The default value for InstanceGroupsListInstancesRequest_InstanceState.
- all → const InstanceGroupsListInstancesRequest_InstanceState
- Includes all instances in the generated list regardless of their state.
- running → const InstanceGroupsListInstancesRequest_InstanceState
- Includes instances in the generated list only if they have a RUNNING state.
- undefinedInstanceState → const InstanceGroupsListInstancesRequest_InstanceState
- A value indicating that the enum field is not set.