InstancePropertiesPatch class final

Represents the change that you want to make to the instance properties.

Constructors

InstancePropertiesPatch({Map<String, String> labels = const {}, Map<String, String> metadata = const {}})
InstancePropertiesPatch.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
labels Map<String, String>
The label key-value pairs that you want to patch onto the instance.
final
metadata Map<String, String>
The metadata key-value pairs that you want to patch onto the instance. For more information, see Project and instance metadata.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String