standardEncryption constant
InstanceProperties_LocalSsdEncryptionMode
const standardEncryption
The given VM will be encrypted using keys managed by the cloud infrastructure and the keys will be deleted when the VM is deleted.
Implementation
static const standardEncryption = InstanceProperties_LocalSsdEncryptionMode(
'STANDARD_ENCRYPTION',
);