InstanceSettings class final
Represents a Instance Settings resource. You can use instance settings to configure default settings for Compute Engine VM instances. For example, you can use it to configure default machine type of Compute Engine VM instances.
Constructors
- InstanceSettings({String? fingerprint, String? kind, InstanceSettingsMetadata? metadata, String? zone})
- InstanceSettings.fromJson(Object? j)
-
factory
Properties
- fingerprint → String?
-
Specifies a fingerprint for instance settings, which is essentially a hash
of the instance settings resource's contents and used for optimistic
locking. The fingerprint is initially generated by Compute Engine and
changes after every request to modify or update the instance settings
resource. You must always provide an up-to-date fingerprint hash in order
to update or change the resource, otherwise the request will fail with
error 412 conditionNotMet.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → String?
-
Output only.
Output OnlyType of the resource. Alwayscompute#instance_settings for instance settings.final - metadata → InstanceSettingsMetadata?
-
The metadata key/value pairs assigned to all the instances in the
corresponding scope.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- zone → String?
-
Output only.
Output OnlyURL of the zone where the resource resides You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String