zone property
Output only. Output Only URL of the zone where the resource resides
You must specify this field as part of the HTTP request URL. It is not
settable as a field in the request body.
Implementation
final String? zone;
Output only. Output Only URL of the zone where the resource resides
You must specify this field as part of the HTTP request URL. It is not
settable as a field in the request body.
final String? zone;