InstanceTemplatesScopedList class
final
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
instanceTemplates
→ List<InstanceTemplate>
-
Output Only A list of instance templates that are contained within
the specified project and zone.
final
-
qualifiedName
→ String
-
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or google.rpc.ErrorInfo.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
warning
→ Warning?
-
Output Only An informational warning that replaces the list of instance
templates when the list is empty.
final