InstanceWithNamedPorts_Status class final
Output only. Output Only The status of the instance.
Constructors
- InstanceWithNamedPorts_Status(String value)
-
const
- InstanceWithNamedPorts_Status.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const InstanceWithNamedPorts_Status
- The default value for InstanceWithNamedPorts_Status.
- deprovisioning → const InstanceWithNamedPorts_Status
- The instance is halted and we are performing tear down tasks like network deprogramming, releasing quota, IP, tearing down disks etc.
- pending → const InstanceWithNamedPorts_Status
- For Flex Start provisioning instance is waiting for available capacity from Dynamic Workload Scheduler (DWS).
- pendingStop → const InstanceWithNamedPorts_Status
- The instance is gracefully shutting down.
- provisioning → const InstanceWithNamedPorts_Status
- Resources are being allocated for the instance.
- repairing → const InstanceWithNamedPorts_Status
- The instance is in repair.
- running → const InstanceWithNamedPorts_Status
- The instance is running.
- staging → const InstanceWithNamedPorts_Status
- All required resources have been allocated and the instance is being started.
- stopped → const InstanceWithNamedPorts_Status
- The instance has stopped successfully.
- stopping → const InstanceWithNamedPorts_Status
- The instance is currently stopping (either being deleted or killed).
- suspended → const InstanceWithNamedPorts_Status
- The instance has suspended.
- suspending → const InstanceWithNamedPorts_Status
- The instance is suspending.
- terminated → const InstanceWithNamedPorts_Status
- The instance has stopped (either by explicit action or underlying failure).
- undefinedStatus → const InstanceWithNamedPorts_Status
- A value indicating that the enum field is not set.