InstancesSetNameRequest class final

Constructors

InstancesSetNameRequest({String? currentName, String? name})
InstancesSetNameRequest.fromJson(Object? j)
factory

Properties

currentName String?
The current name of this resource, used to prevent conflicts. Provide the latest name when making a request to change name.
final
hashCode int
The hash code for this object.
no setterinherited
name String?
The name to be applied to the instance. Needs to be RFC 1035 compliant.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String