InstancesSetSecurityPolicyRequest class final

Constructors

InstancesSetSecurityPolicyRequest({List<String> networkInterfaces = const [], String? securityPolicy})
InstancesSetSecurityPolicyRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
networkInterfaces List<String>
The network interfaces that the security policy will be applied to. Network interfaces use the nicN naming format. You can only set a security policy for network interfaces with an access config.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
securityPolicy String?
A full or partial URL to a security policy to add to this instance. If this field is set to an empty string it will remove the associated security policy.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String