securityPolicy property
A full or partial URL to a security policy to add to this instance. If this field is set to an empty string it will remove the associated security policy.
Implementation
final String? securityPolicy;
A full or partial URL to a security policy to add to this instance. If this field is set to an empty string it will remove the associated security policy.
final String? securityPolicy;