InstantSnapshot class final
Represents a InstantSnapshot resource.
You can use instant snapshots to create disk rollback points quickly..
Constructors
-
InstantSnapshot({String? architecture, String? creationTimestamp, String? description, int? diskSizeGb, BigInt? id, String? kind, String? labelFingerprint, Map<
String, String> labels = const {}, String? name, InstantSnapshotParams? params, String? region, InstantSnapshotResourceStatus? resourceStatus, bool? satisfiesPzi, bool? satisfiesPzs, String? selfLink, String? selfLinkWithId, String? sourceDisk, String? sourceDiskId, String? sourceInstantSnapshotGroup, String? sourceInstantSnapshotGroupId, String? status, String? zone}) - InstantSnapshot.fromJson(Object? j)
-
factory
Properties
- architecture → String?
-
Output only.
Output OnlyThe architecture of the instant snapshot. Valid values are ARM64 or X86_64. Check the Architecture enum for the list of possible values.final - creationTimestamp → String?
-
Output only.
Output OnlyCreation timestamp inRFC3339 text format.final - description → String?
-
An optional description of this resource. Provide this property when you
create the resource.
final
- diskSizeGb → int?
-
Output only.
Output OnlySize of the source disk, specified in GB.final - hashCode → int
-
The hash code for this object.
no setterinherited
- id → BigInt?
-
Output only.
Output OnlyThe unique identifier for the resource. This identifier is defined by the server.final - kind → String?
-
Output only.
Output OnlyType of the resource. Alwayscompute#instantSnapshot for InstantSnapshot resources.final - labelFingerprint → String?
-
A fingerprint for the labels being applied to this InstantSnapshot, which
is essentially a hash of the labels set used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update labels. You must always provide an
up-to-date fingerprint hash in order to update or change labels,
otherwise the request will fail with error412 conditionNotMet.
final
-
labels
→ Map<
String, String> -
Labels to apply to this InstantSnapshot. These can be later modified by
the setLabels method.
Label values may be empty.
final
- name → String?
-
Name of the resource; provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression
[a-z]([-a-z0-9]*[a-z0-9])?which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.final - params → InstantSnapshotParams?
-
Input only. Additional params passed with the request, but not persisted
as part of resource payload.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - region → String?
-
Output only.
Output OnlyURL of the region where the instant snapshot resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.final - resourceStatus → InstantSnapshotResourceStatus?
-
Output only.
Output OnlyStatus information for the instant snapshot resource.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- satisfiesPzi → bool?
-
Output only. Reserved for future use.
final
- satisfiesPzs → bool?
-
Output only.
Output OnlyReserved for future use.final - selfLink → String?
-
Output only.
Output OnlyServer-defined URL for the resource.final - selfLinkWithId → String?
-
Output only.
Output OnlyServer-defined URL for this resource's resource id.final - sourceDisk → String?
-
URL of the source disk used to create this instant snapshot.
Note that the source disk must be in the same zone/region as the
instant snapshot to be created. This can be a full or valid partial URL.
For example, the following are valid values:
final
- sourceDiskId → String?
-
Output only.
Output OnlyThe ID value of the disk used to create this InstantSnapshot. This value may be used to determine whether the InstantSnapshot was taken from the current or a previous instance of a given disk name.final - sourceInstantSnapshotGroup → String?
-
Output only.
Output OnlyURL of the source instant snapshot this instant snapshot is part of. Note that the source instant snapshot group must be in the same zone/region as the instant snapshot to be created. This can be a full or valid partial URL.final - sourceInstantSnapshotGroupId → String?
-
Output only.
Output OnlyThe ID value of the source instant snapshot group this InstantSnapshot is part of. This value may be used to determine whether the InstantSnapshot was created as part of an InstantSnapshotGroup creation.final - status → String?
-
Output only.
Output OnlyThe status of the instantSnapshot. This can beCREATING, DELETING, FAILED, orREADY. Check the Status enum for the list of possible values.final - zone → String?
-
Output only.
Output OnlyURL of the zone where the instant snapshot resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String