sourceDiskId property
Output only. Output Only The ID value of the disk used to create this InstantSnapshot.
This value may be used to determine whether the InstantSnapshot
was taken from the current or a previous instance of a given disk name.
Implementation
final String? sourceDiskId;