InstantSnapshotGroup class final

Represents an InstantSnapshotGroup resource.

An instant snapshot group is a set of instant snapshots that represents a point in time state of a consistency group.

Constructors

InstantSnapshotGroup({String? creationTimestamp, String? description, BigInt? id, String? kind, String? name, String? region, InstantSnapshotGroupResourceStatus? resourceStatus, String? selfLink, String? selfLinkWithId, String? sourceConsistencyGroup, String? status, String? zone})
InstantSnapshotGroup.fromJson(Object? j)
factory

Properties

creationTimestamp String?
Output only. Output Only Creation timestamp inRFC3339 text format.
final
description String?
Optional. An optional description of this resource. Provide this property when you create the resource.
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output only. Output Only The unique identifier for the resource. This identifier is defined by the server.
final
kind String?
Output only. Output Only Type of the resource. Alwayscompute#instantSnapshotGroup for InstantSnapshotGroup resources.
final
name String?
Identifier. Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
region String?
Output only. Output Only URL of the region where the instant snapshot group resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
final
resourceStatus InstantSnapshotGroupResourceStatus?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output only. Output Only Server-defined URL for the resource.
final
selfLinkWithId String?
Output only. Output Only Server-defined URL for this resource's resource id.
final
sourceConsistencyGroup String?
final
status String?
Output only. Output Only Check the Status enum for the list of possible values.
final
zone String?
Output only. Output Only URL of the zone where the instant snapshot group resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String