Int64RangeMatch class final

HttpRouteRuleMatch criteria for field values that must stay within the specified integer range.

Constructors

Int64RangeMatch({int? rangeEnd, int? rangeStart})
Int64RangeMatch.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
rangeEnd int?
The end of the range (exclusive) in signed long integer format.
final
rangeStart int?
The start of the range (inclusive) in signed long integer format.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String