Interconnect class final

Represents an Interconnect resource.

An Interconnect resource is a dedicated connection between the Google Cloud network and your on-premises network. For more information, read the Dedicated Interconnect Overview.

Constructors

Interconnect({bool? aaiEnabled, bool? adminEnabled, InterconnectApplicationAwareInterconnect? applicationAwareInterconnect, List<String> availableFeatures = const [], List<InterconnectCircuitInfo> circuitInfos = const [], String? creationTimestamp, String? customerName, String? description, String? effectiveLocation, List<InterconnectOutageNotification> expectedOutages = const [], String? googleIpAddress, String? googleReferenceId, BigInt? id, List<String> interconnectAttachments = const [], List<String> interconnectGroups = const [], String? interconnectType, String? kind, String? labelFingerprint, Map<String, String> labels = const {}, String? linkType, String? location, InterconnectMacsec? macsec, bool? macsecEnabled, String? name, String? nocContactEmail, String? operationalStatus, InterconnectParams? params, String? peerIpAddress, int? provisionedLinkCount, String? remoteLocation, List<String> requestedFeatures = const [], int? requestedLinkCount, bool? satisfiesPzs, String? selfLink, String? state, String? subzone, List<String> wireGroups = const []})
Interconnect.fromJson(Object? j)
factory

Properties

aaiEnabled bool?
Enable or disable the application awareness feature on this Cloud Interconnect.
final
adminEnabled bool?
Administrative status of the interconnect. When this is set to true, the Interconnect is functional and can carry traffic. When set to false, no packets can be carried over the interconnect and no BGP routes are exchanged over it. By default, the status is set to true.
final
applicationAwareInterconnect InterconnectApplicationAwareInterconnect?
Configuration information for application awareness on this Cloud Interconnect.
final
availableFeatures List<String>
Output only List of features available for this Interconnect connection, which can take one of the following values:
final
circuitInfos List<InterconnectCircuitInfo>
Output only. Output Only A list of CircuitInfo objects, that describe the individual circuits in this LAG.
final
creationTimestamp String?
Output only. Output Only Creation timestamp inRFC3339 text format.
final
customerName String?
Customer name, to put in the Letter of Authorization as the party authorized to request a crossconnect.
final
description String?
An optional description of this resource. Provide this property when you create the resource.
final
effectiveLocation String?
Output only. URL of the InterconnectLocation object that represents where this connection is to be provisioned. By default it will be the same as the location field.
final
expectedOutages List<InterconnectOutageNotification>
Output only. Output Only A list of outages expected for this Interconnect.
final
googleIpAddress String?
Output only. Output Only IP address configured on the Google side of the Interconnect link. This can be used only for ping tests.
final
googleReferenceId String?
Output only. Output Only Google reference ID to be used when raising support tickets with Google or otherwise to debug backend connectivity issues.
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output only. Output Only The unique identifier for the resource. This identifier is defined by the server.
final
interconnectAttachments List<String>
Output only. Output Only A list of the URLs of all InterconnectAttachments configured to use this Interconnect.
final
interconnectGroups List<String>
Output only. Output Only URLs of InterconnectGroups that include this Interconnect. Order is arbitrary and items are unique.
final
interconnectType String?
Type of interconnect, which can take one of the following values:
final
kind String?
Output only. Output Only Type of the resource. Alwayscompute#interconnect for interconnects.
final
labelFingerprint String?
A fingerprint for the labels being applied to this Interconnect, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet.
final
labels Map<String, String>
Labels for this resource. These can only be added or modified by thesetLabels method. Each label key/value pair must comply withRFC1035. Label values may be empty.
final
linkType String?
Type of link requested, which can take one of the following values:
final
location String?
URL of the InterconnectLocation object that represents where this connection is to be provisioned.
final
macsec InterconnectMacsec?
Configuration that enables Media Access Control security (MACsec) on the Cloud Interconnect connection between Google and your on-premises router.
final
macsecEnabled bool?
Enable or disable MACsec on this Interconnect connection. MACsec enablement fails if the MACsec object is not specified.
final
name String?
Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
nocContactEmail String?
Email address to contact the customer NOC for operations and maintenance notifications regarding this Interconnect. If specified, this will be used for notifications in addition to all other forms described, such as Cloud Monitoring logs alerting and Cloud Notifications. This field is required for users who sign up for Cloud Interconnect using workforce identity federation.
final
operationalStatus String?
Output only. Output Only The current status of this Interconnect's functionality, which can take one of the following values:
final
params InterconnectParams?
Input only. Input Only Additional params passed with the request, but not persisted as part of resource payload.
final
peerIpAddress String?
Output only. Output Only IP address configured on the customer side of the Interconnect link. The customer should configure this IP address during turnup when prompted by Google NOC. This can be used only for ping tests.
final
provisionedLinkCount int?
Output only. Output Only Number of links actually provisioned in this interconnect.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
remoteLocation String?
Indicates that this is a Cross-Cloud Interconnect. This field specifies the location outside of Google's network that the interconnect is connected to.
final
requestedFeatures List<String>
Optional. This parameter can be provided only with Interconnect INSERT. It isn't valid for Interconnect PATCH. List of features requested for this Interconnect connection, which can take one of the following values:
final
requestedLinkCount int?
Target number of physical links in the link bundle, as requested by the customer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzs bool?
Output only. Output Only Reserved for future use.
final
Output only. Output Only Server-defined URL for the resource.
final
state String?
Output only. Output Only The current state of Interconnect functionality, which can take one of the following values:
final
subzone String?
To be deprecated. Check the Subzone enum for the list of possible values.
final
wireGroups List<String>
Output only. Output Only A list of the URLs of all CrossSiteNetwork WireGroups configured to use this Interconnect. The Interconnect cannot be deleted if this list is non-empty.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String