effectiveLocation property
Output only. URL of the InterconnectLocation object that represents where this connection is to be provisioned. By default it will be the same as the location field.
Implementation
final String? effectiveLocation;
Output only. URL of the InterconnectLocation object that represents where this connection is to be provisioned. By default it will be the same as the location field.
final String? effectiveLocation;