InterconnectApplicationAwareInterconnectBandwidthPercentage class final

Specify bandwidth percentages 1-100 for various traffic classes in BandwidthPercentagePolicy. The sum of all percentages must equal 100. All traffic classes must have a percentage value specified.

Properties

hashCode int
The hash code for this object.
no setterinherited
percentage int?
Bandwidth percentage for a specific traffic class.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trafficClass String?
TrafficClass whose bandwidth percentage is being specified. Check the TrafficClass enum for the list of possible values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String