InterconnectAttachmentConfigurationConstraints_BgpMd5 class final
Output only. Output Only Whether the attachment's BGP session
requires/allows/disallows BGP MD5 authentication. This can take one of
the following values: MD5_OPTIONAL, MD5_REQUIRED, MD5_UNSUPPORTED.
For example, a Cross-Cloud Interconnect connection to a remote cloud provider that requires BGP MD5 authentication has the interconnectRemoteLocation attachment_configuration_constraints.bgp_md5 field set to MD5_REQUIRED, and that property is propagated to the attachment. Similarly, if BGP MD5 is MD5_UNSUPPORTED, an error is returned if MD5 is requested.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const InterconnectAttachmentConfigurationConstraints_BgpMd5
- The default value for InterconnectAttachmentConfigurationConstraints_BgpMd5.
- md5Optional → const InterconnectAttachmentConfigurationConstraints_BgpMd5
- MD5_OPTIONAL: BGP MD5 authentication is supported and can optionally be configured.
- md5Required → const InterconnectAttachmentConfigurationConstraints_BgpMd5
- MD5_REQUIRED: BGP MD5 authentication must be configured.
- md5Unsupported → const InterconnectAttachmentConfigurationConstraints_BgpMd5
- MD5_UNSUPPORTED: BGP MD5 authentication must not be configured
- undefinedBgpMd5 → const InterconnectAttachmentConfigurationConstraints_BgpMd5
- A value indicating that the enum field is not set.