InterconnectAttachmentGroup class final

An interconnect attachment group resource allows customers to create, analyze, and expand highly available deployments.

Constructors

InterconnectAttachmentGroup({Map<String, InterconnectAttachmentGroupAttachment> attachments = const {}, InterconnectAttachmentGroupConfigured? configured, String? creationTimestamp, String? description, String? etag, BigInt? id, InterconnectAttachmentGroupIntent? intent, String? interconnectGroup, String? kind, InterconnectAttachmentGroupLogicalStructure? logicalStructure, String? name, String? selfLink})
InterconnectAttachmentGroup.fromJson(Object? j)
factory

Properties

attachments Map<String, InterconnectAttachmentGroupAttachment>
Attachments in the AttachmentGroup. Keys are arbitrary user-specified strings. Users are encouraged, but not required, to use their preferred format for resource links as keys. Note that there are add-members and remove-members methods in gcloud. The size of this map is limited by an "Attachments per group" quota.
final
configured InterconnectAttachmentGroupConfigured?
final
creationTimestamp String?
Output only. Output Only Creation timestamp inRFC3339 text format.
final
description String?
An optional description of this resource. Provide this property when you create the resource.
final
etag String?
Opaque system-generated token that uniquely identifies the configuration. If provided when patching a configuration in update mode, the provided token must match the current token or the update is rejected. This provides a reliable means of doing read-modify-write (optimistic locking) as described byAIP 154.
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output only. Output Only The unique identifier for the resource type. The server generates this identifier.
final
intent InterconnectAttachmentGroupIntent?
final
interconnectGroup String?
The URL of an InterconnectGroup that groups these Attachments' Interconnects. Customers do not need to set this unless directed by Google Support.
final
kind String?
Output only. Output Only Type of the resource. Always compute#interconnectAttachmentGroup.
final
logicalStructure InterconnectAttachmentGroupLogicalStructure?
final
name String?
Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output only. Output Only Server-defined URL for the resource.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String