InterconnectAttachmentGroupConfiguredAvailabilitySlaintendedSlaBlockers class final
Output Only Reasons why configuration.availabilitySLA.sla differs from
intent.availabilitySLA. This list is empty if and only if those are the
same.
Constructors
-
InterconnectAttachmentGroupConfiguredAvailabilitySlaintendedSlaBlockers({List<
String> attachments = const [], String? blockerType, String? documentationLink, String? explanation, List<String> metros = const [], List<String> regions = const [], List<String> zones = const []}) - InterconnectAttachmentGroupConfiguredAvailabilitySlaintendedSlaBlockers.fromJson(Object? j)
-
factory
Properties
-
attachments
→ List<
String> -
Output only.
Output OnlyURLs of any particular Attachments to explain this blocker in more detail.final - blockerType → String?
-
Check the BlockerType enum for the list of possible values.
final
- documentationLink → String?
-
Output only.
Output OnlyThe url of Google Cloud public documentation explaining this requirement. This is set for every type of requirement.final - explanation → String?
-
Output only.
Output OnlyA human-readable explanation of this requirement and why it's not met. This is set for every type of requirement.final - hashCode → int
-
The hash code for this object.
no setterinherited
-
metros
→ List<
String> -
Output only.
Output OnlyMetros used to explain this blocker in more detail. These are three-letter lowercase strings like "iad". This will be set for some blockers (like NO_ATTACHMENTS_IN_METRO_AND_ZONE) but does not apply to others.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited -
regions
→ List<
String> -
Output only.
Output OnlyRegions used to explain this blocker in more detail. These are region names formatted like "us-central1". This will be set for some blockers (like INCOMPATIBLE_REGIONS) but does not apply to others.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
zones
→ List<
String> -
Output only.
Output OnlyZones used to explain this blocker in more detail. Format is "zone1" and/or "zone2". This will be set for some blockers (like MISSING_ZONE) but does not apply to others.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String