InterconnectAttachmentGroups class final
The InterconnectAttachmentGroups API.
- Implementers
Constructors
- InterconnectAttachmentGroups({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
InterconnectAttachmentGroupsusingclientfor transport. - InterconnectAttachmentGroups.fromApiKey([String? apiKey])
-
Creates a
InterconnectAttachmentGroupsthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteInterconnectAttachmentGroupRequest request) → Future< Operation> - Deletes the specified InterconnectAttachmentGroup in the given scope
-
get(
GetInterconnectAttachmentGroupRequest request) → Future< InterconnectAttachmentGroup> - Returns the specified InterconnectAttachmentGroup resource in the given scope.
-
getIamPolicy(
GetIamPolicyInterconnectAttachmentGroupRequest request) → Future< Policy> - Gets the access control policy for a resource. May be empty if no such policy or resource exists.
-
getOperationalStatus(
GetOperationalStatusInterconnectAttachmentGroupRequest request) → Future< InterconnectAttachmentGroupsGetOperationalStatusResponse> - Returns the InterconnectAttachmentStatuses for the specified InterconnectAttachmentGroup resource.
-
insert(
InsertInterconnectAttachmentGroupRequest request) → Future< Operation> - Creates a InterconnectAttachmentGroup in the specified project in the given scope using the parameters that are included in the request.
-
list(
ListInterconnectAttachmentGroupsRequest request) → Future< InterconnectAttachmentGroupsListResponse> - Lists the InterconnectAttachmentGroups for a project in the given scope.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchInterconnectAttachmentGroupRequest request) → Future< Operation> - Patches the specified InterconnectAttachmentGroup resource with the data included in the request. This method supports PATCH semantics and usesJSON merge patch format and processing rules.
-
setIamPolicy(
SetIamPolicyInterconnectAttachmentGroupRequest request) → Future< Policy> - Sets the access control policy on the specified resource. Replaces any existing policy.
-
testIamPermissions(
TestIamPermissionsInterconnectAttachmentGroupRequest request) → Future< TestPermissionsResponse> - Returns permissions that a caller has on the specified resource.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited