InterconnectAttachmentGroupsOperationalStatusAttachmentStatus class final
The status of one Attachment in the group. List order is arbitrary.
Constructors
- InterconnectAttachmentGroupsOperationalStatusAttachmentStatus({bool? adminEnabled, String? attachment, String? isActive, String? status})
- InterconnectAttachmentGroupsOperationalStatusAttachmentStatus.fromJson(Object? j)
-
factory
Properties
- adminEnabled → bool?
-
Output only. Whether this Attachment is enabled. This becomes false when the customer
drains their Attachment.
final
- attachment → String?
-
Output only. The URL of the Attachment being described.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isActive → String?
-
Output only. Whether this Attachment is participating in the redundant configuration.
This will be ACTIVE if and only if the status below is CONNECTION_UP.
Any INACTIVE Attachments are excluded from the analysis that generates
operational.availabilitySLA.
Check the IsActive enum for the list of possible values.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String?
-
Output only. Whether this Attachment is active, and if so, whether BGP is up.
Check the Status enum for the list of possible values.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String