status property
Output only. Whether this Attachment is active, and if so, whether BGP is up. Check the Status enum for the list of possible values.
Implementation
final String? status;
Output only. Whether this Attachment is active, and if so, whether BGP is up. Check the Status enum for the list of possible values.
final String? status;