InterconnectAttachmentGroupsOperationalStatusAttachmentStatus_IsActive class final
Output only. Whether this Attachment is participating in the redundant configuration. This will be ACTIVE if and only if the status below is CONNECTION_UP. Any INACTIVE Attachments are excluded from the analysis that generates operational.availabilitySLA.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const InterconnectAttachmentGroupsOperationalStatusAttachmentStatus_IsActive
- The default value for InterconnectAttachmentGroupsOperationalStatusAttachmentStatus_IsActive.
- active → const InterconnectAttachmentGroupsOperationalStatusAttachmentStatus_IsActive
- inactive → const InterconnectAttachmentGroupsOperationalStatusAttachmentStatus_IsActive
- undefinedIsActive → const InterconnectAttachmentGroupsOperationalStatusAttachmentStatus_IsActive
- A value indicating that the enum field is not set.
- unspecified → const InterconnectAttachmentGroupsOperationalStatusAttachmentStatus_IsActive