InterconnectAttachmentL2Forwarding class final
L2 Interconnect Attachment related configuration.
Constructors
-
InterconnectAttachmentL2Forwarding({Map<
String, InterconnectAttachmentL2ForwardingApplianceMapping> applianceMappings = const {}, String? defaultApplianceIpAddress, InterconnectAttachmentL2ForwardingGeneveHeader? geneveHeader, String? network, String? tunnelEndpointIpAddress}) - InterconnectAttachmentL2Forwarding.fromJson(Object? j)
-
factory
Properties
-
applianceMappings
→ Map<
String, InterconnectAttachmentL2ForwardingApplianceMapping> -
Optional. A map of VLAN tags to appliances and optional inner mapping
rules. If VLANs are not explicitly mapped to any appliance, the
defaultApplianceIpAddress is used.
final
- defaultApplianceIpAddress → String?
-
Optional. A single IPv4 or IPv6 address used as the default destination
IP when there is no VLAN mapping result found.
final
- geneveHeader → InterconnectAttachmentL2ForwardingGeneveHeader?
-
Optional. It represents the structure of a Geneve (Generic Network
Virtualization Encapsulation) header, as defined in RFC8926. It encapsulates packets from various
protocols (e.g., Ethernet, IPv4, IPv6) for use in network virtualization
environments.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- network → String?
-
Required. Resource URL of the network to which this attachment belongs.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tunnelEndpointIpAddress → String?
-
Required. A single IPv4 or IPv6 address. This address will be used as the
source IP address for packets sent to the appliances, and must be used as
the destination IP address for packets that should be sent out through
this attachment.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String