InterconnectAttachmentL2ForwardingApplianceMapping class final
Two-level VLAN-to-Appliance mapping rule.
Constructors
-
InterconnectAttachmentL2ForwardingApplianceMapping({String? applianceIpAddress, List<
InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping> innerVlanToApplianceMappings = const [], String? name}) - InterconnectAttachmentL2ForwardingApplianceMapping.fromJson(Object? j)
-
factory
Properties
- applianceIpAddress → String?
-
Optional. A single IPv4 or IPv6 address used as the destination IP
address for ingress packets that match on a VLAN tag, but do not match
a more specific inner VLAN tag.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
innerVlanToApplianceMappings
→ List<
InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping> -
Optional. Used to match against the inner VLAN when the packet
contains two VLAN tags.
final
- name → String?
-
Optional. The name of this appliance mapping rule.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String