InterconnectAttachmentPartnerMetadata class final

Informational metadata about Partner attachments from Partners to display to customers. These fields are propagated from PARTNER_PROVIDER attachments to their corresponding PARTNER attachments.

Constructors

InterconnectAttachmentPartnerMetadata({String? interconnectName, String? partnerName, String? portalUrl})
InterconnectAttachmentPartnerMetadata.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
interconnectName String?
Plain text name of the Interconnect this attachment is connected to, as displayed in the Partner's portal. For instance "Chicago 1". This value may be validated to match approved Partner values.
final
partnerName String?
Plain text name of the Partner providing this attachment. This value may be validated to match approved Partner values.
final
portalUrl String?
URL of the Partner's portal for this Attachment. Partners may customise this to be a deep link to the specific resource on the Partner portal. This value may be validated to match approved Partner values.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String