InterconnectAttachmentPrivateInfo class final
Information for an interconnect attachment when this belongs to an interconnect of type DEDICATED.
Constructors
- InterconnectAttachmentPrivateInfo({int? tag8021Q})
- InterconnectAttachmentPrivateInfo.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag8021Q → int?
-
Output Only802.1q encapsulation tag to be used for traffic between Google and the customer, going to and from this network and region.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String