InterconnectAttachment_EdgeAvailabilityDomain class final
Input only. Desired availability domain for the attachment. Only available for type PARTNER, at creation time, and can take one of the following values:
- AVAILABILITY_DOMAIN_ANY
- AVAILABILITY_DOMAIN_1
- AVAILABILITY_DOMAIN_2
For improved reliability, customers should configure a pair of attachments, one per availability domain. The selected availability domain will be provided to the Partner via the pairing key, so that the provisioned circuit will lie in the specified domain. If not specified, the value will default to AVAILABILITY_DOMAIN_ANY.
Constructors
- InterconnectAttachment_EdgeAvailabilityDomain(String value)
-
const
- InterconnectAttachment_EdgeAvailabilityDomain.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const InterconnectAttachment_EdgeAvailabilityDomain
- The default value for InterconnectAttachment_EdgeAvailabilityDomain.
- availabilityDomain1 → const InterconnectAttachment_EdgeAvailabilityDomain
- availabilityDomain2 → const InterconnectAttachment_EdgeAvailabilityDomain
- availabilityDomainAny → const InterconnectAttachment_EdgeAvailabilityDomain
- undefinedEdgeAvailabilityDomain → const InterconnectAttachment_EdgeAvailabilityDomain
- A value indicating that the enum field is not set.