none constant

This is the default value, which means the Interconnect Attachment will carry unencrypted traffic. VMs will be able to send traffic to or receive traffic from such interconnect attachment.

Implementation

static const none = InterconnectAttachment_Encryption('NONE');