InterconnectAttachment_OperationalStatus class final
Output only. Output Only The current status of whether or not this interconnect
attachment is functional, which can take one of the following values:
- OS_ACTIVE: The attachment has been turned up and is ready to use.
- OS_UNPROVISIONED: The attachment is not ready to use yet, because turnup is not complete.
Constructors
- InterconnectAttachment_OperationalStatus(String value)
-
const
- InterconnectAttachment_OperationalStatus.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const InterconnectAttachment_OperationalStatus
- The default value for InterconnectAttachment_OperationalStatus.
- osActive → const InterconnectAttachment_OperationalStatus
- Indicates that attachment has been turned up and is ready to use.
- osUnprovisioned → const InterconnectAttachment_OperationalStatus
- Indicates that attachment is not ready to use yet, because turnup is not complete.
- undefinedOperationalStatus → const InterconnectAttachment_OperationalStatus
- A value indicating that the enum field is not set.