InterconnectAttachment_State class final
Output only. Output Only The current state of this attachment's functionality.
Enum values ACTIVE and UNPROVISIONED are shared by DEDICATED/PRIVATE,
PARTNER, and PARTNER_PROVIDER interconnect attachments, while enum values
PENDING_PARTNER, PARTNER_REQUEST_RECEIVED, and PENDING_CUSTOMER are used
for only PARTNER and PARTNER_PROVIDER interconnect attachments.
This state can take one of the following values:
- ACTIVE: The attachment has been turned up and is ready to use.
- UNPROVISIONED: The attachment is not ready to use yet, because turnup is not complete.
- PENDING_PARTNER: A newly-created PARTNER attachment that has not yet been configured on the Partner side.
- PARTNER_REQUEST_RECEIVED: A PARTNER attachment is in the process of provisioning after a PARTNER_PROVIDER attachment was created that references it.
- PENDING_CUSTOMER: A PARTNER or PARTNER_PROVIDER attachment that is waiting for a customer to activate it.
- DEFUNCT: The attachment was deleted externally and is no longer functional. This could be because the associated Interconnect was removed, or because the other side of a Partner attachment was deleted.
Constructors
- InterconnectAttachment_State(String value)
-
const
- InterconnectAttachment_State.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const InterconnectAttachment_State
- The default value for InterconnectAttachment_State.
- active → const InterconnectAttachment_State
- Indicates that attachment has been turned up and is ready to use.
- defunct → const InterconnectAttachment_State
- The attachment was deleted externally and is no longer functional. This could be because the associated Interconnect was wiped out, or because the other side of a Partner attachment was deleted.
- partnerRequestReceived → const InterconnectAttachment_State
- A PARTNER attachment is in the process of provisioning after a PARTNER_PROVIDER attachment was created that references it.
- pendingCustomer → const InterconnectAttachment_State
- PARTNER or PARTNER_PROVIDER attachment that is waiting for the customer to activate.
- pendingPartner → const InterconnectAttachment_State
- A newly created PARTNER attachment that has not yet been configured on the Partner side.
- stateUnspecified → const InterconnectAttachment_State
- undefinedState → const InterconnectAttachment_State
- A value indicating that the enum field is not set.
- unprovisioned → const InterconnectAttachment_State
- Indicates that attachment is not ready to use yet, because turnup is not complete.