InterconnectCircuitInfo class final

Describes a single physical circuit between the Customer and Google. CircuitInfo objects are created by Google, so all fields are output only.

Constructors

InterconnectCircuitInfo({String? customerDemarcId, String? googleCircuitId, String? googleDemarcId})
InterconnectCircuitInfo.fromJson(Object? j)
factory

Properties

customerDemarcId String?
Customer-side demarc ID for this circuit.
final
googleCircuitId String?
Google-assigned unique ID for this circuit. Assigned at circuit turn-up.
final
googleDemarcId String?
Google-side demarc ID for this circuit. Assigned at circuit turn-up and provided by Google to the customer in the LOA.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String