InterconnectDiagnostics class final
Diagnostics information about the Interconnect connection, which contains detailed and current technical information about Google's side of the connection.
Constructors
-
InterconnectDiagnostics({List<
InterconnectDiagnosticsArpentry> arpCaches = const [], String? bundleAggregationType, String? bundleOperationalStatus, List<InterconnectDiagnosticsLinkStatus> links = const [], String? macAddress}) - InterconnectDiagnostics.fromJson(Object? j)
-
factory
Properties
-
arpCaches
→ List<
InterconnectDiagnosticsArpentry> -
A list of InterconnectDiagnostics.ARPEntry objects,
describing individual neighbors currently seen by the Google router in
the ARP cache for the Interconnect.
This will be empty when the Interconnect is not bundled.
final
- bundleAggregationType → String?
-
The aggregation type of the bundle interface.
Check the BundleAggregationType enum for the list of possible values.
final
- bundleOperationalStatus → String?
-
The operational status of the bundle interface.
Check the BundleOperationalStatus enum for the list of possible values.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
links
→ List<
InterconnectDiagnosticsLinkStatus> -
A list of InterconnectDiagnostics.LinkStatus objects,
describing the status for each link on the Interconnect.
final
- macAddress → String?
-
The MAC address of the Interconnect's bundle interface.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String