InterconnectDiagnosticsLinkLacpstatus class
final
Properties
-
googleSystemId
→ String?
-
System ID of the port on Google's side of the LACP exchange.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
neighborSystemId
→ String?
-
System ID of the port on the neighbor's side of the LACP exchange.
final
-
qualifiedName
→ String
-
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or google.rpc.ErrorInfo.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
→ String?
-
The state of a LACP link, which can take one of the following values:
final