InterconnectDiagnosticsLinkLacpstatus_State class final

The state of a LACP link, which can take one of the following values:

  • ACTIVE: The link is configured and active within the bundle.
  • DETACHED: The link is not configured within the bundle. This means that the rest of the object should be empty.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const InterconnectDiagnosticsLinkLacpstatus_State
The default value for InterconnectDiagnosticsLinkLacpstatus_State.
active → const InterconnectDiagnosticsLinkLacpstatus_State
The link is configured and active within the bundle.
detached → const InterconnectDiagnosticsLinkLacpstatus_State
The link is not configured within the bundle, this means the rest of the object should be empty.
undefinedState → const InterconnectDiagnosticsLinkLacpstatus_State
A value indicating that the enum field is not set.