InterconnectDiagnosticsLinkOpticalPower_State class final
The status of the current value when compared to the warning and alarm levels for the receiving or transmitting transceiver. Possible states include:
- OK: The value has not crossed a warning threshold.
- LOW_WARNING: The value has crossed below the low
warning threshold.
- HIGH_WARNING: The value has crossed above the high warning threshold. - LOW_ALARM: The value has crossed below the low alarm threshold. - HIGH_ALARM: The value has crossed above the high alarm threshold.
Constructors
- InterconnectDiagnosticsLinkOpticalPower_State(String value)
-
const
- InterconnectDiagnosticsLinkOpticalPower_State.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const InterconnectDiagnosticsLinkOpticalPower_State
- The default value for InterconnectDiagnosticsLinkOpticalPower_State.
- highAlarm → const InterconnectDiagnosticsLinkOpticalPower_State
- The value has crossed above the high alarm threshold.
- highWarning → const InterconnectDiagnosticsLinkOpticalPower_State
- The value of the current optical power has crossed above the high warning threshold.
- lowAlarm → const InterconnectDiagnosticsLinkOpticalPower_State
- The value of the current optical power has crossed below the low alarm threshold.
- lowWarning → const InterconnectDiagnosticsLinkOpticalPower_State
- The value of the current optical power has crossed below the low warning threshold.
- ok → const InterconnectDiagnosticsLinkOpticalPower_State
- The value of the current optical power has not crossed a warning threshold.
- undefinedState → const InterconnectDiagnosticsLinkOpticalPower_State
- A value indicating that the enum field is not set.