InterconnectDiagnosticsLinkStatus_OperationalStatus class final
The operational status of the link.
Constructors
- InterconnectDiagnosticsLinkStatus_OperationalStatus(String value)
-
const
- InterconnectDiagnosticsLinkStatus_OperationalStatus.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const InterconnectDiagnosticsLinkStatus_OperationalStatus
- The default value for InterconnectDiagnosticsLinkStatus_OperationalStatus.
- linkOperationalStatusDown → const InterconnectDiagnosticsLinkStatus_OperationalStatus
- The interface is unable to communicate with the remote end.
- linkOperationalStatusUp → const InterconnectDiagnosticsLinkStatus_OperationalStatus
- The interface has low level communication with the remote end.
- undefinedOperationalStatus → const InterconnectDiagnosticsLinkStatus_OperationalStatus
- A value indicating that the enum field is not set.