InterconnectDiagnosticsMacsecStatus class final

Describes the status of MACsec encryption on the link.

Properties

ckn String?
Indicates the Connectivity Association Key Name (CKN) currently being used if MACsec is operational.
final
hashCode int
The hash code for this object.
no setterinherited
operational bool?
Indicates whether or not MACsec is operational on this link.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String