InterconnectGroups class final
The InterconnectGroups API.
- Implementers
Constructors
- InterconnectGroups({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
InterconnectGroupsusingclientfor transport. - InterconnectGroups.fromApiKey([String? apiKey])
-
Creates a
InterconnectGroupsthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
createMembers(
CreateMembersInterconnectGroupRequest request) → Future< Operation> - Create Interconnects with redundancy by creating them in a specified interconnect group.
-
delete(
DeleteInterconnectGroupRequest request) → Future< Operation> - Deletes the specified InterconnectGroup in the given scope
-
get(
GetInterconnectGroupRequest request) → Future< InterconnectGroup> - Returns the specified InterconnectGroup resource in the given scope.
-
getIamPolicy(
GetIamPolicyInterconnectGroupRequest request) → Future< Policy> - Gets the access control policy for a resource. May be empty if no such policy or resource exists.
-
getOperationalStatus(
GetOperationalStatusInterconnectGroupRequest request) → Future< InterconnectGroupsGetOperationalStatusResponse> - Returns the interconnectStatuses for the specified InterconnectGroup.
-
insert(
InsertInterconnectGroupRequest request) → Future< Operation> - Creates a InterconnectGroup in the specified project in the given scope using the parameters that are included in the request.
-
list(
ListInterconnectGroupsRequest request) → Future< InterconnectGroupsListResponse> - Lists the InterconnectGroups for a project in the given scope.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchInterconnectGroupRequest request) → Future< Operation> - Patches the specified InterconnectGroup resource with the data included in the request. This method supports PATCH semantics and usesJSON merge patch format and processing rules.
-
setIamPolicy(
SetIamPolicyInterconnectGroupRequest request) → Future< Policy> - Sets the access control policy on the specified resource. Replaces any existing policy.
-
testIamPermissions(
TestIamPermissionsInterconnectGroupRequest request) → Future< TestPermissionsResponse> - Returns permissions that a caller has on the specified resource.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited