InterconnectGroupsCreateMembersInterconnectInput class final

Constructors

InterconnectGroupsCreateMembersInterconnectInput({bool? adminEnabled, String? customerName, String? description, String? facility, String? interconnectType, String? linkType, String? name, String? nocContactEmail, String? remoteLocation, List<String> requestedFeatures = const [], int? requestedLinkCount})
InterconnectGroupsCreateMembersInterconnectInput.fromJson(Object? j)
factory

Properties

adminEnabled bool?
Administrative status of the interconnect. When this is set to true, the Interconnect is functional and can carry traffic. When set to false, no packets can be carried over the interconnect and no BGP routes are exchanged over it. By default, the status is set to true.
final
customerName String?
Customer name, to put in the Letter of Authorization as the party authorized to request a crossconnect.
final
description String?
An optional description of this resource. Provide this property when you create the resource.
final
facility String?
A zone-free location to use for all Interconnects created in this call, like "iad-1234".
final
hashCode int
The hash code for this object.
no setterinherited
interconnectType String?
Type of interconnect, which can take one of the following values:
final
linkType String?
Type of link requested, which can take one of the following values:
final
name String?
Name of the Interconnects to be created. This must be specified on the template and/or on each individual interconnect. The name, if not empty, must be 1-63 characters long, and comply with RFC1035. Specifically, any nonempty name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
nocContactEmail String?
Email address to contact the customer NOC for operations and maintenance notifications regarding this Interconnect. If specified, this will be used for notifications in addition to all other forms described, such as Cloud Monitoring logs alerting and Cloud Notifications. This field is required for users who sign up for Cloud Interconnect using workforce identity federation.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
remoteLocation String?
Indicates that this is a Cross-Cloud Interconnect. This field specifies the location outside of Google's network that the interconnect is connected to.
final
requestedFeatures List<String>
Optional. List of features requested for this Interconnect connection, which can take one of the following values:
final
requestedLinkCount int?
Target number of physical links in the link bundle, as requested by the customer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String