requestedFeatures property

List<String> requestedFeatures
final

Optional. List of features requested for this Interconnect connection, which can take one of the following values:

  • IF_MACSEC: If specified, then the connection is created on MACsec capable hardware ports. If not specified, non-MACsec capable ports will also be considered.
  • IF_CROSS_SITE_NETWORK: If specified, then the connection is created exclusively for Cross-Site Networking. The connection can not be used for Cross-Site Networking unless this feature is specified. Check the RequestedFeatures enum for the list of possible values.

Implementation

final List<String> requestedFeatures;