InterconnectGroupsOperationalStatusInterconnectStatus class final
The status of one Interconnect in the group. The order is arbitrary.
Constructors
- InterconnectGroupsOperationalStatusInterconnectStatus({bool? adminEnabled, InterconnectDiagnostics? diagnostics, String? interconnect, String? isActive})
- InterconnectGroupsOperationalStatusInterconnectStatus.fromJson(Object? j)
-
factory
Properties
- adminEnabled → bool?
-
Output only. Whether the Interconnect is enabled.
final
- diagnostics → InterconnectDiagnostics?
-
Output only. The diagnostics of the Interconnect, as returned by the existing
get-diagnostics method.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- interconnect → String?
-
Output only. The URL of the Interconnect being described.
final
- isActive → String?
-
Output only. Whether this interconnect is participating in the redundant
configuration.
Check the IsActive enum for the list of possible values.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String