InterconnectLocation class final
Represents an Interconnect Attachment (VLAN) Location resource.
You can use this resource to find location details about an Interconnect attachment (VLAN). For more information about interconnect attachments, read Creating VLAN Attachments.
Constructors
-
InterconnectLocation({String? address, String? availabilityZone, List<
String> availableFeatures = const [], List<String> availableLinkTypes = const [], String? city, String? continent, String? creationTimestamp, List<InterconnectLocationCrossSiteInterconnectInfo> crossSiteInterconnectInfos = const [], String? description, String? facilityProvider, String? facilityProviderFacilityId, BigInt? id, String? kind, String? name, String? peeringdbFacilityId, List<InterconnectLocationRegionInfo> regionInfos = const [], String? selfLink, List<String> singleRegionProductionCriticalPeerLocations = const [], String? status, bool? supportsPzs}) - InterconnectLocation.fromJson(Object? j)
-
factory
Properties
- address → String?
-
Output only.
Output OnlyThe postal address of the Point of Presence, each line in the address is separated by a newline character.final - availabilityZone → String?
-
Output OnlyAvailability zone for this InterconnectLocation. Within a metropolitan area (metro), maintenance will not be simultaneously scheduled in more than one availability zone. Example: "zone1" or "zone2".final -
availableFeatures
→ List<
String> -
Output onlyList of features available at this InterconnectLocation, which can take one of the following values:final -
availableLinkTypes
→ List<
String> -
Output onlyList of link types available at this InterconnectLocation, which can take one of the following values:final - city → String?
-
Output OnlyMetropolitan area designator that indicates which city an interconnect is located. For example: "Chicago, IL", "Amsterdam, Netherlands".final - continent → String?
-
Output OnlyContinent for this location, which can take one of the following values:final - creationTimestamp → String?
-
Output only.
Output OnlyCreation timestamp inRFC3339 text format.final -
crossSiteInterconnectInfos
→ List<
InterconnectLocationCrossSiteInterconnectInfo> -
Output OnlyA list of InterconnectLocation.CrossSiteInterconnectInfo objects, that describe where Cross-Site Interconnect wires may connect to from this location and associated connection parameters. Cross-Site Interconnect isn't allowed to locations which are not listed.final - description → String?
-
Output only.
Output OnlyAn optional description of the resource.final - facilityProvider → String?
-
Output only.
Output OnlyThe name of the provider for this facility (e.g., EQUINIX).final - facilityProviderFacilityId → String?
-
Output only.
Output OnlyA provider-assigned Identifier for this facility (e.g., Ashburn-DC1).final - hashCode → int
-
The hash code for this object.
no setterinherited
- id → BigInt?
-
Output only.
Output OnlyThe unique identifier for the resource. This identifier is defined by the server.final - kind → String?
-
Output only.
Output OnlyType of the resource. Alwayscompute#interconnectLocation for interconnect locations.final - name → String?
-
Output only.
Output OnlyName of the resource.final - peeringdbFacilityId → String?
-
Output only.
Output OnlyThe peeringdb identifier for this facility (corresponding with a netfac type in peeringdb).final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited -
regionInfos
→ List<
InterconnectLocationRegionInfo> -
Output only.
Output OnlyA list of InterconnectLocation.RegionInfo objects, that describe parameters pertaining to the relation between this InterconnectLocation and various Google Cloud regions.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfLink → String?
-
Output only.
Output OnlyServer-defined URL for the resource.final -
singleRegionProductionCriticalPeerLocations
→ List<
String> -
Output only.
Output OnlyURLs of the other locations that can pair up with this location to support Single-Region 99.99% SLA. E.g. iad-zone1-1 and iad-zone2-5467 are Single-Region 99.99% peer locations of each other.final - status → String?
-
Output OnlyThe status of this InterconnectLocation, which can take one of the following values:final - supportsPzs → bool?
-
Output only.
Output OnlyReserved for future use.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String