status property
Output Only The status of this InterconnectLocation, which can take one
of the following values:
- CLOSED: The InterconnectLocation is closed and is unavailable for provisioning new Interconnects.
- AVAILABLE: The InterconnectLocation is available for provisioning new Interconnects. Check the Status enum for the list of possible values.
Implementation
final String? status;