InterconnectLocationCrossSiteInterconnectInfo class final
Information about Cross-Site Interconnect wires which may be created between the containing location and another remote location.
Constructors
- InterconnectLocationCrossSiteInterconnectInfo({String? city, int? maxDynamicPathBandwidthGbps, int? maxFixedPathBandwidthGbps})
- InterconnectLocationCrossSiteInterconnectInfo.fromJson(Object? j)
-
factory
Properties
- city → String?
-
Output only. The remote location for Cross-Site Interconnect wires. This specifies an
InterconnectLocation city (metropolitan area designator), which itself
may match multiple InterconnectLocations.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxDynamicPathBandwidthGbps → int?
-
Output only. The maximum unmetered bandwidth for dynamic paths allowable per
WireGroup for this metro.
final
- maxFixedPathBandwidthGbps → int?
-
Output only. The maximum unmetered bandwidth for fixed paths allowable per WireGroup
for this metro.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String