InterconnectLocationRegionInfo_LocationPresence class final
Output only. Identifies the network presence of this location.
Constructors
- InterconnectLocationRegionInfo_LocationPresence(String value)
-
const
- InterconnectLocationRegionInfo_LocationPresence.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const InterconnectLocationRegionInfo_LocationPresence
- The default value for InterconnectLocationRegionInfo_LocationPresence.
- global → const InterconnectLocationRegionInfo_LocationPresence
- This region is not in any common network presence with this InterconnectLocation.
- localRegion → const InterconnectLocationRegionInfo_LocationPresence
- This region shares the same regional network presence as this InterconnectLocation.
- lpGlobal → const InterconnectLocationRegionInfo_LocationPresence
- Deprecated This region is not in any common network presence with this InterconnectLocation.
- lpLocalRegion → const InterconnectLocationRegionInfo_LocationPresence
- Deprecated This region shares the same regional network presence as this InterconnectLocation.
- undefinedLocationPresence → const InterconnectLocationRegionInfo_LocationPresence
- A value indicating that the enum field is not set.