InterconnectMacsec class final
Configuration information for enabling Media Access Control security (MACsec) on this Cloud Interconnect connection between Google and your on-premises router.
Constructors
- InterconnectMacsec({bool? failOpen, })
- InterconnectMacsec.fromJson(Object? j)
-
factory
Properties
- failOpen → bool?
-
If set to true, the Interconnect connection is configured with ashould-secure MACsec security policy, that allows the Google
router to fallback to cleartext traffic if the MKA session cannot be
established. By default, the Interconnect connection is configured with amust-secure security policy that drops all traffic if the
MKA session cannot be established with your router.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
Required. A keychain placeholder describing a set of named key objects
along with their start times. A MACsec CKN/CAK is generated for each
key in the key chain. Google router automatically picks the key with
the most recent startTime when establishing or re-establishing a MACsec
secure link.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String