subnetLengthRange property
Output only. Output Only
min-length, max-length
The minimum and maximum value (inclusive) for the IPv4 subnet length.
For example, an interconnectRemoteLocation for Azure has {min: 30, max: 30} because Azure requires /30 subnets.
This range specifies the values supported by both cloud providers. Interconnect currently supports /29 and /30 IPv4 subnet lengths. If a remote cloud has no constraint on IPv4 subnet length, the range would thus be {min: 29, max: 30}.
Implementation
final InterconnectRemoteLocationConstraintsSubnetLengthRange?
subnetLengthRange;