InterconnectRemoteLocation_Lacp class final
Output only. Output Only Link Aggregation Control Protocol (LACP) constraints, which
can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED
Constructors
- InterconnectRemoteLocation_Lacp(String value)
-
const
- InterconnectRemoteLocation_Lacp.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const InterconnectRemoteLocation_Lacp
- The default value for InterconnectRemoteLocation_Lacp.
- lacpSupported → const InterconnectRemoteLocation_Lacp
- LACP_SUPPORTED: LACP is supported, and enabled by default on the Cross-Cloud Interconnect.
- lacpUnsupported → const InterconnectRemoteLocation_Lacp
- LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this port. GetDiagnostics shows bundleAggregationType as "static". GCP does not support LAGs without LACP, so requestedLinkCount must be 1.
- undefinedLacp → const InterconnectRemoteLocation_Lacp
- A value indicating that the enum field is not set.