InterconnectRemoteLocation_Status class final
Output only. Output Only The status of this InterconnectRemoteLocation, which can take
one of the following values:
- CLOSED: The InterconnectRemoteLocation is closed and is unavailable for provisioning new Cross-Cloud Interconnects.
- AVAILABLE: The InterconnectRemoteLocation is available for provisioning new Cross-Cloud Interconnects.
Constructors
- InterconnectRemoteLocation_Status(String value)
-
const
- InterconnectRemoteLocation_Status.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const InterconnectRemoteLocation_Status
- The default value for InterconnectRemoteLocation_Status.
- available → const InterconnectRemoteLocation_Status
- The InterconnectRemoteLocation is available for provisioning new Cross-Cloud Interconnects.
- closed → const InterconnectRemoteLocation_Status
- The InterconnectRemoteLocation is closed for provisioning new Cross-Cloud Interconnects.
- undefinedStatus → const InterconnectRemoteLocation_Status
- A value indicating that the enum field is not set.