InterconnectRemoteLocations class final
The InterconnectRemoteLocations API.
- Implementers
Constructors
- InterconnectRemoteLocations({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
InterconnectRemoteLocationsusingclientfor transport. - InterconnectRemoteLocations.fromApiKey([String? apiKey])
-
Creates a
InterconnectRemoteLocationsthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
get(
GetInterconnectRemoteLocationRequest request) → Future< InterconnectRemoteLocation> - Returns the details for the specified interconnect remote location. Gets a list of available interconnect remote locations by making alist() request.
-
list(
ListInterconnectRemoteLocationsRequest request) → Future< InterconnectRemoteLocationList> - Retrieves the list of interconnect remote locations available to the specified project.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited