getDiagnostics method
Returns the interconnectDiagnostics for the specified Interconnect.
In the event of a global outage, do not use this API to make decisions about where to redirect your network traffic.
Unlike a VLAN attachment, which is regional, a Cloud Interconnect connection is a global resource. A global outage can prevent this API from functioning properly.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
Future<InterconnectsGetDiagnosticsResponse> getDiagnostics(
GetDiagnosticsInterconnectRequest request,
) async {
final url = _endPoint.replace(
path:
'/compute/v1/projects/${request.project}/global/interconnects/${request.interconnect}/getDiagnostics',
);
final response = await _client.get(url);
return InterconnectsGetDiagnosticsResponse.fromJson(response);
}