License class final
Represents a License resource.
A License represents billing and aggregate usage data forpublic andmarketplace images. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
Constructors
-
License({List<
String> allowedReplacementLicenses = const [], bool? appendableToDisk, bool? chargesUseFee, String? creationTimestamp, String? description, BigInt? id, List<String> incompatibleLicenses = const [], String? kind, BigInt? licenseCode, Duration? minimumRetention, bool? multiTenantOnly, String? name, bool? osLicense, LicenseParams? params, bool? removableFromDisk, List<String> requiredCoattachedLicenses = const [], LicenseResourceRequirements? resourceRequirements, String? selfLink, String? selfLinkWithId, bool? soleTenantOnly, bool? transferable, String? updateTimestamp}) - License.fromJson(Object? j)
-
factory
Properties
-
allowedReplacementLicenses
→ List<
String> -
Specifies licenseCodes of licenses that can replace this license. Note:
such replacements are allowed even if removable_from_disk is false.
final
- appendableToDisk → bool?
-
If true, this license can be appended to an existing disk's set of
licenses.
final
- chargesUseFee → bool?
-
Output OnlyDeprecated. This field no longer reflects whether a license charges a usage fee.final - creationTimestamp → String?
-
Output only.
Output OnlyCreation timestamp inRFC3339 text format.final - description → String?
-
An optional textual description of the resource; provided by the client
when the resource is created.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → BigInt?
-
Output OnlyThe unique identifier for the resource. This identifier is defined by the server.final -
incompatibleLicenses
→ List<
String> -
Specifies licenseCodes of licenses that are incompatible with this license.
If a license is incompatible with this license, it cannot be attached to
the same disk or image.
final
- kind → String?
-
Output only.
Output OnlyType of resource. Always compute#license for licenses.final - licenseCode → BigInt?
-
Output OnlyThe unique code used to attach this license to images, snapshots, and disks.final - minimumRetention → Duration?
-
If set, this license will be unable to be removed or replaced once attached
to a disk until the minimum_retention period has passed.
final
- multiTenantOnly → bool?
-
If true, this license can only be used on VMs on multi tenant nodes.
final
- name → String?
-
Name of the resource. The name must be 1-63 characters long and
comply withRFC1035.
final
- osLicense → bool?
-
If true, indicates this is an OS license. Only one OS license can be
attached to a disk or image at a time.
final
- params → LicenseParams?
-
Input only. Additional params passed with the request, but not persisted
as part of resource payload.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - removableFromDisk → bool?
-
If true, this license can be removed from a disk's set of licenses, with no
replacement license needed.
final
-
requiredCoattachedLicenses
→ List<
String> -
Specifies the set of permissible coattached licenseCodes of licenses that
satisfy the coattachment requirement of this license. At least one license
from the set must be attached to the same disk or image as this license.
final
- resourceRequirements → LicenseResourceRequirements?
-
Input OnlyDeprecated.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfLink → String?
-
Output only.
Output OnlyServer-defined URL for the resource.final - selfLinkWithId → String?
-
Output only.
Output OnlyServer-defined URL for this resource with the resource id.final - soleTenantOnly → bool?
-
If true, this license can only be used on VMs on sole tenant nodes.
final
- transferable → bool?
-
If false, licenses will not be copied from the source resource when
creating an image from a disk, disk from snapshot, or snapshot from disk.
final
- updateTimestamp → String?
-
Output only.
Output OnlyLast update timestamp inRFC3339 text format.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String