incompatibleLicenses property
Specifies licenseCodes of licenses that are incompatible with this license. If a license is incompatible with this license, it cannot be attached to the same disk or image.
Implementation
final List<String> incompatibleLicenses;