LicenseCode_State class final

Output only. Output Only Current state of this License Code.

Constructors

LicenseCode_State(String value)
const
LicenseCode_State.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const LicenseCode_State
The default value for LicenseCode_State.
disabled → const LicenseCode_State
Machines are not allowed to attach boot disks with this License Code. Requests to create new resources with this license will be rejected.
enabled → const LicenseCode_State
Use is allowed for anyone with USE_READ_ONLY access to this License Code.
restricted → const LicenseCode_State
Use of this license is limited to a project whitelist.
stateUnspecified → const LicenseCode_State
terminated → const LicenseCode_State
Reserved state.
undefinedState → const LicenseCode_State
A value indicating that the enum field is not set.