LicenseCodes class final
The LicenseCodes API.
- Implementers
Constructors
- LicenseCodes({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
LicenseCodesusingclientfor transport. - LicenseCodes.fromApiKey([String? apiKey])
-
Creates a
LicenseCodesthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
get(
GetLicenseCodeRequest request) → Future< LicenseCode> - Return a specified license code. License codes are mirrored across all projects that have permissions to read the License Code. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
-
getIamPolicy(
GetIamPolicyLicenseCodeRequest request) → Future< Policy> - Gets the access control policy for a resource. May be empty if no such policy or resource exists. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setIamPolicy(
SetIamPolicyLicenseCodeRequest request) → Future< Policy> - Sets the access control policy on the specified resource. Replaces any existing policy. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
-
testIamPermissions(
TestIamPermissionsLicenseCodeRequest request) → Future< TestPermissionsResponse> - Returns permissions that a caller has on the specified resource. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited