get method

Return a specified license code. License codes are mirrored across all projects that have permissions to read the License Code. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<LicenseCode> get(GetLicenseCodeRequest request) async {
  final url = _endPoint.replace(
    path:
        '/compute/v1/projects/${request.project}/global/licenseCodes/${request.licenseCode}',
  );
  final response = await _client.get(url);
  return LicenseCode.fromJson(response);
}