Licenses class final
The Licenses API.
- Implementers
Constructors
- Licenses({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
Licensesusingclientfor transport. - Licenses.fromApiKey([String? apiKey])
-
Creates a
Licensesthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteLicenseRequest request) → Future< Operation> - Deletes the specified license. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
-
get(
GetLicenseRequest request) → Future< License> - Returns the specified License resource. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
-
getIamPolicy(
GetIamPolicyLicenseRequest request) → Future< Policy> - Gets the access control policy for a resource. May be empty if no such policy or resource exists. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
-
insert(
InsertLicenseRequest request) → Future< Operation> - Create a License resource in the specified project. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
-
list(
ListLicensesRequest request) → Future< LicensesListResponse> - Retrieves the list of licenses available in the specified project. This method does not get any licenses that belong to other projects, including licenses attached to publicly-available images, like Debian 9. If you want to get a list of publicly-available licenses, use this method to make a request to the respective image project, such as debian-cloud orwindows-cloud. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setIamPolicy(
SetIamPolicyLicenseRequest request) → Future< Policy> - Sets the access control policy on the specified resource. Replaces any existing policy. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
-
testIamPermissions(
TestIamPermissionsLicenseRequest request) → Future< TestPermissionsResponse> - Returns permissions that a caller has on the specified resource. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
UpdateLicenseRequest request) → Future< Operation> - Updates a License resource in the specified project. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited