list method
Retrieves the list of licenses available in the specified project. This method does not get any licenses that belong to other projects, including licenses attached to publicly-available images, like Debian 9. If you want to get a list of publicly-available licenses, use this method to make a request to the respective image project, such as debian-cloud orwindows-cloud. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
Future<LicensesListResponse> list(ListLicensesRequest request) async {
final url = _endPoint.replace(
path: '/compute/v1/projects/${request.project}/global/licenses',
queryParameters: {
'filter': ?request.filter,
if (request.maxResults case final $1?) 'maxResults': '${$1}',
'orderBy': ?request.orderBy,
'pageToken': ?request.pageToken,
if (request.returnPartialSuccess case final $1?)
'returnPartialSuccess': '${$1}',
},
);
final response = await _client.get(url);
return LicensesListResponse.fromJson(response);
}