ListPeeringRoutesNetworksRequest_Direction class final
The direction of the exchanged routes.
Constructors
- ListPeeringRoutesNetworksRequest_Direction(String value)
-
const
- ListPeeringRoutesNetworksRequest_Direction.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const ListPeeringRoutesNetworksRequest_Direction
- The default value for ListPeeringRoutesNetworksRequest_Direction.
- incoming → const ListPeeringRoutesNetworksRequest_Direction
- For routes exported from peer network.
- outgoing → const ListPeeringRoutesNetworksRequest_Direction
- For routes exported from local network.
- undefinedDirection → const ListPeeringRoutesNetworksRequest_Direction
- A value indicating that the enum field is not set.