menu
google_cloud_compute_v1 package
documentation
compute.dart
LocalDisk class
LocalDisk class
dark_mode
light_mode
LocalDisk
class
final
Constructors
LocalDisk
({
int
?
diskCount
,
int
?
diskSizeGb
,
String
?
diskType
})
LocalDisk.fromJson
(
Object
?
j
)
factory
Properties
diskCount
→
int
?
Specifies the number of such disks.
final
diskSizeGb
→
int
?
Specifies the size of the disk in base-2 GB.
final
diskType
→
String
?
Specifies the desired disk type on the node. This disk type must be a local storage type (e.g.: local-ssd). Note that for nodeTemplates, this should be the name of the disk type and not its URL.
final
hashCode
→
int
The hash code for this object.
no setter
inherited
qualifiedName
→
String
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or
google.rpc.ErrorInfo
.
final
inherited
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson
(
)
→
Object
toString
(
)
→
String
A string representation of this object.
override
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
Constants
fullyQualifiedName
→ const
String
google_cloud_compute_v1 package
documentation
compute
LocalDisk class
compute library