anySingleZone constant
LocationPolicy_TargetShape
const anySingleZone
GCE always selects a single zone for all the VMs, optimizing for resource quotas, available reservations and general capacity. Recommended for batch workloads that cannot tollerate distribution over multiple zones. This the default shape in Bulk Insert and Capacity Advisor APIs.
Implementation
static const anySingleZone = LocationPolicy_TargetShape('ANY_SINGLE_ZONE');