MachineImages class final
The MachineImages API.
- Implementers
Constructors
- MachineImages({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
MachineImagesusingclientfor transport. - MachineImages.fromApiKey([String? apiKey])
-
Creates a
MachineImagesthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteMachineImageRequest request) → Future< Operation> - Deletes the specified machine image. Deleting a machine image is permanent and cannot be undone.
-
get(
GetMachineImageRequest request) → Future< MachineImage> - Returns the specified machine image.
-
getIamPolicy(
GetIamPolicyMachineImageRequest request) → Future< Policy> - Gets the access control policy for a resource. May be empty if no such policy or resource exists.
-
insert(
InsertMachineImageRequest request) → Future< Operation> - Creates a machine image in the specified project using the data that is included in the request. If you are creating a new machine image to update an existing instance, your new machine image should use the same network or, if applicable, the same subnetwork as the original instance.
-
list(
ListMachineImagesRequest request) → Future< MachineImageList> - Retrieves a list of machine images that are contained within the specified project.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setIamPolicy(
SetIamPolicyMachineImageRequest request) → Future< Policy> - Sets the access control policy on the specified resource. Replaces any existing policy.
-
setLabels(
SetLabelsMachineImageRequest request) → Future< Operation> - Sets the labels on a machine image. To learn more about labels, read theLabeling Resources documentation.
-
testIamPermissions(
TestIamPermissionsMachineImageRequest request) → Future< TestPermissionsResponse> - Returns permissions that a caller has on the specified resource.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited