MachineType class final

Represents a Machine Type resource.

You can use specific machine types for your VM instances based on performance and pricing requirements. For more information, readMachine Types.

Constructors

MachineType({List<Accelerators> accelerators = const [], String? architecture, BundledLocalSsds? bundledLocalSsds, String? creationTimestamp, DeprecationStatus? deprecated, String? description, int? guestCpus, BigInt? id, int? imageSpaceGb, bool? isSharedCpu, String? kind, int? maximumPersistentDisks, int? maximumPersistentDisksSizeGb, int? memoryMb, String? name, String? selfLink, String? zone})
MachineType.fromJson(Object? j)
factory

Properties

accelerators List<Accelerators>
Output Only A list of accelerator configurations assigned to this machine type.
final
architecture String?
Output Only The architecture of the machine type. Check the Architecture enum for the list of possible values.
final
bundledLocalSsds BundledLocalSsds?
Output Only The configuration of bundled local SSD for the machine type.
final
creationTimestamp String?
Output Only Creation timestamp inRFC3339 text format.
final
deprecated DeprecationStatus?
Output Only The deprecation status associated with this machine type. Only applicable if the machine type is unavailable.
final
description String?
Output Only An optional textual description of the resource.
final
guestCpus int?
Output Only The number of virtual CPUs that are available to the instance.
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output Only The unique identifier for the resource. This identifier is defined by the server.
final
imageSpaceGb int?
Deprecated This property is deprecated and will never be populated with any relevant values.
final
isSharedCpu bool?
Output Only Whether this machine type has a shared CPU. SeeShared-core machine types for more information.
final
kind String?
Output only. Output Only The type of the resource. Alwayscompute#machineType for machine types.
final
maximumPersistentDisks int?
Output Only Maximum persistent disks allowed.
final
maximumPersistentDisksSizeGb int?
Output Only Maximum total persistent disks size (GB) allowed.
final
memoryMb int?
Output Only The amount of physical memory available to the instance, defined in MB.
final
name String?
Output Only Name of the resource.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output Only Server-defined URL for the resource.
final
zone String?
Output Only The name of the zone where the machine type resides, such as us-central1-a.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String