MachineTypes class final
The MachineTypes API.
- Implementers
Constructors
- MachineTypes({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
MachineTypesusingclientfor transport. - MachineTypes.fromApiKey([String? apiKey])
-
Creates a
MachineTypesthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
aggregatedList(
AggregatedListMachineTypesRequest request) → Future< MachineTypeAggregatedList> - Retrieves an aggregated list of machine types.
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
get(
GetMachineTypeRequest request) → Future< MachineType> - Returns the specified machine type.
-
list(
ListMachineTypesRequest request) → Future< MachineTypeList> - Retrieves a list of machine types available to the specified project.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited