ManagedInstance class final

A Managed Instance resource.

Constructors

ManagedInstance({String? currentAction, BigInt? id, String? instance, List<ManagedInstanceInstanceHealth> instanceHealth = const [], String? instanceStatus, ManagedInstanceLastAttempt? lastAttempt, String? name, PreservedState? preservedStateFromConfig, PreservedState? preservedStateFromPolicy, ManagedInstancePropertiesFromFlexibilityPolicy? propertiesFromFlexibilityPolicy, ManagedInstanceScheduling? scheduling, ManagedInstanceShutdownDetails? shutdownDetails, ManagedInstanceVersion? version})
ManagedInstance.fromJson(Object? j)
factory

Properties

currentAction String?
Output only. Output Only The current action that the managed instance group has scheduled for the instance. Possible values:
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output only. Output only The unique identifier for this resource. This field is empty when instance does not exist.
final
instance String?
Output only. Output Only The URL of the instance. The URL can exist even if the instance has not yet been created.
final
instanceHealth List<ManagedInstanceInstanceHealth>
Output only. Output Only Health state of the instance per health-check.
final
instanceStatus String?
Output only. Output Only The status of the instance. This field is empty when the instance does not exist. Check the InstanceStatus enum for the list of possible values.
final
lastAttempt ManagedInstanceLastAttempt?
Output only. Output Only Information about the last attempt to create or delete the instance.
final
name String?
Output only. Output Only The name of the instance. The name always exists even if the instance has not yet been created.
final
preservedStateFromConfig PreservedState?
Output only. Output Only Preserved state applied from per-instance config for this instance.
final
preservedStateFromPolicy PreservedState?
Output only. Output Only Preserved state generated based on stateful policy for this instance.
final
propertiesFromFlexibilityPolicy ManagedInstancePropertiesFromFlexibilityPolicy?
Output only. Output Only Instance properties selected for this instance resulting from InstanceFlexibilityPolicy.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheduling ManagedInstanceScheduling?
Output only. Information about the termination timestamp of the instance, if applicable.
final
shutdownDetails ManagedInstanceShutdownDetails?
Output only. Specifies the graceful shutdown details if the instance is in PENDING_STOP state or there is a programmed stop scheduled.
final
version ManagedInstanceVersion?
Output only. Output Only Intended version of this instance.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String