shutdownDetails property

ManagedInstanceShutdownDetails? shutdownDetails
final

Output only. Specifies the graceful shutdown details if the instance is in PENDING_STOP state or there is a programmed stop scheduled.

Implementation

final ManagedInstanceShutdownDetails? shutdownDetails;