ManagedInstanceInstanceHealth_DetailedHealthState class final
Output only. Output Only The current detailed instance health state.
Constructors
- ManagedInstanceInstanceHealth_DetailedHealthState(String value)
-
const
- ManagedInstanceInstanceHealth_DetailedHealthState.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const ManagedInstanceInstanceHealth_DetailedHealthState
- The default value for ManagedInstanceInstanceHealth_DetailedHealthState.
- draining → const ManagedInstanceInstanceHealth_DetailedHealthState
- The instance is being drained. The existing connections to the instance have time to complete, but the new ones are being refused.
- healthy → const ManagedInstanceInstanceHealth_DetailedHealthState
- The instance is reachable i.e. a connection to the application health checking endpoint can be established, and conforms to the requirements defined by the health check.
- timeout → const ManagedInstanceInstanceHealth_DetailedHealthState
- The instance is unreachable i.e. a connection to the application health checking endpoint cannot be established, or the server does not respond within the specified timeout.
- undefinedDetailedHealthState → const ManagedInstanceInstanceHealth_DetailedHealthState
- A value indicating that the enum field is not set.
- unhealthy → const ManagedInstanceInstanceHealth_DetailedHealthState
- The instance is reachable, but does not conform to the requirements defined by the health check.
- unknown → const ManagedInstanceInstanceHealth_DetailedHealthState
- The health checking system is aware of the instance but its health is not known at the moment.