draining constant
ManagedInstanceInstanceHealth_DetailedHealthState
const draining
The instance is being drained. The existing connections to the instance have time to complete, but the new ones are being refused.
Implementation
static const draining = ManagedInstanceInstanceHealth_DetailedHealthState(
'DRAINING',
);