unknown constant
ManagedInstanceInstanceHealth_DetailedHealthState
const unknown
The health checking system is aware of the instance but its health is not known at the moment.
Implementation
static const unknown = ManagedInstanceInstanceHealth_DetailedHealthState(
'UNKNOWN',
);