ManagedInstanceScheduling class
final
Properties
gracefulShutdownTimestamp
→ String ?
Output only. The timestamp at which the underlying instance will be
triggered for graceful shutdown if it is configured. This is in RFC3339 text format.
final
hashCode
→ int
The hash code for this object.
no setter inherited
qualifiedName
→ String
The fully qualified name of this message, i.e., google.protobuf.Duration
or google.rpc.ErrorInfo.
final inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
terminationTimestamp
→ String ?
Output only. The timestamp at which the managed instance will be terminated. This is
in RFC3339 text
format.
final
google_cloud_compute_v1 0.1.1