abandoning constant
ManagedInstance_CurrentAction
const abandoning
The managed instance group is abandoning this instance. The instance will be removed from the instance group and from any target pools that are associated with this group.
Implementation
static const abandoning = ManagedInstance_CurrentAction('ABANDONING');