ManagedInstance_InstanceStatus class final

Output only. Output Only The status of the instance. This field is empty when the instance does not exist. Additional supported values which may be not listed in the enum directly due to technical reasons: STOPPING SUSPENDING

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const ManagedInstance_InstanceStatus
The default value for ManagedInstance_InstanceStatus.
deprovisioning → const ManagedInstance_InstanceStatus
The instance is halted and we are performing tear down tasks like network deprogramming, releasing quota, IP, tearing down disks etc.
pending → const ManagedInstance_InstanceStatus
For Flex Start provisioning instance is waiting for available capacity from Dynamic Workload Scheduler (DWS).
pendingStop → const ManagedInstance_InstanceStatus
The instance is gracefully shutting down.
provisioning → const ManagedInstance_InstanceStatus
Resources are being allocated for the instance.
repairing → const ManagedInstance_InstanceStatus
The instance is in repair.
running → const ManagedInstance_InstanceStatus
The instance is running.
staging → const ManagedInstance_InstanceStatus
All required resources have been allocated and the instance is being started.
stopped → const ManagedInstance_InstanceStatus
The instance has stopped successfully.
stopping → const ManagedInstance_InstanceStatus
suspended → const ManagedInstance_InstanceStatus
The instance has suspended.
suspending → const ManagedInstance_InstanceStatus
terminated → const ManagedInstance_InstanceStatus
The instance has stopped (either by explicit action or underlying failure).
undefinedInstanceStatus → const ManagedInstance_InstanceStatus
A value indicating that the enum field is not set.