ManagedInstance_TargetStatus class final
Output only. The eventual status of the instance. The instance group manager will not be identified as stable till each managed instance reaches its targetStatus. Additional supported values which may be not listed in the enum directly due to technical reasons: RUNNING STOPPED SUSPENDED
Constructors
- ManagedInstance_TargetStatus(String value)
-
const
- ManagedInstance_TargetStatus.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const ManagedInstance_TargetStatus
- The default value for ManagedInstance_TargetStatus.
- abandoned → const ManagedInstance_TargetStatus
- The managed instance will eventually be ABANDONED, i.e. dissociated from the managed instance group.
- deleted → const ManagedInstance_TargetStatus
- The managed instance will eventually be DELETED.
- invalid → const ManagedInstance_TargetStatus
- Only present to map the STATUS_INVALID value.
- undefinedTargetStatus → const ManagedInstance_TargetStatus
- A value indicating that the enum field is not set.