Metadata class final

A metadata key/value entry.

Constructors

Metadata({String? fingerprint, List<Items> items = const [], String? kind})
Metadata.fromJson(Object? j)
factory

Properties

fingerprint String?
Specifies a fingerprint for this request, which is essentially a hash of the metadata's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update metadata. You must always provide an up-to-date fingerprint hash in order to update or change metadata, otherwise the request will fail with error412 conditionNotMet.
final
hashCode int
The hash code for this object.
no setterinherited
items List<Items>
Array of key/value pairs. The total size of all keys and values must be less than 512 KB.
final
kind String?
Output only. Output Only Type of the resource. Always compute#metadata for metadata.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String