NamedSet class final

Constructors

NamedSet({String? description, List<Expr> elements = const [], String? fingerprint, String? name, String? type})
NamedSet.fromJson(Object? j)
factory

Properties

description String?
An optional description of named set.
final
elements List<Expr>
CEL expressions that are comparable to constructs of this set's type (see Policy Language).
final
fingerprint String?
A fingerprint for the Named Set being applied to this Router, which is essentially a hash of the Named Set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update the Named Set. You must always provide an up-to-date fingerprint hash in order to update or change labels.
final
hashCode int
The hash code for this object.
no setterinherited
name String?
This set's name, which must be a resource ID segment and unique within all named sets owned by the Router. Name should conform to RFC1035.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
This named set's type Check the Type enum for the list of possible values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String