NatIpInfo class final
Contains NAT IP information of a NAT config (i.e. usage status, mode).
Constructors
-
NatIpInfo({List<
NatIpInfoNatIpInfoMapping> natIpInfoMappings = const [], String? natName}) - NatIpInfo.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
natIpInfoMappings
→ List<
NatIpInfoNatIpInfoMapping> -
Output only. A list of all NAT IPs assigned to this NAT config.
final
- natName → String?
-
Output only. Name of the NAT config which the NAT IP belongs to.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String