NetworkAttachmentConnectedEndpoint class final
Output Only A connection connected to this network attachment.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ipAddress → String?
-
The IPv4 address assigned to the producer instance network interface.
This value will be a range in case of Serverless.
final
- ipv6Address → String?
-
The IPv6 address assigned to the producer instance network interface.
This is only assigned when the stack types of both the instance network
interface and the consumer subnet are IPv4_IPv6.
final
- projectIdOrNum → String?
-
The project id or number of the interface to which the IP was assigned.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
secondaryIpCidrRanges
→ List<
String> -
Alias IP ranges from the same subnetwork.
final
- serviceClassId → String?
-
The service class id of the producer service to which the IP was
assigned.
final
- status → String?
-
The status of a connected endpoint to this network attachment.
Check the Status enum for the list of possible values.
final
- subnetwork → String?
-
The subnetwork used to assign the IP to the producer
instance network interface.
final
- subnetworkCidrRange → String?
-
Output only.
Output OnlyThe CIDR range of the subnet from which the IPv4 internal IP was allocated from.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String