NetworkAttachments class final
The NetworkAttachments API.
- Implementers
Constructors
- NetworkAttachments({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
NetworkAttachmentsusingclientfor transport. - NetworkAttachments.fromApiKey([String? apiKey])
-
Creates a
NetworkAttachmentsthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
aggregatedList(
AggregatedListNetworkAttachmentsRequest request) → Future< NetworkAttachmentAggregatedList> - Retrieves the list of all NetworkAttachment resources, regional and global, available to the specified project.
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteNetworkAttachmentRequest request) → Future< Operation> - Deletes the specified NetworkAttachment in the given scope
-
get(
GetNetworkAttachmentRequest request) → Future< NetworkAttachment> - Returns the specified NetworkAttachment resource in the given scope.
-
getIamPolicy(
GetIamPolicyNetworkAttachmentRequest request) → Future< Policy> - Gets the access control policy for a resource. May be empty if no such policy or resource exists.
-
insert(
InsertNetworkAttachmentRequest request) → Future< Operation> - Creates a NetworkAttachment in the specified project in the given scope using the parameters that are included in the request.
-
list(
ListNetworkAttachmentsRequest request) → Future< NetworkAttachmentList> - Lists the NetworkAttachments for a project in the given scope.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchNetworkAttachmentRequest request) → Future< Operation> - Patches the specified NetworkAttachment resource with the data included in the request. This method supports PATCH semantics and usesJSON merge patch format and processing rules.
-
setIamPolicy(
SetIamPolicyNetworkAttachmentRequest request) → Future< Policy> - Sets the access control policy on the specified resource. Replaces any existing policy.
-
testIamPermissions(
TestIamPermissionsNetworkAttachmentRequest request) → Future< TestPermissionsResponse> - Returns permissions that a caller has on the specified resource.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited