NetworkEdgeSecurityServices class final

The NetworkEdgeSecurityServices API.

Implementers

Constructors

NetworkEdgeSecurityServices({required Client client, Uri? endPoint, String? gcclVersion})
Creates a NetworkEdgeSecurityServices using client for transport.
NetworkEdgeSecurityServices.fromApiKey([String? apiKey])
Creates a NetworkEdgeSecurityServices that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(AggregatedListNetworkEdgeSecurityServicesRequest request) Future<NetworkEdgeSecurityServiceAggregatedList>
Retrieves the list of all NetworkEdgeSecurityService resources available to the specified project.
close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteNetworkEdgeSecurityServiceRequest request) Future<Operation>
Deletes the specified service.
get(GetNetworkEdgeSecurityServiceRequest request) Future<NetworkEdgeSecurityService>
Gets a specified NetworkEdgeSecurityService.
insert(InsertNetworkEdgeSecurityServiceRequest request) Future<Operation>
Creates a new service in the specified project using the data included in the request.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(PatchNetworkEdgeSecurityServiceRequest request) Future<Operation>
Patches the specified policy with the data included in the request.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited