NetworkEndpointGroupAppEngine class final

Configuration for an App Engine network endpoint group (NEG). The service is optional, may be provided explicitly or in the URL mask. The version is optional and can only be provided explicitly or in the URL mask when service is present.

Note: App Engine service must be in the same project and located in the same region as the Serverless NEG.

Constructors

NetworkEndpointGroupAppEngine({String? service, String? urlMask, String? version})
NetworkEndpointGroupAppEngine.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
service String?
Optional serving service.
final
urlMask String?
An URL mask is one of the main components of the Cloud Function.
final
version String?
Optional serving version.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String