NetworkEndpointGroupCloudFunction class final
Configuration for a Cloud Function network endpoint group (NEG). The function must be provided explicitly or in the URL mask.
Note: Cloud Function must be in the same project and located in the same region as the Serverless NEG.
Constructors
- NetworkEndpointGroupCloudFunction({String? function, String? urlMask})
- NetworkEndpointGroupCloudFunction.fromJson(Object? j)
-
factory
Properties
- function → String?
-
A user-defined name of the Cloud Function.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- urlMask → String?
-
An URL
mask is one of the main components of the Cloud Function.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String