urlMask property

String? urlMask
final

An URL mask is one of the main components of the Cloud Function.

A template to parse function field from a request URL. URL mask allows for routing to multiple Cloud Functions without having to create multiple Network Endpoint Groups and backend services.

For example, request URLs mydomain.com/function1 andmydomain.com/function2 can be backed by the same Serverless NEG with URL mask /

Implementation

final String? urlMask;