urlMask property
An URL mask is one of the main components of the Cloud Function.
A template to parse
For example, request URLs foo1.domain.com/bar1 andfoo1.domain.com/bar2 can be backed by the same Serverless Network Endpoint Group (NEG) with URL mask
Implementation
final String? urlMask;