NetworkEndpointGroupPscData class final
All data that is specifically relevant to only network endpoint groups of type PRIVATE_SERVICE_CONNECT.
Constructors
- NetworkEndpointGroupPscData({String? consumerPscAddress, int? producerPort, BigInt? pscConnectionId, String? pscConnectionStatus})
- NetworkEndpointGroupPscData.fromJson(Object? j)
-
factory
Properties
- consumerPscAddress → String?
-
Output only.
Output OnlyAddress allocated from given subnetwork for PSC. This IP address acts as a VIP for a PSC NEG, allowing it to act as an endpoint in L7 PSC-XLB.final - hashCode → int
-
The hash code for this object.
no setterinherited
- producerPort → int?
-
The psc producer port is used to connect PSC NEG with specific port on
the PSC Producer side; should only be used for the
PRIVATE_SERVICE_CONNECT NEG type
final
- pscConnectionId → BigInt?
-
Output only.
Output OnlyThe PSC connection id of the PSC Network Endpoint Group Consumer.final - pscConnectionStatus → String?
-
Output only.
Output OnlyThe connection status of the PSC Forwarding Rule. Check the PscConnectionStatus enum for the list of possible values.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String