aggregatedList method
Retrieves an aggregated list of network firewall policies, listing network firewall policies from all applicable scopes (global and regional) and grouping the results per scope.
To prevent failure, it is recommended that you set the
returnPartialSuccess parameter to true.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
Future<NetworkFirewallPolicyAggregatedList> aggregatedList(
AggregatedListNetworkFirewallPoliciesRequest request,
) async {
final url = _endPoint.replace(
path:
'/compute/v1/projects/${request.project}/aggregated/firewallPolicies',
queryParameters: {
'filter': ?request.filter,
if (request.includeAllScopes case final $1?)
'includeAllScopes': '${$1}',
if (request.maxResults case final $1?) 'maxResults': '${$1}',
'orderBy': ?request.orderBy,
'pageToken': ?request.pageToken,
if (request.returnPartialSuccess case final $1?)
'returnPartialSuccess': '${$1}',
if (request.serviceProjectNumber case final $1?)
'serviceProjectNumber': '${$1}',
},
);
final response = await _client.get(url);
return NetworkFirewallPolicyAggregatedList.fromJson(response);
}