NetworkPeering class final
A network peering attached to a network resource. The message includes the peering name, peer network, peering state, and a flag indicating whether Google Compute Engine should automatically create routes for the peering.
Constructors
- NetworkPeering({bool? autoCreateRoutes, NetworkPeeringConnectionStatus? connectionStatus, bool? exchangeSubnetRoutes, bool? exportCustomRoutes, bool? exportSubnetRoutesWithPublicIp, bool? importCustomRoutes, bool? importSubnetRoutesWithPublicIp, String? name, String? network, int? peerMtu, String? stackType, String? state, String? stateDetails, String? updateStrategy})
- NetworkPeering.fromJson(Object? j)
-
factory
Properties
- autoCreateRoutes → bool?
-
This field will be deprecated soon. Use theexchange_subnet_routes field instead.
Indicates whether full mesh connectivity is created and managed
automatically between peered networks. Currently this field should always
be true since Google Compute Engine will automatically create and manage
subnetwork routes between two networks when peering state isACTIVE.
final
- connectionStatus → NetworkPeeringConnectionStatus?
-
Output only.
Output OnlyThe effective state of the peering connection as a whole.final - exchangeSubnetRoutes → bool?
-
Indicates whether full mesh connectivity is created and managed
automatically between peered networks. Currently this field should always
be true since Google Compute Engine will automatically create and manage
subnetwork routes between two networks when peering state isACTIVE.
final
- exportCustomRoutes → bool?
-
Whether to export the custom routes to peer network. The default value is
false.
final
- exportSubnetRoutesWithPublicIp → bool?
-
Whether subnet routes with public IP range are exported. The default value
is true, all subnet routes are exported.IPv4
special-use ranges are always
exported to peers and are not controlled by this field.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- importCustomRoutes → bool?
-
Whether to import the custom routes from peer network. The default value is
false.
final
- importSubnetRoutesWithPublicIp → bool?
-
Whether subnet routes with public IP range are imported. The default value
is false.IPv4
special-use ranges are always
imported from peers and are not controlled by this field.
final
- name → String?
-
Name of this peering. Provided by the client when the peering is created.
The name must comply withRFC1035.
Specifically, the name must be 1-63 characters long and match regular
expression
[a-z]([-a-z0-9]*[a-z0-9])?. The first character must be a lowercase letter, and all the following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.final - network → String?
-
The URL of the peer network. It can be either full URL or partial URL. The
peer network may belong to a different project. If the partial URL does not
contain project, it is assumed that the peer network is in the same project
as the current network.
final
- peerMtu → int?
-
Output only.
Output OnlyMaximum Transmission Unit in bytes of the peer network.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackType → String?
-
Which IP version(s) of traffic and routes are allowed to be imported or
exported between peer networks. The default value is IPV4_ONLY.
Check the StackType enum for the list of possible values.
final
- state → String?
-
Output only.
Output OnlyState for the peering. Check the State enum for the list of possible values.final - stateDetails → String?
-
Output only.
Output OnlyDetails about the current state of the peering.final - updateStrategy → String?
-
The update strategy determines the semantics for updates and deletes to the
peering connection configuration.
Check the UpdateStrategy enum for the list of possible values.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String