exportSubnetRoutesWithPublicIp property
Whether subnet routes with public IP range are exported. The default value is true, all subnet routes are exported.IPv4 special-use ranges are always exported to peers and are not controlled by this field.
Implementation
final bool? exportSubnetRoutesWithPublicIp;