NetworkPeeringConnectionStatus class final

Output Only Describes the state of a peering connection, not just the local peering. This field provides information about the effective settings for the connection as a whole, including pending delete/update requests for CONSENSUS peerings.

Properties

consensusState NetworkPeeringConnectionStatusConsensusState?
The consensus state contains information about the status of update and delete for a consensus peering connection.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trafficConfiguration NetworkPeeringConnectionStatusTrafficConfiguration?
The active connectivity settings for the peering connection based on the settings of the network peerings.
final
updateStrategy String?
The update strategy determines the update/delete semantics for this peering connection. Check the UpdateStrategy enum for the list of possible values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String