NetworkPeeringConnectionStatusConsensusState_DeleteStatus class final
The status of the delete request.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const NetworkPeeringConnectionStatusConsensusState_DeleteStatus
- The default value for NetworkPeeringConnectionStatusConsensusState_DeleteStatus.
- deleteAcknowledged → const NetworkPeeringConnectionStatusConsensusState_DeleteStatus
- Both network admins have agreed this consensus peering connection can be deleted.
- deleteStatusUnspecified → const NetworkPeeringConnectionStatusConsensusState_DeleteStatus
- localCancelRequested → const NetworkPeeringConnectionStatusConsensusState_DeleteStatus
- The local network admin requested to cancel their delete request after DELETE_ACKNOWLEDGED.
- localDeleteRequested → const NetworkPeeringConnectionStatusConsensusState_DeleteStatus
- Network admin has requested deletion of this peering connection.
- peerCancelRequested → const NetworkPeeringConnectionStatusConsensusState_DeleteStatus
- The peer network admin requested to cancel their delete request after DELETE_ACKNOWLEDGED.
- peerDeleteRequested → const NetworkPeeringConnectionStatusConsensusState_DeleteStatus
- The peer network admin has requested deletion of this peering connection.
- undefinedDeleteStatus → const NetworkPeeringConnectionStatusConsensusState_DeleteStatus
- A value indicating that the enum field is not set.