NetworkPeeringConnectionStatusTrafficConfiguration class final
Constructors
- NetworkPeeringConnectionStatusTrafficConfiguration({bool? exportCustomRoutesToPeer, bool? exportSubnetRoutesWithPublicIpToPeer, bool? importCustomRoutesFromPeer, bool? importSubnetRoutesWithPublicIpFromPeer, String? stackType})
- NetworkPeeringConnectionStatusTrafficConfiguration.fromJson(Object? j)
-
factory
Properties
- exportCustomRoutesToPeer → bool?
-
Whether custom routes are being exported to the peer network.
final
- exportSubnetRoutesWithPublicIpToPeer → bool?
-
Whether subnet routes with public IP ranges are being exported to the
peer network.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- importCustomRoutesFromPeer → bool?
-
Whether custom routes are being imported from the peer network.
final
- importSubnetRoutesWithPublicIpFromPeer → bool?
-
Whether subnet routes with public IP ranges are being imported
from the peer network.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackType → String?
-
Which IP version(s) of traffic and routes are being imported or
exported between peer networks.
Check the StackType enum for the list of possible values.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String