NetworkPeering_UpdateStrategy class final
The update strategy determines the semantics for updates and deletes to the peering connection configuration.
Constructors
- NetworkPeering_UpdateStrategy(String value)
-
const
- NetworkPeering_UpdateStrategy.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const NetworkPeering_UpdateStrategy
- The default value for NetworkPeering_UpdateStrategy.
- consensus → const NetworkPeering_UpdateStrategy
- Updates are reflected in the local peering but aren't applied to the peering connection until a complementary change is made to the matching peering. To delete a peering with the consensus update strategy, both the peerings must request the deletion of the peering before the peering can be deleted.
- independent → const NetworkPeering_UpdateStrategy
- In this mode, changes to the peering configuration can be unilaterally altered by changing either side of the peering. This is the default value if the field is unspecified.
- undefinedUpdateStrategy → const NetworkPeering_UpdateStrategy
- A value indicating that the enum field is not set.
- unspecified → const NetworkPeering_UpdateStrategy
- Peerings with update strategy UNSPECIFIED are created with update strategy INDEPENDENT.