NetworkProfileNetworkFeatures class
final
Constructors
NetworkProfileNetworkFeatures ({List <String > addressPurposes = const [] , String ? allowAddressCreation , String ? allowAliasIpRanges , String ? allowAutoModeSubnet , String ? allowClassDFirewalls , String ? allowCloudNat , String ? allowCloudRouter , String ? allowDefaultNicAttachment , String ? allowExternalIpAccess , String ? allowFirewallPolicy , String ? allowInterconnect , String ? allowIpForwarding , String ? allowLoadBalancing , String ? allowMultiNicInSameNetwork , String ? allowMultiNicInSameSubnetwork , String ? allowMulticast , String ? allowNcc , String ? allowNetworkMigration , String ? allowPacketMirroring , String ? allowPrivateGoogleAccess , String ? allowPsc , String ? allowSameNetworkUnicast , String ? allowStaticRoutes , String ? allowSubInterfaces , String ? allowSubnetworkCreation , String ? allowVpcFirewallRules , String ? allowVpcPeering , String ? allowVpn , List <String > firewallPolicyTypes = const [] , List <String > interfaceTypes = const [] , String ? multicast , String ? predefinedNetworkInternalIpv6Range , List <NetworkProfileNetworkFeaturesPredefinedSubnetworkRange > predefinedSubnetworkRanges = const [] , List <String > subnetPurposes = const [] , List <String > subnetStackTypes = const [] , List <String > subnetworkPurposes = const [] , List <String > subnetworkStackTypes = const [] , String ? unicast })
NetworkProfileNetworkFeatures.fromJson (Object ? j )
factory
Properties
addressPurposes
→ List <String >
Specifies what address purposes are supported. If empty, all address
purposes are supported.
Check the AddressPurposes enum for the list of possible values.
final
allowAddressCreation
→ String ?
Specifies whether address creation is allowed.
Check the AllowAddressCreation enum for the list of possible values.
final
allowAliasIpRanges
→ String ?
Specifies whether alias IP ranges (and secondary address ranges) are
allowed.
Check the AllowAliasIpRanges enum for the list of possible values.
final
allowAutoModeSubnet
→ String ?
Specifies whether auto mode subnet creation is allowed.
Check the AllowAutoModeSubnet enum for the list of possible values.
final
allowClassDFirewalls
→ String ?
Specifies whether firewalls for Class D address ranges are supported.
Check the AllowClassDFirewalls enum for the list of possible values.
final
allowCloudNat
→ String ?
Specifies whether cloud NAT creation is allowed.
Check the AllowCloudNat enum for the list of possible values.
final
allowCloudRouter
→ String ?
Specifies whether cloud router creation is allowed.
Check the AllowCloudRouter enum for the list of possible values.
final
allowDefaultNicAttachment
→ String ?
Specifies whether default NIC attachment is allowed.
Check the AllowDefaultNicAttachment enum for the list of possible values.
final
allowExternalIpAccess
→ String ?
Specifies whether VMs are allowed to have external IP access on network
interfaces connected to this VPC.
Check the AllowExternalIpAccess enum for the list of possible values.
final
allowFirewallPolicy
→ String ?
Specifies whether firewall policy can be attached to the network.
Check the AllowFirewallPolicy enum for the list of possible values.
final
allowInterconnect
→ String ?
Specifies whether Cloud Interconnect creation is allowed.
Check the AllowInterconnect enum for the list of possible values.
final
allowIpForwarding
→ String ?
Specifies whether IP forwarding is allowed.
Check the AllowIpForwarding enum for the list of possible values.
final
allowLoadBalancing
→ String ?
Specifies whether cloud load balancing is allowed.
Check the AllowLoadBalancing enum for the list of possible values.
final
allowMulticast
→ String ?
Specifies whether multicast is allowed.
Check the AllowMulticast enum for the list of possible values.
final
allowMultiNicInSameNetwork
→ String ?
Specifies whether multi-nic in the same network is allowed.
Check the AllowMultiNicInSameNetwork enum for the list of possible values.
final
allowMultiNicInSameSubnetwork
→ String ?
Specifies whether multi-nic in the same subnetwork is allowed.
Check the AllowMultiNicInSameSubnetwork enum for the list of possible values.
final
allowNcc
→ String ?
Specifies whether NCC is allowed.
Check the AllowNcc enum for the list of possible values.
final
allowNetworkMigration
→ String ?
Specifies whether VM network migration is allowed.
Check the AllowNetworkMigration enum for the list of possible values.
final
allowPacketMirroring
→ String ?
Specifies whether Packet Mirroring 1.0 is supported.
Check the AllowPacketMirroring enum for the list of possible values.
final
allowPrivateGoogleAccess
→ String ?
Specifies whether private Google access is allowed.
Check the AllowPrivateGoogleAccess enum for the list of possible values.
final
allowPsc
→ String ?
Specifies whether PSC creation is allowed.
Check the AllowPsc enum for the list of possible values.
final
allowSameNetworkUnicast
→ String ?
Specifies whether unicast within the same network is allowed.
Check the AllowSameNetworkUnicast enum for the list of possible values.
final
allowStaticRoutes
→ String ?
Specifies whether static route creation is allowed.
Check the AllowStaticRoutes enum for the list of possible values.
final
allowSubInterfaces
→ String ?
Specifies whether sub interfaces are allowed.
Check the AllowSubInterfaces enum for the list of possible values.
final
allowSubnetworkCreation
→ String ?
Specifies whether subnetwork creation is allowed.
Check the AllowSubnetworkCreation enum for the list of possible values.
final
allowVpcFirewallRules
→ String ?
Specifies whether VPC firewall rules can be created under the network.
Check the AllowVpcFirewallRules enum for the list of possible values.
final
allowVpcPeering
→ String ?
Specifies whether VPC peering is allowed.
Check the AllowVpcPeering enum for the list of possible values.
final
allowVpn
→ String ?
Specifies whether VPN creation is allowed.
Check the AllowVpn enum for the list of possible values.
final
firewallPolicyTypes
→ List <String >
Check the FirewallPolicyTypes enum for the list of possible values.
final
hashCode
→ int
The hash code for this object.
no setter inherited
interfaceTypes
→ List <String >
If set, limits the interface types that the network supports. If
empty, all interface types are supported.
Check the InterfaceTypes enum for the list of possible values.
final
multicast
→ String ?
Specifies which type of multicast is supported.
Check the Multicast enum for the list of possible values.
final
predefinedNetworkInternalIpv6Range
→ String ?
Specifies a predefined internal IPv6 range for the network.
final
predefinedSubnetworkRanges
→ List <NetworkProfileNetworkFeaturesPredefinedSubnetworkRange >
Predefined subnetwork ranges for the network.
final
qualifiedName
→ String
The fully qualified name of this message, i.e., google.protobuf.Duration
or google.rpc.ErrorInfo.
final inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
subnetPurposes
→ List <String >
Specifies which subnetwork purposes are supported.
Check the SubnetPurposes enum for the list of possible values.
final
subnetStackTypes
→ List <String >
Specifies which subnetwork stack types are supported.
Check the SubnetStackTypes enum for the list of possible values.
final
subnetworkPurposes
→ List <String >
Output only. Specifies which subnetwork purposes are supported.
Check the SubnetworkPurposes enum for the list of possible values.
final
subnetworkStackTypes
→ List <String >
Output only. Specifies which subnetwork stack types are supported.
Check the SubnetworkStackTypes enum for the list of possible values.
final
unicast
→ String ?
Specifies which type of unicast is supported.
Check the Unicast enum for the list of possible values.
final
google_cloud_compute_v1 0.1.0