NetworkProfileNetworkFeatures_AddressPurposes class final
Constructors
- NetworkProfileNetworkFeatures_AddressPurposes(String value)
-
const
- NetworkProfileNetworkFeatures_AddressPurposes.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const NetworkProfileNetworkFeatures_AddressPurposes
- The default value for NetworkProfileNetworkFeatures_AddressPurposes.
- dnsResolver → const NetworkProfileNetworkFeatures_AddressPurposes
- DNS resolver address in the subnetwork.
- gceEndpoint → const NetworkProfileNetworkFeatures_AddressPurposes
- VM internal/alias IP, Internal LB service IP, etc.
- ipsecInterconnect → const NetworkProfileNetworkFeatures_AddressPurposes
- A regional internal IP address range reserved for the VLAN attachment that is used in HA VPN over Cloud Interconnect. This regional internal IP address range must not overlap with any IP address range of subnet/route in the VPC network and its peering networks. After the VLAN attachment is created with the reserved IP address range, when creating a new VPN gateway, its interface IP address is allocated from the associated VLAN attachment's IP address range.
- natAuto → const NetworkProfileNetworkFeatures_AddressPurposes
- External IP automatically reserved for Cloud NAT.
- privateServiceConnect → const NetworkProfileNetworkFeatures_AddressPurposes
- A private network IP address that can be used to configure Private Service Connect. This purpose can be specified only forGLOBAL addresses of Type INTERNAL
- serverless → const NetworkProfileNetworkFeatures_AddressPurposes
- A regional internal IP address range reserved for Serverless.
- A private network IP address that can be shared by multiple Internal Load Balancer forwarding rules.
- undefinedAddressPurposes → const NetworkProfileNetworkFeatures_AddressPurposes
- A value indicating that the enum field is not set.
- vpcPeering → const NetworkProfileNetworkFeatures_AddressPurposes
- IP range for peer networks.