NetworkProfileNetworkFeatures_SubnetworkPurposes class final
Additional supported values which may be not listed in the enum directly due to technical reasons: PRIVATE_SERVICE_CONNECT
Constructors
- NetworkProfileNetworkFeatures_SubnetworkPurposes(String value)
-
const
- NetworkProfileNetworkFeatures_SubnetworkPurposes.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const NetworkProfileNetworkFeatures_SubnetworkPurposes
- The default value for NetworkProfileNetworkFeatures_SubnetworkPurposes.
- globalManagedProxy → const NetworkProfileNetworkFeatures_SubnetworkPurposes
- Subnet reserved for Global Envoy-based Load Balancing.
- internalHttpsLoadBalancer → const NetworkProfileNetworkFeatures_SubnetworkPurposes
- Subnet reserved for Internal HTTP(S) Load Balancing. This is a legacy purpose, please use REGIONAL_MANAGED_PROXY instead.
- peerMigration → const NetworkProfileNetworkFeatures_SubnetworkPurposes
- Subnetwork will be used for Migration from one peered VPC to another. (a transient state of subnetwork while migrating resources from one project to another).
- private → const NetworkProfileNetworkFeatures_SubnetworkPurposes
- Regular user created or automatically created subnet.
- privateNat → const NetworkProfileNetworkFeatures_SubnetworkPurposes
- Subnetwork used as source range for Private NAT Gateways.
- privateRfc1918 → const NetworkProfileNetworkFeatures_SubnetworkPurposes
- Regular user created or automatically created subnet.
- regionalManagedProxy → const NetworkProfileNetworkFeatures_SubnetworkPurposes
- Subnetwork used for Regional Envoy-based Load Balancing.
- undefinedSubnetworkPurposes → const NetworkProfileNetworkFeatures_SubnetworkPurposes
- A value indicating that the enum field is not set.