bgpInterRegionCost property

String? bgpInterRegionCost
final

Allows to define a preferred approach for handling inter-region cost in the selection process when using the STANDARD BGP best path selection algorithm. Can be DEFAULT orADD_COST_TO_MED. Check the BgpInterRegionCost enum for the list of possible values.

Implementation

final String? bgpInterRegionCost;