NetworkRoutingConfig_BgpBestPathSelectionMode class final
The BGP best path selection algorithm to be employed within this network for dynamic routes learned by Cloud Routers. Can be LEGACY (default) or STANDARD.
Constructors
- NetworkRoutingConfig_BgpBestPathSelectionMode(String value)
-
const
- NetworkRoutingConfig_BgpBestPathSelectionMode.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const NetworkRoutingConfig_BgpBestPathSelectionMode
- The default value for NetworkRoutingConfig_BgpBestPathSelectionMode.
- legacy → const NetworkRoutingConfig_BgpBestPathSelectionMode
- standard → const NetworkRoutingConfig_BgpBestPathSelectionMode
- undefinedBgpBestPathSelectionMode → const NetworkRoutingConfig_BgpBestPathSelectionMode
- A value indicating that the enum field is not set.