NetworkRoutingConfig_BgpInterRegionCost class final
Allows to define a preferred approach for handling inter-region cost in the selection process when using the STANDARD BGP best path selection algorithm. Can be DEFAULT orADD_COST_TO_MED. Additional supported values which may be not listed in the enum directly due to technical reasons: ADD_COST_TO_MED DEFAULT
Constructors
- NetworkRoutingConfig_BgpInterRegionCost(String value)
-
const
- NetworkRoutingConfig_BgpInterRegionCost.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const NetworkRoutingConfig_BgpInterRegionCost
- The default value for NetworkRoutingConfig_BgpInterRegionCost.
- addCostToMed → const NetworkRoutingConfig_BgpInterRegionCost
- default$ → const NetworkRoutingConfig_BgpInterRegionCost
- undefinedBgpInterRegionCost → const NetworkRoutingConfig_BgpInterRegionCost
- A value indicating that the enum field is not set.