NetworkRoutingConfig_EffectiveBgpInterRegionCost class final
Output only. Output Only Effective value of the bgp_inter_region_cost
field.
Additional supported values which may be not listed in the enum directly due to technical reasons:
ADD_COST_TO_MED
DEFAULT
Constructors
- NetworkRoutingConfig_EffectiveBgpInterRegionCost(String value)
-
const
- NetworkRoutingConfig_EffectiveBgpInterRegionCost.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const NetworkRoutingConfig_EffectiveBgpInterRegionCost
- The default value for NetworkRoutingConfig_EffectiveBgpInterRegionCost.
- undefinedEffectiveBgpInterRegionCost → const NetworkRoutingConfig_EffectiveBgpInterRegionCost
- A value indicating that the enum field is not set.