NetworkRoutingConfig_RoutingMode class final
The network-wide routing mode to use. If set to REGIONAL, this network's Cloud Routers will only advertise routes with subnets of this network in the same region as the router. If set toGLOBAL, this network's Cloud Routers will advertise routes with all subnets of this network, across regions.
Constructors
- NetworkRoutingConfig_RoutingMode(String value)
-
const
- NetworkRoutingConfig_RoutingMode.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const NetworkRoutingConfig_RoutingMode
- The default value for NetworkRoutingConfig_RoutingMode.
- global → const NetworkRoutingConfig_RoutingMode
- regional → const NetworkRoutingConfig_RoutingMode
- undefinedRoutingMode → const NetworkRoutingConfig_RoutingMode
- A value indicating that the enum field is not set.