NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy class
final
Properties
-
displayName
→ String?
-
Output only.
Output Only Deprecated, please use short name instead. The display name
of the firewall policy.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
name
→ String?
-
Output only.
Output Only The name of the firewall policy.
final
-
packetMirroringRules
→ List<FirewallPolicyRule>
-
Output only.
Output Only The packet mirroring rules that apply to the network.
final
-
priority
→ int?
-
Output only.
Output only Priority of firewall policy association. Not applicable for
type=HIERARCHY.
final
-
qualifiedName
→ String
-
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or google.rpc.ErrorInfo.
finalinherited
-
rules
→ List<FirewallPolicyRule>
-
Output Only The rules that apply to the network.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
shortName
→ String?
-
Output only.
Output Only The short name of the firewall policy.
final
-
type
→ String?
-
Output only.
Output Only The type of the firewall policy.
Check the Type enum for the list of possible values.
final