NodeGroupAutoscalingPolicy class final

Constructors

NodeGroupAutoscalingPolicy({int? maxNodes, int? minNodes, String? mode})
NodeGroupAutoscalingPolicy.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
maxNodes int?
The maximum number of nodes that the group should have. Must be set if autoscaling is enabled. Maximum value allowed is 100.
final
minNodes int?
The minimum number of nodes that the group should have.
final
mode String?
The autoscaling mode. Set to one of: ON, OFF, or ONLY_SCALE_OUT. For more information, see Autoscaler modes. Check the Mode enum for the list of possible values.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String