NodeGroupMaintenanceWindow class final
Time window specified for daily maintenance operations. GCE's internal maintenance will be performed within this window.
Constructors
- NodeGroupMaintenanceWindow({Duration? maintenanceDuration, String? startTime})
- NodeGroupMaintenanceWindow.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maintenanceDuration → Duration?
-
Output only.
Output onlyA predetermined duration for the window, automatically chosen to be the smallest possible in the given scenario.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startTime → String?
-
Start time of the window. This must be in UTC format that resolves to one
of 00:00, 04:00, 08:00,12:00, 16:00, or 20:00. For
example, both 13:00-5 and 08:00 are valid.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String