maintenanceDuration property
Output only. Output only A predetermined duration for the window, automatically
chosen to be the smallest possible in the given scenario.
Implementation
final Duration? maintenanceDuration;
Output only. Output only A predetermined duration for the window, automatically
chosen to be the smallest possible in the given scenario.
final Duration? maintenanceDuration;