recurrent constant
NodeGroup_MaintenanceInterval
const recurrent
VMs receive infrastructure and hypervisor updates on a periodic basis, minimizing the number of maintenance operations (live migrations or terminations) on an individual VM. This may mean a VM will take longer to receive an update than if it was configured forAS_NEEDED. Security updates will still be applied as soon as they are available. RECURRENT is used for GEN3 and Slice of Hardware VMs.
Implementation
static const recurrent = NodeGroup_MaintenanceInterval('RECURRENT');