NodeTemplate class final
Represent a sole-tenant Node Template resource.
You can use a template to define properties for nodes in a node group. For more information, readCreating node groups and instances.
Constructors
-
NodeTemplate({List<
AcceleratorConfig> accelerators = const [], String? cpuOvercommitType, String? creationTimestamp, String? description, List<LocalDisk> disks = const [], BigInt? id, String? kind, String? name, Map<String, String> nodeAffinityLabels = const {}, String? nodeType, NodeTemplateNodeTypeFlexibility? nodeTypeFlexibility, String? region, String? selfLink, ServerBinding? serverBinding, String? status, String? statusMessage}) - NodeTemplate.fromJson(Object? j)
-
factory
Properties
-
accelerators
→ List<
AcceleratorConfig> -
final
- cpuOvercommitType → String?
-
CPU overcommit.
Check the CpuOvercommitType enum for the list of possible values.
final
- creationTimestamp → String?
-
Output only.
Output OnlyCreation timestamp inRFC3339 text format.final - description → String?
-
An optional description of this resource. Provide this property when you
create the resource.
final
-
disks
→ List<
LocalDisk> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → BigInt?
-
Output only.
Output OnlyThe unique identifier for the resource. This identifier is defined by the server.final - kind → String?
-
Output only.
Output OnlyThe type of the resource. Alwayscompute#nodeTemplate for node templates.final - name → String?
-
The name of the resource, provided by the client when initially creating
the resource. The resource name must be 1-63 characters long, and comply
withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression
[a-z]([-a-z0-9]*[a-z0-9])?which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.final -
nodeAffinityLabels
→ Map<
String, String> -
Labels to use for node affinity, which will be used in instance scheduling.
final
- nodeType → String?
-
The node type to use for nodes group that are created from this template.
final
- nodeTypeFlexibility → NodeTemplateNodeTypeFlexibility?
-
Do not use. Instead, use the node_type property.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - region → String?
-
Output only.
Output OnlyThe name of the region where the node template resides, such as us-central1.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfLink → String?
-
Output only.
Output OnlyServer-defined URL for the resource.final - serverBinding → ServerBinding?
-
Sets the binding properties for the physical server. Valid values include:
final
- status → String?
-
Output only.
Output OnlyThe status of the node template. One of the following values:CREATING, READY, and DELETING. Check the Status enum for the list of possible values.final - statusMessage → String?
-
Output only.
Output OnlyAn optional, human-readable explanation of the status.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String