NotificationEndpoint class final

Represents a notification endpoint.

A notification endpoint resource defines an endpoint to receive notifications when there are status changes detected by the associated health check service.

For more information, see Health checks overview.

Constructors

NotificationEndpoint({String? creationTimestamp, String? description, NotificationEndpointGrpcSettings? grpcSettings, BigInt? id, String? kind, String? name, String? region, String? selfLink})
NotificationEndpoint.fromJson(Object? j)
factory

Properties

creationTimestamp String?
Output only. Output Only Creation timestamp inRFC3339 text format.
final
description String?
An optional description of this resource. Provide this property when you create the resource.
final
grpcSettings NotificationEndpointGrpcSettings?
Settings of the gRPC notification endpoint including the endpoint URL and the retry duration.
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output only. Output Only A unique identifier for this resource type. The server generates this identifier.
final
kind String?
Output only. Output Only Type of the resource. Alwayscompute#notificationEndpoint for notification endpoints.
final
name String?
Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
region String?
Output only. Output Only URL of the region where the notification endpoint resides. This field applies only to the regional resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output only. Output Only Server-defined URL for the resource.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String