httpErrorMessage property
Output Only If the operation fails, this field contains the HTTP error
message that was returned, such as NOT FOUND.
Implementation
final String? httpErrorMessage;
Output Only If the operation fails, this field contains the HTTP error
message that was returned, such as NOT FOUND.
final String? httpErrorMessage;