operationGroupId property
Output only. Output Only An ID that represents a group of operations, such as when a
group of operations results from a bulkInsert API request.
Implementation
final String? operationGroupId;
Output only. Output Only An ID that represents a group of operations, such as when a
group of operations results from a bulkInsert API request.
final String? operationGroupId;