OutlierDetection class final
Settings controlling the eviction of unhealthy hosts from the load balancing pool for the backend service.
Constructors
- OutlierDetection({Duration? baseEjectionTime, int? consecutiveErrors, int? consecutiveGatewayFailure, int? enforcingConsecutiveErrors, int? enforcingConsecutiveGatewayFailure, int? enforcingSuccessRate, Duration? interval, int? maxEjectionPercent, int? successRateMinimumHosts, int? successRateRequestVolume, int? successRateStdevFactor})
- OutlierDetection.fromJson(Object? j)
-
factory
Properties
- baseEjectionTime → Duration?
-
The base time that a backend endpoint is ejected for. Defaults to 30000ms
or 30s.
final
- consecutiveErrors → int?
-
Number of consecutive errors before a backend endpoint is ejected from the
load balancing pool. When the backend endpoint is accessed over HTTP, a 5xx
return code qualifies as an error. Defaults to 5.
final
- consecutiveGatewayFailure → int?
-
The number of consecutive gateway failures (502, 503, 504 status or
connection errors that are mapped to one of those status codes) before a
consecutive gateway failure ejection occurs. Defaults to 3.
final
- enforcingConsecutiveErrors → int?
-
The percentage chance that a backend endpoint will be ejected when an
outlier status is detected through consecutive 5xx. This setting can be
used to disable ejection or to ramp it up slowly. Defaults to 0.
final
- enforcingConsecutiveGatewayFailure → int?
-
The percentage chance that a backend endpoint will be ejected when an
outlier status is detected through consecutive gateway failures. This
setting can be used to disable ejection or to ramp it up slowly. Defaults
to 100.
final
- enforcingSuccessRate → int?
-
The percentage chance that a backend endpoint will be ejected when an
outlier status is detected through success rate statistics. This setting
can be used to disable ejection or to ramp it up slowly. Defaults to 100.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- interval → Duration?
-
Time interval between ejection analysis sweeps. This can result in both new
ejections and backend endpoints being returned to service. The interval is
equal to the number of seconds as defined in
outlierDetection.interval.seconds plus the number of nanoseconds as defined
in outlierDetection.interval.nanos. Defaults to 1 second.
final
- maxEjectionPercent → int?
-
Maximum percentage of backend endpoints in the load balancing pool for the
backend service that can be ejected if the ejection conditions are met.
Defaults to 50%.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- successRateMinimumHosts → int?
-
The number of backend endpoints in the load balancing pool that must have
enough request volume to detect success rate outliers. If the number of
backend endpoints is fewer than this setting, outlier detection via success
rate statistics is not performed for any backend endpoint in the load
balancing pool. Defaults to 5.
final
- successRateRequestVolume → int?
-
The minimum number of total requests that must be collected in one interval
(as defined by the interval duration above) to include this backend
endpoint in success rate based outlier detection. If the volume is lower
than this setting, outlier detection via success rate statistics is not
performed for that backend endpoint. Defaults to 100.
final
- successRateStdevFactor → int?
-
This factor is used to determine the ejection threshold for success rate
outlier ejection. The ejection threshold is the difference between the mean
success rate, and the product of this factor and the standard deviation of
the mean success rate: mean - (stdev * successRateStdevFactor). This factor
is divided by a thousand to get a double. That is, if the desired factor
is 1.9, the runtime value should be 1900. Defaults to 1900.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String