duration property

String? duration
final

From how long ago in the past these intervals were observed. Check the Duration enum for the list of possible values.

Implementation

final String? duration;