PacketIntervals_Duration class final
From how long ago in the past these intervals were observed.
Constructors
- PacketIntervals_Duration(String value)
-
const
- PacketIntervals_Duration.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const PacketIntervals_Duration
- The default value for PacketIntervals_Duration.
- durationUnspecified → const PacketIntervals_Duration
- hour → const PacketIntervals_Duration
- max → const PacketIntervals_Duration
- From BfdSession object creation time.
- minute → const PacketIntervals_Duration
- undefinedDuration → const PacketIntervals_Duration
- A value indicating that the enum field is not set.