enable property
Indicates whether or not this packet mirroring takes effect. If set to FALSE, this packet mirroring policy will not be enforced on the network.
The default is TRUE. Check the Enable enum for the list of possible values.
Implementation
final String? enable;