PacketMirrorings class final
The PacketMirrorings API.
- Implementers
Constructors
- PacketMirrorings({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
PacketMirroringsusingclientfor transport. - PacketMirrorings.fromApiKey([String? apiKey])
-
Creates a
PacketMirroringsthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
aggregatedList(
AggregatedListPacketMirroringsRequest request) → Future< PacketMirroringAggregatedList> - Retrieves an aggregated list of packetMirrorings.
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeletePacketMirroringRequest request) → Future< Operation> - Deletes the specified PacketMirroring resource.
-
get(
GetPacketMirroringRequest request) → Future< PacketMirroring> - Returns the specified PacketMirroring resource.
-
insert(
InsertPacketMirroringRequest request) → Future< Operation> - Creates a PacketMirroring resource in the specified project and region using the data included in the request.
-
list(
ListPacketMirroringsRequest request) → Future< PacketMirroringList> - Retrieves a list of PacketMirroring resources available to the specified project and region.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchPacketMirroringRequest request) → Future< Operation> - Patches the specified PacketMirroring resource with the data included in the request. This method supportsPATCH semantics and usesJSON merge patch format and processing rules.
-
testIamPermissions(
TestIamPermissionsPacketMirroringRequest request) → Future< TestPermissionsResponse> - Returns permissions that a caller has on the specified resource.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited