PatchSubnetworkRequest class final
A request message for Subnetworks.Patch. See the method description for details.
Constructors
- PatchSubnetworkRequest({int? drainTimeoutSeconds, required String project, required String region, String? requestId, required String subnetwork, required Subnetwork? subnetworkResource})
- PatchSubnetworkRequest.fromJson(Object? j)
-
factory
Properties
- drainTimeoutSeconds → int?
-
The drain timeout specifies the upper bound in seconds on the amount of
time allowed to drain connections from the current ACTIVE subnetwork
to the current BACKUP subnetwork. The drain timeout is only applicable
when the following conditions are true:
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- project → String
-
Project ID for this request.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - region → String
-
Name of the region scoping this request.
final
- requestId → String?
-
An optional request ID to identify requests. Specify a unique request ID so
that if you must retry your request, the server will know to ignore the
request if it has already been completed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subnetwork → String
-
Name of the Subnetwork resource to patch.
final
- subnetworkResource → Subnetwork?
-
The body resource for this request
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String