PathRule class final
A path-matching rule for a URL. If matched, will use the specifiedBackendService to handle the traffic arriving at this URL.
Constructors
-
PathRule({CustomErrorResponsePolicy? customErrorResponsePolicy, List<
String> paths = const [], HttpRouteAction? routeAction, String? service, HttpRedirectAction? urlRedirect}) - PathRule.fromJson(Object? j)
-
factory
Properties
- customErrorResponsePolicy → CustomErrorResponsePolicy?
-
customErrorResponsePolicy specifies how the Load
Balancer returns error responses when BackendServiceorBackendBucket responds with an error.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
paths
→ List<
String> -
The list of path patterns to match. Each must start with /
and the only place a * is allowed is at the end following
a /. The string fed to the path matcher does not include
any text after the first ? or #, and
those chars are not allowed here.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - routeAction → HttpRouteAction?
-
In response to a matching path, the load balancer
performs advanced routing actions, such as URL rewrites and header
transformations, before forwarding the request to the selected
backend.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- service → String?
-
The full or partial URL of the backend service resource to which traffic
is directed if this rule is matched. If routeAction is
also specified, advanced routing actions, such as URL rewrites,
take effect before sending the request to the backend.
final
- urlRedirect → HttpRedirectAction?
-
When a path pattern is matched, the request is redirected to a URL
specified by urlRedirect.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String