PerInstanceConfig class final

Constructors

PerInstanceConfig({String? fingerprint, String? name, PreservedState? preservedState, String? status})
PerInstanceConfig.fromJson(Object? j)
factory

Properties

fingerprint String?
Fingerprint of this per-instance config. This field can be used in optimistic locking. It is ignored when inserting a per-instance config. An up-to-date fingerprint must be provided in order to update an existing per-instance configuration or the field needs to be unset.
final
hashCode int
The hash code for this object.
no setterinherited
name String?
The name of a per-instance configuration and its corresponding instance. Serves as a merge key during UpdatePerInstanceConfigs operations, that is, if a per-instance configuration with the same name exists then it will be updated, otherwise a new one will be created for the VM instance with the same name. An attempt to create a per-instance configuration for a VM instance that either doesn't exist or is not part of the group will result in an error.
final
preservedState PreservedState?
The intended preserved state for the given instance. Does not contain preserved state generated from a stateful policy.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
The status of applying this per-instance configuration on the corresponding managed instance. Check the Status enum for the list of possible values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String