PerInstanceConfig_Status class final

The status of applying this per-instance configuration on the corresponding managed instance.

Constructors

PerInstanceConfig_Status(String value)
const
PerInstanceConfig_Status.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const PerInstanceConfig_Status
The default value for PerInstanceConfig_Status.
applying → const PerInstanceConfig_Status
The per-instance configuration is being applied to the instance, but is not yet effective, possibly waiting for the instance to, for example,REFRESH.
deleting → const PerInstanceConfig_Status
The per-instance configuration deletion is being applied on the instance, possibly waiting for the instance to, for example, REFRESH.
effective → const PerInstanceConfig_Status
The per-instance configuration is effective on the instance, meaning that all disks, ips and metadata specified in this configuration are attached or set on the instance.
none → const PerInstanceConfig_Status
Default The default status, when no per-instance configuration exists.
unapplied → const PerInstanceConfig_Status
The per-instance configuration is set on an instance but not been applied yet.
unappliedDeletion → const PerInstanceConfig_Status
The per-instance configuration has been deleted, but the deletion is not yet applied.
undefinedStatus → const PerInstanceConfig_Status
A value indicating that the enum field is not set.