applying constant

PerInstanceConfig_Status const applying

The per-instance configuration is being applied to the instance, but is not yet effective, possibly waiting for the instance to, for example,REFRESH.

Implementation

static const applying = PerInstanceConfig_Status('APPLYING');