PreviewFeature class final

Represents a single Google Compute Engine preview feature.

Constructors

PreviewFeature({String? activationStatus, String? creationTimestamp, String? description, BigInt? id, String? kind, String? name, PreviewFeatureRolloutOperation? rolloutOperation, String? selfLink, PreviewFeatureStatus? status})
PreviewFeature.fromJson(Object? j)
factory

Properties

activationStatus String?
Specifies whether the feature is enabled or disabled. Check the ActivationStatus enum for the list of possible values.
final
creationTimestamp String?
Output only. Output Only Creation timestamp inRFC3339 text format.
final
description String?
Output only. Output Only Description of the feature.
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output only. Output Only The unique identifier for the resource. This identifier is defined by the server.
final
kind String?
Output only. Output only The type of the feature. Always "compute#previewFeature" for preview features.
final
name String?
Name of the feature.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
rolloutOperation PreviewFeatureRolloutOperation?
Rollout operation of the feature.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output only. Output Only Server-defined URL for the resource.
final
status PreviewFeatureStatus?
Output only. Output only Status of the feature.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String