defaultNetworkTier property
This signifies the default network tier used for configuring resources of the project and can only take the following values:PREMIUM, STANDARD. Initially the default network tier is PREMIUM. Check the DefaultNetworkTier enum for the list of possible values.
Implementation
final String? defaultNetworkTier;