usageExportLocation property
An optional naming prefix for daily usage reports and the Google Cloud Storage bucket where they are stored.
Implementation
final UsageExportLocation? usageExportLocation;
An optional naming prefix for daily usage reports and the Google Cloud Storage bucket where they are stored.
final UsageExportLocation? usageExportLocation;