ProjectViews class final
The ProjectViews API.
- Implementers
Constructors
- ProjectViews({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
ProjectViewsusingclientfor transport. - ProjectViews.fromApiKey([String? apiKey])
-
Creates a
ProjectViewsthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
get(
GetProjectViewRequest request) → Future< ProjectView> - Returns the specified global ProjectViews resource, with a regional context. This regional API endpoint reads resource metadata from regional read-only replicas. Because changes are copied to these regional replicas asynchronously, for real-time resource reads or any write operations (creating, updating, or deleting resources), use the global projects.get endpoint.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited