Project_CloudArmorTier class final
Output only. Output Only The Cloud Armor tier for this project. It can be one of the
following values: CA_STANDARD,CA_ENTERPRISE_PAYGO.
If this field is not specified, it is assumed to beCA_STANDARD.
Constructors
- Project_CloudArmorTier(String value)
-
const
- Project_CloudArmorTier.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const Project_CloudArmorTier
- The default value for Project_CloudArmorTier.
- caEnterpriseAnnual → const Project_CloudArmorTier
- Enterprise tier protection billed annually.
- caEnterprisePaygo → const Project_CloudArmorTier
- Enterprise tier protection billed monthly.
- caStandard → const Project_CloudArmorTier
- Standard protection.
- undefinedCloudArmorTier → const Project_CloudArmorTier
- A value indicating that the enum field is not set.