Project_VmDnsSetting class final
Output only. Output Only Default internal DNS setting used by VMs running in
this project.
Constructors
- Project_VmDnsSetting(String value)
-
const
- Project_VmDnsSetting.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const Project_VmDnsSetting
- The default value for Project_VmDnsSetting.
- globalDefault → const Project_VmDnsSetting
- undefinedVmDnsSetting → const Project_VmDnsSetting
- A value indicating that the enum field is not set.
- unspecifiedVmDnsSetting → const Project_VmDnsSetting
- zonalDefault → const Project_VmDnsSetting
- zonalOnly → const Project_VmDnsSetting