setCloudArmorTier method
Sets the Cloud Armor tier of the project. To set ENTERPRISE or above the billing account of the project must be subscribed to Cloud Armor Enterprise. See Subscribing to Cloud Armor Enterprise for more information.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
Future<Operation> setCloudArmorTier(
SetCloudArmorTierProjectRequest request,
) async {
final url = _endPoint.replace(
path: '/compute/v1/projects/${request.project}/setCloudArmorTier',
queryParameters: {'requestId': ?request.requestId},
);
final response = await _client.post(
url,
body: request.projectsSetCloudArmorTierRequestResource,
);
return Operation.fromJson(response);
}