setDefaultNetworkTier method
Sets the default network tier of the project. The default network tier is used when an address/forwardingRule/instance is created without specifying the network tier field.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
Future<Operation> setDefaultNetworkTier(
SetDefaultNetworkTierProjectRequest request,
) async {
final url = _endPoint.replace(
path: '/compute/v1/projects/${request.project}/setDefaultNetworkTier',
queryParameters: {'requestId': ?request.requestId},
);
final response = await _client.post(
url,
body: request.projectsSetDefaultNetworkTierRequestResource,
);
return Operation.fromJson(response);
}