setUsageExportBucket method

Future<Operation> setUsageExportBucket(
  1. SetUsageExportBucketProjectRequest request
)

Enables the usage export feature and sets theusage export bucket where reports are stored. If you provide an empty request body using this method, the usage export feature will be disabled.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Operation> setUsageExportBucket(
  SetUsageExportBucketProjectRequest request,
) async {
  final url = _endPoint.replace(
    path: '/compute/v1/projects/${request.project}/setUsageExportBucket',
    queryParameters: {'requestId': ?request.requestId},
  );
  final response = await _client.post(
    url,
    body: request.usageExportLocationResource,
  );
  return Operation.fromJson(response);
}