menu
google_cloud_compute_v1 package
documentation
compute.dart
ProjectsListXpnHostsRequest class
ProjectsListXpnHostsRequest class
dark_mode
light_mode
ProjectsListXpnHostsRequest
class
final
Constructors
ProjectsListXpnHostsRequest
({
String
?
organization
})
ProjectsListXpnHostsRequest.fromJson
(
Object
?
j
)
factory
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
organization
→
String
?
Optional organization ID managed by Cloud Resource Manager, for which to list shared VPC host projects. If not specified, the organization will be inferred from the project.
final
qualifiedName
→
String
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or
google.rpc.ErrorInfo
.
final
inherited
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson
(
)
→
Object
toString
(
)
→
String
A string representation of this object.
override
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
Constants
fullyQualifiedName
→ const
String
google_cloud_compute_v1 package
documentation
compute
ProjectsListXpnHostsRequest class
compute library