PublicDelegatedPrefixes class final
The PublicDelegatedPrefixes API.
- Implementers
Constructors
- PublicDelegatedPrefixes({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
PublicDelegatedPrefixesusingclientfor transport. - PublicDelegatedPrefixes.fromApiKey([String? apiKey])
-
Creates a
PublicDelegatedPrefixesthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
aggregatedList(
AggregatedListPublicDelegatedPrefixesRequest request) → Future< PublicDelegatedPrefixAggregatedList> - Lists all PublicDelegatedPrefix resources owned by the specific project across all scopes.
-
announce(
AnnouncePublicDelegatedPrefixeRequest request) → Future< Operation> - Announces the specified PublicDelegatedPrefix in the given region.
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeletePublicDelegatedPrefixeRequest request) → Future< Operation> - Deletes the specified PublicDelegatedPrefix in the given region.
-
get(
GetPublicDelegatedPrefixeRequest request) → Future< PublicDelegatedPrefix> - Returns the specified PublicDelegatedPrefix resource in the given region.
-
insert(
InsertPublicDelegatedPrefixeRequest request) → Future< Operation> - Creates a PublicDelegatedPrefix in the specified project in the given region using the parameters that are included in the request.
-
list(
ListPublicDelegatedPrefixesRequest request) → Future< PublicDelegatedPrefixList> - Lists the PublicDelegatedPrefixes for a project in the given region.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchPublicDelegatedPrefixeRequest request) → Future< Operation> - Patches the specified PublicDelegatedPrefix resource with the data included in the request. This method supportsPATCH semantics and usesJSON merge patch format and processing rules.
-
toString(
) → String -
A string representation of this object.
inherited
-
withdraw(
WithdrawPublicDelegatedPrefixeRequest request) → Future< Operation> - Withdraws the specified PublicDelegatedPrefix in the given region.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited