code property
Output Only A warning code, if applicable. For example, Compute
Engine returns NO_RESULTS_ON_PAGE if there
are no results in the response.
Check the Code enum for the list of possible values.
Implementation
final String? code;
Output Only A warning code, if applicable. For example, Compute
Engine returns NO_RESULTS_ON_PAGE if there
are no results in the response.
Check the Code enum for the list of possible values.
final String? code;