resourceNotDeleted constant
QuotaStatusWarning_Code
const resourceNotDeleted
One or more of the resources set to auto-delete could not be deleted because they were in use.
Implementation
static const resourceNotDeleted = QuotaStatusWarning_Code(
'RESOURCE_NOT_DELETED',
);