RawDisk class final
The parameters of the raw disk image.
Constructors
Properties
- containerType → String?
-
The format used to encode and transmit the block device, which should beTAR. This is just a container and transmission format and not
a runtime format. Provided by the client when the disk image is created.
Check the ContainerType enum for the list of possible values.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sha1Checksum → String?
-
Deprecated This field is deprecated.
An optional SHA1 checksum of the disk image before unpackaging provided
by the client when the disk image is created.
final
- source → String?
-
The full Google Cloud Storage URL or Artifact Registry path where the raw
disk image archive is stored.
The following are valid formats:
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String