sha1Checksum property
Deprecated This field is deprecated. An optional SHA1 checksum of the disk image before unpackaging provided by the client when the disk image is created.
Implementation
final String? sha1Checksum;
Deprecated This field is deprecated. An optional SHA1 checksum of the disk image before unpackaging provided by the client when the disk image is created.
final String? sha1Checksum;