Reference class final
Represents a reference to a resource.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → String?
-
Output only.
Output OnlyType of the resource. Always compute#reference for references.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - referenceType → String?
-
A description of the reference type with no implied semantics. Possible
values include:
final
- referrer → String?
-
URL of the resource which refers to the target.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- target → String?
-
URL of the resource to which this reference points.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String