Region class final
Represents a Region resource.
A region is a geographical area where a resource is located. For more information, readRegions and Zones.
Constructors
-
Region({String? creationTimestamp, DeprecationStatus? deprecated, String? description, BigInt? id, String? kind, String? name, QuotaStatusWarning? quotaStatusWarning, List<
Quota> quotas = const [], String? selfLink, String? status, bool? supportsPzs, List<String> zones = const []}) - Region.fromJson(Object? j)
-
factory
Properties
- creationTimestamp → String?
-
Output OnlyCreation timestamp inRFC3339 text format.final - deprecated → DeprecationStatus?
-
Output OnlyThe deprecation status associated with this region.final - description → String?
-
Output OnlyTextual description of the resource.final - hashCode → int
-
The hash code for this object.
no setterinherited
- id → BigInt?
-
Output OnlyThe unique identifier for the resource. This identifier is defined by the server.final - kind → String?
-
Output only.
Output OnlyType of the resource. Always compute#region for regions.final - name → String?
-
Output OnlyName of the resource.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited -
quotas
→ List<
Quota> -
Output OnlyQuotas assigned to this region.final - quotaStatusWarning → QuotaStatusWarning?
-
Output only.
Output OnlyWarning of fetching thequotasfield for this region. This field is populated only if fetching of thequotasfield fails.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfLink → String?
-
Output OnlyServer-defined URL for the resource.final - status → String?
-
Output OnlyStatus of the region, either UP orDOWN. Check the Status enum for the list of possible values.final - supportsPzs → bool?
-
Output only.
Output OnlyReserved for future use.final -
zones
→ List<
String> -
Output OnlyA list of zones available in this region, in the form of resource URLs.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String