RegionDisks class final
The RegionDisks API.
- Implementers
Constructors
- RegionDisks({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
RegionDisksusingclientfor transport. - RegionDisks.fromApiKey([String? apiKey])
-
Creates a
RegionDisksthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addResourcePolicies(
AddResourcePoliciesRegionDiskRequest request) → Future< Operation> - Adds existing resource policies to a regional disk. You can only add one policy which will be applied to this disk for scheduling snapshot creation.
-
bulkInsert(
BulkInsertRegionDiskRequest request) → Future< Operation> - Bulk create a set of disks.
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
createSnapshot(
CreateSnapshotRegionDiskRequest request) → Future< Operation> - Creates a snapshot of a specified persistent disk. For regular snapshot creation, consider using snapshots.insert instead, as that method supports more features, such as creating snapshots in a project different from the source disk project.
-
delete(
DeleteRegionDiskRequest request) → Future< Operation> - Deletes the specified regional persistent disk. Deleting a regional disk removes all the replicas of its data permanently and is irreversible. However, deleting a disk does not delete anysnapshots previously made from the disk. You must separatelydelete snapshots.
-
get(
GetRegionDiskRequest request) → Future< Disk> - Returns a specified regional persistent disk.
-
getIamPolicy(
GetIamPolicyRegionDiskRequest request) → Future< Policy> - Gets the access control policy for a resource. May be empty if no such policy or resource exists.
-
insert(
InsertRegionDiskRequest request) → Future< Operation> - Creates a persistent regional disk in the specified project using the data included in the request.
-
list(
ListRegionDisksRequest request) → Future< DiskList> - Retrieves the list of persistent disks contained within the specified region.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeResourcePolicies(
RemoveResourcePoliciesRegionDiskRequest request) → Future< Operation> - Removes resource policies from a regional disk.
-
resize(
ResizeRegionDiskRequest request) → Future< Operation> - Resizes the specified regional persistent disk.
-
setIamPolicy(
SetIamPolicyRegionDiskRequest request) → Future< Policy> - Sets the access control policy on the specified resource. Replaces any existing policy.
-
setLabels(
SetLabelsRegionDiskRequest request) → Future< Operation> - Sets the labels on the target regional disk.
-
startAsyncReplication(
StartAsyncReplicationRegionDiskRequest request) → Future< Operation> - Starts asynchronous replication. Must be invoked on the primary disk.
-
stopAsyncReplication(
StopAsyncReplicationRegionDiskRequest request) → Future< Operation> - Stops asynchronous replication. Can be invoked either on the primary or on the secondary disk.
-
stopGroupAsyncReplication(
StopGroupAsyncReplicationRegionDiskRequest request) → Future< Operation> - Stops asynchronous replication for a consistency group of disks. Can be invoked either in the primary or secondary scope.
-
testIamPermissions(
TestIamPermissionsRegionDiskRequest request) → Future< TestPermissionsResponse> - Returns permissions that a caller has on the specified resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
UpdateRegionDiskRequest request) → Future< Operation> - Update the specified disk with the data included in the request. Update is performed only on selected fields included as part of update-mask.
-
updateKmsKey(
UpdateKmsKeyRegionDiskRequest request) → Future< Operation> - Rotates the customer-managed encryption key to the latest version for the specified persistent disk.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited