delete method
Deletes the specified regional persistent disk. Deleting a regional disk removes all the replicas of its data permanently and is irreversible. However, deleting a disk does not delete anysnapshots previously made from the disk. You must separatelydelete snapshots.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
Future<Operation> delete(DeleteRegionDiskRequest request) async {
final url = _endPoint.replace(
path:
'/compute/v1/projects/${request.project}/regions/${request.region}/disks/${request.disk}',
queryParameters: {'requestId': ?request.requestId},
);
final response = await _client.delete(url);
return Operation.fromJson(response);
}