RegionHealthCheckServices class final
The RegionHealthCheckServices API.
- Implementers
Constructors
- RegionHealthCheckServices({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
RegionHealthCheckServicesusingclientfor transport. - RegionHealthCheckServices.fromApiKey([String? apiKey])
-
Creates a
RegionHealthCheckServicesthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
aggregatedList(
AggregatedListRegionHealthCheckServicesRequest request) → Future< HealthCheckServiceAggregatedList> - Retrieves the list of all HealthCheckService resources, regional and global, available to the specified project.
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteRegionHealthCheckServiceRequest request) → Future< Operation> - Deletes the specified regional HealthCheckService.
-
get(
GetRegionHealthCheckServiceRequest request) → Future< HealthCheckService> - Returns the specified regional HealthCheckService resource.
-
insert(
InsertRegionHealthCheckServiceRequest request) → Future< Operation> - Creates a regional HealthCheckService resource in the specified project and region using the data included in the request.
-
list(
ListRegionHealthCheckServicesRequest request) → Future< HealthCheckServicesList> - Lists all the HealthCheckService resources that have been configured for the specified project in the given region.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchRegionHealthCheckServiceRequest request) → Future< Operation> - Updates the specified regional HealthCheckService resource with the data included in the request. This method supportsPATCH semantics and uses theJSON merge patch format and processing rules.
-
testIamPermissions(
TestIamPermissionsRegionHealthCheckServiceRequest request) → Future< TestPermissionsResponse> - Returns permissions that a caller has on the specified resource.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited