cancel method
Cancels the specified resize request. Cancelled resize request no longer waits for the resources to be provisioned. Cancel is only possible for requests that are in accepted state.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
Future<Operation> cancel(
CancelRegionInstanceGroupManagerResizeRequestRequest request,
) async {
final url = _endPoint.replace(
path:
'/compute/v1/projects/${request.project}/regions/${request.region}/instanceGroupManagers/${request.instanceGroupManager}/resizeRequests/${request.resizeRequest}/cancel',
queryParameters: {'requestId': ?request.requestId},
);
final response = await _client.post(url);
return Operation.fromJson(response);
}