RegionInstantSnapshots class final
The RegionInstantSnapshots API.
- Implementers
Constructors
- RegionInstantSnapshots({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
RegionInstantSnapshotsusingclientfor transport. - RegionInstantSnapshots.fromApiKey([String? apiKey])
-
Creates a
RegionInstantSnapshotsthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteRegionInstantSnapshotRequest request) → Future< Operation> - Deletes the specified InstantSnapshot resource. Keep in mind that deleting a single instantSnapshot might not necessarily delete all the data on that instantSnapshot. If any data on the instantSnapshot that is marked for deletion is needed for subsequent instantSnapshots, the data will be moved to the next corresponding instantSnapshot.
-
get(
GetRegionInstantSnapshotRequest request) → Future< InstantSnapshot> - Returns the specified InstantSnapshot resource in the specified region.
-
getIamPolicy(
GetIamPolicyRegionInstantSnapshotRequest request) → Future< Policy> - Gets the access control policy for a resource. May be empty if no such policy or resource exists.
-
insert(
InsertRegionInstantSnapshotRequest request) → Future< Operation> - Creates an instant snapshot in the specified region.
-
list(
ListRegionInstantSnapshotsRequest request) → Future< InstantSnapshotList> - Retrieves the list of InstantSnapshot resources contained within the specified region.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setIamPolicy(
SetIamPolicyRegionInstantSnapshotRequest request) → Future< Policy> - Sets the access control policy on the specified resource. Replaces any existing policy.
-
setLabels(
SetLabelsRegionInstantSnapshotRequest request) → Future< Operation> - Sets the labels on a instantSnapshot in the given region. To learn more about labels, read the Labeling Resources documentation.
-
testIamPermissions(
TestIamPermissionsRegionInstantSnapshotRequest request) → Future< TestPermissionsResponse> - Returns permissions that a caller has on the specified resource.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited