RegionNetworkEndpointGroups class final

The RegionNetworkEndpointGroups API.

Implementers

Constructors

RegionNetworkEndpointGroups({required Client client, Uri? endPoint, String? gcclVersion})
Creates a RegionNetworkEndpointGroups using client for transport.
RegionNetworkEndpointGroups.fromApiKey([String? apiKey])
Creates a RegionNetworkEndpointGroups that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

attachNetworkEndpoints(AttachNetworkEndpointsRegionNetworkEndpointGroupRequest request) Future<Operation>
Attach a list of network endpoints to the specified network endpoint group.
close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteRegionNetworkEndpointGroupRequest request) Future<Operation>
Deletes the specified network endpoint group. Note that the NEG cannot be deleted if it is configured as a backend of a backend service.
detachNetworkEndpoints(DetachNetworkEndpointsRegionNetworkEndpointGroupRequest request) Future<Operation>
Detach the network endpoint from the specified network endpoint group.
get(GetRegionNetworkEndpointGroupRequest request) Future<NetworkEndpointGroup>
Returns the specified network endpoint group.
insert(InsertRegionNetworkEndpointGroupRequest request) Future<Operation>
Creates a network endpoint group in the specified project using the parameters that are included in the request.
list(ListRegionNetworkEndpointGroupsRequest request) Future<NetworkEndpointGroupList>
Retrieves the list of regional network endpoint groups available to the specified project in the given region.
listNetworkEndpoints(ListNetworkEndpointsRegionNetworkEndpointGroupsRequest request) Future<NetworkEndpointGroupsListNetworkEndpoints>
Lists the network endpoints in the specified network endpoint group.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited