RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse class final
Constructors
-
RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse({List<
RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy> firewallPolicys = const [], List<Firewall> firewalls = const []}) - RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse.fromJson(Object? j)
-
factory
Properties
-
firewallPolicys
→ List<
RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy> -
Output only.
Output onlyEffective firewalls from firewall policy. It applies to Regional Network Firewall Policies in the specified region, Global Network Firewall Policies and Hierachial Firewall Policies which are associated with the network.final -
firewalls
→ List<
Firewall> -
Effective firewalls on the network.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String