RegionNotificationEndpoints class final

The RegionNotificationEndpoints API.

Implementers

Constructors

RegionNotificationEndpoints({required Client client, Uri? endPoint, String? gcclVersion})
Creates a RegionNotificationEndpoints using client for transport.
RegionNotificationEndpoints.fromApiKey([String? apiKey])
Creates a RegionNotificationEndpoints that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(AggregatedListRegionNotificationEndpointsRequest request) Future<NotificationEndpointAggregatedList>
Retrieves the list of all NotificationEndpoint resources, regional and global, available to the specified project.
close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteRegionNotificationEndpointRequest request) Future<Operation>
Deletes the specified NotificationEndpoint in the given region
get(GetRegionNotificationEndpointRequest request) Future<NotificationEndpoint>
Returns the specified NotificationEndpoint resource in the given region.
insert(InsertRegionNotificationEndpointRequest request) Future<Operation>
Create a NotificationEndpoint in the specified project in the given region using the parameters that are included in the request.
list(ListRegionNotificationEndpointsRequest request) Future<NotificationEndpointList>
Lists the NotificationEndpoints for a project in the given region.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
testIamPermissions(TestIamPermissionsRegionNotificationEndpointRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited