RegionOperations class final
The RegionOperations API.
- Implementers
Constructors
- RegionOperations({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
RegionOperationsusingclientfor transport. - RegionOperations.fromApiKey([String? apiKey])
-
Creates a
RegionOperationsthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteRegionOperationRequest request) → Future< DeleteRegionOperationResponse> - Deletes the specified region-specific Operations resource.
-
get(
GetRegionOperationRequest request) → Future< Operation> - Retrieves the specified region-specific Operations resource.
-
list(
ListRegionOperationsRequest request) → Future< OperationList> - Retrieves a list of Operation resources contained within the specified region.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
wait(
WaitRegionOperationRequest request) → Future< Operation> -
Waits for the specified Operation resource to return as
DONEor for the request to approach the 2 minute deadline, and retrieves the specified Operation resource. This method differs from theGETmethod in that it waits for no more than the default deadline (2 minutes) and then returns the current state of the operation, which might beDONEor still in progress.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited