RegionSnapshots class final
The RegionSnapshots API.
- Implementers
Constructors
- RegionSnapshots({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
RegionSnapshotsusingclientfor transport. - RegionSnapshots.fromApiKey([String? apiKey])
-
Creates a
RegionSnapshotsthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteRegionSnapshotRequest request) → Future< Operation> - Deletes the specified Snapshot resource. Keep in mind that deleting a single snapshot might not necessarily delete all the data on that snapshot. If any data on the snapshot that is marked for deletion is needed for subsequent snapshots, the data will be moved to the next corresponding snapshot.
-
get(
GetRegionSnapshotRequest request) → Future< Snapshot> - Returns the specified Snapshot resource.
-
getIamPolicy(
GetIamPolicyRegionSnapshotRequest request) → Future< Policy> - Gets the access control policy for a resource. May be empty if no such policy or resource exists.
-
insert(
InsertRegionSnapshotRequest request) → Future< Operation> - Creates a snapshot in the specified region using the data included in the request.
-
list(
ListRegionSnapshotsRequest request) → Future< SnapshotList> - Retrieves the list of Snapshot resources contained within the specified region.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setIamPolicy(
SetIamPolicyRegionSnapshotRequest request) → Future< Policy> - Sets the access control policy on the specified resource. Replaces any existing policy.
-
setLabels(
SetLabelsRegionSnapshotRequest request) → Future< Operation> - Sets the labels on a regional snapshot. To learn more about labels, read the Labeling Resources documentation.
-
testIamPermissions(
TestIamPermissionsRegionSnapshotRequest request) → Future< TestPermissionsResponse> - Returns permissions that a caller has on the specified resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
updateKmsKey(
UpdateKmsKeyRegionSnapshotRequest request) → Future< Operation> - Rotates the customer-managed encryption key to the latest version for the specified snapshot.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited