RegionTargetHttpsProxies class final
The RegionTargetHttpsProxies API.
- Implementers
Constructors
- RegionTargetHttpsProxies({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
RegionTargetHttpsProxiesusingclientfor transport. - RegionTargetHttpsProxies.fromApiKey([String? apiKey])
-
Creates a
RegionTargetHttpsProxiesthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteRegionTargetHttpsProxyRequest request) → Future< Operation> - Deletes the specified TargetHttpsProxy resource.
-
get(
GetRegionTargetHttpsProxyRequest request) → Future< TargetHttpsProxy> - Returns the specified TargetHttpsProxy resource in the specified region.
-
insert(
InsertRegionTargetHttpsProxyRequest request) → Future< Operation> - Creates a TargetHttpsProxy resource in the specified project and region using the data included in the request.
-
list(
ListRegionTargetHttpsProxiesRequest request) → Future< TargetHttpsProxyList> - Retrieves the list of TargetHttpsProxy resources available to the specified project in the specified region.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchRegionTargetHttpsProxyRequest request) → Future< Operation> - Patches the specified regional TargetHttpsProxy resource with the data included in the request. This method supports PATCH semantics and usesJSON merge patch format and processing rules.
-
setSslCertificates(
SetSslCertificatesRegionTargetHttpsProxyRequest request) → Future< Operation> - Replaces SslCertificates for TargetHttpsProxy.
-
setUrlMap(
SetUrlMapRegionTargetHttpsProxyRequest request) → Future< Operation> - Changes the URL map for TargetHttpsProxy.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited