Reservation class final

Represents a reservation resource. A reservation ensures that capacity is held in a specific zone even if the reserved VMs are not running. For more information, read Reserving zonal resources.

Constructors

Reservation({ReservationAdvancedDeploymentControl? advancedDeploymentControl, AllocationAggregateReservation? aggregateReservation, String? commitment, String? confidentialComputeType, String? creationTimestamp, Duration? deleteAfterDuration, String? deleteAtTime, String? deploymentType, String? description, String? earlyAccessMaintenance, bool? enableEmergentMaintenance, BigInt? id, String? kind, List<String> linkedCommitments = const [], String? name, ReservationParams? params, String? protectionTier, AllocationReservationSharingPolicy? reservationSharingPolicy, Map<String, String> resourcePolicies = const {}, AllocationResourceStatus? resourceStatus, bool? satisfiesPzs, String? schedulingType, String? selfLink, ShareSettings? shareSettings, AllocationSpecificSkureservation? specificReservation, bool? specificReservationRequired, String? status, String? zone})
Reservation.fromJson(Object? j)
factory

Properties

advancedDeploymentControl ReservationAdvancedDeploymentControl?
Advanced control for cluster management, applicable only to DENSE deployment type reservations.
final
aggregateReservation AllocationAggregateReservation?
Reservation for aggregated resources, providing shape flexibility.
final
commitment String?
Output only. Output Only Full or partial URL to a parent commitment. This field displays for reservations that are tied to a commitment.
final
confidentialComputeType String?
Check the ConfidentialComputeType enum for the list of possible values.
final
creationTimestamp String?
Output only. Output Only Creation timestamp inRFC3339 text format.
final
deleteAfterDuration Duration?
Duration time relative to reservation creation when Compute Engine will automatically delete this resource.
final
deleteAtTime String?
Absolute time in future when the reservation will be auto-deleted by Compute Engine. Timestamp is represented inRFC3339 text format.
final
deploymentType String?
Specifies the deployment strategy for this reservation. Check the DeploymentType enum for the list of possible values.
final
description String?
An optional description of this resource. Provide this property when you create the resource.
final
earlyAccessMaintenance String?
Indicates the early access maintenance for the reservation. If this field is absent or set to NO_EARLY_ACCESS, the reservation is not enrolled in early access maintenance and the standard notice applies. Check the EarlyAccessMaintenance enum for the list of possible values.
final
enableEmergentMaintenance bool?
Indicates whether Compute Engine allows unplanned maintenance for your VMs; for example, to fix hardware errors.
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output only. Output Only The unique identifier for the resource. This identifier is defined by the server.
final
kind String?
Output only. Output Only Type of the resource. Alwayscompute#reservations for reservations.
final
linkedCommitments List<String>
Output only. Output Only Full or partial URL to parent commitments. This field displays for reservations that are tied to multiple commitments.
final
name String?
The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
params ReservationParams?
Input only. Additional params passed with the request, but not persisted as part of resource payload.
final
protectionTier String?
Protection tier for the workload which specifies the workload expectations in the event of infrastructure failures at data center (e.g. power and/or cooling failures). Check the ProtectionTier enum for the list of possible values.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
reservationSharingPolicy AllocationReservationSharingPolicy?
Specify the reservation sharing policy. If unspecified, the reservation will not be shared with Google Cloud managed services.
final
resourcePolicies Map<String, String>
Resource policies to be added to this reservation. The key is defined by user, and the value is resource policy url. This is to define placement policy with reservation.
final
resourceStatus AllocationResourceStatus?
Output only. Output Only Status information for Reservation resource.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzs bool?
Output only. Output Only Reserved for future use.
final
schedulingType String?
The type of maintenance for the reservation. Check the SchedulingType enum for the list of possible values.
final
Output only. Output Only Server-defined fully-qualified URL for this resource.
final
shareSettings ShareSettings?
Specify share-settings to create a shared reservation. This property is optional. For more information about the syntax and options for this field and its subfields, see the guide for creating a shared reservation.
final
specificReservation AllocationSpecificSkureservation?
Reservation for instances with specific machine shapes.
final
specificReservationRequired bool?
Indicates whether the reservation can be consumed by VMs with affinity for "any" reservation. If the field is set, then only VMs that target the reservation by name can consume from this reservation.
final
status String?
Output only. Output Only The status of the reservation.
final
zone String?
Zone in which the reservation resides. A zone must be provided if the reservation is created within a commitment.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String