protectionTier property
Protection tier for the workload which specifies the workload expectations in the event of infrastructure failures at data center (e.g. power and/or cooling failures). Check the ProtectionTier enum for the list of possible values.
Implementation
final String? protectionTier;