ReservationAdvancedDeploymentControl_ReservationOperationalMode class final
Indicates chosen reservation operational mode for the reservation.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const ReservationAdvancedDeploymentControl_ReservationOperationalMode
- The default value for ReservationAdvancedDeploymentControl_ReservationOperationalMode.
- allCapacity → const ReservationAdvancedDeploymentControl_ReservationOperationalMode
- Google Cloud does not manage the failure of machines, but provides additional capacity, which is not guaranteed to be available.
- highlyAvailableCapacity → const ReservationAdvancedDeploymentControl_ReservationOperationalMode
- Google Cloud manages the failure of machines to provide high availability.
- reservationOperationalModeUnspecified → const ReservationAdvancedDeploymentControl_ReservationOperationalMode
- undefinedReservationOperationalMode → const ReservationAdvancedDeploymentControl_ReservationOperationalMode
- A value indicating that the enum field is not set.