ReservationSlotStatus class final

Constructors

ReservationSlotStatus({ReservationSlotPhysicalTopology? physicalTopology, List<String> rdmaIpAddresses = const [], List<String> runningInstances = const []})
ReservationSlotStatus.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
physicalTopology ReservationSlotPhysicalTopology?
Output only. Output Only The physical topology of the reservation sub-block.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
rdmaIpAddresses List<String>
Output only. The RDMA IP address of the physical host.
final
runningInstances List<String>
Output only. The URIs of the instances currently running on this slot.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String