ReservationSlots class final
The ReservationSlots API.
- Implementers
Constructors
- ReservationSlots({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
ReservationSlotsusingclientfor transport. - ReservationSlots.fromApiKey([String? apiKey])
-
Creates a
ReservationSlotsthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
get(
GetReservationSlotRequest request) → Future< ReservationSlotsGetResponse> - Retrieves information about the specified reservation slot.
-
getVersion(
GetVersionReservationSlotRequest request) → Future< Operation> - Allows customers to get SBOM versions of a reservation slot.
-
list(
ListReservationSlotsRequest request) → Future< ReservationSlotsListResponse> - Retrieves a list of reservation slots under a single reservation.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
UpdateReservationSlotRequest request) → Future< Operation> - Update a reservation slot in the specified sub-block.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited