ReservationSubBlockHealthInfo_HealthStatus class final
The health status of the reservation subBlock.
Constructors
- ReservationSubBlockHealthInfo_HealthStatus(String value)
-
const
- ReservationSubBlockHealthInfo_HealthStatus.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const ReservationSubBlockHealthInfo_HealthStatus
- The default value for ReservationSubBlockHealthInfo_HealthStatus.
- degraded → const ReservationSubBlockHealthInfo_HealthStatus
- The reservation subBlock is degraded.
- healthStatusUnspecified → const ReservationSubBlockHealthInfo_HealthStatus
- The health status of the reservation subBlock is unspecified.
- healthy → const ReservationSubBlockHealthInfo_HealthStatus
- The reservation subBlock is healthy.
- undefinedHealthStatus → const ReservationSubBlockHealthInfo_HealthStatus
- A value indicating that the enum field is not set.