ReservationSubBlocksReportFaultyRequestFaultReason class final

The reason for the fault experienced with the subBlock.

Properties

behavior String?
The behavior of the fault experienced with the subBlock. Check the Behavior enum for the list of possible values.
final
description String?
The description of the fault experienced with the subBlock.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String