Reservation_EarlyAccessMaintenance class final
Indicates the early access maintenance for the reservation. If this field is absent or set to NO_EARLY_ACCESS, the reservation is not enrolled in early access maintenance and the standard notice applies.
Constructors
- Reservation_EarlyAccessMaintenance(String value)
-
const
- Reservation_EarlyAccessMaintenance.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const Reservation_EarlyAccessMaintenance
- The default value for Reservation_EarlyAccessMaintenance.
- noEarlyAccess → const Reservation_EarlyAccessMaintenance
- No early access.
- undefinedEarlyAccessMaintenance → const Reservation_EarlyAccessMaintenance
- A value indicating that the enum field is not set.
- wave1 → const Reservation_EarlyAccessMaintenance
- Wave 1: Fastest notification period
- wave2 → const Reservation_EarlyAccessMaintenance
- Wave 2: Medium notification period