Reservation_Status class final

Output only. Output Only The status of the reservation.

 - CREATING: Reservation resources are being
   allocated.
 - READY: Reservation resources have been allocated,
   and the reservation is ready for use.
 - DELETING: Reservation deletion is in progress.
 - UPDATING: Reservation update is in progress.

Constructors

Reservation_Status(String value)
const
Reservation_Status.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const Reservation_Status
The default value for Reservation_Status.
creating → const Reservation_Status
Reservation resources are being allocated.
deleting → const Reservation_Status
Reservation deletion is in progress.
invalid → const Reservation_Status
ready → const Reservation_Status
Reservation resources have been allocated, and the reservation is ready for use.
undefinedStatus → const Reservation_Status
A value indicating that the enum field is not set.
updating → const Reservation_Status
Reservation update is in progress.