Reservations class final

The Reservations API.

Implementers

Constructors

Reservations({required Client client, Uri? endPoint, String? gcclVersion})
Creates a Reservations using client for transport.
Reservations.fromApiKey([String? apiKey])
Creates a Reservations that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(AggregatedListReservationsRequest request) Future<ReservationAggregatedList>
Retrieves an aggregated list of reservations.
close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteReservationRequest request) Future<Operation>
Deletes the specified reservation.
get(GetReservationRequest request) Future<Reservation>
Retrieves information about the specified reservation.
getIamPolicy(GetIamPolicyReservationRequest request) Future<Policy>
Gets the access control policy for a resource. May be empty if no such policy or resource exists.
insert(InsertReservationRequest request) Future<Operation>
Creates a new reservation. For more information, readReserving zonal resources.
list(ListReservationsRequest request) Future<ReservationList>
A list of all the reservations that have been configured for the specified project in specified zone.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
performMaintenance(PerformMaintenanceReservationRequest request) Future<Operation>
Perform maintenance on an extended reservation
resize(ResizeReservationRequest request) Future<Operation>
Resizes the reservation (applicable to standalone reservations only). For more information, readModifying reservations.
setIamPolicy(SetIamPolicyReservationRequest request) Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy.
testIamPermissions(TestIamPermissionsReservationRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
toString() String
A string representation of this object.
inherited
update(UpdateReservationRequest request) Future<Operation>
Update share settings of the reservation.

Operators

operator ==(Object other) bool
The equality operator.
inherited