ReservationsBlocksPerformMaintenanceRequest class
final
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
maintenanceScope
→ String?
-
Specifies if all, running or unused hosts are in scope for this request.
Check the MaintenanceScope enum for the list of possible values.
final
-
qualifiedName
→ String
-
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or google.rpc.ErrorInfo.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited