ResizeInstanceGroupManagerRequest class final

A request message for InstanceGroupManagers.Resize. See the method description for details.

Constructors

ResizeInstanceGroupManagerRequest({required String instanceGroupManager, required String project, String? requestId, required int size, required String zone})
ResizeInstanceGroupManagerRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
instanceGroupManager String
The name of the managed instance group.
final
project String
Project ID for this request.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requestId String?
An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
The number of running instances that the managed instance group should maintain at any given time. The group automatically adds or removes instances to maintain the number of instances specified by this parameter.
final
zone String
The name of thezone where the managed instance group is located.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String