ResourceMetadata class final
Standardized resource metadata common to all compute resources.
Constructors
- ResourceMetadata({String? apiVersion, String? resourceType})
- ResourceMetadata.fromJson(Object? j)
-
factory
Properties
- apiVersion → String?
-
The version of the API interface that this resource was retrieved through.
For example,
"2025-01-01"or"2025-01-01-preview".final - hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - resourceType → String?
-
The canonical resource type name in the format of a resource type
as defined by AIP-123.
For example,
"compute.googleapis.com/Instance".final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String