ResourcePolicyInstanceSchedulePolicy class final
An InstanceSchedulePolicy specifies when and how frequent certain operations are performed on the instance.
Constructors
- ResourcePolicyInstanceSchedulePolicy({String? expirationTime, String? startTime, String? timeZone, ResourcePolicyInstanceSchedulePolicySchedule? vmStartSchedule, ResourcePolicyInstanceSchedulePolicySchedule? vmStopSchedule})
- ResourcePolicyInstanceSchedulePolicy.fromJson(Object? j)
-
factory
Properties
- expirationTime → String?
-
The expiration time of the schedule. The timestamp is an RFC3339 string.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startTime → String?
-
The start time of the schedule. The timestamp is an RFC3339 string.
final
- timeZone → String?
-
Specifies the time zone to be used in interpreting Schedule.schedule.
The value of this field must be a time zone name from the tz database:
https://wikipedia.org/wiki/Tz_database.
final
- vmStartSchedule → ResourcePolicyInstanceSchedulePolicySchedule?
-
Specifies the schedule for starting instances.
final
- vmStopSchedule → ResourcePolicyInstanceSchedulePolicySchedule?
-
Specifies the schedule for stopping instances.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String