ResourcePolicyResourceStatus class final
Contains output only fields. Use this sub-message for all output fields set on ResourcePolicy. The internal structure of this "status" field should mimic the structure of ResourcePolicy proto specification.
Constructors
- ResourcePolicyResourceStatus({ResourcePolicyResourceStatusInstanceSchedulePolicyStatus? instanceSchedulePolicy})
- ResourcePolicyResourceStatus.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- instanceSchedulePolicy → ResourcePolicyResourceStatusInstanceSchedulePolicyStatus?
-
Output only.
Output OnlySpecifies a set of output values reffering to the instance_schedule_policy system status. This field should have the same name as corresponding policy field.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String