ResourcePolicyResourceStatusInstanceSchedulePolicyStatus class
final
Properties
hashCode
→ int
The hash code for this object.
no setter inherited
lastRunStartTime
→ String ?
Output only. Output Only The last time the schedule successfully ran.
The timestamp is an RFC3339 string.
final
nextRunStartTime
→ String ?
Output only. Output Only The next time the schedule is planned to run.
The actual time might be slightly different.
The timestamp is an RFC3339 string.
final
qualifiedName
→ String
The fully qualified name of this message, i.e., google.protobuf.Duration
or google.rpc.ErrorInfo.
final inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
google_cloud_compute_v1 0.1.1