ResourceStatus class final
Contains output only fields. Use this sub-message for actual values set on Instance attributes as compared to the value requested by the user (intent) in their instance CRUD calls.
Constructors
- ResourceStatus({ResourceStatusEffectiveInstanceMetadata? effectiveInstanceMetadata, String? physicalHost, ResourceStatusPhysicalHostTopology? physicalHostTopology, ResourceStatusReservationConsumptionInfo? reservationConsumptionInfo, ResourceStatusScheduling? scheduling, ResourceStatusShutdownDetails? shutdownDetails, UpcomingMaintenance? upcomingMaintenance})
- ResourceStatus.fromJson(Object? j)
-
factory
Properties
- effectiveInstanceMetadata → ResourceStatusEffectiveInstanceMetadata?
-
Output only.
Output OnlyEffective metadata is a field that consolidates project, zonal instance settings, and instance-level predefined metadata keys to provide the overridden value for those metadata keys at the instance level.final - hashCode → int
-
The hash code for this object.
no setterinherited
- physicalHost → String?
-
Output only.
Output OnlyThe precise location of your instance within the zone's data center, including the block, sub-block, and host. The field is formatted as follows: blockId/subBlockId/hostId.final - physicalHostTopology → ResourceStatusPhysicalHostTopology?
-
Output only.
Output OnlyA series of fields containing the global name of the Compute Engine cluster, as well as the ID of the block, sub-block, and host on which the running instance is located.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - reservationConsumptionInfo → ResourceStatusReservationConsumptionInfo?
-
Output only.
Output OnlyReservation information that the instance is consuming from.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scheduling → ResourceStatusScheduling?
-
final
- shutdownDetails → ResourceStatusShutdownDetails?
-
Output only.
Output OnlyDetails about the instance stopping state.final - upcomingMaintenance → UpcomingMaintenance?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String