effectiveInstanceMetadata property
Output only. Output Only Effective metadata is a field that consolidates project,
zonal instance settings, and instance-level predefined metadata keys to
provide the overridden value for those metadata keys at the instance level.
Implementation
final ResourceStatusEffectiveInstanceMetadata? effectiveInstanceMetadata;