ResourceStatusEffectiveInstanceMetadata class final

Effective values of predefined metadata keys for an instance.

Constructors

ResourceStatusEffectiveInstanceMetadata({bool? blockProjectSshKeysMetadataValue, bool? enableGuestAttributesMetadataValue, bool? enableOsInventoryMetadataValue, bool? enableOsconfigMetadataValue, bool? enableOsloginMetadataValue, bool? gceContainerDeclarationMetadataValue, bool? serialPortEnableMetadataValue, bool? serialPortLoggingEnableMetadataValue, String? vmDnsSettingMetadataValue})
ResourceStatusEffectiveInstanceMetadata.fromJson(Object? j)
factory

Properties

blockProjectSshKeysMetadataValue bool?
Effective block-project-ssh-keys value at Instance level.
final
enableGuestAttributesMetadataValue bool?
Effective enable-guest-attributes value at Instance level.
final
enableOsconfigMetadataValue bool?
Effective enable-osconfig value at Instance level.
final
enableOsInventoryMetadataValue bool?
Effective enable-os-inventory value at Instance level.
final
enableOsloginMetadataValue bool?
Effective enable-oslogin value at Instance level.
final
gceContainerDeclarationMetadataValue bool?
Effective gce-container-declaration value at Instance level.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serialPortEnableMetadataValue bool?
Effective serial-port-enable value at Instance level.
final
serialPortLoggingEnableMetadataValue bool?
Effective serial-port-logging-enable value at Instance level.
final
vmDnsSettingMetadataValue String?
Effective VM DNS setting at Instance level.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String