block property

String? block
final

Output Only The ID of the block in which the running instance is located. Instances within the same block experience low network latency.

Implementation

final String? block;