host property
Output Only The ID of the host on which the running instance is located.
Instances on the same host experience the lowest possible network
latency.
Implementation
final String? host;
Output Only The ID of the host on which the running instance is located.
Instances on the same host experience the lowest possible network
latency.
final String? host;