ResourceStatusPhysicalHostTopologyAdditionalAttributes class final
Additional location information of the running instance.
Constructors
-
ResourceStatusPhysicalHostTopologyAdditionalAttributes({Map<
String, String> acceleratorTopologyIds = const {}}) - ResourceStatusPhysicalHostTopologyAdditionalAttributes.fromJson(Object? j)
-
factory
Properties
-
acceleratorTopologyIds
→ Map<
String, String> -
Output only. The IDs of the accelerator topologies the instance belongs to. For
example
The key will be topologies like "4x4", "2x2x2" and the value will be
the location ID of the topologies.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String