ResourceStatusReservationConsumptionInfo class final
Reservation consumption information that the instance is consuming from.
Constructors
- ResourceStatusReservationConsumptionInfo({String? consumedReservation, String? consumedReservationBlock, String? consumedReservationSubBlock})
- ResourceStatusReservationConsumptionInfo.fromJson(Object? j)
-
factory
Properties
- consumedReservation → String?
-
Output only.
Output OnlyThe full resource name of the reservation that this instance is consuming from.final - consumedReservationBlock → String?
-
Output only.
Output OnlyThe full resource name of the reservation block that this instance is consuming from.final - consumedReservationSubBlock → String?
-
Output only.
Output OnlyThe full resource name of the reservation sub-block that this instance is consuming from.final - hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String