ResourceStatusScheduling class
final
Properties
availabilityDomain
→ int ?
Specifies the availability domain to place the instance in. The value
must be a number between 1 and the number of availability domains
specified in the spread placement policy attached to the instance.
final
gracefulShutdownTimestamp
→ String ?
Output only. Specifies the timestamp, when the instance will start graceful shutdown
process, in RFC3339 text format.
final
hashCode
→ int
The hash code for this object.
no setter inherited
qualifiedName
→ String
The fully qualified name of this message, i.e., google.protobuf.Duration
or google.rpc.ErrorInfo.
final inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
terminationTimestamp
→ String ?
Time in future when the instance will be terminated inRFC3339 text format.
final
google_cloud_compute_v1 0.1.1