ResourceStatusShutdownDetails_StopState class final
Current stopping state of the instance.
Constructors
- ResourceStatusShutdownDetails_StopState(String value)
-
const
- ResourceStatusShutdownDetails_StopState.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const ResourceStatusShutdownDetails_StopState
- The default value for ResourceStatusShutdownDetails_StopState.
- pendingStop → const ResourceStatusShutdownDetails_StopState
- The instance is gracefully shutting down.
- stopping → const ResourceStatusShutdownDetails_StopState
- The instance is stopping.
- undefinedStopState → const ResourceStatusShutdownDetails_StopState
- A value indicating that the enum field is not set.