ResourceStatusShutdownDetails_TargetState class final
Target instance state.
Constructors
- ResourceStatusShutdownDetails_TargetState(String value)
-
const
- ResourceStatusShutdownDetails_TargetState.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const ResourceStatusShutdownDetails_TargetState
- The default value for ResourceStatusShutdownDetails_TargetState.
- deleted → const ResourceStatusShutdownDetails_TargetState
- The instance will be deleted.
- stopped → const ResourceStatusShutdownDetails_TargetState
- The instance will be stopped.
- undefinedTargetState → const ResourceStatusShutdownDetails_TargetState
- A value indicating that the enum field is not set.