Rollout class final

Rollout resource.

A Rollout is a specific instance of a RolloutPlan. It represents a single execution of a strategy to roll out a specific resource. It also provides APIs to interact with the rollout.

Constructors

Rollout({String? cancellationTime, String? completionTime, String? creationTimestamp, int? currentWaveNumber, String? description, String? etag, BigInt? id, String? kind, String? name, String? pauseTime, String? resumeTime, RolloutRolloutEntity? rolloutEntity, String? rolloutPlan, String? selfLink, String? selfLinkWithId, String? state, List<RolloutWaveDetails> waveDetails = const []})
Rollout.fromJson(Object? j)
factory

Properties

cancellationTime String?
Output only. The timestamp at which the Rollout was cancelled.
final
completionTime String?
Output only. The timestamp at which the Rollout was completed.
final
creationTimestamp String?
Output only. Output Only Creation timestamp inRFC3339 text format.
final
currentWaveNumber int?
Output only. The number of the currently running wave. Ex. 1
final
description String?
An optional description of this resource. Provide this property when you create the resource.
final
etag String?
Output only. etag of the Rollout Ex. abc1234
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output only. Output Only The unique identifier for the resource. This identifier is defined by the server.
final
kind String?
Output only. Output Only Type of the resource. Always compute#rollout for rollouts.
final
name String?
Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
pauseTime String?
Output only. The timestamp at which the Rollout was paused.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
resumeTime String?
Output only. The timestamp at which the Rollout was resumed.
final
rolloutEntity RolloutRolloutEntity?
Required. The resource being rolled out.
final
rolloutPlan String?
Required. Rollout Plan used to model the Rollout. Ex. compute.googleapis.com/v1/projects/1234/rolloutPlans/rp1
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output only. Output Only Server-defined fully-qualified URL for this resource.
final
selfLinkWithId String?
Output only. Output Only Server-defined URL for this resource's resource id.
final
state String?
Output only. The current state of the Rollout. Check the State enum for the list of possible values.
final
waveDetails List<RolloutWaveDetails>
Output only. Details about each wave of the rollout.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String