RolloutPlanWaveOrchestrationOptions class final
Options to control the pace of orchestration of a wave. These options are required only if the resource being rolled out follows the Orchestrated pattern.
Constructors
-
RolloutPlanWaveOrchestrationOptions({List<
RolloutPlanWaveOrchestrationOptionsDelay> delays = const [], int? maxConcurrentLocations, int? maxConcurrentResourcesPerLocation}) - RolloutPlanWaveOrchestrationOptions.fromJson(Object? j)
-
factory
Properties
-
delays
→ List<
RolloutPlanWaveOrchestrationOptionsDelay> -
Optional. Delays, if any, to be added between batches of projects. We allow
multiple Delays to be specified, letting users set separate delays
between batches of projects corresponding to different locations and
batches of projects corresponding to the same location.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxConcurrentLocations → int?
-
Optional. Maximum number of locations to be orchestrated in parallel.
final
- maxConcurrentResourcesPerLocation → int?
-
Optional. Maximum number of resources to be orchestrated per location in
parallel.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String