RolloutPlanWaveOrchestrationOptionsDelay class final
Options to control the delay, if any, between batches of projects.
Constructors
- RolloutPlanWaveOrchestrationOptionsDelay({String? delimiter, String? duration, String? type})
- RolloutPlanWaveOrchestrationOptionsDelay.fromJson(Object? j)
-
factory
Properties
- delimiter → String?
-
Optional. Controls whether the delay should only be added between batches of
projects corresponding to different locations, or also between
batches of projects corresponding to the same location.
final
- duration → String?
-
Optional. The duration of the delay, if any, to be added between batches of
projects. A zero duration corresponds to no delay.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String?
-
Optional. Controls whether the specified duration is to be added at the end of
each batch, or if the total processing time for each batch will be
padded if needed to meet the specified duration.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String