RolloutPlanWaveSelectorResourceHierarchySelector class final
Roll out to resources by Cloud Resource Manager resource hierarchy nodes such as projects, folders, orgs.
Constructors
-
RolloutPlanWaveSelectorResourceHierarchySelector({List<
String> includedFolders = const [], List<String> includedOrganizations = const [], List<String> includedProjects = const []}) - RolloutPlanWaveSelectorResourceHierarchySelector.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
includedFolders
→ List<
String> -
Optional. Format: "folders/{folder_id}"
final
-
includedOrganizations
→ List<
String> -
Optional. Format: "organizations/{organization_id}"
final
-
includedProjects
→ List<
String> -
Optional. Format: "projects/{project_id}"
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String