RolloutPlanWaveValidation class final
The validation to be performed before progressing to the next wave.
Constructors
- RolloutPlanWaveValidation({RolloutPlanWaveValidationTimeBasedValidationMetadata? timeBasedValidationMetadata, String? type})
- RolloutPlanWaveValidation.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeBasedValidationMetadata → RolloutPlanWaveValidationTimeBasedValidationMetadata?
-
Optional. Metadata required if type = "time".
final
- type → String?
-
Required. The type of the validation. If a type of validation is associated with
a metadata object, the appropriate metadata field mapping to the
validation type must be provided in the validation message. Possible
values are in quotes below alongside an explanation:
"manual": The system waits for an end-user approval API before
progressing to the next wave.
"time": The system waits for a user specified duration before
progressing to the next wave. TimeBasedValidation must be provided.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String