RolloutPlans class final
The RolloutPlans API.
- Implementers
Constructors
- RolloutPlans({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
RolloutPlansusingclientfor transport. - RolloutPlans.fromApiKey([String? apiKey])
-
Creates a
RolloutPlansthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteRolloutPlanRequest request) → Future< Operation> - Deletes a RolloutPlan.
-
get(
GetRolloutPlanRequest request) → Future< RolloutPlan> - Gets details of a single project-scoped RolloutPlan.
-
insert(
InsertRolloutPlanRequest request) → Future< Operation> - Creates a new RolloutPlan in a given project and location.
-
list(
ListRolloutPlansRequest request) → Future< RolloutPlansListResponse> - Lists RolloutPlans in a given project and location.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited