RolloutRolloutEntityOrchestratedEntity class final
This message is used if the resource type follows the Orchestrated integration model with ProgressiveRollout.
Constructors
- RolloutRolloutEntityOrchestratedEntity({String? conflictBehavior, String? orchestrationAction, String? orchestrationSource})
- RolloutRolloutEntityOrchestratedEntity.fromJson(Object? j)
-
factory
Properties
- conflictBehavior → String?
-
Required. Specifies the behavior of the Rollout if an out of band update is
detected in a project during a Rollout. It can be one of the following
values:
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- orchestrationAction → String?
-
Required. Orchestration action during the Rollout. It can be one of the following
values:
final
- orchestrationSource → String?
-
Required. Fully qualified resource name of the resource which contains the source
of truth of the configuration being rolled out across
locations/projects. For example, in the case of a global Rollout which
is applied across regions, this contains the name of the global
resource created by the user which contains a payload for a resource
that is orchestrated across regions. This follows the following format:
//.googleapis.com/projects//locations/global//
e.g.
//osconfig.googleapis.com/projects/1/locations/global/policyOrchestrators/po1
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String