conflictBehavior property
Required. Specifies the behavior of the Rollout if an out of band update is detected in a project during a Rollout. It can be one of the following values:
- overwrite : Overwrite the local value with the rollout value.
- no_overwrite : Do not overwrite the local value with the rollout value.
Implementation
final String? conflictBehavior;