RolloutWaveDetails class final
Additional metadata about the status of each wave provided by the server.
Constructors
- RolloutWaveDetails({RolloutWaveDetailsOrchestratedWaveDetails? orchestratedWaveDetails, String? waveDisplayName, int? waveNumber})
- RolloutWaveDetails.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- orchestratedWaveDetails → RolloutWaveDetailsOrchestratedWaveDetails?
-
Output only. Additional details of the wave for products using the Orchestrated
Integration model.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- waveDisplayName → String?
-
Output only. Wave name.
Ex. wave1
final
- waveNumber → int?
-
Output only. System generated number for the wave.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String