Rollout_State class final
Output only. The current state of the Rollout.
Constructors
- Rollout_State(String value)
-
const
- Rollout_State.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const Rollout_State
- The default value for Rollout_State.
- cancelFailed → const Rollout_State
- An attempted cancel operation was unsuccessful.
- cancelled → const Rollout_State
- The rollout is in a failure terminal state.
- cancelling → const Rollout_State
- The rollout is being cancelled.
- completed → const Rollout_State
- The rollout is in a successful terminal state.
- completeFailed → const Rollout_State
- An attempted complete operation was unsuccessful.
- completing → const Rollout_State
- The rollout is being marked as completed.
- failed → const Rollout_State
- The rollout completed with failures.
- paused → const Rollout_State
- The rollout is paused.
- pauseFailed → const Rollout_State
- An attempted pause operation was unsuccessful.
- pausing → const Rollout_State
- The rollout is being paused.
- processing → const Rollout_State
- A wave is being processed by the product.
- ready → const Rollout_State
- The rollout has been successfully initialized and is ready to start.
- resuming → const Rollout_State
- The rollout is being resumed after being paused.
- rollbackWaveFailed → const Rollout_State
- An attempted rollback operation failed to complete successfully.
- rollingBack → const Rollout_State
- A wave rollback is in progress for this rollout.
- stateUnspecified → const Rollout_State
- Undefined default state. Should never be exposed to users.
- undefinedState → const Rollout_State
- A value indicating that the enum field is not set.
- uninitialized → const Rollout_State
- The rollout has been created but is not yet ready to be started.
- waveFailed → const Rollout_State
- The product failed to process the wave.