Rollouts class final
The Rollouts API.
- Implementers
Constructors
- Rollouts({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
Rolloutsusingclientfor transport. - Rollouts.fromApiKey([String? apiKey])
-
Creates a
Rolloutsthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
advance(
AdvanceRolloutRequest request) → Future< Operation> - Advances a Rollout to the next wave, or completes it if no waves remain.
-
cancel(
CancelRolloutRequest request) → Future< Operation> - Cancels a Rollout.
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteRolloutRequest request) → Future< Operation> - Deletes a Rollout.
-
get(
GetRolloutRequest request) → Future< Rollout> - Gets details of a single project-scoped Rollout.
-
list(
ListRolloutsRequest request) → Future< RolloutsListResponse> - Lists Rollouts in a given project and location.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pause(
PauseRolloutRequest request) → Future< Operation> - Pauses a Rollout.
-
resume(
ResumeRolloutRequest request) → Future< Operation> - Resumes a Rollout.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited