Route_NextHopOrigin class final

Output only. Output Only Indicates the origin of the route. Can be IGP (Interior Gateway Protocol), EGP (Exterior Gateway Protocol), or INCOMPLETE.

Constructors

Route_NextHopOrigin(String value)
const
Route_NextHopOrigin.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const Route_NextHopOrigin
The default value for Route_NextHopOrigin.
egp → const Route_NextHopOrigin
igp → const Route_NextHopOrigin
incomplete → const Route_NextHopOrigin
undefinedNextHopOrigin → const Route_NextHopOrigin
A value indicating that the enum field is not set.