User-specified list of individual IP ranges to advertise in custom mode.
This field can only be populated if advertise_mode is CUSTOM and
overrides the list defined for the router (in the "bgp" message).
These IP ranges are advertised in addition to any specified groups.
Leave this field blank to advertise no custom IP ranges.
The priority of routes advertised to this BGP peer. Where there is more
than one matching route of maximum length, the routes with the lowest
priority value win.
The user-defined custom learned route priority for a BGP session. This
value is applied to all custom learned route ranges for the session.
You can choose a value from 0 to 65335. If you don't provide a
value, Google Cloud assigns a priority of 100 to the ranges.
List of export policies applied to this peer, in the order they must be
evaluated. The name must correspond to an existing policy that has
ROUTE_POLICY_TYPE_EXPORT type.
List of import policies applied to this peer, in the order they must be
evaluated. The name must correspond to an existing policy that has
ROUTE_POLICY_TYPE_IMPORT type.
Present if MD5 authentication is enabled for the peering. Must be the
name of one of the entries in the Router.md5_authentication_keys. The
field must comply with RFC1035.
Name of this BGP peer.
The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63
characters long and match the regular expression
[a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a
lowercase letter, and all following characters must be a dash, lowercase
letter, or digit, except the last character, which cannot be a dash.
URI of the VM instance that is used as third-party router
appliances such as Next Gen Firewalls, Virtual Routers, or Router
Appliances. The VM instance must be located in zones contained in the
same region as this Cloud Router.
The VM instance is the peer side of the BGP session.