RouterBgp_AdvertiseMode class final
User-specified flag to indicate which mode to use for advertisement. The options are DEFAULT or CUSTOM.
Constructors
- RouterBgp_AdvertiseMode(String value)
-
const
- RouterBgp_AdvertiseMode.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const RouterBgp_AdvertiseMode
- The default value for RouterBgp_AdvertiseMode.
- custom → const RouterBgp_AdvertiseMode
- default$ → const RouterBgp_AdvertiseMode
- undefinedAdvertiseMode → const RouterBgp_AdvertiseMode
- A value indicating that the enum field is not set.