linkedInterconnectAttachment property
URI of the linked Interconnect attachment. It must be in the same region as the router. Each interface can have one linked resource, which can be a VPN tunnel, an Interconnect attachment, or a subnetwork.
Implementation
final String? linkedInterconnectAttachment;