RouterNatRule class final

Constructors

RouterNatRule({RouterNatRuleAction? action, String? description, String? match, int? ruleNumber})
RouterNatRule.fromJson(Object? j)
factory

Properties

action RouterNatRuleAction?
The action to be enforced for traffic that matches this rule.
final
description String?
An optional description of this rule.
final
hashCode int
The hash code for this object.
no setterinherited
match String?
CEL expression that specifies the match condition that egress traffic from a VM is evaluated against. If it evaluates to true, the corresponding action is enforced.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
ruleNumber int?
An integer uniquely identifying a rule in the list. The rule number must be a positive value between 0 and 65000, and must be unique among rules within a NAT.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String