ruleNumber property

int? ruleNumber
final

An integer uniquely identifying a rule in the list. The rule number must be a positive value between 0 and 65000, and must be unique among rules within a NAT.

Implementation

final int? ruleNumber;