RouterNat_NatIpAllocateOption class final
Specify the NatIpAllocateOption, which can take one of the following values:
- MANUAL_ONLY: Uses only Nat IP addresses provided by customers. When there are not enough specified Nat IPs, the Nat service fails for new VMs.
- AUTO_ONLY: Nat IPs are allocated by Google Cloud Platform; customers can't specify any Nat IPs. When choosing AUTO_ONLY, then nat_ip should be empty.
Constructors
- RouterNat_NatIpAllocateOption(String value)
-
const
- RouterNat_NatIpAllocateOption.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const RouterNat_NatIpAllocateOption
- The default value for RouterNat_NatIpAllocateOption.
- autoOnly → const RouterNat_NatIpAllocateOption
- Nat IPs are allocated by GCP; customers can not specify any Nat IPs.
- manualOnly → const RouterNat_NatIpAllocateOption
- Only use Nat IPs provided by customers. When specified Nat IPs are not enough then the Nat service fails for new VMs.
- undefinedNatIpAllocateOption → const RouterNat_NatIpAllocateOption
- A value indicating that the enum field is not set.