RouterNat_SourceSubnetworkIpRangesToNat64 class final
Specify the Nat option for NAT64, which can take one of the following values:
- ALL_IPV6_SUBNETWORKS: All of the IP ranges in every Subnetwork are allowed to Nat.
- LIST_OF_IPV6_SUBNETWORKS: A list of Subnetworks are allowed to Nat (specified in the field nat64_subnetwork below)
The default is NAT64_OPTION_UNSPECIFIED. Note that if this field contains NAT64_ALL_V6_SUBNETWORKS no other Router.Nat section in this region can also enable NAT64 for any Subnetworks in this network. Other Router.Nat sections can still be present to enable NAT44 only.
Constructors
- RouterNat_SourceSubnetworkIpRangesToNat64(String value)
-
const
- RouterNat_SourceSubnetworkIpRangesToNat64.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const RouterNat_SourceSubnetworkIpRangesToNat64
- The default value for RouterNat_SourceSubnetworkIpRangesToNat64.
- allIpv6Subnetworks → const RouterNat_SourceSubnetworkIpRangesToNat64
- NAT64 is enabled for all the IPv6 subnet ranges. In dual stack subnets, NAT64 will only be enabled for IPv6-only VMs.
- listOfIpv6Subnetworks → const RouterNat_SourceSubnetworkIpRangesToNat64
- NAT64 is enabled for a list of IPv6 subnet ranges. In dual stack subnets, NAT64 will only be enabled for IPv6-only VMs. If this option is used, the nat64_subnetworks field must be specified.
- undefinedSourceSubnetworkIpRangesToNat64 → const RouterNat_SourceSubnetworkIpRangesToNat64
- A value indicating that the enum field is not set.