RouterStatusBgpPeerStatus class
final
Constructors
RouterStatusBgpPeerStatus ({List <Route > advertisedRoutes = const [] , BfdStatus ? bfdStatus , bool ? enableIpv4 , bool ? enableIpv6 , String ? ipAddress , String ? ipv4NexthopAddress , String ? ipv6NexthopAddress , String ? linkedVpnTunnel , bool ? md5AuthEnabled , String ? name , int ? numLearnedRoutes , String ? peerIpAddress , String ? peerIpv4NexthopAddress , String ? peerIpv6NexthopAddress , String ? routerApplianceInstance , String ? state , String ? status , String ? statusReason , String ? uptime , String ? uptimeSeconds })
RouterStatusBgpPeerStatus.fromJson (Object ? j )
factory
Properties
advertisedRoutes
→ List <Route >
Routes that were advertised to the remote BGP peer
final
bfdStatus
→ BfdStatus ?
final
enableIpv4
→ bool ?
Output only. Enable IPv4 traffic over BGP Peer.
It is enabled by default if the peerIpAddress is version 4.
final
enableIpv6
→ bool ?
Output only. Enable IPv6 traffic over BGP Peer.
It is enabled by default if the peerIpAddress is version 6.
final
hashCode
→ int
The hash code for this object.
no setter inherited
ipAddress
→ String ?
Output only. IP address of the local BGP interface.
final
ipv4NexthopAddress
→ String ?
Output only. IPv4 address of the local BGP interface.
final
ipv6NexthopAddress
→ String ?
Output only. IPv6 address of the local BGP interface.
final
linkedVpnTunnel
→ String ?
Output only. URL of the VPN tunnel that this BGP peer controls.
final
md5AuthEnabled
→ bool ?
Informs whether MD5 authentication is enabled on this BGP peer.
final
name
→ String ?
Output only. Name of this BGP peer. Unique within the Routers resource.
final
numLearnedRoutes
→ int ?
Output only. Number of routes learned from the remote BGP Peer.
final
peerIpAddress
→ String ?
Output only. IP address of the remote BGP interface.
final
peerIpv4NexthopAddress
→ String ?
Output only. IPv4 address of the remote BGP interface.
final
peerIpv6NexthopAddress
→ String ?
Output only. IPv6 address of the remote BGP interface.
final
qualifiedName
→ String
The fully qualified name of this message, i.e., google.protobuf.Duration
or google.rpc.ErrorInfo.
final inherited
routerApplianceInstance
→ String ?
Output only. Output only URI of the VM instance that is used as third-party router
appliances such as Next Gen Firewalls, Virtual Routers, or Router
Appliances.
The VM instance is the peer side of the BGP session.
final
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
state
→ String ?
Output only. The state of the BGP session. For a list of possible values for this
field, seeBGP session states.
final
status
→ String ?
Output only. Status of the BGP peer: {UP, DOWN}
Check the Status enum for the list of possible values.
final
statusReason
→ String ?
Indicates why particular status was returned.
Check the StatusReason enum for the list of possible values.
final
uptime
→ String ?
Output only. Time this session has been up.
Format:
14 years, 51 weeks, 6 days, 23 hours, 59 minutes, 59 seconds
final
uptimeSeconds
→ String ?
Output only. Time this session has been up, in seconds.
Format:
145
final
google_cloud_compute_v1 0.1.0