RouterStatusNatStatus class final

Status of a NAT contained in this router.

Constructors

RouterStatusNatStatus({List<String> autoAllocatedNatIps = const [], List<String> drainAutoAllocatedNatIps = const [], List<String> drainUserAllocatedNatIps = const [], int? minExtraNatIpsNeeded, String? name, int? numVmEndpointsWithNatMappings, List<RouterStatusNatStatusNatRuleStatus> ruleStatus = const [], List<String> userAllocatedNatIpResources = const [], List<String> userAllocatedNatIps = const []})
RouterStatusNatStatus.fromJson(Object? j)
factory

Properties

autoAllocatedNatIps List<String>
Output only. A list of IPs auto-allocated for NAT. Example: "1.1.1.1", "129.2.16.89"
final
drainAutoAllocatedNatIps List<String>
Output only. A list of IPs auto-allocated for NAT that are in drain mode. Example: "1.1.1.1", "179.12.26.133".
final
drainUserAllocatedNatIps List<String>
Output only. A list of IPs user-allocated for NAT that are in drain mode. Example: "1.1.1.1", "179.12.26.133".
final
hashCode int
The hash code for this object.
no setterinherited
minExtraNatIpsNeeded int?
Output only. The number of extra IPs to allocate. This will be greater than 0 only if user-specified IPs are NOT enough to allow all configured VMs to use NAT. This value is meaningful only when auto-allocation of NAT IPs is not used.
final
name String?
Output only. Unique name of this NAT.
final
numVmEndpointsWithNatMappings int?
Output only. Number of VM endpoints (i.e., Nics) that can use NAT.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
ruleStatus List<RouterStatusNatStatusNatRuleStatus>
Status of rules in this NAT.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userAllocatedNatIpResources List<String>
Output only. A list of fully qualified URLs of reserved IP address resources.
final
userAllocatedNatIps List<String>
Output only. A list of IPs user-allocated for NAT. They will be raw IP strings like "179.12.26.133".
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String