RouterStatusNatStatusNatRuleStatus class final

Status of a NAT Rule contained in this NAT.

Constructors

RouterStatusNatStatusNatRuleStatus({List<String> activeNatIps = const [], List<String> drainNatIps = const [], int? minExtraIpsNeeded, int? numVmEndpointsWithNatMappings, int? ruleNumber})
RouterStatusNatStatusNatRuleStatus.fromJson(Object? j)
factory

Properties

activeNatIps List<String>
Output only. A list of active IPs for NAT. Example: "1.1.1.1", "179.12.26.133".
final
drainNatIps List<String>
Output only. A list of IPs for NAT that are in drain mode. Example: "1.1.1.1", "179.12.26.133".
final
hashCode int
The hash code for this object.
no setterinherited
minExtraIpsNeeded int?
Output only. The number of extra IPs to allocate. This will be greater than 0 only if the existing IPs in this NAT Rule are NOT enough to allow all configured VMs to use NAT.
final
numVmEndpointsWithNatMappings int?
Output only. Number of VM endpoints (i.e., NICs) that have NAT Mappings from this NAT Rule.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
ruleNumber int?
Output only. Rule number of the rule.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String