Routers class final
The Routers API.
- Implementers
Constructors
- Routers({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
Routersusingclientfor transport. - Routers.fromApiKey([String? apiKey])
-
Creates a
Routersthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
aggregatedList(
AggregatedListRoutersRequest request) → Future< RouterAggregatedList> - Retrieves an aggregated list of routers.
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteRouterRequest request) → Future< Operation> - Deletes the specified Router resource.
-
deleteNamedSet(
DeleteNamedSetRouterRequest request) → Future< Operation> - Deletes Named Set
-
deleteRoutePolicy(
DeleteRoutePolicyRouterRequest request) → Future< Operation> - Deletes Route Policy
-
get(
GetRouterRequest request) → Future< Router> - Returns the specified Router resource.
-
getNamedSet(
GetNamedSetRouterRequest request) → Future< RoutersGetNamedSetResponse> - Returns specified Named Set
-
getNatIpInfo(
GetNatIpInfoRouterRequest request) → Future< NatIpInfoResponse> - Retrieves runtime NAT IP information.
-
getNatMappingInfo(
GetNatMappingInfoRoutersRequest request) → Future< VmEndpointNatMappingsList> - Retrieves runtime Nat mapping information of VM endpoints.
-
getRoutePolicy(
GetRoutePolicyRouterRequest request) → Future< RoutersGetRoutePolicyResponse> - Returns specified Route Policy
-
getRouterStatus(
GetRouterStatusRouterRequest request) → Future< RouterStatusResponse> - Retrieves runtime information of the specified router.
-
insert(
InsertRouterRequest request) → Future< Operation> - Creates a Router resource in the specified project and region using the data included in the request.
-
list(
ListRoutersRequest request) → Future< RouterList> - Retrieves a list of Router resources available to the specified project.
-
listBgpRoutes(
ListBgpRoutesRoutersRequest request) → Future< RoutersListBgpRoutes> - Retrieves a list of router bgp routes available to the specified project.
-
listNamedSets(
ListNamedSetsRoutersRequest request) → Future< RoutersListNamedSets> - Retrieves a list of router named set subresources available to the specified project.
-
listRoutePolicies(
ListRoutePoliciesRoutersRequest request) → Future< RoutersListRoutePolicies> - Retrieves a list of router route policy subresources available to the specified project.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchRouterRequest request) → Future< Operation> - Patches the specified Router resource with the data included in the request. This method supportsPATCH semantics and usesJSON merge patch format and processing rules.
-
patchNamedSet(
PatchNamedSetRouterRequest request) → Future< Operation> - Patches Named Set
-
patchRoutePolicy(
PatchRoutePolicyRouterRequest request) → Future< Operation> - Patches Route Policy
-
preview(
PreviewRouterRequest request) → Future< RoutersPreviewResponse> - Preview fields auto-generated during router create andupdate operations. Calling this method does NOT create or update the router.
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
UpdateRouterRequest request) → Future< Operation> - Updates the specified Router resource with the data included in the request. This method conforms toPUT semantics, which requests that the state of the target resource be created or replaced with the state defined by the representation enclosed in the request message payload.
-
updateNamedSet(
UpdateNamedSetRouterRequest request) → Future< Operation> - Updates or creates new Named Set
-
updateRoutePolicy(
UpdateRoutePolicyRouterRequest request) → Future< Operation> - Updates or creates new Route Policy
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited