SavedAttachedDisk class final
DEPRECATED: Please use compute#savedDisk instead. An instance-attached disk resource.
Constructors
-
SavedAttachedDisk({bool? autoDelete, bool? boot, String? deviceName, CustomerEncryptionKey? diskEncryptionKey, int? diskSizeGb, String? diskType, List<
GuestOsFeature> guestOsFeatures = const [], int? index, String? interface, String? kind, List<String> licenses = const [], String? mode, String? source, int? storageBytes, String? storageBytesStatus, String? type}) - SavedAttachedDisk.fromJson(Object? j)
-
factory
Properties
- autoDelete → bool?
-
Specifies whether the disk will be auto-deleted when the instance is
deleted (but not when the disk is detached from the instance).
final
- boot → bool?
-
Indicates that this is a boot disk. The virtual machine will use the first
partition of the disk for its root filesystem.
final
- deviceName → String?
-
Specifies the name of the disk attached to the source instance.
final
- diskEncryptionKey → CustomerEncryptionKey?
-
The encryption key for the disk.
final
- diskSizeGb → int?
-
The size of the disk in base-2 GB.
final
- diskType → String?
-
Output only.
Output OnlyURL of the disk type resource. For example:projects/project/zones/zone/diskTypes/pd-standard or pd-ssdfinal -
guestOsFeatures
→ List<
GuestOsFeature> -
A list of features to enable on the guest operating system. Applicable only
for bootable images. Read
Enabling guest operating system features to see a list of available
options.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int?
-
Output only. Specifies zero-based index of the disk that is attached to the source
instance.
final
- interface → String?
-
Specifies the disk interface to use for attaching this disk, which is
either SCSI or NVME.
Check the Interface enum for the list of possible values.
final
- kind → String?
-
Output only.
Output OnlyType of the resource. Alwayscompute#attachedDisk for attached disks.final -
licenses
→ List<
String> -
Output only.
Output OnlyAny valid publicly visible licenses.final - mode → String?
-
The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY.
Check the Mode enum for the list of possible values.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → String?
-
Specifies a URL of the disk attached to the source instance.
final
- storageBytes → int?
-
Output only.
Output OnlyA size of the storage used by the disk's snapshot by this machine image.final - storageBytesStatus → String?
-
Output only.
Output OnlyAn indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be UPDATING, meaning the size of the snapshot is being updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date. Check the StorageBytesStatus enum for the list of possible values.final - type → String?
-
Specifies the type of the attached disk, either SCRATCH orPERSISTENT.
Check the Type enum for the list of possible values.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String