interface property
Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. Check the Interface enum for the list of possible values.
Implementation
final String? interface;
Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. Check the Interface enum for the list of possible values.
final String? interface;