mode property
The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. Check the Mode enum for the list of possible values.
Implementation
final String? mode;
The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. Check the Mode enum for the list of possible values.
final String? mode;