SavedAttachedDisk_Mode class final
The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY.
Constructors
- SavedAttachedDisk_Mode(String value)
-
const
- SavedAttachedDisk_Mode.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const SavedAttachedDisk_Mode
- The default value for SavedAttachedDisk_Mode.
- readOnly → const SavedAttachedDisk_Mode
- Attaches this disk in read-only mode. Multiple virtual machines can use a disk in read-only mode at a time.
- readWrite → const SavedAttachedDisk_Mode
-
DefaultAttaches this disk in read-write mode. Only one virtual machine at a time can be attached to a disk in read-write mode. - undefinedMode → const SavedAttachedDisk_Mode
- A value indicating that the enum field is not set.