lastStartTime property

String? lastStartTime
final

Output Only The last time the scaling schedule became active. Note: this is a timestamp when a schedule actually became active, not when it was planned to do so. The timestamp is in RFC3339 text format.

Implementation

final String? lastStartTime;