nextStartTime property
Output Only The next time the scaling schedule is to become active.
Note: this is a timestamp when a schedule is planned to run, but the actual
time might be slightly different.
The timestamp is in RFC3339
text format.
Implementation
final String? nextStartTime;