maxRunDuration property
Specifies the max run duration for the given instance. If specified, the instance termination action will be performed at the end of the run duration.
Implementation
final Duration? maxRunDuration;
Specifies the max run duration for the given instance. If specified, the instance termination action will be performed at the end of the run duration.
final Duration? maxRunDuration;