terminationTime property

String? terminationTime
final

Specifies the timestamp, when the instance will be terminated, inRFC3339 text format. If specified, the instance termination action will be performed at the termination time.

Implementation

final String? terminationTime;