Scheduling_InstanceTerminationAction class final

Specifies the termination action for the instance.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const Scheduling_InstanceTerminationAction
The default value for Scheduling_InstanceTerminationAction.
delete → const Scheduling_InstanceTerminationAction
Delete the VM.
instanceTerminationActionUnspecified → const Scheduling_InstanceTerminationAction
Default value. This value is unused.
stop → const Scheduling_InstanceTerminationAction
Stop the VM without storing in-memory content. default action.
undefinedInstanceTerminationAction → const Scheduling_InstanceTerminationAction
A value indicating that the enum field is not set.