region property
Output only. Output Only URL of the region where the regional security policy
resides. This field is not applicable to global security policies.
Implementation
final String? region;
Output only. Output Only URL of the region where the regional security policy
resides. This field is not applicable to global security policies.
final String? region;