SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig class final
Configuration options for L7 DDoS detection. This field is only supported in Global Security Policies of type CLOUD_ARMOR.
Constructors
-
SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig({bool? enable, String? ruleVisibility, List<
SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig> thresholdConfigs = const []}) - SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig.fromJson(Object? j)
-
factory
Properties
- enable → bool?
-
If set to true, enables CAAP for L7 DDoS detection.
This field is only supported in Global Security Policies of type
CLOUD_ARMOR.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - ruleVisibility → String?
-
Rule visibility can be one of the following:
STANDARD - opaque rules. (default)
PREMIUM - transparent rules.
This field is only supported in Global Security Policies of type
CLOUD_ARMOR.
Check the RuleVisibility enum for the list of possible values.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
thresholdConfigs
→ List<
SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig> -
Configuration options for layer7 adaptive protection for various
customizable thresholds.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String