SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig class final
Constructors
-
SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig({double? autoDeployConfidenceThreshold, int? autoDeployExpirationSec, double? autoDeployImpactedBaselineThreshold, double? autoDeployLoadThreshold, double? detectionAbsoluteQps, double? detectionLoadThreshold, double? detectionRelativeToBaselineQps, String? name, List<
SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig> trafficGranularityConfigs = const []}) - SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig.fromJson(Object? j)
-
factory
Properties
- autoDeployConfidenceThreshold → double?
-
final
- autoDeployExpirationSec → int?
-
final
- autoDeployImpactedBaselineThreshold → double?
-
final
- autoDeployLoadThreshold → double?
-
final
- detectionAbsoluteQps → double?
-
final
- detectionLoadThreshold → double?
-
final
- detectionRelativeToBaselineQps → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String?
-
The name must be 1-63 characters long, and comply withRFC1035.
The name must be unique within the security policy.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
trafficGranularityConfigs
→ List<
SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig> -
Configuration options for enabling Adaptive Protection to operate
on specified granular traffic units.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String