SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig class final
Configurations to specifc granular traffic units processed by Adaptive Protection.
Constructors
- SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig({bool? enableEachUniqueValue, String? type, String? value})
- SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig.fromJson(Object? j)
-
factory
Properties
- enableEachUniqueValue → bool?
-
If enabled, traffic matching each unique value for the specified
type constitutes a separate traffic unit.
It can only be set to true if
valueis empty.final - hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String?
-
Type of this configuration.
Check the Type enum for the list of possible values.
final
- value → String?
-
Requests that match this value constitute a granular traffic unit.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String