enableEachUniqueValue property
If enabled, traffic matching each unique value for the specified
type constitutes a separate traffic unit.
It can only be set to true if value is empty.
Implementation
final bool? enableEachUniqueValue;
If enabled, traffic matching each unique value for the specified
type constitutes a separate traffic unit.
It can only be set to true if value is empty.
final bool? enableEachUniqueValue;