SecurityPolicyAdvancedOptionsConfig class
final
Properties
hashCode
→ int
The hash code for this object.
no setter inherited
jsonCustomConfig
→ SecurityPolicyAdvancedOptionsConfigJsonCustomConfig ?
Custom configuration to apply the JSON parsing. Only applicable when
json_parsing is set to STANDARD.
final
jsonParsing
→ String ?
Check the JsonParsing enum for the list of possible values.
final
logLevel
→ String ?
Check the LogLevel enum for the list of possible values.
final
qualifiedName
→ String
The fully qualified name of this message, i.e., google.protobuf.Duration
or google.rpc.ErrorInfo.
final inherited
requestBodyInspectionSize
→ String ?
The maximum request size chosen by the customer with Waf enabled.
Values supported are "8KB", "16KB, "32KB", "48KB" and "64KB".
Values are case insensitive.
final
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
An optional list of case-insensitive request header names to use for
resolving the callers client IP address.
final
google_cloud_compute_v1 0.1.0