SecurityPolicyAssociation class
final
Properties
-
attachmentId
→ String?
-
The resource that the security policy is attached to.
final
-
displayName
→ String?
-
Output only.
Output Only The display name of the security policy of the association.
final
-
excludedFolders
→ List<String>
-
A list of folders to exclude from the security policy.
final
-
excludedProjects
→ List<String>
-
A list of projects to exclude from the security policy.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
name
→ String?
-
The name for an association.
final
-
qualifiedName
→ String
-
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or google.rpc.ErrorInfo.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
securityPolicyId
→ String?
-
Output only.
Output Only The security policy ID of the association.
final
-
shortName
→ String?
-
Output only.
Output Only The short name of the security policy of the association.
final