SecurityPolicyRulePreconfiguredWafConfigExclusion class final
Constructors
-
SecurityPolicyRulePreconfiguredWafConfigExclusion({List<
SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams> requestCookiesToExclude = const [], List<SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams> requestHeadersToExclude = const [], List<SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams> requestQueryParamsToExclude = const [], List<SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams> requestUrisToExclude = const [], List<String> targetRuleIds = const [], String? targetRuleSet}) - SecurityPolicyRulePreconfiguredWafConfigExclusion.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited -
requestCookiesToExclude
→ List<
SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams> -
A list of request cookie names whose value will be excluded from
inspection during preconfigured WAF evaluation.
final
-
requestHeadersToExclude
→ List<
SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams> -
A list of request header names whose value will be excluded from
inspection during preconfigured WAF evaluation.
final
-
requestQueryParamsToExclude
→ List<
SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams> -
A list of request query parameter names whose value will be excluded
from inspection during preconfigured WAF evaluation. Note that the
parameter can be in the query string or in the POST body.
final
-
requestUrisToExclude
→ List<
SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams> -
A list of request URIs from the request line to be excluded from
inspection during preconfigured WAF evaluation. When specifying this
field, the query or fragment part should be excluded.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
targetRuleIds
→ List<
String> -
A list of target rule IDs under the WAF rule set to apply the
preconfigured WAF exclusion. If omitted, it refers to all the rule
IDs under the WAF rule set.
final
- targetRuleSet → String?
-
Target WAF rule set to apply the preconfigured WAF exclusion.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String