menu
google_cloud_compute_v1 package
documentation
compute.dart
SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig class
SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig class
dark_mode
light_mode
SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig
class
final
Constructors
SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig
({
String
?
enforceOnKeyName
,
String
?
enforceOnKeyType
})
SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig.fromJson
(
Object
?
j
)
factory
Properties
enforceOnKeyName
→
String
?
Rate limit key name applicable only for the following key types: HTTP_HEADER -- Name of the HTTP header whose value is taken as the key value. HTTP_COOKIE -- Name of the HTTP cookie whose value is taken as the key value.
final
enforceOnKeyType
→
String
?
Determines the key to enforce the rate_limit_threshold on. Possible values are:
final
hashCode
→
int
The hash code for this object.
no setter
inherited
qualifiedName
→
String
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or
google.rpc.ErrorInfo
.
final
inherited
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson
(
)
→
Object
toString
(
)
→
String
A string representation of this object.
override
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
Constants
fullyQualifiedName
→ const
String
google_cloud_compute_v1 package
documentation
compute
SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig class
compute library