SecuritySettings class final
The authentication and authorization settings for a BackendService.
Constructors
-
SecuritySettings({Awsv4Signature? awsV4Authentication, String? clientTlsPolicy, List<
String> subjectAltNames = const []}) - SecuritySettings.fromJson(Object? j)
-
factory
Properties
- awsV4Authentication → Awsv4Signature?
-
The configuration needed to generate a signature for access to private
storage buckets that support AWS's Signature Version 4 for authentication.
Allowed only for INTERNET_IP_PORT and INTERNET_FQDN_PORT NEG backends.
final
- clientTlsPolicy → String?
-
Optional. A URL referring to a networksecurity.ClientTlsPolicy resource
that describes how clients should authenticate with this service's
backends.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subjectAltNames
→ List<
String> -
Optional. A list of Subject Alternative Names (SANs) that the client
verifies during a mutual TLS handshake with an server/endpoint for thisBackendService. When the server presents its X.509 certificate
to the client, the client inspects the certificate'ssubjectAltName field. If the field contains one of the
specified values, the communication continues. Otherwise, it fails. This
additional check enables the client to verify that the server is authorized
to run the requested service.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String