ServiceAttachmentConnectedEndpoint_Status class final
The status of a connected endpoint to this service attachment.
Constructors
- ServiceAttachmentConnectedEndpoint_Status(String value)
-
const
- ServiceAttachmentConnectedEndpoint_Status.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const ServiceAttachmentConnectedEndpoint_Status
- The default value for ServiceAttachmentConnectedEndpoint_Status.
- accepted → const ServiceAttachmentConnectedEndpoint_Status
- The connection has been accepted by the producer.
- closed → const ServiceAttachmentConnectedEndpoint_Status
- The connection has been closed by the producer.
- needsAttention → const ServiceAttachmentConnectedEndpoint_Status
- The connection has been accepted by the producer, but the producer needs to take further action before the forwarding rule can serve traffic.
- pending → const ServiceAttachmentConnectedEndpoint_Status
- The connection is pending acceptance by the producer.
- rejected → const ServiceAttachmentConnectedEndpoint_Status
- The consumer is still connected but not using the connection.
- statusUnspecified → const ServiceAttachmentConnectedEndpoint_Status
- undefinedStatus → const ServiceAttachmentConnectedEndpoint_Status
- A value indicating that the enum field is not set.