ServiceAttachmentConsumerProjectLimit class
final
Properties
-
connectionLimit
→ int?
-
The value of the limit to set. For endpoint_url, the limit should be no
more than 1.
final
-
endpointUrl
→ String?
-
The URL for the PSC endpoint to accept
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
networkUrl
→ String?
-
The network URL for the network to set the limit for.
final
-
projectIdOrNum
→ String?
-
The project id or number for the project to set the limit for.
final
-
qualifiedName
→ String
-
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or google.rpc.ErrorInfo.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited