ServiceAttachment_ConnectionPreference class final
The connection preference of service attachment. The value can be set to ACCEPT_AUTOMATIC. An ACCEPT_AUTOMATIC service attachment is one that always accepts the connection from consumer forwarding rules.
Constructors
- ServiceAttachment_ConnectionPreference(String value)
-
const
- ServiceAttachment_ConnectionPreference.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const ServiceAttachment_ConnectionPreference
- The default value for ServiceAttachment_ConnectionPreference.
- acceptAutomatic → const ServiceAttachment_ConnectionPreference
- acceptManual → const ServiceAttachment_ConnectionPreference
- connectionPreferenceUnspecified → const ServiceAttachment_ConnectionPreference
- undefinedConnectionPreference → const ServiceAttachment_ConnectionPreference
- A value indicating that the enum field is not set.