state property
Output Only Status of the action, which can be one of the following:
PROPAGATING, PROPAGATED, ABANDONED, FAILED, or DONE.
Check the State enum for the list of possible values.
Implementation
final String? state;
Output Only Status of the action, which can be one of the following:
PROPAGATING, PROPAGATED, ABANDONED, FAILED, or DONE.
Check the State enum for the list of possible values.
final String? state;