ShieldedInstanceIdentity class final
A Shielded Instance Identity.
Constructors
- ShieldedInstanceIdentity({ShieldedInstanceIdentityEntry? eccP256EncryptionKey, ShieldedInstanceIdentityEntry? eccP256SigningKey, ShieldedInstanceIdentityEntry? encryptionKey, String? kind, ShieldedInstanceIdentityEntry? signingKey})
- ShieldedInstanceIdentity.fromJson(Object? j)
-
factory
Properties
- eccP256EncryptionKey → ShieldedInstanceIdentityEntry?
-
An Endorsement Key (EK) made by the ECC P256 algorithm
issued to the Shielded Instance's vTPM.
final
- eccP256SigningKey → ShieldedInstanceIdentityEntry?
-
An Attestation Key (AK) made by the ECC P256 algorithm
issued to the Shielded Instance's vTPM.
final
- encryptionKey → ShieldedInstanceIdentityEntry?
-
An Endorsement Key (EK) made by the RSA 2048 algorithm
issued to the Shielded Instance's vTPM.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → String?
-
Output only.
Output OnlyType of the resource. Alwayscompute#shieldedInstanceIdentity for shielded Instance identity entry.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signingKey → ShieldedInstanceIdentityEntry?
-
An Attestation Key (AK) made by the RSA 2048 algorithm
issued to the Shielded Instance's vTPM.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String