autoCreated property
Output only. Output Only Set to true if snapshots are automatically created by
applying resource policy on the target disk.
Implementation
final bool? autoCreated;
Output only. Output Only Set to true if snapshots are automatically created by
applying resource policy on the target disk.
final bool? autoCreated;