sourceDiskId property
Output only. Output Only The ID value of the disk used to create this snapshot. This
value may be used to determine whether the snapshot was taken from the
current or a previous instance of a given disk name.
Implementation
final String? sourceDiskId;