SnapshotSettingsStorageLocationSettings_Policy class final
The chosen location policy.
Constructors
- SnapshotSettingsStorageLocationSettings_Policy(String value)
-
const
- SnapshotSettingsStorageLocationSettings_Policy.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const SnapshotSettingsStorageLocationSettings_Policy
- The default value for SnapshotSettingsStorageLocationSettings_Policy.
- localRegion → const SnapshotSettingsStorageLocationSettings_Policy
- Store snapshot in the same region as with the originating disk. No additional parameters are needed.
- nearestMultiRegion → const SnapshotSettingsStorageLocationSettings_Policy
- Store snapshot in the nearest multi region Cloud Storage bucket, relative to the originating disk. No additional parameters are needed.
- specificLocations → const SnapshotSettingsStorageLocationSettings_Policy
-
Store snapshot in the specific locations, as specified by the user.
The list of regions to store must be defined under the
locationsfield. - storageLocationPolicyUnspecified → const SnapshotSettingsStorageLocationSettings_Policy
- undefinedPolicy → const SnapshotSettingsStorageLocationSettings_Policy
- A value indicating that the enum field is not set.