specificLocations constant
SnapshotSettingsStorageLocationSettings_Policy
const specificLocations
Store snapshot in the specific locations, as specified by the user.
The list of regions to store must be defined under the locations
field.
Implementation
static const specificLocations =
SnapshotSettingsStorageLocationSettings_Policy('SPECIFIC_LOCATIONS');