Snapshot_StorageBytesStatus class final

Output only. Deprecated Instead, check the storageBytes field. After snapshot creation, the storageBytesStatus field is alwaysUP_TO_DATE. Output Only An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be unset, meaning the snapshot is being created, or UP_TO_DATE, meaning the size of the snapshot is up-to-date.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const Snapshot_StorageBytesStatus
The default value for Snapshot_StorageBytesStatus.
undefinedStorageBytesStatus → const Snapshot_StorageBytesStatus
A value indicating that the enum field is not set.
updating → const Snapshot_StorageBytesStatus
upToDate → const Snapshot_StorageBytesStatus