SourceInstanceParams class final
A specification of the parameters to use when creating the instance template from a source instance.
Constructors
-
SourceInstanceParams({List<
DiskInstantiationConfig> diskConfigs = const []}) - SourceInstanceParams.fromJson(Object? j)
-
factory
Properties
-
diskConfigs
→ List<
DiskInstantiationConfig> -
Attached disks configuration. If not provided, defaults are applied:
For boot disk and any other R/W disks, the source images for each disk
will be used. For read-only disks, they will be attached in read-only
mode. Local SSD disks will be created as blank volumes.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String