SourceInstanceProperties class final
DEPRECATED: Please use compute#instanceProperties instead. New properties will not be added to this field.
Constructors
-
SourceInstanceProperties({bool? canIpForward, bool? deletionProtection, String? description, List<
SavedAttachedDisk> disks = const [], List<AcceleratorConfig> guestAccelerators = const [], String? keyRevocationActionType, Map<String, String> labels = const {}, String? machineType, Metadata? metadata, String? minCpuPlatform, List<NetworkInterface> networkInterfaces = const [], String? postKeyRevocationActionType, Scheduling? scheduling, List<ServiceAccount> serviceAccounts = const [], Tags? tags}) - SourceInstanceProperties.fromJson(Object? j)
-
factory
Properties
- canIpForward → bool?
-
Enables instances created based on this machine image to send packets with
source IP addresses other than their own and receive packets with
destination IP addresses other than their own. If these instances will be
used as an IP gateway or it will be set as the next-hop in a Route
resource, specify true. If unsure, leave this set tofalse. See theEnable IP forwarding
documentation for more information.
final
- deletionProtection → bool?
-
Whether the instance created from this machine image should be protected
against deletion.
final
- description → String?
-
An optional text description for the instances that are created from this
machine image.
final
-
disks
→ List<
SavedAttachedDisk> -
An array of disks that are associated with the instances that are created
from this machine image.
final
-
guestAccelerators
→ List<
AcceleratorConfig> -
A list of guest accelerator cards' type and count to use for instances
created from this machine image.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyRevocationActionType → String?
-
KeyRevocationActionType of the instance. Supported options are "STOP" and
"NONE". The default value is "NONE" if it is not specified.
Check the KeyRevocationActionType enum for the list of possible values.
final
-
labels
→ Map<
String, String> -
Labels to apply to instances that are created from this machine image.
final
- machineType → String?
-
The machine type to use for instances that are created from this machine
image.
final
- metadata → Metadata?
-
The metadata key/value pairs to assign to instances that are created from
this machine image. These pairs can consist of custom metadata or
predefined keys. SeeProject and
instance metadata for more information.
final
- minCpuPlatform → String?
-
Minimum cpu/platform to be used by instances created from this machine
image. The instance may be scheduled on the specified or newer
cpu/platform. Applicable values are the friendly names of CPU platforms,
such as minCpuPlatform: "Intel Haswell" orminCpuPlatform: "Intel Sandy Bridge". For more
information, read Specifying a
Minimum CPU Platform.
final
-
networkInterfaces
→ List<
NetworkInterface> -
An array of network access configurations for this interface.
final
- postKeyRevocationActionType → String?
-
PostKeyRevocationActionType of the instance.
Check the PostKeyRevocationActionType enum for the list of possible values.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scheduling → Scheduling?
-
Specifies the scheduling options for the instances that are created from
this machine image.
final
-
serviceAccounts
→ List<
ServiceAccount> -
A list of service accounts with specified scopes. Access tokens for these
service accounts are available to the instances that are created from this
machine image. Use metadata queries to obtain the access tokens for these
instances.
final
-
A list of tags to apply to the instances that are created from this machine
image. The tags identify valid sources or targets for network firewalls.
The setTags method can modify this list of tags. Each tag within the list
must comply withRFC1035.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String