disks property
An array of disks that are associated with the instances that are created from this machine image.
Implementation
final List<SavedAttachedDisk> disks;
An array of disks that are associated with the instances that are created from this machine image.
final List<SavedAttachedDisk> disks;