SslCertificate class final
Represents an SSL certificate resource.
Google Compute Engine has two SSL certificate resources:
The global SSL certificates (sslCertificates) are used by:
- Global external Application Load Balancers
- Classic Application Load Balancers
- Proxy Network Load Balancers (with target SSL proxies)
The regional SSL certificates (regionSslCertificates) are used by:
- Regional external Application Load Balancers
- Regional internal Application Load Balancers
Optionally, certificate file contents that you upload can contain a set of up to five PEM-encoded certificates. The API call creates an object (sslCertificate) that holds this data. You can use SSL keys and certificates to secure connections to a load balancer. For more information, read Creating and using SSL certificates,SSL certificates quotas and limits, and Troubleshooting SSL certificates.
Constructors
-
SslCertificate({String? certificate, String? creationTimestamp, String? description, String? expireTime, BigInt? id, String? kind, SslCertificateManagedSslCertificate? managed, String? name, String? privateKey, String? region, String? selfLink, SslCertificateSelfManagedSslCertificate? selfManaged, List<
String> subjectAlternativeNames = const [], String? type}) - SslCertificate.fromJson(Object? j)
-
factory
Properties
- certificate → String?
-
A value read into memory from a certificate file. The certificate file must
be in PEM format. The certificate chain must be no greater than 5 certs
long. The chain must include at least one intermediate cert.
final
- creationTimestamp → String?
-
Output OnlyCreation timestamp inRFC3339 text format.final - description → String?
-
An optional description of this resource. Provide this property when you
create the resource.
final
- expireTime → String?
-
Output only.
Output OnlyExpire time of the certificate. RFC3339final - hashCode → int
-
The hash code for this object.
no setterinherited
- id → BigInt?
-
Output OnlyThe unique identifier for the resource. This identifier is defined by the server.final - kind → String?
-
Output only.
Output OnlyType of the resource. Alwayscompute#sslCertificate for SSL certificates.final - managed → SslCertificateManagedSslCertificate?
-
Configuration and status of a managed SSL certificate.
final
- name → String?
-
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression
[a-z]([-a-z0-9]*[a-z0-9])?which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.final - privateKey → String?
-
A value read into memory from a write-only private key file. The private
key file must be in PEM format. For security, only insert
requests include this field.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - region → String?
-
Output only.
Output OnlyURL of the region where the regional SSL Certificate resides. This field is not applicable to global SSL Certificate.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfLink → String?
-
Output onlyServer-defined URL for the resource.final - selfManaged → SslCertificateSelfManagedSslCertificate?
-
Configuration and status of a self-managed SSL certificate.
final
-
subjectAlternativeNames
→ List<
String> -
Output only.
Output OnlyDomains associated with the certificate via Subject Alternative Name.final - type → String?
-
(Optional) Specifies the type of SSL certificate, either "SELF_MANAGED" or
"MANAGED". If not specified, the certificate is self-managed and the fieldscertificate and private_key are used.
Check the Type enum for the list of possible values.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String