SslPolicies class final
The SslPolicies API.
- Implementers
Constructors
- SslPolicies({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
SslPoliciesusingclientfor transport. - SslPolicies.fromApiKey([String? apiKey])
-
Creates a
SslPoliciesthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
aggregatedList(
AggregatedListSslPoliciesRequest request) → Future< SslPoliciesAggregatedList> - Retrieves the list of all SslPolicy resources, regional and global, available to the specified project.
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteSslPolicyRequest request) → Future< Operation> - Deletes the specified SSL policy. The SSL policy resource can be deleted only if it is not in use by any TargetHttpsProxy or TargetSslProxy resources.
-
get(
GetSslPolicyRequest request) → Future< SslPolicy> - Lists all of the ordered rules present in a single specified policy.
-
insert(
InsertSslPolicyRequest request) → Future< Operation> - Returns the specified SSL policy resource.
-
list(
ListSslPoliciesRequest request) → Future< SslPoliciesList> - Lists all the SSL policies that have been configured for the specified project.
-
listAvailableFeatures(
ListAvailableFeaturesSslPoliciesRequest request) → Future< SslPoliciesListAvailableFeaturesResponse> - Lists all features that can be specified in the SSL policy when using custom profile.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchSslPolicyRequest request) → Future< Operation> - Patches the specified SSL policy with the data included in the request.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited