SslPolicy class final
Represents an SSL Policy resource.
Use SSL policies to control SSL features, such as versions and cipher suites, that are offered by Application Load Balancers and proxy Network Load Balancers. For more information, read SSL policies overview.
Constructors
-
SslPolicy({String? creationTimestamp, List<
String> customFeatures = const [], String? description, List<String> enabledFeatures = const [], String? fingerprint, BigInt? id, String? kind, String? minTlsVersion, String? name, String? postQuantumKeyExchange, String? profile, String? region, String? selfLink, List<Warnings> warnings = const []}) - SslPolicy.fromJson(Object? j)
-
factory
Properties
- creationTimestamp → String?
-
Output only.
Output OnlyCreation timestamp inRFC3339 text format.final -
customFeatures
→ List<
String> -
A list of features enabled when the selected profile is CUSTOM. The
method returns the set of features that can be
specified in this list. This field must be empty if the profile is notCUSTOM.
final
- description → String?
-
An optional description of this resource. Provide this property when you
create the resource.
final
-
enabledFeatures
→ List<
String> -
Output only.
Output OnlyThe list of features enabled in the SSL policy.final - fingerprint → String?
-
Fingerprint of this resource. A hash of the contents stored in this object.
This field is used in optimistic locking. This field will be ignored when
inserting a SslPolicy. An up-to-date fingerprint must be
provided in order to update the SslPolicy, otherwise the
request will fail with error 412 conditionNotMet.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → BigInt?
-
Output only.
Output OnlyThe unique identifier for the resource. This identifier is defined by the server.final - kind → String?
-
Output only.
Output onlyType of the resource. Alwayscompute#sslPolicyfor SSL policies.final - minTlsVersion → String?
-
The minimum version of SSL protocol that can be used by the clients to
establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field
must be set to RESTRICTED.
Check the MinTlsVersion enum for the list of possible values.
final
- name → String?
-
Name of the resource. The name must be 1-63 characters long, and comply
with RFC1035. Specifically, the name must be 1-63 characters
long and match the regular expression
[a-z]([-a-z0-9]*[a-z0-9])?which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.final - postQuantumKeyExchange → String?
-
One of DEFAULT, ENABLED, orDEFERRED. Controls whether the load balancer negotiates
X25519MLKEM768 key exchange when clients advertise support for it. When set
to DEFAULT, or if no SSL Policy is attached to the target
proxy, the load balancer disallows X25519MLKEM768 key exchange before
October 2026, and allows it afterward. When set to ENABLED,
the load balancer allows X25519MLKEM768 key exchange. When set toDEFERRED, the load balancer disallows X25519MLKEM768 key
exchange until October 2027, and allows it afterward.
Check the PostQuantumKeyExchange enum for the list of possible values.
final
- profile → String?
-
Profile specifies the set of SSL features that can be used by the load
balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in
the customFeatures field. If using FIPS_202205,
the min_tls_version field must be set to TLS_1_2.
Check the Profile enum for the list of possible values.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - region → String?
-
Output only.
Output OnlyURL of the region where the regional SSL policy resides. This field is not applicable to global SSL policies.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfLink → String?
-
Output only.
Output OnlyServer-defined URL for the resource.final -
warnings
→ List<
Warnings> -
Output only.
Output OnlyIf potential misconfigurations are detected for this SSL policy, this field will be populated with warning messages.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String