SslPolicy_MinTlsVersion class final
The minimum version of SSL protocol that can be used by the clients to establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field must be set to RESTRICTED.
Constructors
- SslPolicy_MinTlsVersion(String value)
-
const
- SslPolicy_MinTlsVersion.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const SslPolicy_MinTlsVersion
- The default value for SslPolicy_MinTlsVersion.
- tls10 → const SslPolicy_MinTlsVersion
- TLS 1.0
- tls11 → const SslPolicy_MinTlsVersion
- TLS 1.1
- tls12 → const SslPolicy_MinTlsVersion
- TLS 1.2
- tls13 → const SslPolicy_MinTlsVersion
- TLS 1.3
- undefinedMinTlsVersion → const SslPolicy_MinTlsVersion
- A value indicating that the enum field is not set.