SslPolicy_Profile class final
Profile specifies the set of SSL features that can be used by the load balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in the customFeatures field. If using FIPS_202205, the min_tls_version field must be set to TLS_1_2.
Constructors
- SslPolicy_Profile(String value)
-
const
- SslPolicy_Profile.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const SslPolicy_Profile
- The default value for SslPolicy_Profile.
- compatible → const SslPolicy_Profile
- Compatible profile. Allows the broadset set of clients, even those which support only out-of-date SSL features to negotiate with the load balancer.
- custom → const SslPolicy_Profile
- Custom profile. Allow only the set of allowed SSL features specified in the customFeatures field.
- fips202205 → const SslPolicy_Profile
- FIPS compatible profile. Supports a reduced set of SSL features, intended to meet FIPS 140-3 compliance requirements.
- modern → const SslPolicy_Profile
- Modern profile. Supports a wide set of SSL features, allowing modern clients to negotiate SSL with the load balancer.
- restricted → const SslPolicy_Profile
- Restricted profile. Supports a reduced set of SSL features, intended to meet stricter compliance requirements.
- undefinedProfile → const SslPolicy_Profile
- A value indicating that the enum field is not set.