StatefulPolicyPreservedState class final
Configuration of preserved resources.
Constructors
-
StatefulPolicyPreservedState({Map<
String, StatefulPolicyPreservedStateDiskDevice> disks = const {}, Map<String, StatefulPolicyPreservedStateNetworkIp> externalIPs = const {}, Map<String, StatefulPolicyPreservedStateNetworkIp> internalIPs = const {}}) - StatefulPolicyPreservedState.fromJson(Object? j)
-
factory
Properties
-
disks
→ Map<
String, StatefulPolicyPreservedStateDiskDevice> -
Disks created on the instances that will be preserved on instance
delete, update, etc. This map is keyed with the device names of
the disks.
final
-
externalIPs
→ Map<
String, StatefulPolicyPreservedStateNetworkIp> -
External network IPs assigned to the instances that will be preserved on
instance delete, update, etc. This map is keyed with the network
interface name.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
internalIPs
→ Map<
String, StatefulPolicyPreservedStateNetworkIp> -
Internal network IPs assigned to the instances that will be preserved on
instance delete, update, etc. This map is keyed with the network
interface name.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String