StoragePoolDisk class final

Constructors

StoragePoolDisk({List<String> attachedInstances = const [], String? creationTimestamp, String? disk, String? name, int? provisionedIops, int? provisionedThroughput, List<String> resourcePolicies = const [], int? sizeGb, String? status, String? type, int? usedBytes})
StoragePoolDisk.fromJson(Object? j)
factory

Properties

attachedInstances List<String>
Output only. Output Only Instances this disk is attached to.
final
creationTimestamp String?
Output only. Output Only Creation timestamp inRFC3339 text format.
final
disk String?
Output only. Output Only The URL of the disk.
final
hashCode int
The hash code for this object.
no setterinherited
name String?
Output only. Output Only The name of the disk.
final
provisionedIops int?
Output only. Output Only The number of IOPS provisioned for the disk.
final
provisionedThroughput int?
Output only. Output Only The throughput provisioned for the disk.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
resourcePolicies List<String>
Output only. Output Only Resource policies applied to disk for automatic snapshot creations.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizeGb int?
Output only. Output Only The disk size, in GB.
final
status String?
Output only. Output Only The disk status. Check the Status enum for the list of possible values.
final
type String?
Output only. Output Only The disk type.
final
usedBytes int?
Output only. Output Only Amount of disk space used.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String