SubnetworkSecondaryRange class final

Represents a secondary IP range of a subnetwork.

Constructors

SubnetworkSecondaryRange({String? ipCidrRange, String? ipCollection, String? ipVersion, String? rangeName, String? reservedInternalRange})
SubnetworkSecondaryRange.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ipCidrRange String?
The range of IP addresses belonging to this subnetwork secondary range. Provide this property when you create the subnetwork. Ranges must be unique and non-overlapping with all primary and secondary IP ranges within a network. Both IPv4 and IPv6 ranges are supported. For IPv4, the range can be any range listed in theValid ranges list.
final
ipCollection String?
Reference to a Public Delegated Prefix (PDP) for BYOIP. This field should be specified for configuring BYOGUA internal IPv6 secondary range. When specified along with the ip_cidr_range, the ip_cidr_range must lie within the PDP referenced by the ipCollection field. When specified without the ip_cidr_range, the range is auto-allocated from the PDP referenced by the ipCollection field.
final
ipVersion String?
Check the IpVersion enum for the list of possible values.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
rangeName String?
The name associated with this subnetwork secondary range, used when adding an alias IP/IPv6 range to a VM instance. The name must be 1-63 characters long, and comply withRFC1035. The name must be unique within the subnetwork.
final
reservedInternalRange String?
The URL of the reserved internal range. Only IPv4 is supported.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String