Subnetwork_Ipv6GceEndpoint class final
Output only. Output Only Possible endpoints of this subnetwork. It can be one of the
following:
- VM_ONLY: The subnetwork can be used for creating instances and IPv6 addresses with VM endpoint type. Such a subnetwork gets external IPv6 ranges from a public delegated prefix and cannot be used to create NetLb.
- VM_AND_FR: The subnetwork can be used for creating both VM instances and Forwarding Rules. It can also be used to reserve IPv6 addresses with both VM and FR endpoint types. Such a subnetwork gets its IPv6 range from Google IP Pool directly.
Constructors
- Subnetwork_Ipv6GceEndpoint(String value)
-
const
- Subnetwork_Ipv6GceEndpoint.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const Subnetwork_Ipv6GceEndpoint
- The default value for Subnetwork_Ipv6GceEndpoint.
- undefinedIpv6GceEndpoint → const Subnetwork_Ipv6GceEndpoint
- A value indicating that the enum field is not set.
- vmAndFr → const Subnetwork_Ipv6GceEndpoint
- vmOnly → const Subnetwork_Ipv6GceEndpoint