Subnetwork_PrivateIpv6GoogleAccess class final
This field is for internal use.
This field can be both set at resource creation time and updated usingpatch.
Constructors
- Subnetwork_PrivateIpv6GoogleAccess(String value)
-
const
- Subnetwork_PrivateIpv6GoogleAccess.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const Subnetwork_PrivateIpv6GoogleAccess
- The default value for Subnetwork_PrivateIpv6GoogleAccess.
- disableGoogleAccess → const Subnetwork_PrivateIpv6GoogleAccess
- Disable private IPv6 access to/from Google services.
- enableBidirectionalAccessToGoogle → const Subnetwork_PrivateIpv6GoogleAccess
- Bidirectional private IPv6 access to/from Google services.
- enableOutboundVmAccessToGoogle → const Subnetwork_PrivateIpv6GoogleAccess
- Outbound private IPv6 access from VMs in this subnet to Google services.
- undefinedPrivateIpv6GoogleAccess → const Subnetwork_PrivateIpv6GoogleAccess
- A value indicating that the enum field is not set.