Subnetwork_ResolveSubnetMask class final
Configures subnet mask resolution for this subnetwork.
Constructors
- Subnetwork_ResolveSubnetMask(String value)
-
const
- Subnetwork_ResolveSubnetMask.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const Subnetwork_ResolveSubnetMask
- The default value for Subnetwork_ResolveSubnetMask.
- arpAllRanges → const Subnetwork_ResolveSubnetMask
- All ranges assigned to the VM NIC will respond to ARP.
- arpPrimaryRange → const Subnetwork_ResolveSubnetMask
- Only the primary range of the VM NIC will respond to ARP.
- undefinedResolveSubnetMask → const Subnetwork_ResolveSubnetMask
- A value indicating that the enum field is not set.