arpBroadcastPrimaryRangeWithLearning constant
Subnetwork_ResolveSubnetMask
const arpBroadcastPrimaryRangeWithLearning
Combines ARP_BROADCAST_PRIMARY_RANGE with MAC learning. Enables cache mapping between IP addresses and custom MAC addresses of instances and use of it to set the correct destination MAC address. If this option is chosen, the subnetwork must have /24 or a smaller CIDR range.
Implementation
static const arpBroadcastPrimaryRangeWithLearning =
Subnetwork_ResolveSubnetMask('ARP_BROADCAST_PRIMARY_RANGE_WITH_LEARNING');