Subnetwork_State class final
Output only. Output Only The state of the subnetwork, which can be one of the
following values:READY: Subnetwork is created and ready to useDRAINING: only applicable to subnetworks that have the
purpose set to INTERNAL_HTTPS_LOAD_BALANCER and indicates that
connections to the load balancer are being drained. A subnetwork that is
draining cannot be used or modified until it reaches a status ofREADY
Constructors
- Subnetwork_State(String value)
-
const
- Subnetwork_State.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const Subnetwork_State
- The default value for Subnetwork_State.
- draining → const Subnetwork_State
- Subnetwork is being drained.
- ready → const Subnetwork_State
- Subnetwork is ready for use.
- undefinedState → const Subnetwork_State
- A value indicating that the enum field is not set.