Subnetworks class final
The Subnetworks API.
- Implementers
Constructors
- Subnetworks({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
Subnetworksusingclientfor transport. - Subnetworks.fromApiKey([String? apiKey])
-
Creates a
Subnetworksthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
aggregatedList(
AggregatedListSubnetworksRequest request) → Future< SubnetworkAggregatedList> - Retrieves an aggregated list of subnetworks.
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteSubnetworkRequest request) → Future< Operation> - Deletes the specified subnetwork.
-
expandIpCidrRange(
ExpandIpCidrRangeSubnetworkRequest request) → Future< Operation> - Expands the IP CIDR range of the subnetwork to a specified value.
-
get(
GetSubnetworkRequest request) → Future< Subnetwork> - Returns the specified subnetwork.
-
getIamPolicy(
GetIamPolicySubnetworkRequest request) → Future< Policy> - Gets the access control policy for a resource. May be empty if no such policy or resource exists.
-
insert(
InsertSubnetworkRequest request) → Future< Operation> - Creates a subnetwork in the specified project using the data included in the request.
-
list(
ListSubnetworksRequest request) → Future< SubnetworkList> - Retrieves a list of subnetworks available to the specified project.
-
listUsable(
ListUsableSubnetworksRequest request) → Future< UsableSubnetworksAggregatedList> - Retrieves an aggregated list of all usable subnetworks in the project.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchSubnetworkRequest request) → Future< Operation> - Patches the specified subnetwork with the data included in the request. Only certain fields can be updated with a patch request as indicated in the field descriptions. You must specify the current fingerprint of the subnetwork resource being patched.
-
setIamPolicy(
SetIamPolicySubnetworkRequest request) → Future< Policy> - Sets the access control policy on the specified resource. Replaces any existing policy.
-
setPrivateIpGoogleAccess(
SetPrivateIpGoogleAccessSubnetworkRequest request) → Future< Operation> - Set whether VMs in this subnet can access Google services without assigning external IP addresses through Private Google Access.
-
testIamPermissions(
TestIamPermissionsSubnetworkRequest request) → Future< TestPermissionsResponse> - Returns permissions that a caller has on the specified resource.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited