Subsetting_Policy class final

Constructors

Subsetting_Policy(String value)
const
Subsetting_Policy.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const Subsetting_Policy
The default value for Subsetting_Policy.
consistentHashSubsetting → const Subsetting_Policy
Subsetting based on consistent hashing.
none → const Subsetting_Policy
No Subsetting.
undefinedPolicy → const Subsetting_Policy
A value indicating that the enum field is not set.