consistentHashSubsetting constant
Subsetting_Policy
const consistentHashSubsetting
Subsetting based on consistent hashing.
For Traffic Director, the number of backends per backend group
(the subset size) is based on the subset_size parameter.
For Internal HTTP(S) load balancing, the number of backends per backend group (the subset size) is dynamically adjusted in two cases:
- As the number of proxy instances participating in Internal HTTP(S) load balancing increases, the subset size decreases.
- When the total number of backends in a network exceeds the capacity of a single proxy instance, subset sizes are reduced automatically for each service that has backend subsetting enabled.
Implementation
static const consistentHashSubsetting = Subsetting_Policy(
'CONSISTENT_HASH_SUBSETTING',
);