TargetHttpProxies class final
The TargetHttpProxies API.
- Implementers
Constructors
- TargetHttpProxies({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
TargetHttpProxiesusingclientfor transport. - TargetHttpProxies.fromApiKey([String? apiKey])
-
Creates a
TargetHttpProxiesthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
aggregatedList(
AggregatedListTargetHttpProxiesRequest request) → Future< TargetHttpProxyAggregatedList> - Retrieves the list of all TargetHttpProxy resources, regional and global, available to the specified project.
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteTargetHttpProxyRequest request) → Future< Operation> - Deletes the specified TargetHttpProxy resource.
-
get(
GetTargetHttpProxyRequest request) → Future< TargetHttpProxy> - Returns the specified TargetHttpProxy resource.
-
insert(
InsertTargetHttpProxyRequest request) → Future< Operation> - Creates a TargetHttpProxy resource in the specified project using the data included in the request.
-
list(
ListTargetHttpProxiesRequest request) → Future< TargetHttpProxyList> - Retrieves the list of TargetHttpProxy resources available to the specified project.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchTargetHttpProxyRequest request) → Future< Operation> - Patches the specified TargetHttpProxy resource with the data included in the request. This method supports PATCH semantics and usesJSON merge patch format and processing rules.
-
setUrlMap(
SetUrlMapTargetHttpProxyRequest request) → Future< Operation> - Changes the URL map for TargetHttpProxy.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited