region property
Output only. Output Only URL of the region where the regional Target HTTP Proxy
resides. This field is not applicable to global Target HTTP Proxies.
Implementation
final String? region;
Output only. Output Only URL of the region where the regional Target HTTP Proxy
resides. This field is not applicable to global Target HTTP Proxies.
final String? region;