TargetHttpsProxiesSetQuicOverrideRequest_QuicOverride class final
QUIC policy for the TargetHttpsProxy resource.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const TargetHttpsProxiesSetQuicOverrideRequest_QuicOverride
- The default value for TargetHttpsProxiesSetQuicOverrideRequest_QuicOverride.
- disable → const TargetHttpsProxiesSetQuicOverrideRequest_QuicOverride
- The load balancer will not attempt to negotiate QUIC with clients.
- enable → const TargetHttpsProxiesSetQuicOverrideRequest_QuicOverride
- The load balancer will attempt to negotiate QUIC with clients.
- none → const TargetHttpsProxiesSetQuicOverrideRequest_QuicOverride
- No overrides to the default QUIC policy. This option is implicit if no QUIC override has been specified in the request.
- undefinedQuicOverride → const TargetHttpsProxiesSetQuicOverrideRequest_QuicOverride
- A value indicating that the enum field is not set.