TargetHttpsProxy class final
Represents a Target HTTPS Proxy resource.
Google Compute Engine has two Target HTTPS Proxy resources:
A target HTTPS proxy is a component of Google Cloud HTTPS load balancers.
- targetHttpsProxies are used by global external Application Load Balancers, classic Application Load Balancers, cross-region internal Application Load Balancers, and Traffic Director.
- regionTargetHttpsProxies are used by regional internal Application Load Balancers and regional external Application Load Balancers.
Forwarding rules reference a target HTTPS proxy, and the target proxy then references a URL map. For more information, readUsing Target Proxies and Forwarding rule concepts.
Constructors
-
TargetHttpsProxy({String? authorizationPolicy, String? certificateMap, String? creationTimestamp, String? description, String? fingerprint, int? httpKeepAliveTimeoutSec, BigInt? id, String? kind, String? name, bool? proxyBind, String? quicOverride, String? region, String? selfLink, String? serverTlsPolicy, List<
String> sslCertificates = const [], String? sslPolicy, String? tlsEarlyData, String? urlMap}) - TargetHttpsProxy.fromJson(Object? j)
-
factory
Properties
-
Optional. A URL referring to a networksecurity.AuthorizationPolicy resource
that describes how the proxy should authorize inbound traffic. If left
blank, access will not be restricted by an authorization policy.
final
- certificateMap → String?
-
URL of a certificate map that identifies a certificate map associated with
the given target proxy.
This field can only be set for Global external Application Load Balancer or
Classic Application Load Balancer. For other products use Certificate
Manager Certificates instead.
final
- creationTimestamp → String?
-
Output only.
Output OnlyCreation timestamp inRFC3339 text format.final - description → String?
-
An optional description of this resource. Provide this property when you
create the resource.
final
- fingerprint → String?
-
Fingerprint of this resource. A hash of the contents stored in this object.
This field is used in optimistic locking. This field will be ignored when
inserting a TargetHttpsProxy. An up-to-date fingerprint must
be provided in order to patch the TargetHttpsProxy; otherwise, the request
will fail with error 412 conditionNotMet. To see the latest
fingerprint, make a get() request to retrieve the
TargetHttpsProxy.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpKeepAliveTimeoutSec → int?
-
Specifies how long to keep a connection open, after completing a response,
while there is no matching traffic (in seconds). If an HTTP keep-alive is
not specified, a default value (610 seconds) will be used.
final
- id → BigInt?
-
Output OnlyThe unique identifier for the resource. This identifier is defined by the server.final - kind → String?
-
Output only.
Output OnlyType of resource. Alwayscompute#targetHttpsProxy for target HTTPS proxies.final - name → String?
-
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression
[a-z]([-a-z0-9]*[a-z0-9])?which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.final - proxyBind → bool?
-
This field only applies when the forwarding rule that references this
target proxy has a loadBalancingScheme set toINTERNAL_SELF_MANAGED.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - quicOverride → String?
-
Specifies the QUIC override policy for this TargetHttpsProxy resource. This
setting determines whether the load balancer attempts to negotiate QUIC
with clients.
You can specify NONE, ENABLE, orDISABLE.
final
- region → String?
-
Output only.
Output OnlyURL of the region where the regional TargetHttpsProxy resides. This field is not applicable to global TargetHttpsProxies.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfLink → String?
-
Output OnlyServer-defined URL for the resource.final - serverTlsPolicy → String?
-
Optional. A URL referring to a networksecurity.ServerTlsPolicy resource
that describes how the proxy should authenticate inbound traffic.
final
-
sslCertificates
→ List<
String> -
URLs to SslCertificate resources that are used to authenticate
connections between users and the load balancer. At least one SSL
certificate must be specified. SslCertificates do not apply when the load
balancing scheme is set to INTERNAL_SELF_MANAGED.
final
- sslPolicy → String?
-
URL of SslPolicy resource that will be associated with the TargetHttpsProxy
resource. If not set, the TargetHttpsProxy resource has no
SSL policy configured.
final
- tlsEarlyData → String?
-
Specifies whether TLS 1.3 0-RTT Data ("Early Data") should be accepted
for this service. Early Data allows a TLS resumption handshake to include
the initial application payload (a HTTP request) alongside the handshake,
reducing the effective round trips to "zero". This applies to TLS 1.3
connections over TCP (HTTP/2) as well as over UDP (QUIC/h3).
final
- urlMap → String?
-
A fully-qualified or valid partial URL to the UrlMap resource that defines
the mapping from URL to the BackendService. For example, the following are
all valid URLs for specifying a URL map:
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String