natPolicy property

String? natPolicy
final

Must have a value of NO_NAT. Protocol forwarding delivers packets while preserving the destination IP address of the forwarding rule referencing the target instance. Check the NatPolicy enum for the list of possible values.

Implementation

final String? natPolicy;