TargetPool_SessionAffinity class final

Session affinity option, must be one of the following values: NONE: Connections from the same client IP may go to any instance in the pool. CLIENT_IP: Connections from the same client IP will go to the same instance in the pool while that instance remains healthy. CLIENT_IP_PROTO: Connections from the same client IP with the same IP protocol will go to the same instance in the pool while that instance remains healthy.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const TargetPool_SessionAffinity
The default value for TargetPool_SessionAffinity.
clientIp → const TargetPool_SessionAffinity
2-tuple hash on packet's source and destination IP addresses. Connections from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy.
clientIpNoDestination → const TargetPool_SessionAffinity
1-tuple hash only on packet's source IP address. Connections from the same source IP address will be served by the same backend VM while that VM remains healthy. This option can only be used for Internal TCP/UDP Load Balancing.
clientIpPortProto → const TargetPool_SessionAffinity
5-tuple hash on packet's source and destination IP addresses, IP protocol, and source and destination ports. Connections for the same IP protocol from the same source IP address and port to the same destination IP address and port will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing.
clientIpProto → const TargetPool_SessionAffinity
3-tuple hash on packet's source and destination IP addresses, and IP protocol. Connections for the same IP protocol from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing.
generatedCookie → const TargetPool_SessionAffinity
Hash based on a cookie generated by the L7 loadbalancer. Only valid for HTTP(S) load balancing.
headerField → const TargetPool_SessionAffinity
The hash is based on a user specified header field.
httpCookie → const TargetPool_SessionAffinity
The hash is based on a user provided cookie.
none → const TargetPool_SessionAffinity
No session affinity. Connections from the same client IP may go to any instance in the pool.
strongCookieAffinity → const TargetPool_SessionAffinity
Strong cookie-based affinity. Connections bearing the same cookie will be served by the same backend VM while that VM remains healthy, as long as the cookie has not expired.
undefinedSessionAffinity → const TargetPool_SessionAffinity
A value indicating that the enum field is not set.