TargetPools class final
The TargetPools API.
- Implementers
Constructors
- TargetPools({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
TargetPoolsusingclientfor transport. - TargetPools.fromApiKey([String? apiKey])
-
Creates a
TargetPoolsthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addHealthCheck(
AddHealthCheckTargetPoolRequest request) → Future< Operation> - Adds health check URLs to a target pool.
-
addInstance(
AddInstanceTargetPoolRequest request) → Future< Operation> - Adds an instance to a target pool.
-
aggregatedList(
AggregatedListTargetPoolsRequest request) → Future< TargetPoolAggregatedList> - Retrieves an aggregated list of target pools.
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteTargetPoolRequest request) → Future< Operation> - Deletes the specified target pool.
-
get(
GetTargetPoolRequest request) → Future< TargetPool> - Returns the specified target pool.
-
getHealth(
GetHealthTargetPoolRequest request) → Future< TargetPoolInstanceHealth> - Gets the most recent health check results for each IP for the instance that is referenced by the given target pool.
-
insert(
InsertTargetPoolRequest request) → Future< Operation> - Creates a target pool in the specified project and region using the data included in the request.
-
list(
ListTargetPoolsRequest request) → Future< TargetPoolList> - Retrieves a list of target pools available to the specified project and region.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeHealthCheck(
RemoveHealthCheckTargetPoolRequest request) → Future< Operation> - Removes health check URL from a target pool.
-
removeInstance(
RemoveInstanceTargetPoolRequest request) → Future< Operation> - Removes instance URL from a target pool.
-
setBackup(
SetBackupTargetPoolRequest request) → Future< Operation> - Changes a backup target pool's configurations.
-
setSecurityPolicy(
SetSecurityPolicyTargetPoolRequest request) → Future< Operation> - Sets the Google Cloud Armor security policy for the specified target pool. For more information, seeGoogle Cloud Armor Overview
-
testIamPermissions(
TestIamPermissionsTargetPoolRequest request) → Future< TestPermissionsResponse> - Returns permissions that a caller has on the specified resource.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited