insert method
Creates a target pool in the specified project and region using the data included in the request.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
Future<Operation> insert(InsertTargetPoolRequest request) async {
final url = _endPoint.replace(
path:
'/compute/v1/projects/${request.project}/regions/${request.region}/targetPools',
queryParameters: {'requestId': ?request.requestId},
);
final response = await _client.post(url, body: request.targetPoolResource);
return Operation.fromJson(response);
}