TargetSslProxies class final
The TargetSslProxies API.
- Implementers
Constructors
- TargetSslProxies({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
TargetSslProxiesusingclientfor transport. - TargetSslProxies.fromApiKey([String? apiKey])
-
Creates a
TargetSslProxiesthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteTargetSslProxyRequest request) → Future< Operation> - Deletes the specified TargetSslProxy resource.
-
get(
GetTargetSslProxyRequest request) → Future< TargetSslProxy> - Returns the specified TargetSslProxy resource.
-
insert(
InsertTargetSslProxyRequest request) → Future< Operation> - Creates a TargetSslProxy resource in the specified project using the data included in the request.
-
list(
ListTargetSslProxiesRequest request) → Future< TargetSslProxyList> - Retrieves the list of TargetSslProxy resources available to the specified project.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setBackendService(
SetBackendServiceTargetSslProxyRequest request) → Future< Operation> - Changes the BackendService for TargetSslProxy.
-
setCertificateMap(
SetCertificateMapTargetSslProxyRequest request) → Future< Operation> - Changes the Certificate Map for TargetSslProxy.
-
setProxyHeader(
SetProxyHeaderTargetSslProxyRequest request) → Future< Operation> - Changes the ProxyHeaderType for TargetSslProxy.
-
setSslCertificates(
SetSslCertificatesTargetSslProxyRequest request) → Future< Operation> - Changes SslCertificates for TargetSslProxy.
-
setSslPolicy(
SetSslPolicyTargetSslProxyRequest request) → Future< Operation> - Sets the SSL policy for TargetSslProxy. The SSL policy specifies the server-side support for SSL features. This affects connections between clients and the load balancer. They do not affect the connection between the load balancer and the backends.
-
testIamPermissions(
TestIamPermissionsTargetSslProxyRequest request) → Future< TestPermissionsResponse> - Returns permissions that a caller has on the specified resource.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited