status property

String? status
final

Output Only The status of the VPN gateway, which can be one of the following: CREATING, READY, FAILED, or DELETING. Check the Status enum for the list of possible values.

Implementation

final String? status;