TargetVpnGateways class final

The TargetVpnGateways API.

Implementers

Constructors

TargetVpnGateways({required Client client, Uri? endPoint, String? gcclVersion})
Creates a TargetVpnGateways using client for transport.
TargetVpnGateways.fromApiKey([String? apiKey])
Creates a TargetVpnGateways that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(AggregatedListTargetVpnGatewaysRequest request) Future<TargetVpnGatewayAggregatedList>
Retrieves an aggregated list of target VPN gateways.
close() → void
Closes the client and cleans up any resources associated with it.
delete(DeleteTargetVpnGatewayRequest request) Future<Operation>
Deletes the specified target VPN gateway.
get(GetTargetVpnGatewayRequest request) Future<TargetVpnGateway>
Returns the specified target VPN gateway.
insert(InsertTargetVpnGatewayRequest request) Future<Operation>
Creates a target VPN gateway in the specified project and region using the data included in the request.
list(ListTargetVpnGatewaysRequest request) Future<TargetVpnGatewayList>
Retrieves a list of target VPN gateways available to the specified project and region.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setLabels(SetLabelsTargetVpnGatewayRequest request) Future<Operation>
Sets the labels on a TargetVpnGateway. To learn more about labels, read theLabeling Resources documentation.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited