Properties
-
actualOutputUrl
→ String?
-
The actual output URL evaluated by a load balancer containing the scheme,
host, path and query parameters.
final
-
actualRedirectResponseCode
→ int?
-
Actual HTTP status code for rule with
urlRedirect
calculated by load balancer
final
-
actualService
→ String?
-
BackendService or BackendBucket returned by load
balancer.
final
-
expectedOutputUrl
→ String?
-
The expected output URL evaluated by a load balancer containing the scheme,
host, path and query parameters.
final
-
expectedRedirectResponseCode
→ int?
-
Expected HTTP status code for rule with
urlRedirect
calculated by load balancer
final
-
expectedService
→ String?
-
Expected BackendService or BackendBucket resource
the given URL should be mapped to.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
HTTP headers of the request.
final
-
host
→ String?
-
Host portion of the URL.
final
-
path
→ String?
-
Path portion including query parameters in the URL.
final
-
qualifiedName
→ String
-
The fully qualified name of this message, i.e.,
google.protobuf.Duration
or google.rpc.ErrorInfo.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited