UpcomingMaintenance class final
Upcoming Maintenance notification information.
Constructors
Properties
- canReschedule → bool?
-
Indicates if the maintenance can be customer triggered.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- latestWindowStartTime → String?
-
The latest time for the planned maintenance window to start.
This timestamp value is in RFC3339 text format.
final
- maintenanceOnShutdown → bool?
-
Indicates whether the UpcomingMaintenance will be triggered on VM shutdown.
final
-
maintenanceReasons
→ List<
String> -
The reasons for the maintenance. Only valid for vms.
Check the MaintenanceReasons enum for the list of possible values.
final
- maintenanceStatus → String?
-
Check the MaintenanceStatus enum for the list of possible values.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String?
-
Defines the type of maintenance.
Check the Type enum for the list of possible values.
final
- windowEndTime → String?
-
The time by which the maintenance disruption will be completed.
This timestamp value is in RFC3339 text format.
final
- windowStartTime → String?
-
The current start time of the maintenance window.
This timestamp value is in RFC3339 text format.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String