UpdateReservationSlotRequest class final
A request message for ReservationSlots.Update. See the method description for details.
Constructors
- UpdateReservationSlotRequest({required String parentName, required String project, required String reservationSlot, required ReservationSlot? reservationSlotResource, String? updateMask, required String zone})
- UpdateReservationSlotRequest.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- parentName → String
-
The name of the sub-block resource.
final
- project → String
-
The project ID for this request.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - reservationSlot → String
-
The name of the slot resource.
final
- reservationSlotResource → ReservationSlot?
-
The body resource for this request
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updateMask → String?
-
The fields to be updated as part of this request.
final
- zone → String
-
The name of the zone for this request, formatted as RFC1035.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String