UrlMapTest class final
Message for the expected URL mappings.
Constructors
-
UrlMapTest({String? description, String? expectedOutputUrl, int? expectedRedirectResponseCode, List<
UrlMapTestHeader> headers = const [], String? host, String? path, String? service}) - UrlMapTest.fromJson(Object? j)
-
factory
Properties
- description → String?
-
Description of this test case.
final
- expectedOutputUrl → String?
-
The expected output URL evaluated by the load balancer
containing the scheme, host, path and query parameters.
final
- expectedRedirectResponseCode → int?
-
For rules with urlRedirect, the test passes only ifexpectedRedirectResponseCode matches the HTTP status code in
load balancer's redirect response.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ List<
UrlMapTestHeader> -
HTTP headers for this request. If headers contains
a host header, then host must also match the header value.
final
- host → String?
-
Host portion of the URL. If headers contains a host header,
then host must also match the header value.
final
- path → String?
-
Path portion of the URL.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- service → String?
-
Expected BackendService or BackendBucket resource
the given URL should be mapped to.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String