loadBalancingSchemeUnspecified constant
UrlMapsValidateRequest_LoadBalancingSchemes
const loadBalancingSchemeUnspecified
If unspecified, the validation will try to infer the scheme from the backend service resources this Url map references. If the inference is not possible, EXTERNAL will be used as the default type.
Implementation
static const loadBalancingSchemeUnspecified =
UrlMapsValidateRequest_LoadBalancingSchemes(
'LOAD_BALANCING_SCHEME_UNSPECIFIED',
);