UsableSubnetwork class final

Subnetwork which the current user has compute.subnetworks.use permission on.

Constructors

UsableSubnetwork({String? externalIpv6Prefix, String? internalIpv6Prefix, String? ipCidrRange, String? ipv6AccessType, String? network, String? purpose, String? role, List<UsableSubnetworkSecondaryRange> secondaryIpRanges = const [], String? stackType, String? subnetwork})
UsableSubnetwork.fromJson(Object? j)
factory

Properties

externalIpv6Prefix String?
Output only. Output Only The external IPv6 address range that is assigned to this subnetwork.
final
hashCode int
The hash code for this object.
no setterinherited
internalIpv6Prefix String?
Output only. Output Only The internal IPv6 address range that is assigned to this subnetwork.
final
ipCidrRange String?
The range of internal addresses that are owned by this subnetwork.
final
ipv6AccessType String?
The access type of IPv6 address this subnet holds. It's immutable and can only be specified during creation or the first time the subnet is updated into IPV4_IPV6 dual stack. Check the Ipv6AccessType enum for the list of possible values.
final
network String?
Network URL.
final
purpose String?
Check the Purpose enum for the list of possible values.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
role String?
The role of subnetwork. Currently, this field is only used when purpose is set to GLOBAL_MANAGED_PROXY orREGIONAL_MANAGED_PROXY. The value can be set toACTIVE or BACKUP. An ACTIVE subnetwork is one that is currently being used for Envoy-based load balancers in a region. A BACKUP subnetwork is one that is ready to be promoted to ACTIVE or is currently draining. This field can be updated with a patch request. Check the Role enum for the list of possible values.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryIpRanges List<UsableSubnetworkSecondaryRange>
Secondary IP ranges.
final
stackType String?
The stack type for the subnet. If set to IPV4_ONLY, new VMs in the subnet are assigned IPv4 addresses only. If set toIPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and IPv6 addresses. If not specified, IPV4_ONLY is used.
final
subnetwork String?
Subnetwork URL.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String