Output Only This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
In special cases listUsable may return 0 subnetworks andnextPageToken which still should be used to get the
next page of results.