VmEndpointNatMappingsInterfaceNatMappings class final

Contain information of Nat mapping for an interface of this endpoint.

Constructors

VmEndpointNatMappingsInterfaceNatMappings({List<String> drainNatIpPortRanges = const [], List<String> natIpPortRanges = const [], int? numTotalDrainNatPorts, int? numTotalNatPorts, List<VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings> ruleMappings = const [], String? sourceAliasIpRange, String? sourceVirtualIp})
VmEndpointNatMappingsInterfaceNatMappings.fromJson(Object? j)
factory

Properties

drainNatIpPortRanges List<String>
Output only. List of all drain IP:port-range mappings assigned to this interface. These ranges are inclusive, that is, both the first and the last ports can be used for NAT. Example: "2.2.2.2:12345-12355", "1.1.1.1:2234-2234".
final
hashCode int
The hash code for this object.
no setterinherited
natIpPortRanges List<String>
Output only. A list of all IP:port-range mappings assigned to this interface. These ranges are inclusive, that is, both the first and the last ports can be used for NAT. Example: "2.2.2.2:12345-12355", "1.1.1.1:2234-2234".
final
numTotalDrainNatPorts int?
Output only. Total number of drain ports across all NAT IPs allocated to this interface. It equals to the aggregated port number in the field drain_nat_ip_port_ranges.
final
numTotalNatPorts int?
Output only. Total number of ports across all NAT IPs allocated to this interface. It equals to the aggregated port number in the field nat_ip_port_ranges.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
ruleMappings List<VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings>
Output only. Information about mappings provided by rules in this NAT.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceAliasIpRange String?
Output only. Alias IP range for this interface endpoint. It will be a private (RFC 1918) IP range. Examples: "10.33.4.55/32", or "192.168.5.0/24".
final
sourceVirtualIp String?
Output only. Primary IP of the VM for this NIC.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String