VmExtensionPolicy class final

Represents a VM extension policy.

Constructors

VmExtensionPolicy({String? creationTimestamp, String? description, Map<String, VmExtensionPolicyExtensionPolicy> extensionPolicies = const {}, String? globalResourceLink, BigInt? id, List<VmExtensionPolicyInstanceSelector> instanceSelectors = const [], String? kind, bool? managedByGlobal, String? name, int? priority, String? selfLink, String? selfLinkWithId, String? state, String? updateTimestamp})
VmExtensionPolicy.fromJson(Object? j)
factory

Properties

creationTimestamp String?
Output only. Output Only Creation timestamp inRFC3339 text format.
final
description String?
An optional description of this resource.
final
extensionPolicies Map<String, VmExtensionPolicyExtensionPolicy>
Required. A map of extension names (for example, "ops-agent") to their corresponding policy configurations.
final
Optional. Output only. Output Only Link to the global policy that manages this zone policy, if applicable.
final
hashCode int
The hash code for this object.
no setterinherited
id BigInt?
Output only. Output Only The unique identifier for the resource. This identifier is defined by the server.
final
instanceSelectors List<VmExtensionPolicyInstanceSelector>
Optional. Selectors to target VMs for this policy. VMs are selected if they match any of the provided selectors (logical OR). If this list is empty, the policy applies to all VMs.
final
kind String?
Output only. Output Only Type of the resource. Alwayscompute#vmExtensionPolicy.
final
managedByGlobal bool?
Optional. Output only. Output Only Indicates if this policy is managed by a global policy.
final
name String?
Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
final
priority int?
Optional. Priority of this policy. Used to resolve conflicts when multiple policies apply to the same extension. The policy priority is an integer from 0 to 65535, inclusive. Lower integers indicate higher priorities. If you do not specify a priority when creating a rule, it is assigned a priority of 1000. If priorities are equal, the policy with the most recent creation timestamp takes precedence.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Output only. Output Only Server-defined fully-qualified URL for this resource.
final
selfLinkWithId String?
Output only. Output Only Server-defined URL for this resource's resource id.
final
state String?
Optional. Output only. Output Only Current state of the policy: ACTIVE or DELETING. Check the State enum for the list of possible values.
final
updateTimestamp String?
Output only. Output Only Update timestamp inRFC3339 text format.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String