VmExtensionPolicyLabelSelector class final

A LabelSelector is applied to a VM only if it matches all the specified labels.

Constructors

VmExtensionPolicyLabelSelector({Map<String, String> inclusionLabels = const {}})
VmExtensionPolicyLabelSelector.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
inclusionLabels Map<String, String>
Optional. A map of key-value pairs representing VM labels. VMs must have all of the labels specified in this map to be selected (logical AND).
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String