VmExtensionPolicy_State class final
Optional. Output only. Output Only Current state of the policy: ACTIVE or DELETING.
Constructors
- VmExtensionPolicy_State(String value)
-
const
- VmExtensionPolicy_State.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const VmExtensionPolicy_State
- The default value for VmExtensionPolicy_State.
- active → const VmExtensionPolicy_State
- The policy is active and applied to matching VMs. Newly created VMs that match the policy will also receive the extension policy.
- deleting → const VmExtensionPolicy_State
- The policy is in the process of being deleted. After the extension is removed from all matching VMs, the policy will be deleted.
- stateUnspecified → const VmExtensionPolicy_State
- Default value. Do not use.
- undefinedState → const VmExtensionPolicy_State
- A value indicating that the enum field is not set.