active constant
VmExtensionPolicy_State
const active
The policy is active and applied to matching VMs. Newly created VMs that match the policy will also receive the extension policy.
Implementation
static const active = VmExtensionPolicy_State('ACTIVE');