VpnGatewayStatusHighAvailabilityRequirementState class final
Describes the high availability requirement state for the VPN connection between this Cloud VPN gateway and a peer gateway.
Constructors
- VpnGatewayStatusHighAvailabilityRequirementState({String? state, String? unsatisfiedReason})
- VpnGatewayStatusHighAvailabilityRequirementState.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → String?
-
Indicates the high availability requirement state for the VPN connection.
Valid values are CONNECTION_REDUNDANCY_MET,CONNECTION_REDUNDANCY_NOT_MET.
Check the State enum for the list of possible values.
final
- unsatisfiedReason → String?
-
Indicates the reason why the VPN connection does not meet the high
availability redundancy criteria/requirement.
Valid values is INCOMPLETE_TUNNELS_COVERAGE.
Check the UnsatisfiedReason enum for the list of possible values.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String