VpnGatewayStatusHighAvailabilityRequirementState_State class final

Indicates the high availability requirement state for the VPN connection. Valid values are CONNECTION_REDUNDANCY_MET,CONNECTION_REDUNDANCY_NOT_MET.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const VpnGatewayStatusHighAvailabilityRequirementState_State
The default value for VpnGatewayStatusHighAvailabilityRequirementState_State.
connectionRedundancyMet → const VpnGatewayStatusHighAvailabilityRequirementState_State
VPN tunnels are configured with adequate redundancy from Cloud VPN gateway to the peer VPN gateway. For both GCP-to-non-GCP and GCP-to-GCP connections, the adequate redundancy is a pre-requirement for users to get 99.99% availability on GCP side; please note that for any connection, end-to-end 99.99% availability is subject to proper configuration on the peer VPN gateway.
connectionRedundancyNotMet → const VpnGatewayStatusHighAvailabilityRequirementState_State
VPN tunnels are not configured with adequate redundancy from the Cloud VPN gateway to the peer gateway
undefinedState → const VpnGatewayStatusHighAvailabilityRequirementState_State
A value indicating that the enum field is not set.