VpnGatewayStatusVpnConnection class final
A VPN connection contains all VPN tunnels connected from this VpnGateway to the same peer gateway. The peer gateway could either be an external VPN gateway or a Google Cloud VPN gateway.
Constructors
-
VpnGatewayStatusVpnConnection({String? peerExternalGateway, String? peerGcpGateway, VpnGatewayStatusHighAvailabilityRequirementState? state, List<
VpnGatewayStatusTunnel> tunnels = const []}) - VpnGatewayStatusVpnConnection.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- peerExternalGateway → String?
-
Output only. URL reference to the peer external VPN gateways to which the VPN tunnels
in this VPN connection are connected.
This field is mutually exclusive with peer_gcp_gateway.
final
- peerGcpGateway → String?
-
Output only. URL reference to the peer side VPN gateways to which the VPN tunnels in
this VPN connection are connected.
This field is mutually exclusive with peer_gcp_gateway.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → VpnGatewayStatusHighAvailabilityRequirementState?
-
HighAvailabilityRequirementState for the VPN connection.
final
-
tunnels
→ List<
VpnGatewayStatusTunnel> -
List of VPN tunnels that are in this VPN connection.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String