VpnGateway_GatewayIpVersion class final
The IP family of the gateway IPs for the HA-VPN gateway interfaces. If not specified, IPV4 will be used.
Constructors
- VpnGateway_GatewayIpVersion(String value)
-
const
- VpnGateway_GatewayIpVersion.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const VpnGateway_GatewayIpVersion
- The default value for VpnGateway_GatewayIpVersion.
- ipv4 → const VpnGateway_GatewayIpVersion
- Every HA-VPN gateway interface is configured with an IPv4 address.
- ipv6 → const VpnGateway_GatewayIpVersion
- Every HA-VPN gateway interface is configured with an IPv6 address.
- undefinedGatewayIpVersion → const VpnGateway_GatewayIpVersion
- A value indicating that the enum field is not set.