VpnTunnel class final
Represents a Cloud VPN Tunnel resource.
For more information about VPN, read the the Cloud VPN Overview.
Constructors
-
VpnTunnel({VpnTunnelCipherSuite? cipherSuite, String? creationTimestamp, String? description, String? detailedStatus, BigInt? id, int? ikeVersion, String? kind, String? labelFingerprint, Map<
String, String> labels = const {}, List<String> localTrafficSelector = const [], String? name, VpnTunnelParams? params, String? peerExternalGateway, int? peerExternalGatewayInterface, String? peerGcpGateway, String? peerIp, String? region, List<String> remoteTrafficSelector = const [], String? router, String? selfLink, String? status, String? targetVpnGateway, String? vpnGateway, int? vpnGatewayInterface}) - VpnTunnel.fromJson(Object? j)
-
factory
Properties
- cipherSuite → VpnTunnelCipherSuite?
-
User specified list of ciphers to use for the phase 1 and phase 2 of the
IKE protocol.
final
- creationTimestamp → String?
-
Output only.
Output OnlyCreation timestamp inRFC3339 text format.final - description → String?
-
An optional description of this resource. Provide this property when you
create the resource.
final
- detailedStatus → String?
-
Output OnlyDetailed status message for the VPN tunnel.final - hashCode → int
-
The hash code for this object.
no setterinherited
- id → BigInt?
-
Output OnlyThe unique identifier for the resource. This identifier is defined by the server.final - ikeVersion → int?
-
IKE protocol version to use when establishing the VPN tunnel with the peer
VPN gateway. Acceptable IKE versions are 1 or 2.
The default version is 2.
final
- kind → String?
-
Output only.
Output OnlyType of resource. Always compute#vpnTunnel for VPN tunnels.final - labelFingerprint → String?
-
A fingerprint for the labels being applied to this VpnTunnel, which is
essentially a hash of the labels set used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update labels. You must always provide an
up-to-date fingerprint hash in order to update or change labels,
otherwise the request will fail with error412 conditionNotMet.
final
-
labels
→ Map<
String, String> -
Labels for this resource. These can only be added or modified by thesetLabels method. Each label key/value pair must comply withRFC1035.
Label values may be empty.
final
-
localTrafficSelector
→ List<
String> -
Local traffic selector to use when establishing the VPN tunnel with the
peer VPN gateway. The value should be a CIDR formatted string, for
example: 192.168.0.0/16. The ranges must be disjoint.
Only IPv4 is supported for Classic VPN tunnels. This field is output only
for HA VPN tunnels.
final
- name → String?
-
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression
[a-z]([-a-z0-9]*[a-z0-9])?which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.final - params → VpnTunnelParams?
-
Input only.
Input OnlyAdditional params passed with the request, but not persisted as part of resource payload.final - peerExternalGateway → String?
-
URL of the peer side external VPN gateway to which this VPN tunnel is
connected.
Provided by the client when the VPN tunnel is created.
This field is exclusive with the field peerGcpGateway.
final
- peerExternalGatewayInterface → int?
-
The interface ID of the external VPN gateway to which this VPN tunnel is
connected. Provided by the client when the VPN tunnel is created.
Possible values are:
0,1,2,3. The number of IDs in use depends on the external VPN gateway redundancy type.final - peerGcpGateway → String?
-
URL of the peer side HA VPN gateway to which this VPN tunnel
is connected. Provided by the client when the VPN tunnel is created.
This field can be used when creating highly available VPN from VPC network
to VPC network, the field is exclusive with the field peerExternalGateway.
If provided, the VPN tunnel will automatically use the same
vpnGatewayInterface ID in the peer Google Cloud VPN gateway.
final
- peerIp → String?
-
IP address of the peer VPN gateway. Only IPv4 is supported. This field can
be set only for Classic VPN tunnels.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - region → String?
-
Output OnlyURL of the region where the VPN tunnel resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.final -
remoteTrafficSelector
→ List<
String> -
Remote traffic selectors to use when establishing the VPN tunnel with
the peer VPN gateway. The value should be a CIDR formatted string,
for example: 192.168.0.0/16. The ranges should be disjoint. Only IPv4 is
supported for Classic VPN tunnels. This field is output only for HA VPN
tunnels.
final
- router → String?
-
URL of the router resource to be used for dynamic routing.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfLink → String?
-
Output OnlyServer-defined URL for the resource.final -
Shared secret used to set the secure session between the Cloud VPN gateway
and the peer VPN gateway.
final
-
Hash of the shared secret.
final
- status → String?
-
Output OnlyThe status of the VPN tunnel, which can be one of the following:final - targetVpnGateway → String?
-
URL of the Target VPN gateway with which this VPN tunnel is associated.
Provided by the client when the VPN tunnel is created.
This field can be set only for Classic VPN tunnels.
final
- vpnGateway → String?
-
URL of the VPN gateway with which this VPN tunnel is associated.
Provided by the client when the VPN tunnel is created. This must be
used (instead of target_vpn_gateway) if a High Availability VPN gateway
resource is created.
final
- vpnGatewayInterface → int?
-
The interface ID of the VPN gateway with which this VPN tunnel is
associated.
Possible values are:
0,1.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String