VpnTunnel_Status class final
Output Only The status of the VPN tunnel, which can be one of the
following:
- PROVISIONING: Resource is being allocated for the VPN tunnel.
- WAITING_FOR_FULL_CONFIG: Waiting to receive all VPN-related configs from the user. Network, TargetVpnGateway, VpnTunnel, ForwardingRule, and Route resources are needed to setup the VPN tunnel.
- FIRST_HANDSHAKE: Successful first handshake with the peer VPN.
- ESTABLISHED: Secure session is successfully established with the peer VPN.
- NETWORK_ERROR: Deprecated, replaced by NO_INCOMING_PACKETS
- AUTHORIZATION_ERROR: Auth error (for example, bad shared secret).
- NEGOTIATION_FAILURE: Handshake failed.
- DEPROVISIONING: Resources are being deallocated for the VPN tunnel.
- FAILED: Tunnel creation has failed and the tunnel is not ready to be used.
- NO_INCOMING_PACKETS: No incoming packets from peer.
- REJECTED: Tunnel configuration was rejected, can be result of being denied access.
- ALLOCATING_RESOURCES: Cloud VPN is in the process of allocating all required resources.
- STOPPED: Tunnel is stopped due to its Forwarding Rules being deleted for Classic VPN tunnels or the project is in frozen state.
- PEER_IDENTITY_MISMATCH: Peer identity does not match peer IP, probably behind NAT.
- TS_NARROWING_NOT_ALLOWED: Traffic selector narrowing not allowed for an HA-VPN tunnel.
Constructors
- VpnTunnel_Status(String value)
-
const
- VpnTunnel_Status.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const VpnTunnel_Status
- The default value for VpnTunnel_Status.
- allocatingResources → const VpnTunnel_Status
- Cloud VPN is in the process of allocating all required resources (specifically, a borg task).
- Auth error (e.g. bad shared secret).
- deprovisioning → const VpnTunnel_Status
- Resources is being deallocated for the VPN tunnel.
- established → const VpnTunnel_Status
- Secure session is successfully established with peer VPN.
- failed → const VpnTunnel_Status
- Tunnel creation has failed and the tunnel is not ready to be used.
- firstHandshake → const VpnTunnel_Status
- Successful first handshake with peer VPN.
- negotiationFailure → const VpnTunnel_Status
- Handshake failed.
- networkError → const VpnTunnel_Status
- Deprecated, replaced by NO_INCOMING_PACKETS
- noIncomingPackets → const VpnTunnel_Status
- No incoming packets from peer
- provisioning → const VpnTunnel_Status
- Resource is being allocated for the VPN tunnel.
- rejected → const VpnTunnel_Status
- Tunnel configuration was rejected, can be result of being denylisted.
- stopped → const VpnTunnel_Status
- Tunnel is stopped due to its Forwarding Rules being deleted.
- undefinedStatus → const VpnTunnel_Status
- A value indicating that the enum field is not set.
- waitingForFullConfig → const VpnTunnel_Status
- Waiting to receive all VPN-related configs from user. Network, TargetVpnGateway, VpnTunnel, ForwardingRule and Route resources are needed to setup VPN tunnel.