VpnTunnels class final
The VpnTunnels API.
- Implementers
Constructors
- VpnTunnels({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
VpnTunnelsusingclientfor transport. - VpnTunnels.fromApiKey([String? apiKey])
-
Creates a
VpnTunnelsthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
aggregatedList(
AggregatedListVpnTunnelsRequest request) → Future< VpnTunnelAggregatedList> - Retrieves an aggregated list of VPN tunnels.
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteVpnTunnelRequest request) → Future< Operation> - Deletes the specified VpnTunnel resource.
-
get(
GetVpnTunnelRequest request) → Future< VpnTunnel> - Returns the specified VpnTunnel resource.
-
insert(
InsertVpnTunnelRequest request) → Future< Operation> - Creates a VpnTunnel resource in the specified project and region using the data included in the request.
-
list(
ListVpnTunnelsRequest request) → Future< VpnTunnelList> - Retrieves a list of VpnTunnel resources contained in the specified project and region.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setLabels(
SetLabelsVpnTunnelRequest request) → Future< Operation> - Sets the labels on a VpnTunnel. To learn more about labels, read theLabeling Resources documentation.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited