WafExpressionSet class final

Constructors

WafExpressionSet({List<String> aliases = const [], List<WafExpressionSetExpression> expressions = const [], String? id})
WafExpressionSet.fromJson(Object? j)
factory

Properties

aliases List<String>
A list of alternate IDs. The format should be:
final
expressions List<WafExpressionSetExpression>
List of available expressions.
final
hashCode int
The hash code for this object.
no setterinherited
id String?
Google specified expression set ID. The format should be:
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String