Warning class final

Informational warning message.

Constructors

Warning({String? code, List<Data> data = const [], String? message})
Warning.fromJson(Object? j)
factory

Properties

code String?
Output Only A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response. Check the Code enum for the list of possible values.
final
data List<Data>
Output Only Metadata about this warning in key: value format. For example:
final
hashCode int
The hash code for this object.
no setterinherited
message String?
Output Only A human-readable description of the warning code.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String