Wire class final

A pseudowire that connects two Interconnect connections.

Constructors

Wire({bool? adminEnabled, List<WireEndpoint> endpoints = const [], String? label, WireProperties? wireProperties})
Wire.fromJson(Object? j)
factory

Properties

adminEnabled bool?
Output only. Output Only Indicates whether the wire is enabled. When false, the wire is disabled. When true and when the wire group of the wire is also enabled, the wire is enabled. Defaults to true.
final
endpoints List<WireEndpoint>
Output only. Wire endpoints are specific Interconnect connections.
final
hashCode int
The hash code for this object.
no setterinherited
label String?
Output only. Output Only A label that identifies the wire. The format of this label combines the existing labels of the wire group endpoints and Interconnect connections used by this wire in alphabetical order as follows: ENDPOINT_A+CONNECTION_A1,ENDPOINT_B+CONNECTION_B1, where:
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wireProperties WireProperties?
Output only. Output Only Properties of the wire.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String