WireGroupEndpointInterconnect class final
The redundant Interconnect connections for this endpoint.
Constructors
-
WireGroupEndpointInterconnect({String? interconnect, List<
int> vlanTags = const []}) - WireGroupEndpointInterconnect.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- interconnect → String?
-
Required. An Interconnect connection. You can specify the connection as
a partial or full URL. If the connection is in a different project from
the cross-site network, use a format that specifies the project. See
the following examples of partial and full URLs:
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
vlanTags
→ List<
int> -
Required. To configure the wire group for VLAN mode, enter a VLAN tag,
which is a number from
2to4093. You can autoallocate a tag by entering0. To configure the wire group for port mode, enter-1. Review the following guidelines:final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String