WireGroupTopologyEndpoint class final
Topology details for a single wire group endpoint.
Constructors
- WireGroupTopologyEndpoint({String? city, String? label})
- WireGroupTopologyEndpoint.fromJson(Object? j)
-
factory
Properties
- city → String?
-
Output only. The InterconnectLocation.city (metropolitan area designator) that all
interconnects are located in.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String?
-
Output only. Endpoint label from the wire group.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String