WireGroups class final
The WireGroups API.
- Implementers
Constructors
- WireGroups({required Client client, Uri? endPoint, String? gcclVersion})
-
Creates a
WireGroupsusingclientfor transport. - WireGroups.fromApiKey([String? apiKey])
-
Creates a
WireGroupsthat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the client and cleans up any resources associated with it.
-
delete(
DeleteWireGroupRequest request) → Future< Operation> - Deletes the specified wire group in the given scope.
-
get(
GetWireGroupRequest request) → Future< WireGroup> - Gets the specified wire group resource in the given scope.
-
insert(
InsertWireGroupRequest request) → Future< Operation> - Creates a wire group in the specified project in the given scope using the parameters that are included in the request.
-
list(
ListWireGroupsRequest request) → Future< WireGroupList> - Lists the wire groups for a project in the given scope.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchWireGroupRequest request) → Future< Operation> - Updates the specified wire group resource with the data included in the request. This method supportsPATCH semantics and usesJSON merge patch format and processing rules.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited