insert method
Creates a wire group in the specified project in the given scope using the parameters that are included in the request.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
Future<Operation> insert(InsertWireGroupRequest request) async {
final url = _endPoint.replace(
path:
'/compute/v1/projects/${request.project}/global/crossSiteNetworks/${request.crossSiteNetwork}/wireGroups',
queryParameters: {
'requestId': ?request.requestId,
if (request.validateOnly case final $1?) 'validateOnly': '${$1}',
},
);
final response = await _client.post(url, body: request.wireGroupResource);
return Operation.fromJson(response);
}