WireProperties class final
The properties of a wire.
Constructors
- WireProperties({String? bandwidthAllocation, int? bandwidthUnmetered, String? faultResponse})
- WireProperties.fromJson(Object? j)
-
factory
Properties
- bandwidthAllocation → String?
-
The configuration of the bandwidth allocation, one of the following:
final
- bandwidthUnmetered → int?
-
The unmetered bandwidth in Gigabits per second, using decimal units.
10is 10 Gbps,100is 100 Gbps. The bandwidth must be greater than 0.final - faultResponse → String?
-
Response when a fault is detected in a pseudowire:
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String