faultResponse property
Response when a fault is detected in a pseudowire:
- NONE: default.
- DISABLE_PORT: set the port line protocol down when inline probes detect a fault. This setting is only permitted on port mode pseudowires. Check the FaultResponse enum for the list of possible values.
Implementation
final String? faultResponse;