XpnResourceId class final
Service resource (a.k.a service project) ID.
Constructors
- XpnResourceId({String? id, String? type})
- XpnResourceId.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
The ID of the service resource. In the case of projects, this field
supports project id (e.g., my-project-123) and project number
(e.g. 12345678).
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String?
-
The type of the service resource.
Check the Type enum for the list of possible values.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String