FakeAdvice class base
Testing fake for Advice.
- Implemented types
Constructors
-
FakeAdvice({Future<
CalendarModeAdviceResponse> calendarMode(CalendarModeAdviceRpcRequest request)?})
Properties
Methods
-
calendarMode(
CalendarModeAdviceRpcRequest request) → Future< CalendarModeAdviceResponse> -
Advise how, where and when to create the requested amount of instances
with specified accelerators, within the specified time and location limits.
The method recommends creating future reservations for the requested
resources.
override
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited