FakeBackendServices class base
Testing fake for BackendServices.
- Implemented types
Constructors
-
FakeBackendServices({Future<
Operation> addSignedUrlKey(AddSignedUrlKeyBackendServiceRequest request)?, Future<BackendServiceAggregatedList> aggregatedList(AggregatedListBackendServicesRequest request)?, Future<Operation> delete(DeleteBackendServiceRequest request)?, Future<Operation> deleteSignedUrlKey(DeleteSignedUrlKeyBackendServiceRequest request)?, Future<BackendService> get(GetBackendServiceRequest request)?, Future<GetEffectiveSecurityPoliciesBackendServiceResponse> getEffectiveSecurityPolicies(GetEffectiveSecurityPoliciesBackendServiceRequest request)?, Future<BackendServiceGroupHealth> getHealth(GetHealthBackendServiceRequest request)?, Future<Policy> getIamPolicy(GetIamPolicyBackendServiceRequest request)?, Future<Operation> insert(InsertBackendServiceRequest request)?, Future<BackendServiceList> list(ListBackendServicesRequest request)?, Future<BackendServiceListUsable> listUsable(ListUsableBackendServicesRequest request)?, Future<Operation> patch(PatchBackendServiceRequest request)?, Future<Operation> setEdgeSecurityPolicy(SetEdgeSecurityPolicyBackendServiceRequest request)?, Future<Policy> setIamPolicy(SetIamPolicyBackendServiceRequest request)?, Future<Operation> setSecurityPolicy(SetSecurityPolicyBackendServiceRequest request)?, Future<TestPermissionsResponse> testIamPermissions(TestIamPermissionsBackendServiceRequest request)?, Future<Operation> update(UpdateBackendServiceRequest request)?})
Properties
Methods
-
addSignedUrlKey(
AddSignedUrlKeyBackendServiceRequest request) → Future< Operation> -
Adds a key for validating requests with signed URLs for this backend
service.
override
-
aggregatedList(
AggregatedListBackendServicesRequest request) → Future< BackendServiceAggregatedList> -
Retrieves the list of all BackendService resources, regional and global,
available to the specified project.
override
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
delete(
DeleteBackendServiceRequest request) → Future< Operation> -
Deletes the specified BackendService resource.
override
-
deleteSignedUrlKey(
DeleteSignedUrlKeyBackendServiceRequest request) → Future< Operation> -
Deletes a key for validating requests with signed URLs for this backend
service.
override
-
get(
GetBackendServiceRequest request) → Future< BackendService> -
Returns the specified BackendService resource.
override
-
getEffectiveSecurityPolicies(
GetEffectiveSecurityPoliciesBackendServiceRequest request) → Future< GetEffectiveSecurityPoliciesBackendServiceResponse> -
Returns effective security policies applied to this backend service.
override
-
getHealth(
GetHealthBackendServiceRequest request) → Future< BackendServiceGroupHealth> -
Gets the most recent health check results for this
BackendService.
override
-
getIamPolicy(
GetIamPolicyBackendServiceRequest request) → Future< Policy> -
Gets the access control policy for a resource. May be empty if no such
policy or resource exists.
override
-
insert(
InsertBackendServiceRequest request) → Future< Operation> -
Creates a BackendService resource in the specified project using
the data included in the request. For more information, see
Backend services overview.
override
-
list(
ListBackendServicesRequest request) → Future< BackendServiceList> -
Retrieves the list of BackendService resources available to the specified
project.
override
-
listUsable(
ListUsableBackendServicesRequest request) → Future< BackendServiceListUsable> -
Retrieves a list of all usable backend services for Application Load
Balancers and Proxy Network Load Balancers in the specified project.
Backend services for external and internal passthrough Network Load
Balancers are not included in the response.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchBackendServiceRequest request) → Future< Operation> -
Patches the specified BackendService resource with the data included in the
request. For more information, see
Backend services overview. This method
supports PATCH semantics and uses the JSON merge
patch format and processing rules.
override
-
setEdgeSecurityPolicy(
SetEdgeSecurityPolicyBackendServiceRequest request) → Future< Operation> -
Sets the edge security policy for the specified backend service.
override
-
setIamPolicy(
SetIamPolicyBackendServiceRequest request) → Future< Policy> -
Sets the access control policy on the specified resource.
Replaces any existing policy.
override
-
setSecurityPolicy(
SetSecurityPolicyBackendServiceRequest request) → Future< Operation> -
Sets the Google Cloud Armor security policy for the specified backend
service. For more information, seeGoogle
Cloud Armor Overview
override
-
testIamPermissions(
TestIamPermissionsBackendServiceRequest request) → Future< TestPermissionsResponse> -
Returns permissions that a caller has on the specified resource.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
UpdateBackendServiceRequest request) → Future< Operation> -
Updates the specified BackendService resource with the data included in the
request. For more information, seeBackend
services overview.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited