FakeCrossSiteNetworks class base
Testing fake for CrossSiteNetworks.
- Implemented types
Constructors
-
FakeCrossSiteNetworks({Future<
Operation> delete(DeleteCrossSiteNetworkRequest request)?, Future<CrossSiteNetwork> get(GetCrossSiteNetworkRequest request)?, Future<Operation> insert(InsertCrossSiteNetworkRequest request)?, Future<CrossSiteNetworkList> list(ListCrossSiteNetworksRequest request)?, Future<Operation> patch(PatchCrossSiteNetworkRequest request)?})
Properties
Methods
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
delete(
DeleteCrossSiteNetworkRequest request) → Future< Operation> -
Deletes the specified cross-site network in the given scope.
override
-
get(
GetCrossSiteNetworkRequest request) → Future< CrossSiteNetwork> -
Returns the specified cross-site network in the given scope.
override
-
insert(
InsertCrossSiteNetworkRequest request) → Future< Operation> -
Creates a cross-site network in the specified project in the given scope
using the parameters that are included in the request.
override
-
list(
ListCrossSiteNetworksRequest request) → Future< CrossSiteNetworkList> -
Lists the cross-site networks for a project in the given scope.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchCrossSiteNetworkRequest request) → Future< Operation> -
Updates the specified cross-site network with the data included in
the request. This method supportsPATCH
semantics and uses theJSON merge
patch format and processing rules.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited