FakeDiskTypes class base
Testing fake for DiskTypes.
- Implemented types
Constructors
-
FakeDiskTypes({Future<
DiskTypeAggregatedList> aggregatedList(AggregatedListDiskTypesRequest request)?, Future<DiskType> get(GetDiskTypeRequest request)?, Future<DiskTypeList> list(ListDiskTypesRequest request)?})
Properties
Methods
-
aggregatedList(
AggregatedListDiskTypesRequest request) → Future< DiskTypeAggregatedList> -
Retrieves an aggregated list of disk types.
override
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
get(
GetDiskTypeRequest request) → Future< DiskType> -
Returns the specified disk type.
override
-
list(
ListDiskTypesRequest request) → Future< DiskTypeList> -
Retrieves a list of disk types available to the specified
project.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited