delete method
Deletes the specified persistent disk. Deleting a disk removes its data permanently and is irreversible. However, deleting a disk does not delete any snapshots previously made from the disk. You must separatelydelete snapshots.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<Operation> delete(DeleteDiskRequest request) async {
if (isClosed) throw StateError('Service is closed');
if (_delete case final delete?) {
return delete(request);
}
throw UnsupportedError('delete');
}