FakeGlobalForwardingRules class base
Testing fake for GlobalForwardingRules.
- Implemented types
Constructors
-
FakeGlobalForwardingRules({Future<
Operation> delete(DeleteGlobalForwardingRuleRequest request)?, Future<ForwardingRule> get(GetGlobalForwardingRuleRequest request)?, Future<Operation> insert(InsertGlobalForwardingRuleRequest request)?, Future<ForwardingRuleList> list(ListGlobalForwardingRulesRequest request)?, Future<Operation> patch(PatchGlobalForwardingRuleRequest request)?, Future<Operation> setLabels(SetLabelsGlobalForwardingRuleRequest request)?, Future<Operation> setTarget(SetTargetGlobalForwardingRuleRequest request)?})
Properties
Methods
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
delete(
DeleteGlobalForwardingRuleRequest request) → Future< Operation> -
Deletes the specified GlobalForwardingRule resource.
override
-
get(
GetGlobalForwardingRuleRequest request) → Future< ForwardingRule> -
Returns the specified GlobalForwardingRule resource. Gets a list of
available forwarding rules by making a list() request.
override
-
insert(
InsertGlobalForwardingRuleRequest request) → Future< Operation> -
Creates a GlobalForwardingRule resource in the specified project using
the data included in the request.
override
-
list(
ListGlobalForwardingRulesRequest request) → Future< ForwardingRuleList> -
Retrieves a list of GlobalForwardingRule resources available to the
specified project.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchGlobalForwardingRuleRequest request) → Future< Operation> -
Updates the specified forwarding rule with the data included in the
request. This method supportsPATCH
semantics and uses theJSON merge
patch format and processing rules. Currently, you can only
patch the network_tier field.
override
-
setLabels(
SetLabelsGlobalForwardingRuleRequest request) → Future< Operation> -
Sets the labels on the specified resource. To learn more about labels,
read the
Labeling resources documentation.
override
-
setTarget(
SetTargetGlobalForwardingRuleRequest request) → Future< Operation> -
Changes target URL for the GlobalForwardingRule resource. The new target
should be of the same type as the old target.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited