delete method

Purge scoped resources (zonal policies) from a global VM extension policy, and then delete the global VM extension policy. Purge of the scoped resources is a pre-condition of the global VM extension policy deletion. The deletion of the global VM extension policy happens after the purge rollout is done, so it's not a part of the LRO. It's an automatic process that triggers in the backend.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> delete(DeleteGlobalVmExtensionPolicyRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_delete case final delete?) {
    return delete(request);
  }
  throw UnsupportedError('delete');
}