FakeImages class base

Testing fake for Images.

Implemented types

Constructors

FakeImages({Future<Operation> delete(DeleteImageRequest request)?, Future<Operation> deprecate(DeprecateImageRequest request)?, Future<Image> get(GetImageRequest request)?, Future<Image> getFromFamily(GetFromFamilyImageRequest request)?, Future<Policy> getIamPolicy(GetIamPolicyImageRequest request)?, Future<Operation> insert(InsertImageRequest request)?, Future<ImageList> list(ListImagesRequest request)?, Future<Operation> patch(PatchImageRequest request)?, Future<Policy> setIamPolicy(SetIamPolicyImageRequest request)?, Future<Operation> setLabels(SetLabelsImageRequest request)?, Future<TestPermissionsResponse> testIamPermissions(TestIamPermissionsImageRequest request)?})

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteImageRequest request) Future<Operation>
Deletes the specified image.
override
deprecate(DeprecateImageRequest request) Future<Operation>
Sets the deprecation status of an image.
override
get(GetImageRequest request) Future<Image>
Returns the specified image.
override
getFromFamily(GetFromFamilyImageRequest request) Future<Image>
Returns the latest image that is part of an image family and is not deprecated. For more information on image families, seePublic image families documentation.
override
getIamPolicy(GetIamPolicyImageRequest request) Future<Policy>
Gets the access control policy for a resource. May be empty if no such policy or resource exists.
override
insert(InsertImageRequest request) Future<Operation>
Creates an image in the specified project using the data included in the request.
override
list(ListImagesRequest request) Future<ImageList>
Retrieves the list of custom images available to the specified project. Custom images are images you create that belong to your project. This method does not get any images that belong to other projects, including publicly-available images, like Debian 8. If you want to get a list of publicly-available images, use this method to make a request to the respective image project, such as debian-cloud or windows-cloud.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(PatchImageRequest request) Future<Operation>
Patches the specified image with the data included in the request. Only the following fields can be modified: family, description, deprecation status.
override
setIamPolicy(SetIamPolicyImageRequest request) Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy.
override
setLabels(SetLabelsImageRequest request) Future<Operation>
Sets the labels on an image. To learn more about labels, read theLabeling Resources documentation.
override
testIamPermissions(TestIamPermissionsImageRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited