FakeInstanceGroupManagers class base
Testing fake for InstanceGroupManagers.
- Implemented types
Constructors
-
FakeInstanceGroupManagers({Future<
Operation> abandonInstances(AbandonInstancesInstanceGroupManagerRequest request)?, Future<InstanceGroupManagerAggregatedList> aggregatedList(AggregatedListInstanceGroupManagersRequest request)?, Future<Operation> applyUpdatesToInstances(ApplyUpdatesToInstancesInstanceGroupManagerRequest request)?, Future<Operation> createInstances(CreateInstancesInstanceGroupManagerRequest request)?, Future<Operation> delete(DeleteInstanceGroupManagerRequest request)?, Future<Operation> deleteInstances(DeleteInstancesInstanceGroupManagerRequest request)?, Future<Operation> deletePerInstanceConfigs(DeletePerInstanceConfigsInstanceGroupManagerRequest request)?, Future<InstanceGroupManager> get(GetInstanceGroupManagerRequest request)?, Future<Operation> insert(InsertInstanceGroupManagerRequest request)?, Future<InstanceGroupManagerList> list(ListInstanceGroupManagersRequest request)?, Future<InstanceGroupManagersListErrorsResponse> listErrors(ListErrorsInstanceGroupManagersRequest request)?, Future<InstanceGroupManagersListManagedInstancesResponse> listManagedInstances(ListManagedInstancesInstanceGroupManagersRequest request)?, Future<InstanceGroupManagersListPerInstanceConfigsResp> listPerInstanceConfigs(ListPerInstanceConfigsInstanceGroupManagersRequest request)?, Future<Operation> patch(PatchInstanceGroupManagerRequest request)?, Future<Operation> patchPerInstanceConfigs(PatchPerInstanceConfigsInstanceGroupManagerRequest request)?, Future<Operation> recreateInstances(RecreateInstancesInstanceGroupManagerRequest request)?, Future<Operation> resize(ResizeInstanceGroupManagerRequest request)?, Future<Operation> resumeInstances(ResumeInstancesInstanceGroupManagerRequest request)?, Future<Operation> setInstanceTemplate(SetInstanceTemplateInstanceGroupManagerRequest request)?, Future<Operation> setTargetPools(SetTargetPoolsInstanceGroupManagerRequest request)?, Future<Operation> startInstances(StartInstancesInstanceGroupManagerRequest request)?, Future<Operation> stopInstances(StopInstancesInstanceGroupManagerRequest request)?, Future<Operation> suspendInstances(SuspendInstancesInstanceGroupManagerRequest request)?, Future<Operation> updatePerInstanceConfigs(UpdatePerInstanceConfigsInstanceGroupManagerRequest request)?})
Properties
Methods
-
abandonInstances(
AbandonInstancesInstanceGroupManagerRequest request) → Future< Operation> -
Flags the specified instances to be removed from the
managed instance group. Abandoning an instance does not delete the
instance, but it does remove the instance from any target pools that are
applied by the managed instance group. This method reduces thetargetSize of the managed instance group by the
number of instances that you abandon. This operation is marked asDONE when the action is scheduled even if the instances have
not yet been removed from the group. You must separately verify the
status of the abandoning action with thelistmanagedinstances
method.
override
-
aggregatedList(
AggregatedListInstanceGroupManagersRequest request) → Future< InstanceGroupManagerAggregatedList> -
Retrieves the list of managed instance groups and groups them by zone.
override
-
applyUpdatesToInstances(
ApplyUpdatesToInstancesInstanceGroupManagerRequest request) → Future< Operation> -
Applies changes to selected instances on the managed instance group.
This method can be used to apply new overrides and/or new versions.
override
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
createInstances(
CreateInstancesInstanceGroupManagerRequest request) → Future< Operation> -
Creates instances with per-instance configurations in this managed instance
group. Instances are created using the current instance template. Thecreate instances operation is marked DONE if thecreateInstances request is successful. The underlying actions
take additional time. You must separately verify the status of thecreating or actions with the listmanagedinstances
method.
override
-
delete(
DeleteInstanceGroupManagerRequest request) → Future< Operation> -
Deletes the specified managed instance group and all of the instances
in that group. Note that the instance group must not belong to a
backend service. Read
Deleting an instance group for more information.
override
-
deleteInstances(
DeleteInstancesInstanceGroupManagerRequest request) → Future< Operation> -
Flags the specified instances in the managed instance group for immediate
deletion. The instances are also removed from any target
pools of which they were a member. This method reduces thetargetSize of the managed instance group by the number of
instances that you delete. This operation is marked as DONE
when the action is scheduled even if the instances are still being deleted.
You must separately verify the status of the deleting action
with thelistmanagedinstances
method.
override
-
deletePerInstanceConfigs(
DeletePerInstanceConfigsInstanceGroupManagerRequest request) → Future< Operation> -
Deletes selected per-instance configurations for the managed instance
group.
override
-
get(
GetInstanceGroupManagerRequest request) → Future< InstanceGroupManager> -
Returns all of the details about the specified managed instance group.
override
-
insert(
InsertInstanceGroupManagerRequest request) → Future< Operation> -
Creates a managed instance group using the information that you specify
in the request. After the group is created, instances in the group are
created using the specified instance template.
This operation is marked as DONE when the group is created
even if the instances in the group have not yet been created. You
must separately verify the status of the individual instances with thelistmanagedinstances
method.
override
-
list(
ListInstanceGroupManagersRequest request) → Future< InstanceGroupManagerList> -
Retrieves a list of managed instance groups that are contained within the
specified project and zone.
override
-
listErrors(
ListErrorsInstanceGroupManagersRequest request) → Future< InstanceGroupManagersListErrorsResponse> -
Lists all errors thrown by actions on instances for a given managed
instance group. The filter and orderBy query
parameters are not supported.
override
-
listManagedInstances(
ListManagedInstancesInstanceGroupManagersRequest request) → Future< InstanceGroupManagersListManagedInstancesResponse> -
Lists all of the instances in the managed instance group. Each instance
in the list has a currentAction, which indicates the action
that the managed instance group is performing on the instance. For example,
if the group is still creating an instance, the currentAction
is CREATING. If a previous action failed, the
list displays the errors for that failed action. The orderBy
query parameter is not supported. The
pageTokenquery parameter is supported only if the group'slistManagedInstancesResultsfield is set toPAGINATED.override -
listPerInstanceConfigs(
ListPerInstanceConfigsInstanceGroupManagersRequest request) → Future< InstanceGroupManagersListPerInstanceConfigsResp> -
Lists all of the per-instance configurations defined for the managed
instance group. The orderBy query parameter is not supported.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchInstanceGroupManagerRequest request) → Future< Operation> -
Updates a managed instance group using the information that you specify
in the request.
This operation is marked as DONE when the group is patched
even if the instances in the group are still in the process of being
patched. You must separately verify the status of the individual instances
with thelistManagedInstances
method. This method supportsPATCH
semantics and uses theJSON merge
patch format and processing rules.
override
-
patchPerInstanceConfigs(
PatchPerInstanceConfigsInstanceGroupManagerRequest request) → Future< Operation> -
Inserts or patches per-instance configurations for the managed instance
group. perInstanceConfig.name serves as a key used to
distinguish whether to perform insert or patch.
override
-
recreateInstances(
RecreateInstancesInstanceGroupManagerRequest request) → Future< Operation> -
Flags the specified VM instances in the managed instance group to be
immediately recreated. Each instance is recreated using the group's current
configuration. This operation is marked as DONE when the flag
is set even if the instances have not yet been recreated. You must
separately verify the status of each instance by checking itscurrentAction field; for more information, see Checking
the status of managed instances.
override
-
resize(
ResizeInstanceGroupManagerRequest request) → Future< Operation> -
Resizes the managed instance group. If you increase the size, the group
creates new instances using the current instance template. If you decrease
the size, the group deletes instances. The resize operation is markedDONE when the resize actions are scheduled even if the group
has not yet added or deleted any instances. You must separately
verify the status of the creating or deleting
actions with thelistmanagedinstances
method.
override
-
resumeInstances(
ResumeInstancesInstanceGroupManagerRequest request) → Future< Operation> -
Flags the specified instances in the managed instance group to be
resumed. This method increases thetargetSize and decreases the targetSuspendedSize
of the managed instance group by the number of instances that you resume.
The resumeInstances operation is marked DONE if
the resumeInstances request is successful. The underlying
actions take additional time. You must separately verify the status of theRESUMING action with thelistmanagedinstances
method.
override
-
setInstanceTemplate(
SetInstanceTemplateInstanceGroupManagerRequest request) → Future< Operation> -
Specifies the instance template to use when creating new instances in this
group. The templates for existing instances in the group do not change
unless you run recreateInstances, runapplyUpdatesToInstances, or set the group'supdatePolicy.type to PROACTIVE.
override
-
setTargetPools(
SetTargetPoolsInstanceGroupManagerRequest request) → Future< Operation> -
Modifies the target pools to which all instances in this managed instance
group are assigned. The target pools automatically apply to all of the
instances in the managed instance group. This operation is markedDONE when you make the request even if the instances have not
yet been added to their target pools. The change might take some time to
apply to all of the instances in the group depending on the size of the
group.
override
-
startInstances(
StartInstancesInstanceGroupManagerRequest request) → Future< Operation> -
Flags the specified instances in the managed instance group to be
started. This method increases thetargetSize and decreases the targetStoppedSize
of the managed instance group by the number of instances that you start.
The startInstances operation is marked DONE if
the startInstances request is successful. The underlying
actions take additional time. You must separately verify the status of theSTARTING action with thelistmanagedinstances
method.
override
-
stopInstances(
StopInstancesInstanceGroupManagerRequest request) → Future< Operation> -
Flags the specified instances in the managed instance group to be
immediately stopped. You can only specify instances that are running in
this request. This method reduces thetargetSize and increases the targetStoppedSize
of the managed instance group by the number of instances that you stop.
The stopInstances operation is marked DONE if
the stopInstances request is successful. The underlying
actions take additional time. You must separately verify the status of theSTOPPING action with thelistmanagedinstances
method.
override
-
suspendInstances(
SuspendInstancesInstanceGroupManagerRequest request) → Future< Operation> -
Flags the specified instances in the managed instance group to be
immediately suspended. You can only specify instances that are running in
this request. This method reduces thetargetSize and increases the targetSuspendedSize
of the managed instance group by the number of instances that you suspend.
The suspendInstances operation is marked DONE if
the suspendInstances request is successful. The underlying
actions take additional time. You must separately verify the status of theSUSPENDING action with thelistmanagedinstances
method.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
updatePerInstanceConfigs(
UpdatePerInstanceConfigsInstanceGroupManagerRequest request) → Future< Operation> -
Inserts or updates per-instance configurations for the managed instance
group. perInstanceConfig.name serves as a key used to
distinguish whether to perform insert or patch.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited