listManagedInstances method
Lists all of the instances in the managed instance group. Each instance
in the list has a currentAction, which indicates the action
that the managed instance group is performing on the instance. For example,
if the group is still creating an instance, the currentAction
is CREATING. If a previous action failed, the
list displays the errors for that failed action. The orderBy
query parameter is not supported. The pageToken query parameter is
supported only if the group's listManagedInstancesResults field is set
to PAGINATED.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<InstanceGroupManagersListManagedInstancesResponse>
listManagedInstances(
ListManagedInstancesInstanceGroupManagersRequest request,
) async {
if (isClosed) throw StateError('Service is closed');
if (_listManagedInstances case final listManagedInstances?) {
return listManagedInstances(request);
}
throw UnsupportedError('listManagedInstances');
}