aggregatedList method
Retrieves an aggregated list of all of the instances in your project across all regions and zones.
The performance of this method degrades when a filter is specified on a project that has a very large number of instances.
To prevent failure, Google recommends that you set the
returnPartialSuccess parameter to true.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<InstanceAggregatedList> aggregatedList(
AggregatedListInstancesRequest request,
) async {
if (isClosed) throw StateError('Service is closed');
if (_aggregatedList case final aggregatedList?) {
return aggregatedList(request);
}
throw UnsupportedError('aggregatedList');
}