setShieldedInstanceIntegrityPolicy method

  1. @override
Future<Operation> setShieldedInstanceIntegrityPolicy(
  1. SetShieldedInstanceIntegrityPolicyInstanceRequest request
)
override

Sets the Shielded Instance integrity policy for an instance. You can only use this method on a running instance. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Operation> setShieldedInstanceIntegrityPolicy(
  SetShieldedInstanceIntegrityPolicyInstanceRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_setShieldedInstanceIntegrityPolicy
      case final setShieldedInstanceIntegrityPolicy?) {
    return setShieldedInstanceIntegrityPolicy(request);
  }
  throw UnsupportedError('setShieldedInstanceIntegrityPolicy');
}