FakeInstantSnapshots class base
Testing fake for InstantSnapshots.
- Implemented types
Constructors
-
FakeInstantSnapshots({Future<
InstantSnapshotAggregatedList> aggregatedList(AggregatedListInstantSnapshotsRequest request)?, Future<Operation> delete(DeleteInstantSnapshotRequest request)?, Future<InstantSnapshot> get(GetInstantSnapshotRequest request)?, Future<Policy> getIamPolicy(GetIamPolicyInstantSnapshotRequest request)?, Future<Operation> insert(InsertInstantSnapshotRequest request)?, Future<InstantSnapshotList> list(ListInstantSnapshotsRequest request)?, Future<Policy> setIamPolicy(SetIamPolicyInstantSnapshotRequest request)?, Future<Operation> setLabels(SetLabelsInstantSnapshotRequest request)?, Future<TestPermissionsResponse> testIamPermissions(TestIamPermissionsInstantSnapshotRequest request)?})
Properties
Methods
-
aggregatedList(
AggregatedListInstantSnapshotsRequest request) → Future< InstantSnapshotAggregatedList> -
Retrieves an aggregated list of instantSnapshots.
override
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
delete(
DeleteInstantSnapshotRequest request) → Future< Operation> -
Deletes the specified InstantSnapshot resource. Keep in mind that deleting
a single instantSnapshot might not necessarily delete all the data on that
instantSnapshot. If any data on the instantSnapshot that is marked for
deletion is needed for subsequent instantSnapshots, the data will be moved
to the next corresponding instantSnapshot.
override
-
get(
GetInstantSnapshotRequest request) → Future< InstantSnapshot> -
Returns the specified InstantSnapshot resource in the specified zone.
override
-
getIamPolicy(
GetIamPolicyInstantSnapshotRequest request) → Future< Policy> -
Gets the access control policy for a resource. May be empty if no such
policy or resource exists.
override
-
insert(
InsertInstantSnapshotRequest request) → Future< Operation> -
Creates an instant snapshot in the specified zone.
override
-
list(
ListInstantSnapshotsRequest request) → Future< InstantSnapshotList> -
Retrieves the list of InstantSnapshot resources contained within
the specified zone.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setIamPolicy(
SetIamPolicyInstantSnapshotRequest request) → Future< Policy> -
Sets the access control policy on the specified resource.
Replaces any existing policy.
override
-
setLabels(
SetLabelsInstantSnapshotRequest request) → Future< Operation> -
Sets the labels on a instantSnapshot in the given zone. To learn more about
labels, read the Labeling
Resources documentation.
override
-
testIamPermissions(
TestIamPermissionsInstantSnapshotRequest request) → Future< TestPermissionsResponse> -
Returns permissions that a caller has on the specified resource.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited