FakeInterconnectAttachmentGroups class base
Testing fake for InterconnectAttachmentGroups.
- Implemented types
Constructors
-
FakeInterconnectAttachmentGroups({Future<
Operation> delete(DeleteInterconnectAttachmentGroupRequest request)?, Future<InterconnectAttachmentGroup> get(GetInterconnectAttachmentGroupRequest request)?, Future<Policy> getIamPolicy(GetIamPolicyInterconnectAttachmentGroupRequest request)?, Future<InterconnectAttachmentGroupsGetOperationalStatusResponse> getOperationalStatus(GetOperationalStatusInterconnectAttachmentGroupRequest request)?, Future<Operation> insert(InsertInterconnectAttachmentGroupRequest request)?, Future<InterconnectAttachmentGroupsListResponse> list(ListInterconnectAttachmentGroupsRequest request)?, Future<Operation> patch(PatchInterconnectAttachmentGroupRequest request)?, Future<Policy> setIamPolicy(SetIamPolicyInterconnectAttachmentGroupRequest request)?, Future<TestPermissionsResponse> testIamPermissions(TestIamPermissionsInterconnectAttachmentGroupRequest request)?})
Properties
Methods
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
delete(
DeleteInterconnectAttachmentGroupRequest request) → Future< Operation> -
Deletes the specified InterconnectAttachmentGroup in the given scope
override
-
get(
GetInterconnectAttachmentGroupRequest request) → Future< InterconnectAttachmentGroup> -
Returns the specified InterconnectAttachmentGroup resource in the given
scope.
override
-
getIamPolicy(
GetIamPolicyInterconnectAttachmentGroupRequest request) → Future< Policy> -
Gets the access control policy for a resource. May be empty if no such
policy or resource exists.
override
-
getOperationalStatus(
GetOperationalStatusInterconnectAttachmentGroupRequest request) → Future< InterconnectAttachmentGroupsGetOperationalStatusResponse> -
Returns the InterconnectAttachmentStatuses for the specified
InterconnectAttachmentGroup resource.
override
-
insert(
InsertInterconnectAttachmentGroupRequest request) → Future< Operation> -
Creates a InterconnectAttachmentGroup in the specified project in the given
scope using the parameters that are included in the request.
override
-
list(
ListInterconnectAttachmentGroupsRequest request) → Future< InterconnectAttachmentGroupsListResponse> -
Lists the InterconnectAttachmentGroups for a project in the given scope.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchInterconnectAttachmentGroupRequest request) → Future< Operation> -
Patches the specified InterconnectAttachmentGroup resource with the data
included in the request. This method supports PATCH
semantics and usesJSON merge
patch format and processing rules.
override
-
setIamPolicy(
SetIamPolicyInterconnectAttachmentGroupRequest request) → Future< Policy> -
Sets the access control policy on the specified resource.
Replaces any existing policy.
override
-
testIamPermissions(
TestIamPermissionsInterconnectAttachmentGroupRequest request) → Future< TestPermissionsResponse> -
Returns permissions that a caller has on the specified resource.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited