FakeInterconnectRemoteLocations class base
Testing fake for InterconnectRemoteLocations.
- Implemented types
Constructors
Properties
Methods
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
get(
GetInterconnectRemoteLocationRequest request) → Future< InterconnectRemoteLocation> -
Returns the details for the specified interconnect remote location. Gets a
list of available interconnect remote locations by making alist() request.
override
-
list(
ListInterconnectRemoteLocationsRequest request) → Future< InterconnectRemoteLocationList> -
Retrieves the list of interconnect remote locations available to the
specified project.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited