FakeInterconnects class base
Testing fake for Interconnects.
- Implemented types
Constructors
-
FakeInterconnects({Future<
Operation> delete(DeleteInterconnectRequest request)?, Future<Interconnect> get(GetInterconnectRequest request)?, Future<InterconnectsGetDiagnosticsResponse> getDiagnostics(GetDiagnosticsInterconnectRequest request)?, Future<InterconnectsGetMacsecConfigResponse> getMacsecConfig(GetMacsecConfigInterconnectRequest request)?, Future<Operation> insert(InsertInterconnectRequest request)?, Future<InterconnectList> list(ListInterconnectsRequest request)?, Future<Operation> patch(PatchInterconnectRequest request)?, Future<Operation> setLabels(SetLabelsInterconnectRequest request)?})
Properties
Methods
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
delete(
DeleteInterconnectRequest request) → Future< Operation> -
Deletes the specified Interconnect.
override
-
get(
GetInterconnectRequest request) → Future< Interconnect> -
Returns the specified Interconnect. Get a list of available Interconnects
by making a list() request.
override
-
getDiagnostics(
GetDiagnosticsInterconnectRequest request) → Future< InterconnectsGetDiagnosticsResponse> -
Returns the interconnectDiagnostics for the specified
Interconnect.
override
-
getMacsecConfig(
GetMacsecConfigInterconnectRequest request) → Future< InterconnectsGetMacsecConfigResponse> -
Returns the interconnectMacsecConfig for the specified
Interconnect.
override
-
insert(
InsertInterconnectRequest request) → Future< Operation> -
Creates an Interconnect in the specified project using
the data included in the request.
override
-
list(
ListInterconnectsRequest request) → Future< InterconnectList> -
Retrieves the list of Interconnects available to the specified project.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchInterconnectRequest request) → Future< Operation> -
Updates the specified Interconnect with the data included in the request.
This method supportsPATCH
semantics and uses theJSON merge
patch format and processing rules.
override
-
setLabels(
SetLabelsInterconnectRequest request) → Future< Operation> -
Sets the labels on an Interconnect. To learn more about labels,
read the Labeling
Resources documentation.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited