get method
Return a specified license code. License codes are mirrored across all projects that have permissions to read the License Code. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<LicenseCode> get(GetLicenseCodeRequest request) async {
if (isClosed) throw StateError('Service is closed');
if (_get case final get?) {
return get(request);
}
throw UnsupportedError('get');
}