FakeLicenses class base
Testing fake for Licenses.
- Implemented types
Constructors
-
FakeLicenses({Future<
Operation> delete(DeleteLicenseRequest request)?, Future<License> get(GetLicenseRequest request)?, Future<Policy> getIamPolicy(GetIamPolicyLicenseRequest request)?, Future<Operation> insert(InsertLicenseRequest request)?, Future<LicensesListResponse> list(ListLicensesRequest request)?, Future<Policy> setIamPolicy(SetIamPolicyLicenseRequest request)?, Future<TestPermissionsResponse> testIamPermissions(TestIamPermissionsLicenseRequest request)?, Future<Operation> update(UpdateLicenseRequest request)?})
Properties
Methods
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
delete(
DeleteLicenseRequest request) → Future< Operation> -
Deletes the specified license.
Caution This resource is intended
for use only by third-party partners who are creatingCloud Marketplace
images.
override
-
get(
GetLicenseRequest request) → Future< License> -
Returns the specified License resource.
Caution This resource is intended
for use only by third-party partners who are creatingCloud Marketplace
images.
override
-
getIamPolicy(
GetIamPolicyLicenseRequest request) → Future< Policy> -
Gets the access control policy for a resource. May be empty if no such
policy or resource exists.
Caution This resource is intended
for use only by third-party partners who are creatingCloud Marketplace
images.
override
-
insert(
InsertLicenseRequest request) → Future< Operation> -
Create a License resource in the specified project.
Caution This resource is intended
for use only by third-party partners who are creatingCloud Marketplace
images.
override
-
list(
ListLicensesRequest request) → Future< LicensesListResponse> -
Retrieves the list of licenses
available in the specified project. This method does not
get any licenses that belong to other projects, including licenses attached
to publicly-available images, like Debian 9. If you want to get a list of
publicly-available licenses, use this method to make a request to the
respective image project, such as debian-cloud orwindows-cloud.
Caution This resource is intended
for use only by third-party partners who are creatingCloud Marketplace
images.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setIamPolicy(
SetIamPolicyLicenseRequest request) → Future< Policy> -
Sets the access control policy on the specified resource.
Replaces any existing policy.
Caution This resource is intended
for use only by third-party partners who are creatingCloud Marketplace
images.
override
-
testIamPermissions(
TestIamPermissionsLicenseRequest request) → Future< TestPermissionsResponse> -
Returns permissions that a caller has on the specified resource.
Caution This resource is intended
for use only by third-party partners who are creatingCloud Marketplace
images.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
UpdateLicenseRequest request) → Future< Operation> -
Updates a License resource in the specified project.
Caution This resource is intended
for use only by third-party partners who are creatingCloud Marketplace
images.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited