FakeMachineImages class base
Testing fake for MachineImages.
- Implemented types
Constructors
-
FakeMachineImages({Future<
Operation> delete(DeleteMachineImageRequest request)?, Future<MachineImage> get(GetMachineImageRequest request)?, Future<Policy> getIamPolicy(GetIamPolicyMachineImageRequest request)?, Future<Operation> insert(InsertMachineImageRequest request)?, Future<MachineImageList> list(ListMachineImagesRequest request)?, Future<Policy> setIamPolicy(SetIamPolicyMachineImageRequest request)?, Future<Operation> setLabels(SetLabelsMachineImageRequest request)?, Future<TestPermissionsResponse> testIamPermissions(TestIamPermissionsMachineImageRequest request)?})
Properties
Methods
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
delete(
DeleteMachineImageRequest request) → Future< Operation> -
Deletes the specified machine image. Deleting a machine image is permanent
and cannot be undone.
override
-
get(
GetMachineImageRequest request) → Future< MachineImage> -
Returns the specified machine image.
override
-
getIamPolicy(
GetIamPolicyMachineImageRequest request) → Future< Policy> -
Gets the access control policy for a resource. May be empty if no such
policy or resource exists.
override
-
insert(
InsertMachineImageRequest request) → Future< Operation> -
Creates a machine image in the specified project using the
data that is included in the request. If you are creating a new machine
image to update an existing instance, your new machine image should use the
same network or, if applicable, the same subnetwork as the original
instance.
override
-
list(
ListMachineImagesRequest request) → Future< MachineImageList> -
Retrieves a list of machine images that are contained within
the specified project.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setIamPolicy(
SetIamPolicyMachineImageRequest request) → Future< Policy> -
Sets the access control policy on the specified resource.
Replaces any existing policy.
override
-
setLabels(
SetLabelsMachineImageRequest request) → Future< Operation> -
Sets the labels on a machine image. To learn more about labels, read theLabeling
Resources documentation.
override
-
testIamPermissions(
TestIamPermissionsMachineImageRequest request) → Future< TestPermissionsResponse> -
Returns permissions that a caller has on the specified resource.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited