FakeMachineTypes class base
Testing fake for MachineTypes.
- Implemented types
Constructors
-
FakeMachineTypes({Future<
MachineTypeAggregatedList> aggregatedList(AggregatedListMachineTypesRequest request)?, Future<MachineType> get(GetMachineTypeRequest request)?, Future<MachineTypeList> list(ListMachineTypesRequest request)?})
Properties
Methods
-
aggregatedList(
AggregatedListMachineTypesRequest request) → Future< MachineTypeAggregatedList> -
Retrieves an aggregated list of machine types.
override
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
get(
GetMachineTypeRequest request) → Future< MachineType> -
Returns the specified machine type.
override
-
list(
ListMachineTypesRequest request) → Future< MachineTypeList> -
Retrieves a list of machine types available to the specified
project.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited