aggregatedList method
Retrieves an aggregated list of network firewall policies, listing network firewall policies from all applicable scopes (global and regional) and grouping the results per scope.
To prevent failure, it is recommended that you set the
returnPartialSuccess parameter to true.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<NetworkFirewallPolicyAggregatedList> aggregatedList(
AggregatedListNetworkFirewallPoliciesRequest request,
) async {
if (isClosed) throw StateError('Service is closed');
if (_aggregatedList case final aggregatedList?) {
return aggregatedList(request);
}
throw UnsupportedError('aggregatedList');
}