FakeNetworkProfiles class base
Testing fake for NetworkProfiles.
- Implemented types
Constructors
-
FakeNetworkProfiles({Future<
NetworkProfile> get(GetNetworkProfileRequest request)?, Future<NetworkProfilesListResponse> list(ListNetworkProfilesRequest request)?})
Properties
Methods
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
get(
GetNetworkProfileRequest request) → Future< NetworkProfile> -
Returns the specified network profile.
override
-
list(
ListNetworkProfilesRequest request) → Future< NetworkProfilesListResponse> -
Retrieves a list of network profiles available to the specified
project.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited