FakeNodeTypes class base
Testing fake for NodeTypes.
- Implemented types
Constructors
-
FakeNodeTypes({Future<
NodeTypeAggregatedList> aggregatedList(AggregatedListNodeTypesRequest request)?, Future<NodeType> get(GetNodeTypeRequest request)?, Future<NodeTypeList> list(ListNodeTypesRequest request)?})
Properties
Methods
-
aggregatedList(
AggregatedListNodeTypesRequest request) → Future< NodeTypeAggregatedList> -
Retrieves an aggregated list of node types.
override
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
get(
GetNodeTypeRequest request) → Future< NodeType> -
Returns the specified node type.
override
-
list(
ListNodeTypesRequest request) → Future< NodeTypeList> -
Retrieves a list of node types available to the specified
project.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited