FakePreviewFeatures class base
Testing fake for PreviewFeatures.
- Implemented types
Constructors
-
FakePreviewFeatures({Future<
PreviewFeature> get(GetPreviewFeatureRequest request)?, Future<PreviewFeatureList> list(ListPreviewFeaturesRequest request)?, Future<Operation> update(UpdatePreviewFeatureRequest request)?})
Properties
Methods
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
get(
GetPreviewFeatureRequest request) → Future< PreviewFeature> -
Returns the details of the given PreviewFeature.
override
-
list(
ListPreviewFeaturesRequest request) → Future< PreviewFeatureList> -
Returns the details of the given PreviewFeature.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
UpdatePreviewFeatureRequest request) → Future< Operation> -
Patches the given PreviewFeature. This method is used to enable or disable
a PreviewFeature.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited