FakeProjectViews class base
Testing fake for ProjectViews.
- Implemented types
Constructors
-
FakeProjectViews({Future<
ProjectView> get(GetProjectViewRequest request)?})
Properties
Methods
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
get(
GetProjectViewRequest request) → Future< ProjectView> -
Returns the specified global ProjectViews resource, with a regional
context.
This regional API endpoint reads resource metadata from regional
read-only replicas. Because changes are copied to these regional replicas
asynchronously, for real-time resource reads or any write operations
(creating, updating, or deleting resources), use the global
projects.get
endpoint.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited