setCommonInstanceMetadata method
Sets metadata common to all instances within the specified project using the data included in the request.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<Operation> setCommonInstanceMetadata(
SetCommonInstanceMetadataProjectRequest request,
) async {
if (isClosed) throw StateError('Service is closed');
if (_setCommonInstanceMetadata case final setCommonInstanceMetadata?) {
return setCommonInstanceMetadata(request);
}
throw UnsupportedError('setCommonInstanceMetadata');
}