createSnapshot method
Creates a snapshot of a specified persistent disk. For regular snapshot creation, consider using snapshots.insert instead, as that method supports more features, such as creating snapshots in a project different from the source disk project.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<Operation> createSnapshot(
CreateSnapshotRegionDiskRequest request,
) async {
if (isClosed) throw StateError('Service is closed');
if (_createSnapshot case final createSnapshot?) {
return createSnapshot(request);
}
throw UnsupportedError('createSnapshot');
}