FakeRegionInstanceGroupManagers class base
Testing fake for RegionInstanceGroupManagers.
- Implemented types
Constructors
-
FakeRegionInstanceGroupManagers({Future<
Operation> abandonInstances(AbandonInstancesRegionInstanceGroupManagerRequest request)?, Future<Operation> applyUpdatesToInstances(ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest request)?, Future<Operation> createInstances(CreateInstancesRegionInstanceGroupManagerRequest request)?, Future<Operation> delete(DeleteRegionInstanceGroupManagerRequest request)?, Future<Operation> deleteInstances(DeleteInstancesRegionInstanceGroupManagerRequest request)?, Future<Operation> deletePerInstanceConfigs(DeletePerInstanceConfigsRegionInstanceGroupManagerRequest request)?, Future<InstanceGroupManager> get(GetRegionInstanceGroupManagerRequest request)?, Future<Operation> insert(InsertRegionInstanceGroupManagerRequest request)?, Future<RegionInstanceGroupManagerList> list(ListRegionInstanceGroupManagersRequest request)?, Future<RegionInstanceGroupManagersListErrorsResponse> listErrors(ListErrorsRegionInstanceGroupManagersRequest request)?, Future<RegionInstanceGroupManagersListInstancesResponse> listManagedInstances(ListManagedInstancesRegionInstanceGroupManagersRequest request)?, Future<RegionInstanceGroupManagersListInstanceConfigsResp> listPerInstanceConfigs(ListPerInstanceConfigsRegionInstanceGroupManagersRequest request)?, Future<Operation> patch(PatchRegionInstanceGroupManagerRequest request)?, Future<Operation> patchPerInstanceConfigs(PatchPerInstanceConfigsRegionInstanceGroupManagerRequest request)?, Future<Operation> recreateInstances(RecreateInstancesRegionInstanceGroupManagerRequest request)?, Future<Operation> resize(ResizeRegionInstanceGroupManagerRequest request)?, Future<Operation> resumeInstances(ResumeInstancesRegionInstanceGroupManagerRequest request)?, Future<Operation> setInstanceTemplate(SetInstanceTemplateRegionInstanceGroupManagerRequest request)?, Future<Operation> setTargetPools(SetTargetPoolsRegionInstanceGroupManagerRequest request)?, Future<Operation> startInstances(StartInstancesRegionInstanceGroupManagerRequest request)?, Future<Operation> stopInstances(StopInstancesRegionInstanceGroupManagerRequest request)?, Future<Operation> suspendInstances(SuspendInstancesRegionInstanceGroupManagerRequest request)?, Future<Operation> updatePerInstanceConfigs(UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest request)?})
Properties
Methods
-
abandonInstances(
AbandonInstancesRegionInstanceGroupManagerRequest request) → Future< Operation> -
Flags the specified instances to be immediately removed from the managed
instance group. Abandoning an instance does not delete the
instance, but it does remove the instance from any target pools that are
applied by the managed instance group. This method reduces thetargetSize of the managed instance group by the
number of instances that you abandon. This operation is marked asDONE when the action is scheduled even if the instances have
not yet been removed from the group. You must separately verify the
status of the abandoning action with thelistmanagedinstances
method.
override
-
applyUpdatesToInstances(
ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest request) → Future< Operation> -
Apply updates to selected instances the managed instance group.
override
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
createInstances(
CreateInstancesRegionInstanceGroupManagerRequest request) → Future< Operation> -
Creates instances with per-instance configurations in this regional managed
instance group. Instances are created using the current instance template.
The create instances operation is marked DONE if
the createInstances request is successful. The underlying
actions take additional time. You must separately verify the status of thecreating or actions with the listmanagedinstances
method.
override
-
delete(
DeleteRegionInstanceGroupManagerRequest request) → Future< Operation> -
Deletes the specified managed instance group and all of the instances
in that group.
override
-
deleteInstances(
DeleteInstancesRegionInstanceGroupManagerRequest request) → Future< Operation> -
Flags the specified instances in the managed instance group to be
immediately deleted. The instances are also removed from any target
pools of which they were a member. This method reduces thetargetSize of the managed instance group by the number of
instances that you delete.
The deleteInstances operation is marked DONE if
the deleteInstances request is successful. The underlying
actions take additional time. You must separately verify the status of thedeleting action with thelistmanagedinstances
method.
override
-
deletePerInstanceConfigs(
DeletePerInstanceConfigsRegionInstanceGroupManagerRequest request) → Future< Operation> -
Deletes selected per-instance configurations for the managed instance
group.
override
-
get(
GetRegionInstanceGroupManagerRequest request) → Future< InstanceGroupManager> -
Returns all of the details about the specified managed instance group.
override
-
insert(
InsertRegionInstanceGroupManagerRequest request) → Future< Operation> -
Creates a managed instance group using the information that you specify
in the request. After the group is created, instances in the group are
created using the specified instance template.
This operation is marked as DONE when the group is created
even if the instances in the group have not yet been created. You must
separately verify the status of the individual instances with thelistmanagedinstances
method.
override
-
list(
ListRegionInstanceGroupManagersRequest request) → Future< RegionInstanceGroupManagerList> -
Retrieves the list of managed instance groups that are contained
within the specified region.
override
-
listErrors(
ListErrorsRegionInstanceGroupManagersRequest request) → Future< RegionInstanceGroupManagersListErrorsResponse> -
Lists all errors thrown by actions on instances for a given regional
managed instance group. The filter andorderBy query parameters are not supported.
override
-
listManagedInstances(
ListManagedInstancesRegionInstanceGroupManagersRequest request) → Future< RegionInstanceGroupManagersListInstancesResponse> -
Lists the instances in the managed instance group and instances that are
scheduled to be created. The list includes any current actions
that the group has scheduled for its instances. The orderBy
query parameter is not supported. The
pageTokenquery parameter is supported only if the group'slistManagedInstancesResultsfield is set toPAGINATED.override -
listPerInstanceConfigs(
ListPerInstanceConfigsRegionInstanceGroupManagersRequest request) → Future< RegionInstanceGroupManagersListInstanceConfigsResp> -
Lists all of the per-instance configurations defined for the managed
instance group. The orderBy query parameter is not supported.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchRegionInstanceGroupManagerRequest request) → Future< Operation> -
Updates a managed instance group using the information that you specify
in the request.
This operation is marked as DONE when the group is patched
even if the instances in the group are still in the process of being
patched. You must separately verify the status of the individual instances
with the listmanagedinstances
method. This method supportsPATCH
semantics and uses theJSON merge
patch format and processing rules.
override
-
patchPerInstanceConfigs(
PatchPerInstanceConfigsRegionInstanceGroupManagerRequest request) → Future< Operation> -
Inserts or patches per-instance configurations for the managed instance
group. perInstanceConfig.name serves as a key used to
distinguish whether to perform insert or patch.
override
-
recreateInstances(
RecreateInstancesRegionInstanceGroupManagerRequest request) → Future< Operation> -
Flags the specified VM instances in the managed instance group to be
immediately recreated. Each instance is recreated using the group's current
configuration. This operation is marked as DONE when the flag
is set even if the instances have not yet been recreated. You must
separately verify the status of each instance by checking itscurrentAction field; for more information, see Checking
the status of managed instances.
override
-
resize(
ResizeRegionInstanceGroupManagerRequest request) → Future< Operation> -
Changes the intended size of the managed instance group. If you increase
the size, the group creates new instances using the current instance
template. If you decrease the size, the group deletes one or more
instances.
override
-
resumeInstances(
ResumeInstancesRegionInstanceGroupManagerRequest request) → Future< Operation> -
Flags the specified instances in the managed instance group to be
resumed. This method increases thetargetSize and decreases the targetSuspendedSize
of the managed instance group by the number of instances that you resume.
The resumeInstances operation is marked DONE if
the resumeInstances request is successful. The underlying
actions take additional time. You must separately verify the status of theRESUMING action with thelistmanagedinstances
method.
override
-
setInstanceTemplate(
SetInstanceTemplateRegionInstanceGroupManagerRequest request) → Future< Operation> -
Sets the instance template to use when creating new instances or recreating
instances in this group. Existing instances are not affected.
override
-
setTargetPools(
SetTargetPoolsRegionInstanceGroupManagerRequest request) → Future< Operation> -
Modifies the target pools to which all new instances in this group are
assigned. Existing instances in the group are not affected.
override
-
startInstances(
StartInstancesRegionInstanceGroupManagerRequest request) → Future< Operation> -
Flags the specified instances in the managed instance group to be
started. This method increases thetargetSize and decreases the targetStoppedSize
of the managed instance group by the number of instances that you start.
The startInstances operation is marked DONE if
the startInstances request is successful. The underlying
actions take additional time. You must separately verify the status of theSTARTING action with thelistmanagedinstances
method.
override
-
stopInstances(
StopInstancesRegionInstanceGroupManagerRequest request) → Future< Operation> -
Flags the specified instances in the managed instance group to be
immediately stopped. You can only specify instances that are running in
this request. This method reduces thetargetSize and increases the targetStoppedSize
of the managed instance group by the number of instances that you stop.
The stopInstances operation is marked DONE if
the stopInstances request is successful. The underlying
actions take additional time. You must separately verify the status of theSTOPPING action with thelistmanagedinstances
method.
override
-
suspendInstances(
SuspendInstancesRegionInstanceGroupManagerRequest request) → Future< Operation> -
Flags the specified instances in the managed instance group to be
immediately suspended. You can only specify instances that are running in
this request. This method reduces thetargetSize and increases the targetSuspendedSize
of the managed instance group by the number of instances that you suspend.
The suspendInstances operation is marked DONE if
the suspendInstances request is successful. The underlying
actions take additional time. You must separately verify the status of theSUSPENDING action with thelistmanagedinstances
method.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
updatePerInstanceConfigs(
UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest request) → Future< Operation> -
Inserts or updates per-instance configurations for the managed instance
group. perInstanceConfig.name serves as a key used to
distinguish whether to perform insert or patch.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited