FakeRegionInstances class base
Testing fake for RegionInstances.
- Implemented types
Constructors
-
FakeRegionInstances({Future<
Operation> bulkInsert(BulkInsertRegionInstanceRequest request)?})
Properties
Methods
-
bulkInsert(
BulkInsertRegionInstanceRequest request) → Future< Operation> -
Creates multiple instances in a given region. Count specifies the number of
instances to create.
override
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited