FakeRegionNotificationEndpoints class base

Testing fake for RegionNotificationEndpoints.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(AggregatedListRegionNotificationEndpointsRequest request) Future<NotificationEndpointAggregatedList>
Retrieves the list of all NotificationEndpoint resources, regional and global, available to the specified project.
override
close() → void
Closes the client and cleans up any resources associated with it.
override
delete(DeleteRegionNotificationEndpointRequest request) Future<Operation>
Deletes the specified NotificationEndpoint in the given region
override
get(GetRegionNotificationEndpointRequest request) Future<NotificationEndpoint>
Returns the specified NotificationEndpoint resource in the given region.
override
insert(InsertRegionNotificationEndpointRequest request) Future<Operation>
Create a NotificationEndpoint in the specified project in the given region using the parameters that are included in the request.
override
list(ListRegionNotificationEndpointsRequest request) Future<NotificationEndpointList>
Lists the NotificationEndpoints for a project in the given region.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
testIamPermissions(TestIamPermissionsRegionNotificationEndpointRequest request) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited