FakeRegionUrlMaps class base
Testing fake for RegionUrlMaps.
- Implemented types
Constructors
-
FakeRegionUrlMaps({Future<
Operation> delete(DeleteRegionUrlMapRequest request)?, Future<UrlMap> get(GetRegionUrlMapRequest request)?, Future<Operation> insert(InsertRegionUrlMapRequest request)?, Future<UrlMapList> list(ListRegionUrlMapsRequest request)?, Future<Operation> patch(PatchRegionUrlMapRequest request)?, Future<Operation> update(UpdateRegionUrlMapRequest request)?, Future<UrlMapsValidateResponse> validate(ValidateRegionUrlMapRequest request)?})
Properties
Methods
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
delete(
DeleteRegionUrlMapRequest request) → Future< Operation> -
Deletes the specified UrlMap resource.
override
-
get(
GetRegionUrlMapRequest request) → Future< UrlMap> -
Returns the specified UrlMap resource.
override
-
insert(
InsertRegionUrlMapRequest request) → Future< Operation> -
Creates a UrlMap resource in the specified project using
the data included in the request.
override
-
list(
ListRegionUrlMapsRequest request) → Future< UrlMapList> -
Retrieves the list of UrlMap resources available to the specified
project in the specified region.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchRegionUrlMapRequest request) → Future< Operation> -
Patches the specified UrlMap resource with the data included in the
request. This method supportsPATCH
semantics and usesJSON merge
patch format and processing rules.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
UpdateRegionUrlMapRequest request) → Future< Operation> -
Updates the specified UrlMap resource with the data included in the
request.
override
-
validate(
ValidateRegionUrlMapRequest request) → Future< UrlMapsValidateResponse> -
Runs static validation for the UrlMap. In particular, the tests of the
provided UrlMap will be run. Calling this method does NOT create the
UrlMap.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited