FakeRegionZones class base
Testing fake for RegionZones.
- Implemented types
Constructors
-
FakeRegionZones({Future<
ZoneList> list(ListRegionZonesRequest request)?})
Properties
Methods
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
list(
ListRegionZonesRequest request) → Future< ZoneList> -
Retrieves the list of Zone resources under the specific region available to
the specified project.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited