FakeSecurityPolicies class base
Testing fake for SecurityPolicies.
- Implemented types
Constructors
-
FakeSecurityPolicies({Future<
Operation> addRule(AddRuleSecurityPolicyRequest request)?, Future<SecurityPoliciesAggregatedList> aggregatedList(AggregatedListSecurityPoliciesRequest request)?, Future<Operation> delete(DeleteSecurityPolicyRequest request)?, Future<SecurityPolicy> get(GetSecurityPolicyRequest request)?, Future<SecurityPolicyRule> getRule(GetRuleSecurityPolicyRequest request)?, Future<Operation> insert(InsertSecurityPolicyRequest request)?, Future<SecurityPolicyList> list(ListSecurityPoliciesRequest request)?, Future<SecurityPoliciesListPreconfiguredExpressionSetsResponse> listPreconfiguredExpressionSets(ListPreconfiguredExpressionSetsSecurityPoliciesRequest request)?, Future<Operation> patch(PatchSecurityPolicyRequest request)?, Future<Operation> patchRule(PatchRuleSecurityPolicyRequest request)?, Future<Operation> removeRule(RemoveRuleSecurityPolicyRequest request)?, Future<Operation> setLabels(SetLabelsSecurityPolicyRequest request)?})
Properties
Methods
-
addRule(
AddRuleSecurityPolicyRequest request) → Future< Operation> -
Inserts a rule into a security policy.
override
-
aggregatedList(
AggregatedListSecurityPoliciesRequest request) → Future< SecurityPoliciesAggregatedList> -
Retrieves the list of all SecurityPolicy resources, regional and global,
available to the specified project.
override
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
delete(
DeleteSecurityPolicyRequest request) → Future< Operation> -
Deletes the specified policy.
override
-
get(
GetSecurityPolicyRequest request) → Future< SecurityPolicy> -
List all of the ordered rules present in a single specified policy.
override
-
getRule(
GetRuleSecurityPolicyRequest request) → Future< SecurityPolicyRule> -
Gets a rule at the specified priority.
override
-
insert(
InsertSecurityPolicyRequest request) → Future< Operation> -
Creates a new policy in the specified project using the data included in
the request.
override
-
list(
ListSecurityPoliciesRequest request) → Future< SecurityPolicyList> -
List all the policies that have been configured for the specified project.
override
-
listPreconfiguredExpressionSets(
ListPreconfiguredExpressionSetsSecurityPoliciesRequest request) → Future< SecurityPoliciesListPreconfiguredExpressionSetsResponse> -
Gets the current list of preconfigured Web Application Firewall (WAF)
expressions.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchSecurityPolicyRequest request) → Future< Operation> -
Patches the specified policy with the data included in the request. To
clear fields in the policy, leave the fields empty and specify them in the
updateMask. This cannot be used to be update the rules in the policy.
Please use the per rule methods like addRule, patchRule, and removeRule
instead.
override
-
patchRule(
PatchRuleSecurityPolicyRequest request) → Future< Operation> -
Patches a rule at the specified priority. To clear fields in the rule,
leave the fields empty and specify them in the updateMask.
override
-
removeRule(
RemoveRuleSecurityPolicyRequest request) → Future< Operation> -
Deletes a rule at the specified priority.
override
-
setLabels(
SetLabelsSecurityPolicyRequest request) → Future< Operation> -
Sets the labels on a security policy. To learn more about labels,
read the Labeling Resources
documentation.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited