FakeSnapshots class base
Testing fake for Snapshots.
- Implemented types
Constructors
-
FakeSnapshots({Future<
Operation> delete(DeleteSnapshotRequest request)?, Future<Snapshot> get(GetSnapshotRequest request)?, Future<Policy> getIamPolicy(GetIamPolicySnapshotRequest request)?, Future<Operation> insert(InsertSnapshotRequest request)?, Future<SnapshotList> list(ListSnapshotsRequest request)?, Future<Policy> setIamPolicy(SetIamPolicySnapshotRequest request)?, Future<Operation> setLabels(SetLabelsSnapshotRequest request)?, Future<TestPermissionsResponse> testIamPermissions(TestIamPermissionsSnapshotRequest request)?, Future<Operation> updateKmsKey(UpdateKmsKeySnapshotRequest request)?})
Properties
Methods
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
delete(
DeleteSnapshotRequest request) → Future< Operation> -
Deletes the specified Snapshot resource. Keep in mind that deleting
a single snapshot might not necessarily delete all the data on that
snapshot. If any data on the snapshot that is marked for deletion is
needed for subsequent snapshots, the data will be moved to the next
corresponding snapshot.
override
-
get(
GetSnapshotRequest request) → Future< Snapshot> -
Returns the specified Snapshot resource.
override
-
getIamPolicy(
GetIamPolicySnapshotRequest request) → Future< Policy> -
Gets the access control policy for a resource. May be empty if no such
policy or resource exists.
override
-
insert(
InsertSnapshotRequest request) → Future< Operation> -
Creates a snapshot in the specified project using the data included
in the request. For regular snapshot creation, consider using this method
instead of disks.createSnapshot,
as this method supports more features, such as creating snapshots in a
project different from the source disk project.
override
-
list(
ListSnapshotsRequest request) → Future< SnapshotList> -
Retrieves the list of Snapshot resources contained within
the specified project.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setIamPolicy(
SetIamPolicySnapshotRequest request) → Future< Policy> -
Sets the access control policy on the specified resource.
Replaces any existing policy.
override
-
setLabels(
SetLabelsSnapshotRequest request) → Future< Operation> -
Sets the labels on a snapshot. To learn more about labels, read theLabeling
Resources documentation.
override
-
testIamPermissions(
TestIamPermissionsSnapshotRequest request) → Future< TestPermissionsResponse> -
Returns permissions that a caller has on the specified resource.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
updateKmsKey(
UpdateKmsKeySnapshotRequest request) → Future< Operation> -
Rotates the customer-managed
encryption key to the latest version for the specified snapshot.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited