FakeSslPolicies class base
Testing fake for SslPolicies.
- Implemented types
Constructors
-
FakeSslPolicies({Future<
SslPoliciesAggregatedList> aggregatedList(AggregatedListSslPoliciesRequest request)?, Future<Operation> delete(DeleteSslPolicyRequest request)?, Future<SslPolicy> get(GetSslPolicyRequest request)?, Future<Operation> insert(InsertSslPolicyRequest request)?, Future<SslPoliciesList> list(ListSslPoliciesRequest request)?, Future<SslPoliciesListAvailableFeaturesResponse> listAvailableFeatures(ListAvailableFeaturesSslPoliciesRequest request)?, Future<Operation> patch(PatchSslPolicyRequest request)?})
Properties
Methods
-
aggregatedList(
AggregatedListSslPoliciesRequest request) → Future< SslPoliciesAggregatedList> -
Retrieves the list of all SslPolicy resources, regional and global,
available to the specified project.
override
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
delete(
DeleteSslPolicyRequest request) → Future< Operation> -
Deletes the specified SSL policy. The SSL policy resource can be deleted
only if it is not in use by any TargetHttpsProxy or TargetSslProxy
resources.
override
-
get(
GetSslPolicyRequest request) → Future< SslPolicy> -
Lists all of the ordered rules present in a single specified policy.
override
-
insert(
InsertSslPolicyRequest request) → Future< Operation> -
Returns the specified SSL policy resource.
override
-
list(
ListSslPoliciesRequest request) → Future< SslPoliciesList> -
Lists all the SSL policies that have been configured for the specified
project.
override
-
listAvailableFeatures(
ListAvailableFeaturesSslPoliciesRequest request) → Future< SslPoliciesListAvailableFeaturesResponse> -
Lists all features that can be specified in the SSL policy when using
custom profile.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchSslPolicyRequest request) → Future< Operation> -
Patches the specified SSL policy with the data included in the request.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited