FakeTargetTcpProxies class base
Testing fake for TargetTcpProxies.
- Implemented types
Constructors
-
FakeTargetTcpProxies({Future<
TargetTcpProxyAggregatedList> aggregatedList(AggregatedListTargetTcpProxiesRequest request)?, Future<Operation> delete(DeleteTargetTcpProxyRequest request)?, Future<TargetTcpProxy> get(GetTargetTcpProxyRequest request)?, Future<Operation> insert(InsertTargetTcpProxyRequest request)?, Future<TargetTcpProxyList> list(ListTargetTcpProxiesRequest request)?, Future<Operation> setBackendService(SetBackendServiceTargetTcpProxyRequest request)?, Future<Operation> setProxyHeader(SetProxyHeaderTargetTcpProxyRequest request)?, Future<TestPermissionsResponse> testIamPermissions(TestIamPermissionsTargetTcpProxyRequest request)?})
Properties
Methods
-
aggregatedList(
AggregatedListTargetTcpProxiesRequest request) → Future< TargetTcpProxyAggregatedList> -
Retrieves the list of all TargetTcpProxy resources, regional and global,
available to the specified project.
override
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
delete(
DeleteTargetTcpProxyRequest request) → Future< Operation> -
Deletes the specified TargetTcpProxy resource.
override
-
get(
GetTargetTcpProxyRequest request) → Future< TargetTcpProxy> -
Returns the specified TargetTcpProxy resource.
override
-
insert(
InsertTargetTcpProxyRequest request) → Future< Operation> -
Creates a TargetTcpProxy resource in the specified project using
the data included in the request.
override
-
list(
ListTargetTcpProxiesRequest request) → Future< TargetTcpProxyList> -
Retrieves the list of TargetTcpProxy resources
available to the specified project.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setBackendService(
SetBackendServiceTargetTcpProxyRequest request) → Future< Operation> -
Changes the BackendService for TargetTcpProxy.
override
-
setProxyHeader(
SetProxyHeaderTargetTcpProxyRequest request) → Future< Operation> -
Changes the ProxyHeaderType for TargetTcpProxy.
override
-
testIamPermissions(
TestIamPermissionsTargetTcpProxyRequest request) → Future< TestPermissionsResponse> -
Returns permissions that a caller has on the specified resource.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited