FakeTargetVpnGateways class base
Testing fake for TargetVpnGateways.
- Implemented types
Constructors
-
FakeTargetVpnGateways({Future<
TargetVpnGatewayAggregatedList> aggregatedList(AggregatedListTargetVpnGatewaysRequest request)?, Future<Operation> delete(DeleteTargetVpnGatewayRequest request)?, Future<TargetVpnGateway> get(GetTargetVpnGatewayRequest request)?, Future<Operation> insert(InsertTargetVpnGatewayRequest request)?, Future<TargetVpnGatewayList> list(ListTargetVpnGatewaysRequest request)?, Future<Operation> setLabels(SetLabelsTargetVpnGatewayRequest request)?})
Properties
Methods
-
aggregatedList(
AggregatedListTargetVpnGatewaysRequest request) → Future< TargetVpnGatewayAggregatedList> -
Retrieves an aggregated list of target VPN gateways.
override
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
delete(
DeleteTargetVpnGatewayRequest request) → Future< Operation> -
Deletes the specified target VPN gateway.
override
-
get(
GetTargetVpnGatewayRequest request) → Future< TargetVpnGateway> -
Returns the specified target VPN gateway.
override
-
insert(
InsertTargetVpnGatewayRequest request) → Future< Operation> -
Creates a target VPN gateway in the specified project and region using
the data included in the request.
override
-
list(
ListTargetVpnGatewaysRequest request) → Future< TargetVpnGatewayList> -
Retrieves a list of target VPN gateways available to the specified
project and region.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setLabels(
SetLabelsTargetVpnGatewayRequest request) → Future< Operation> -
Sets the labels on a TargetVpnGateway. To learn more about labels, read theLabeling
Resources documentation.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited