FakeWireGroups class base
Testing fake for WireGroups.
- Implemented types
Constructors
-
FakeWireGroups({Future<
Operation> delete(DeleteWireGroupRequest request)?, Future<WireGroup> get(GetWireGroupRequest request)?, Future<Operation> insert(InsertWireGroupRequest request)?, Future<WireGroupList> list(ListWireGroupsRequest request)?, Future<Operation> patch(PatchWireGroupRequest request)?})
Properties
Methods
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
delete(
DeleteWireGroupRequest request) → Future< Operation> -
Deletes the specified wire group in the given scope.
override
-
get(
GetWireGroupRequest request) → Future< WireGroup> -
Gets the specified wire group resource in the given scope.
override
-
insert(
InsertWireGroupRequest request) → Future< Operation> -
Creates a wire group in the specified project in the given scope
using the parameters that are included in the request.
override
-
list(
ListWireGroupsRequest request) → Future< WireGroupList> -
Lists the wire groups for a project in the given scope.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
PatchWireGroupRequest request) → Future< Operation> -
Updates the specified wire group resource with the data included in the
request. This method supportsPATCH
semantics and usesJSON merge
patch format and processing rules.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited