FakeZoneOperations class base
Testing fake for ZoneOperations.
- Implemented types
Constructors
-
FakeZoneOperations({Future<
DeleteZoneOperationResponse> delete(DeleteZoneOperationRequest request)?, Future<Operation> get(GetZoneOperationRequest request)?, Future<OperationList> list(ListZoneOperationsRequest request)?, Future<Operation> wait(WaitZoneOperationRequest request)?})
Properties
Methods
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
delete(
DeleteZoneOperationRequest request) → Future< DeleteZoneOperationResponse> -
Deletes the specified zone-specific Operations resource.
override
-
get(
GetZoneOperationRequest request) → Future< Operation> -
Retrieves the specified zone-specific Operations resource.
override
-
list(
ListZoneOperationsRequest request) → Future< OperationList> -
Retrieves a list of Operation resources contained within
the specified zone.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
wait(
WaitZoneOperationRequest request) → Future< Operation> -
Waits for the specified Operation resource to return as
DONEor for the request to approach the 2 minute deadline, and retrieves the specified Operation resource. This method waits for no more than the 2 minutes and then returns the current state of the operation, which might beDONEor still in progress.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited